




/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* CDCK01 Project - 09/30/2020-09/29/2023 */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* 
   This SAS program is to import CDC US County Opioid Dispensing Rate Data (Source: https://www.cdc.gov/drugoverdose/maps/rxrate-maps.html) and manage the data.
   The data provide county-level retail opioid prescriptions dispensed per 100 persons per year and cover 87.1% to 98.5% of US counties for a given year from 2006-2019.
   This study will use the data from 2009 to 2018.
   
   CDC Notes--------------------------------------------------------------------------------------------------------------------------------------------------------------------
   "Source for all dispensing data: IQVIA Xponent 20062019. IQVIA Xponent is based on a sample of approximately 49,900 retail (non-hospital) pharmacies, which dispense nearly 
    92% of all retail prescriptions in the United States. For this database, a prescription is a new or refill prescription dispensed at a retail pharmacy in the sample and 
    paid for by commercial insurance, Medicaid, Medicare, cash or its equivalent, and other third-party coverage. This database does not include mail order prescriptions."

   "Opioid prescriptions, including buprenorphine, codeine, fentanyl, hydrocodone, hydromorphone, methadone, morphine, oxycodone, oxymorphone, propoxyphene, tapentadol, and 
    tramadol, were identified using National Drug Codes. All prescriptions with days supply between 1 and 365 days and a known strength description were included. Cough and 
    cold formulations containing opioids and buprenorphine products typically used to treat opioid use disorder were not included. In addition, methadone dispensed through 
    methadone treatment programs is not included in the IQVIA Xponent data."

   "In January 2019, IQVIA changed the frame of measurement in their projected prescription services from reflecting prescription demand to be number of prescriptions 
    dispensed to bin to reflecting total prescriptions actually sold to the patient.  To do this, IQVIA eliminated the effects of voided and reversed prescriptions 
    (prescriptions that were never received by the patient) beginning in 2017. This change in measurement frame resulted in a 1.9% downward shift in the measured opioid 
    prescriptions dispensed. This enhancement was applied to data from 2017 and thereafter. Thus, caution should be exercised when examining trends during this time period."

   "Table 2 displays the percentage of counties in the United States that have opioid dispensing rates available for a given year. A lack of available data may indicate that 
    the county had no retail pharmacies and/or prescribers, the county had no retail pharmacies and/or prescribers sampled, or the prescription volume was erroneously 
    attributed to an adjacent, more populous county according to the sampling rules used."
   -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Counties in 50 US States and DC, 2009-2018 */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Hyunil Kim, 01/08/2021 */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/





ods html newfile=proc path="E:\SASWork\Output"; /* SAS output option */
libname a "Z:\CDCK01\Data_County\Opioid";        /* Telling SAS where to load/save SAS data */





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Importing & Managing CDC US Opioid Dispensing Rate Data *********************************************************************************************************************/
/* Importing & Managing CDC US Opioid Dispensing Rate Data *********************************************************************************************************************/
/* Importing & Managing CDC US Opioid Dispensing Rate Data *********************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/

/* Importing */
proc import datafile= "Z:\CDCK01\Data_County\Opioid\RAW\CDC_OD_2009.xlsx" out=Opi2009 dbms=xlsx replace;getnames=YES;run;
proc import datafile= "Z:\CDCK01\Data_County\Opioid\RAW\CDC_OD_2010.xlsx" out=Opi2010 dbms=xlsx replace;getnames=YES;run;
proc import datafile= "Z:\CDCK01\Data_County\Opioid\RAW\CDC_OD_2011.xlsx" out=Opi2011 dbms=xlsx replace;getnames=YES;run;
proc import datafile= "Z:\CDCK01\Data_County\Opioid\RAW\CDC_OD_2012.xlsx" out=Opi2012 dbms=xlsx replace;getnames=YES;run;
proc import datafile= "Z:\CDCK01\Data_County\Opioid\RAW\CDC_OD_2013.xlsx" out=Opi2013 dbms=xlsx replace;getnames=YES;run;
proc import datafile= "Z:\CDCK01\Data_County\Opioid\RAW\CDC_OD_2014.xlsx" out=Opi2014 dbms=xlsx replace;getnames=YES;run;
proc import datafile= "Z:\CDCK01\Data_County\Opioid\RAW\CDC_OD_2015.xlsx" out=Opi2015 dbms=xlsx replace;getnames=YES;run;
proc import datafile= "Z:\CDCK01\Data_County\Opioid\RAW\CDC_OD_2016.xlsx" out=Opi2016 dbms=xlsx replace;getnames=YES;run;
proc import datafile= "Z:\CDCK01\Data_County\Opioid\RAW\CDC_OD_2017.xlsx" out=Opi2017 dbms=xlsx replace;getnames=YES;run;
proc import datafile= "Z:\CDCK01\Data_County\Opioid\RAW\CDC_OD_2018.xlsx" out=Opi2018 dbms=xlsx replace;getnames=YES;run;

/* Changing variable names, creating the "Year" variable, and dropping unnecessary variables */
data Opi2009a(rename=(CountyFIPSCode=CountyFIPS OpioidDispensingRate=Opioid));set Opi2009;Year=2009;drop County State;run;
data Opi2010a(rename=(CountyFIPSCode=CountyFIPS OpioidDispensingRate=Opioid));set Opi2010;Year=2010;drop County State;run;
data Opi2011a(rename=(CountyFIPSCode=CountyFIPS OpioidDispensingRate=Opioid));set Opi2011;Year=2011;drop County State;run;
data Opi2012a(rename=(CountyFIPSCode=CountyFIPS OpioidDispensingRate=Opioid));set Opi2012;Year=2012;drop County State;run;
data Opi2013a(rename=(CountyFIPSCode=CountyFIPS OpioidDispensingRate=Opioid));set Opi2013;Year=2013;drop County State;run;
data Opi2014a(rename=(CountyFIPSCode=CountyFIPS OpioidDispensingRate=Opioid));set Opi2014;Year=2014;drop County State;run;
data Opi2015a(rename=(CountyFIPSCode=CountyFIPS OpioidDispensingRate=Opioid));set Opi2015;Year=2015;drop County State;run;
data Opi2016a(rename=(CountyFIPSCode=CountyFIPS OpioidDispensingRate=Opioid));set Opi2016;Year=2016;drop County State;run;
data Opi2017a(rename=(CountyFIPSCode=CountyFIPS OpioidDispensingRate=Opioid));set Opi2017;Year=2017;drop County State;run;
data Opi2018a(rename=(CountyFIPSCode=CountyFIPS OpioidDispensingRate=Opioid));set Opi2018;Year=2018;drop County State;run;

/* Creating long-form data, Labeling variables, & saving a permanent data */
data a.Opioid;retain Year;set Opi2009a Opi2010a Opi2011a Opi2012a Opi2013a Opi2014a Opi2015a Opi2016a Opi2017a Opi2018a;
label
Year="Calendar Year"
CountyFIPS="County FIPS Code"
Opioid="Retail opioid prescription rate per 100 persons per year/county"
;run;
proc contents data=a.Opioid varnum;run;
