




/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* CDCK01 Project - 09/30/2020-09/29/2023 */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* 
   This SAS program is to import the NCHS Urban-Rural Classification Scheme for Counties (Source: https://www.cdc.gov/drugoverdose/maps/rxrate-maps.html) and manage the data.
   The data provide the 2013, 2006, and 1990 codes for every county and county equivalent
   This study will use the 2013 codes for the entire study years (2009-2018 for county-level data and 2011-2018 for zip code-level data).
   The longitudinal change in the level of urbanicity could not be measured due to the lack of data. 
   This may pose no serious issue since most counties showed little change in the level of urbanicity. 
   Between 2006 and 2013, 90.9% of US counties showed no change in the Urban-Rural code (six units = six categories) and 5.7% showed one-unit change.

   Categories of the 2013 NCHS Urban-Rural Classification Scheme for Counties:
   1. Large central metro = central counties of metropolitan statistical areas (MSAs) of 1 million or more population
   2. Large fringe metro = fringe counties of MSAs of 1 million or more population
   3. Medium metro = counties within MSAs of 250,000 to 999,999 population
   4. Small metro = counties within MSAs of 50,000 to 249,999 population
   5. Micropolitan = counties in micropolitan statistical areas
   6. Noncore = counties not within micropolitan statistical areas

   This study will combine the "large central metro" and "large fringe metro" categories into "large urban", the "medium metro" and "small metro" categories into "small urban", 
   and "micropolitan" and "noncore" into "rural".

*/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Counties in 50 US States and DC, 2009-2018 */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Hyunil Kim, 01/08/2021 */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/





ods html newfile=proc path="E:\SASWork\Output"; /* SAS output option */
libname a "Z:\CDCK01\Data_County\NCHS_RUC\Raw"; /* Telling SAS where to load/save SAS data */
libname b "Z:\CDCK01\Data_County\NCHS_RUC";     /* Telling SAS where to load/save SAS data */





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Importing & Managing Data ***************************************************************************************************************************************************/
/* Importing & Managing Data ***************************************************************************************************************************************************/
/* Importing & Managing Data ***************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/




data b.NCHS_RUC;retain CountyFIPS NCHS_RUC0 NCHS_RUC;set a.NCHSurbruralcodes2013(rename=(CODE2013=NCHS_RUC0));
if NCHS_RUC0 in (1 2) then NCHS_RUC=1;
if NCHS_RUC0 in (3 4) then NCHS_RUC=2;
if NCHS_RUC0 in (5 6) then NCHS_RUC=3;
CountyFIPS=stfips*1000+ctyfips;
label
CountyFIPS="County FIPS code"
NCHS_RUC0="NCHS 2013 Urban-Rural Code:1=Large central metro,2=Large fringe metro,3=Medium metro,4=Small metro,5=Micropolitan,6=Noncore"
NCHS_RUC="1=large urban (NCHS Code1-2), 2=small urban (NCHS Code3-4), 3=rural (NCHS Code5-6)"
ctypop="County July 1 2021 resident population (Vintage 2012 postcensal series)";
keep CountyFIPS NCHS_RUC0 NCHS_RUC ctypop;
run;
proc contents data=b.NCHS_RUC varnum;run;
