




/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* CDCK01 Project - 09/30/2020-09/29/2023 */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* 
   This SAS program is to import the USDA Rural-Urban Continuum Codes (Source: https://www.ers.usda.gov/data-products/rural-urban-continuum-codes.aspx) and manage the data.
   This study will use the 2013 codes for the entire study years (2009-2018 for county-level data and 2011-2018 for zip code-level data).
   The longitudinal change in the level of urbanicity could not be measured due to the lack of data. 
   This may pose no serious issue since most counties showed little change in the level of urbanicity.

   Categories of the USDA 2013 code:
   1. Metro - Counties in metro areas of 1 million population or more
   2. Metro - Counties in metro areas of 250,000 to 1 million population
   3. Metro - Counties in metro areas of fewer than 250,000 population 
   4. Nonmetro - Urban population of 20,000 or more, adjacent to a metro area
   5. Nonmetro - Urban population of 20,000 or more, not adjacent to a metro area
   6. Nonmetro - Urban population of 2,500 to 19,999, adjacent to a metro area
   7. Nonmetro - Urban population of 2,500 to 19,999, not adjacent to a metro area
   8. Nonmetro - Completely rural or less than 2,500 urban population, adjacent to a metro area
   9. Nonmetro - Completely rural or less than 2,500 urban population, not adjacent to a metro area

   Categories of the NCHS 2013 code:
   1. Large central metro = central counties of metropolitan statistical areas (MSAs) of 1 million or more population
   2. Large fringe metro = fringe counties of MSAs of 1 million or more population
   3. Medium metro = counties within MSAs of 250,000 to 999,999 population
   4. Small metro = counties within MSAs of 50,000 to 249,999 population
   5. Micropolitan = counties in micropolitan statistical areas
   6. Noncore = counties not within micropolitan statistical areas

   Consistency between USDA and NCHS codes (USDA_RUC0 vs NCHS_RUC0)
   USDA_RUC0 1   -- NCHS_RUC0 1-2:  99.08%
   USDA_RUC0 2   -- NCHS_RUC0 1-2:   0.02%
   USDA_RUC0 2-3 -- NCHS_RUC0 3-4: 100.00&
   USDA_RUC0 4-9 -- NCHS_RUC0 5-6: 100.00%

   Consistency between collapsed codes (USDA_RUC vs NCHS_RUC)
   USDA_RUC 1 -- NCHS_RUC 1:  99.08%
   USDA_RUC 2 -- NCHS_RUC 1:   0.02%
   USDA_RUC 2 -- NCHS_RUC 2: 100.00%
   USDA_RUC 3 -- NCHS_RUC 3: 100.00%

   This study will combine the USDA code into three categories: large urban (USDA code 1), small urban (USDA code 2-3), and rural (USDA code 4-9).

*/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Counties in 50 US States and DC, 2009-2018 */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Hyunil Kim, 03/30/2021 */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/





ods html newfile=proc path="E:\SASWork\Output"; /* SAS output option */
libname a "Z:\CDCK01\Data_County\USDA_RUC"; /* Telling SAS where to load/save SAS data */
libname b "Z:\CDCK01\Data_County\NCHS_RUC"; /* Telling SAS where to load/save SAS data */





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Importing & Managing Data ***************************************************************************************************************************************************/
/* Importing & Managing Data ***************************************************************************************************************************************************/
/* Importing & Managing Data ***************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Importing Data */
proc import datafile= "Z:\CDCK01\Data_County\USDA_RUC\ruralurbancodes2013.xls" out=USDA1 dbms=xls replace;getnames=yes;run;
data a.USDA_RUC;retain USDAFlag CountyFIPS USDA_RUC0 USDA_RUC Population_2010;set USDA1;
USDAFlag=1;
CountyFIPS=FIPS+0;
USDA_RUC0=RUCC_2013;
if   USDA_RUC0=1 then USDA_RUC=1;
if 1<USDA_RUC0<4 then USDA_RUC=2;
if 3<USDA_RUC0   then USDA_RUC=3;
if CountyFIPS=. | CountyFIPS>60000 then delete;
label
CountyFIPS="County FIPS code"
USDA_RUC0="USDA 2013 RUC(1-3=Metro;4-9=Nonmetro;(1)>=1M;(2)250K-1M;(3)<250K;(4)adjacent to metro(AM),>=20K;(5)not AM,>=20K;(6)AM,2.5K-19,999;(7)not AM,2.5K-19,999;(8)AM,<2.5K;(9)not AM,<2.5K)"
USDA_RUC="USDA 2013 RUC-collapsed: 1=large urban(USDA code1);2=small urban(USDA code2-3);3=rural(USDA code4-9)"
;
keep USDAFlag CountyFIPS USDA_RUC0 USDA_RUC Population_2010;
run;
proc contents data=a.USDA_RUC varnum;run;





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Checking Consistency with NCHS Code *****************************************************************************************************************************************/
/* Checking Consistency with NCHS Code *****************************************************************************************************************************************/
/* Checking Consistency with NCHS Code *****************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/

data J1;set a.USDA_RUC;run;
data J2;set b.NCHS_RUC;NCHSFlag=1;run;
proc sort data=J1;by CountyFIPS;run;
proc sort data=J2;by CountyFIPS;run;
data JUNK;merge J1 J2;by CountyFIPS;run;
proc freq data=JUNK;tables NCHS_RUC0*USDA_RUC0 NCHS_RUC*USDA_RUC/missing;run;

proc print data=junk;where NCHSFlag=. | USDAFlag=.;run;

