




/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* CDCK01 Project - 09/30/2020-09/29/2023 */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* 
   This SAS program is to import MIECHV data (2015-2018) and manage the data.
   (Source: https://mchb.hrsa.gov/maternal-child-health-initiatives/home-visiting/home-visiting-program-state-fact-sheets)
   Previous years' data (i.e., state fact sheets) were obtained through the Freedom of Information Act (FOIA) request (https://www.hrsa.gov/foia/index.html)
   From each state fact sheet, the names of counties with MIECHV programs were copied and pasted into an excel spreadsheet per each year.
   For example, "MIECHV_2015_v1.xlsx" looks like the below table:

   CountyName  |StateName
   ----------------------
   Anchorage   |Alaska
   ----------------------
   Barbour     |Alabama
   ----------------------
   Bibb        |Alabama
   ...

   This SAS program will import "MIECHV_2015_v1.xlsx", "MIECHV_2016_v1.xlsx", "MIECHV_2017_v1.xlsx", and "MIECHV_2018_v1.xlsx".
   Then, the program will link these data with ACS data (ACS 2011-2015, ACS 2012-2016, ACS 2013-2017, and ACS 2014-2018) to assign FIPS codes.
   It doesn't matter the kinds of tables (variables) in ACS data. We only need Name and FIPS.
*/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Counties in 50 US States and DC, 2009-2018 */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Hyunil Kim, 03/04/2021 */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/





ods html newfile=proc path="E:\SASWork\Output"; /* SAS output option */
libname a "Z:\CDCK01\Data_County\MHV";        /* Telling SAS where to load/save SAS data */
libname b "Z:\CDCK01\Data_County\Census";        /* Telling SAS where to load/save SAS data */

/* Importing MIECHV data */
proc import datafile= "Z:\CDCK01\Data_County\MHV\HRSA\Data\MIECHV_2015_v1.xlsx" out=M15 dbms=xlsx replace;getnames=YES;run;
proc import datafile= "Z:\CDCK01\Data_County\MHV\HRSA\Data\MIECHV_2016_v1.xlsx" out=M16 dbms=xlsx replace;getnames=YES;run;
proc import datafile= "Z:\CDCK01\Data_County\MHV\HRSA\Data\MIECHV_2017_v1.xlsx" out=M17 dbms=xlsx replace;getnames=YES;run;
proc import datafile= "Z:\CDCK01\Data_County\MHV\HRSA\Data\MIECHV_2018_v1.xlsx" out=M18 dbms=xlsx replace;getnames=YES;run;

/* Dealing with blanks and case */
data M15a;length State $ 20 County $ 37;set M15;Year=2015;State=upcase(strip(compbl(StateName)));County=upcase(strip(compbl(CountyName)));drop CountyName StateName;run;
data M16a;length State $ 20 County $ 37;set M16;Year=2016;State=upcase(strip(compbl(StateName)));County=upcase(strip(compbl(CountyName)));drop CountyName StateName;run;
data M17a;length State $ 20 County $ 37;set M17;Year=2017;State=upcase(strip(compbl(StateName)));County=upcase(strip(compbl(CountyName)));drop CountyName StateName;run;
data M18a;length State $ 20 County $ 37;set M18;Year=2018;State=upcase(strip(compbl(StateName)));County=upcase(strip(compbl(CountyName)));drop CountyName StateName;run;

/* Making longitudinal data and cleaning up county names of MIECHV data to link with Census data (to get FIPS codes from census data) */
data M1;length NAME $ 100;set M15a M16a M17a M18a;MFlag=1;
if State="SOUTH CAROLINA" & County="BAMBURG"                  then County="BAMBERG";
if State="MARYLAND" & County="BALTIMORE"                      then County="BALTIMORE CITY";
if State="ARIZONA" & County="COCOCINO"                        then County="COCONINO";
if State="ILLINOIS" & County="DEWITT"                         then County="DE WITT";
if State="KENTUCKY" & County="ELLIOT"                         then County="ELLIOTT";
if State="FLORIDA" & County="ESCAMBIAESCAMBIA"                then County="ESCAMBIA";
if State="PENNSYLVANIA" & County="GREEN"                      then County="GREENE";
if State="CALIFORNIA" & County="IMPERIA"                      then County="IMPERIAL";
if State="VIRGINIA" & County="JAMES CITY"                     then County="JAMES CITY COUNTY";
if State="VIRGINIA" & County="LYNCHBURG"                      then County="LYNCHBURG CITY";
if State="VIRGINIA" & County="LYNCHBURG COUNTY"               then County="LYNCHBURG CITY";
if State="KENTUCKY" & County="METCALF"                        then County="METCALFE";
if State="NEBRASKA" & County="MORRIL"                         then County="MORRILL";
if State="MONTANA" & County="NORTHERN CHEYENNE TRIBE/ROSEBUD" then County="ROSEBUD";
if State="NORTH CAROLINA" & County="NORTHHAMPTON"             then County="NORTHAMPTON";
if State="KENTUCKY" & County="OWS LEY"                        then County="OWSLEY";
if State="MARYLAND" & County="PRINCE GEORGES"                then County="PRINCE GEORGE'S";
if State="SOUTH DAKOTA" & County="SHANNON"                    then County="OGLALA LAKOTA";
if State="LOUISIANA" & County="ST BERNARD"                    then County="ST. BERNARD";
if State="LOUISIANA" & County="ST. JOHN"                      then County="ST. JOHN THE BAPTIST";
if State="WASHINGTON" & County="WALLA"                      then County="WALLA WALLA";
if State="ALASKA" & County="ANCHORAGE"                        then NAME=catx(' MUNICIPALITY, ',County             ,State);
if State="ALASKA" & County="MATANUSKA-SUSITNA"                then NAME=catx(' BOROUGH, '     ,County             ,State);
if State="ALASKA" & County="MAT-SU"                           then NAME=catx(' BOROUGH, '     ,'MATANUSKA-SUSITNA',State);
if State="DISTRICT OF COLUMBIA"                               then NAME=catx(', '             ,County             ,State);
if State="LOUISIANA"                                          then NAME=catx(' PARISH, '      ,County             ,State);
if State="PUERTO RICO"                                        then NAME=catx(' MUNICIPIO, '   ,County             ,State);
if substr(County,length(County)-3,4)="CITY"                   then NAME=catx(', '             ,County             ,State);
if substr(County,length(County)-5,6)="COUNTY"                 then NAME=catx(', '             ,County             ,State);
if NAME=""                                                    then NAME=catx(' COUNTY, '      ,County             ,State);
run;

/* Importing Census data and dealing with possible blank and case issues */
data C15;length NAME $ 100;set b.acs20112015(keep=FIPS QNAME);NAME=upcase(strip(compbl(QNAME)));Year=2015;run;
data C16;length NAME $ 100;set b.acs20122016(keep=FIPS QNAME);NAME=upcase(strip(compbl(QNAME)));Year=2016;run;
data C17;length NAME $ 100;set b.acs20132017(keep=FIPS QNAME);NAME=upcase(strip(compbl(QNAME)));Year=2017;run;
data C18;length NAME $ 100;set b.acs20142018(keep=FIPS QNAME);NAME=upcase(strip(compbl(QNAME)));Year=2018;run;

/* Making longitudinal data and cleaning up county names to link with MIECHV data */
data C1;set C15 C16 C17 C18;CFlag=1;
if NAME="DOñA ANA COUNTY, NEW MEXICO" then NAME="DOA ANA COUNTY, NEW MEXICO";
run;

/* Merging MIECHV data and Census data */
proc sort data=M1;by NAME Year;run;
proc sort data=C1;by NAME Year;run;
data M2;merge M1 C1;by NAME Year;run;

/* Checking data */
/* proc freq data=M2;tables MFlag*CFlag/missing;run; */
/* All MIECHV counties were identified in Census data. */

/* Saving Permanent data after renaming/labeling variables */
data M3;set M2(rename=(MFlag=MIECHV));
CountyFIPS=FIPS+0;
CountyYear=CountyFIPS*10000+Year;
if MIECHV=. then MIECHV=0;
label
Year="Fiscal Year"
CountyFIPS="County FIPS Code"
CountyYear="CntyFIPS & Year (CCCCCYYYY)"
MIECHV="1=County served by the MIECHV program";
keep Year CountyFIPS CountyYear MIECHV NAME;
run;

/* Checking duplicate & Removing duplicate */
/*
proc sort data=M3;by CountyYear;run;
data junk;set M3;by CountyYear;retain count;if first.CountyYear then count=0;count+1;run;
proc print data=junk;where count>1;run;
*/
/* "RICH COUNTY, UTAH" was recorded twice in M3, as well as the raw data (the state fact sheet). Let's remove this duplicate. */
proc sort data=M3;by CountyYear;run;
data M4;set M3;by CountyYear;if first.CountyYear;run;

/* Checking data */
/* proc freq data=M4;tables MIECHV/missing;run; */
/* All MIECHV counties were identified in Census data. Among 12880 county-years, 3402 county-years had MIECHV programs (26.41%). */

/* Saving permanent data */
data a.MIECHV;set M4;run; 
proc contents data=a.MIECHV varnum;run;





