




/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* CDCK01 Project - 09/30/2020-09/29/2023 */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* 
   This SAS program is to import NHVRC data (2016-2019) and manage the data.
   (Source: https://nhvrc.org/yearbook/2020-yearbook/)
   Data were obtained through an email request (data@nhvrc.org)--NHVRC guys were very reponsive and super helpful :)

   This SAS program will import "NHVRC2016.xlsx", "NHVRC2017.xlsx", "NHVRC2018.xlsx", and "NHVRC2019.xlsx".
   Then, the program will link the 2016 data with with ACS data (ACS 2012-2016) to assign FIPS codes. Other years' data have FIPS codes.
   It doesn't matter the kinds of tables (variables) in ACS data. We only need Name and FIPS.
*/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Counties in 50 US States and DC, 2009-2018 */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Hyunil Kim, 03/15/2021 */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/







ods html newfile=proc path="E:\SASWork\Output"; /* SAS output option */
libname a "Z:\CDCK01\Data_County\MHV";        /* Telling SAS where to load/save SAS data */
libname b "Z:\CDCK01\Data_County\Census";        /* Telling SAS where to load/save SAS data */

/* Importing NHVRC data */
proc import datafile= "Z:\CDCK01\Data_County\MHV\NHVRC\NHVRC2016.xlsx" out=N16 dbms=xlsx replace;getnames=YES;run;
proc import datafile= "Z:\CDCK01\Data_County\MHV\NHVRC\NHVRC2017.xlsx" out=N17 dbms=xlsx replace;getnames=YES;run;
proc import datafile= "Z:\CDCK01\Data_County\MHV\NHVRC\NHVRC2018.xlsx" out=N18 dbms=xlsx replace;getnames=YES;run;
proc import datafile= "Z:\CDCK01\Data_County\MHV\NHVRC\NHVRC2019.xlsx" out=N19 dbms=xlsx replace;getnames=YES;run;

/* Excluding records from territories */
data N16;set N16;if state not in ("Guam" "Puerto Rico" "Virgin Islands");Year=2016;run;
data N17;set N17;if StateAbbr not in ("AS" "GU" "MP" "PR" "VI");Year=2017;keep Year CountyFIPS;run;
data N18;set N18;if StateAbbr not in ("AS" "GU" "MP" "PR" "VI");Year=2018;keep Year CountyFIPS;run;
data N19;set N19;if StateAbbr not in ("AS" "GU" "MP" "PR" "VI");Year=2019;run;

/* "Effective May 1, 2015, Shannon County, SD (FIPS=46113) was renamed Oglala Lakota County and assigned a new FIPS code (FIPS=46102)"
   (https://www.cdc.gov/nchs/nvss/bridged_race/county_geography-_changes2015.pdf) */;
data N19;set N19;
if CountyFIPS=46113 then StateName="South Dakota";
if CountyFIPS=46113 then StateAbbr="SD";
if CountyFIPS=46113 then CountyName="Oglala Lakota County";
if CountyFIPS=46113 then CountyFIPS=46102;
keep Year CountyFIPS;
run;



/* Assigning CountyFIPS to the 2016 data */
/* Assigning CountyFIPS to the 2016 data */
/* Assigning CountyFIPS to the 2016 data */
/***/
/* Dealing with blanks and case */;
data N16;length st $ 21 cnty $ 20;set N16;st=upcase(strip(compbl(State)));cnty=upcase(strip(compbl(CountyName)));drop State CountyName;run;
/* Cleaning up county names of NHVRC2016 data to link with Census data (to get FIPS codes from census data) */
data N16;length NAME $ 100;set N16;
if st="ALASKA" & cnty="ANCHORAGE"                 then NAME=catx(' MUNICIPALITY, '    ,cnty,st);
if st="ALASKA" & cnty="JUNEAU"                    then NAME=catx(' CITY AND BOROUGH, ',cnty,st);
if st="ALASKA" & cnty in ("NOME" "YUKON-KOYUKUK") then NAME=catx(' CENSUS AREA, '     ,cnty,st);
if st="ALASKA" & NAME=""                          then NAME=catx(' BOROUGH, '         ,cnty,st);
if st="DISTRICT OF COLUMBIA"                      then NAME=catx(', '                 ,cnty,st);
if st="LOUISIANA"                                 then NAME=catx(' PARISH, '          ,cnty,st);
if substr(cnty,length(cnty)-3,4)="CITY"           then NAME=catx(', '                 ,cnty,st);
if substr(cnty,length(cnty)-5,6)="COUNTY"         then NAME=catx(', '                 ,cnty,st);
if NAME=""                                        then NAME=catx(' COUNTY, '          ,cnty,st);
drop st cnty;
run;
/* Importing Census data and dealing with possible blank and case issues */
data C16;length NAME $ 100;set b.acs20122016(keep=FIPS QNAME);
NAME=upcase(strip(compbl(QNAME)));
if NAME="DOñA ANA COUNTY, NEW MEXICO" then NAME="DOA ANA COUNTY, NEW MEXICO";
drop QNAME;
run;
/* Merging NHVRC2016 data and Census data */
proc sort data=N16;by NAME;run;
proc sort data=C16;by NAME;run;
data N16;merge N16 C16;by NAME;if Year^=.;CountyFIPS=FIPS+0;keep Year CountyFIPS;run;



/* Making longitudinal data & Saving permanent data */
data a.NHVRC;set N16 N17 N18 N19;
CountyYear=CountyFIPS*10000+Year;
NHVRC=1;
label
Year="Fiscal Year"
CountyFIPS="County FIPS Code"
CountyYear="CntyFIPS & Year (CCCCCYYYY)"
NHVRC="1=County with at least 1 local agency implementing any of 11 EB-models(Child First,Early Head Start,Family Check-Up,Family Connects,Family Spirit,HFA,HIPPY,NFP,PAT,PALS,SafeCare)";
run;
proc contents data=a.NHVRC varnum;run;





