




/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* CDCK01 Project - 09/30/2020-09/29/2023 */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* 
   This SAS program is to import CDC Birth Data (Source: https://wonder.cdc.gov/natality.html) and manage the data.
   CDC WONDER Natality Data Request Form (online query) provides tab delimited txt files of selected query parameters of birth data.
   For 1-Year data (1-Year estimates), "Group Results By" -- "Year" and "County" were selected.
   For 5-Year data (5-Year estimates), "Group Results By" -- "County" was selected. Then, specified years were selected from "4. Select birth characteristics -- Year".
   Other query parameters were selected by the combination of the following variables:

   - Newborn Sex ("4. Select birth characteristics -- Gender")
         Male
         Female
   - Maternal Race/Ethnicity ("3. Select other maternal characteristics -- Mother's Hispanic Origin & Mother's Single Race")
         White    = non-Hispanic/Latino White alone
         Black    = Black alone
         Asian    = Asian alone
         AIAN     = American Indian and Alaska Native alone
         NHPI     = Native Hawaiian and other Pacific Islander alone
         Multiple = Two or more race
         Hispanic = Hispanic or Latino
   - Birth conditions ("4. Select birth characteristics" & "3. Select other maternal characteristics")
         Total Birth          (BIR): total live births
         Low birth weight     (LWB): birth weight < 2500 grams ("Infant Birth Weight 12")
         Preterm birth        (PTB): gestational age < 37 weeks -- Obstetric/Clinical Gestation Estimate (OE) based gestation period ("OE Gestational Age 11")
         Prenatal care        (PNC): first trimester care access -- beginning prenatal care in the first trimester of pregnancy ("Month Prenatal Care Began")
         Teen birth per birth (TBB): live births with mother's age < 20 years ("Age of Mother 9")
         Teen birth per teen  (TBT): live births among women aged 15-19 years ("Age of Mother 9")
   - 1-Year Estimates (each year from 2007 to 2019)
         BIR: Total, Male, Female, White, Black, Asian, AIAN, NHPI, Multiple, Hispanic
         LBW: Total, Male, Female, White, Black, Asian, AIAN, NHPI, Multiple, Hispanic
         PTB: Total, Male, Female, White, Black, Asian, AIAN, NHPI, Multiple, Hispanic
         PNC: Total, Male, Female, White, Black, Asian, AIAN, NHPI, Multiple, Hispanic
         TBB: Total, Male, Female, White, Black, Asian, AIAN, NHPI, Multiple, Hispanic
         TBT: Total, Male, Female, White, Black, Asian, AIAN, NHPI, Multiple, Hispanic
   - 5-Year Estimates (2007-2011, 2008-2012, 2009-2013, 2010-2014, 2011-2015, 2012-2016, 2013-2017, 2014-2018, 2015-2019)
         BIR: Total, Male, Female, White, Black, Asian, AIAN, NHPI, Multiple, Hispanic
         LBW: Total, Male, Female, White, Black, Asian, AIAN, NHPI, Multiple, Hispanic
         PTB: Total, Male, Female, White, Black, Asian, AIAN, NHPI, Multiple, Hispanic
         PNC: Total, Male, Female, White, Black, Asian, AIAN, NHPI, Multiple, Hispanic
         TBB: Total, Male, Female, White, Black, Asian, AIAN, NHPI, Multiple, Hispanic
         TBT: Total, Male, Female, White, Black, Asian, AIAN, NHPI, Multiple, Hispanic

   *** CDC Birth Data suppressed all sub-national data representing 0 to 9 births to protect confidentiality.
   *** If this suppressed a small number of counties, using 1-year estimates would be fine.
   *** If this suppressed a large number of counties, 5-year estimates may have substantially less suppressed counties than 1-year estimates.
*/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Counties in 50 US States and DC, 2009-2018 */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Hyunil Kim, 01/06/2021 */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/





ods html newfile=proc path="E:\SASWork\Output"; /* SAS output option */
libname a "Z:\CDCK01\Data_County\Birth";        /* Telling SAS where to load/save SAS data */





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Importing 1-Year Data *******************************************************************************************************************************************************/
/* Importing 1-Year Data *******************************************************************************************************************************************************/
/* Importing 1-Year Data *******************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/

data BIRT1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Total_Birth_Total.txt"                         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data BIRM1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Total_Birth_Total_Male.txt"                    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data BIRF1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Total_Birth_Total_Female.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data BIRW1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Total_Birth_Total_NonHispanicWh.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data BIRB1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Total_Birth_Total_AllHispanicBK.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data BIRA1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Total_Birth_Total_AllHispanicAsian.txt"        dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data BIRN1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Total_Birth_Total_NativeAmerican.txt"          dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data BIRP1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Total_Birth_Total_NHPI.txt"                    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data BIRO1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Total_Birth_Total_Moreraces.txt"               dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data BIRH1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Total_Birth_Total_Hispanic.txt"                dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data LBWT1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\LBWBirth_Total.txt"                            dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data LBWM1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\LBWBirth_Total_Male.txt"                       dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data LBWF1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\LBWBirth_Total_Female.txt"                     dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data LBWW1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\LBWBirth_Total_NonHispanicWh.txt"              dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data LBWB1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\LBWBirth_Total_AllHispanicBK.txt"              dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data LBWA1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\LBWBirth_Total_AllHispanicAsian.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data LBWN1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\LBWBirth_Total_NativeAmerican.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data LBWP1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\LBWBirth_Total_NHPI.txt"                       dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data LBWO1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\LBWBirth_Total_Morerace.txt"                   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data LBWH1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\LBWBirth_Total_Hispanic.txt"                   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data PTBT1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Preterm_Total.txt"                             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data PTBM1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Preterm_Total_Male.txt"                        dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data PTBF1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Preterm_Total_female.txt"                      dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data PTBW1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Preterm_Total_NonHispanicWh.txt"               dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data PTBB1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Preterm_Total_AllHispanicBK.txt"               dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data PTBA1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Preterm_Total_AllHispanicAsian.txt"            dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data PTBN1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Preterm_Total_NativeAmerican.txt"              dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data PTBP1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Preterm_Total_NHPI.txt"                        dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data PTBO1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Preterm_Total_Morerace.txt"                    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data PTBH1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Preterm_Total_Hispanic.txt"                    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data PNCT1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Prenatal_Birth_Total.txt"                      dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data PNCM1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Prenatal_Birth_Male.txt"                       dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data PNCF1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Prenatal_Birth_Female.txt"                     dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data PNCW1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Prenatal_Birth_NonHispanicWh.txt"              dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data PNCB1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Prenatal_Birth_AllHispanicBK.txt"              dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data PNCA1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Prenatal_Birth_AllHispanicAsian.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data PNCN1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Prenatal_Birth_NativeAmerican.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data PNCP1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Prenatal_Birth_NHPI.txt"                       dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data PNCO1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Prenatal_Birth_Morerace.txt"                   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data PNCH1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Prenatal_Birth_Hispanic.txt"                   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data TBBT1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Teen birth (20)_Total.txt"                     dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data TBBM1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Teen birth (20)_Total_Male.txt"                dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data TBBF1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Teen birth (20)_Total_Female.txt"              dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data TBBW1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Teen birth (20)_Total_NonHispanicWh.txt"       dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data TBBB1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Teen birth (20)_Total_AllHispanicBK.txt"       dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data TBBA1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Teen birth (20)_Total_AllHispanicAsian.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data TBBN1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Teen birth (20)_Total_NativeAmerican.txt"      dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data TBBP1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Teen birth (20)_Total_NHPI.txt"                dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data TBBO1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Teen birth (20)_Total_Morerace.txt"            dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data TBBH1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Teen birth (20)_Total_Hispanic.txt"            dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data TBTT1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Teen birth (15-19)_Total.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data TBTM1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Teen birth (15-19)_Total_Male.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data TBTF1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Teen birth (15-19)_Total_Female.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data TBTW1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Teen birth (15-19)_Total_NonHispanicWh.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data TBTB1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Teen birth (15-19)_Total_AllHispanicBK.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data TBTA1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Teen birth (15-19)_Total_AllHispanicAsian.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data TBTN1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Teen birth (15-19)_Total_NativeAmerican.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data TBTP1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Teen birth (15-19)_Total_NHPI.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data TBTO1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Teen birth (15-19)_Total_Morerace.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;
data TBTH1;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_2007_2019\Teen birth (15-19)_Total_Hispanic.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ Year YearCode County $ FIPS $ Births $;run;

/* Changing Variable Names & Keeping Necessary Variables */
data BIRT1a(rename=(Births=BIRT1));set BIRT1;if Notes="";keep FIPS Year Births;run;
data BIRM1a(rename=(Births=BIRM1));set BIRM1;if Notes="";keep FIPS Year Births;run;
data BIRF1a(rename=(Births=BIRF1));set BIRF1;if Notes="";keep FIPS Year Births;run;
data BIRW1a(rename=(Births=BIRW1));set BIRW1;if Notes="";keep FIPS Year Births;run;
data BIRB1a(rename=(Births=BIRB1));set BIRB1;if Notes="";keep FIPS Year Births;run;
data BIRA1a(rename=(Births=BIRA1));set BIRA1;if Notes="";keep FIPS Year Births;run;
data BIRN1a(rename=(Births=BIRN1));set BIRN1;if Notes="";keep FIPS Year Births;run;
data BIRP1a(rename=(Births=BIRP1));set BIRP1;if Notes="";keep FIPS Year Births;run;
data BIRO1a(rename=(Births=BIRO1));set BIRO1;if Notes="";keep FIPS Year Births;run;
data BIRH1a(rename=(Births=BIRH1));set BIRH1;if Notes="";keep FIPS Year Births;run;
data LBWT1a(rename=(Births=LBWT1));set LBWT1;if Notes="";keep FIPS Year Births;run;
data LBWM1a(rename=(Births=LBWM1));set LBWM1;if Notes="";keep FIPS Year Births;run;
data LBWF1a(rename=(Births=LBWF1));set LBWF1;if Notes="";keep FIPS Year Births;run;
data LBWW1a(rename=(Births=LBWW1));set LBWW1;if Notes="";keep FIPS Year Births;run;
data LBWB1a(rename=(Births=LBWB1));set LBWB1;if Notes="";keep FIPS Year Births;run;
data LBWA1a(rename=(Births=LBWA1));set LBWA1;if Notes="";keep FIPS Year Births;run;
data LBWN1a(rename=(Births=LBWN1));set LBWN1;if Notes="";keep FIPS Year Births;run;
data LBWP1a(rename=(Births=LBWP1));set LBWP1;if Notes="";keep FIPS Year Births;run;
data LBWO1a(rename=(Births=LBWO1));set LBWO1;if Notes="";keep FIPS Year Births;run;
data LBWH1a(rename=(Births=LBWH1));set LBWH1;if Notes="";keep FIPS Year Births;run;
data PTBT1a(rename=(Births=PTBT1));set PTBT1;if Notes="";keep FIPS Year Births;run;
data PTBM1a(rename=(Births=PTBM1));set PTBM1;if Notes="";keep FIPS Year Births;run;
data PTBF1a(rename=(Births=PTBF1));set PTBF1;if Notes="";keep FIPS Year Births;run;
data PTBW1a(rename=(Births=PTBW1));set PTBW1;if Notes="";keep FIPS Year Births;run;
data PTBB1a(rename=(Births=PTBB1));set PTBB1;if Notes="";keep FIPS Year Births;run;
data PTBA1a(rename=(Births=PTBA1));set PTBA1;if Notes="";keep FIPS Year Births;run;
data PTBN1a(rename=(Births=PTBN1));set PTBN1;if Notes="";keep FIPS Year Births;run;
data PTBP1a(rename=(Births=PTBP1));set PTBP1;if Notes="";keep FIPS Year Births;run;
data PTBO1a(rename=(Births=PTBO1));set PTBO1;if Notes="";keep FIPS Year Births;run;
data PTBH1a(rename=(Births=PTBH1));set PTBH1;if Notes="";keep FIPS Year Births;run;
data PNCT1a(rename=(Births=PNCT1));set PNCT1;if Notes="";keep FIPS Year Births;run;
data PNCM1a(rename=(Births=PNCM1));set PNCM1;if Notes="";keep FIPS Year Births;run;
data PNCF1a(rename=(Births=PNCF1));set PNCF1;if Notes="";keep FIPS Year Births;run;
data PNCW1a(rename=(Births=PNCW1));set PNCW1;if Notes="";keep FIPS Year Births;run;
data PNCB1a(rename=(Births=PNCB1));set PNCB1;if Notes="";keep FIPS Year Births;run;
data PNCA1a(rename=(Births=PNCA1));set PNCA1;if Notes="";keep FIPS Year Births;run;
data PNCN1a(rename=(Births=PNCN1));set PNCN1;if Notes="";keep FIPS Year Births;run;
data PNCP1a(rename=(Births=PNCP1));set PNCP1;if Notes="";keep FIPS Year Births;run;
data PNCO1a(rename=(Births=PNCO1));set PNCO1;if Notes="";keep FIPS Year Births;run;
data PNCH1a(rename=(Births=PNCH1));set PNCH1;if Notes="";keep FIPS Year Births;run;
data TBBT1a(rename=(Births=TBBT1));set TBBT1;if Notes="";keep FIPS Year Births;run;
data TBBM1a(rename=(Births=TBBM1));set TBBM1;if Notes="";keep FIPS Year Births;run;
data TBBF1a(rename=(Births=TBBF1));set TBBF1;if Notes="";keep FIPS Year Births;run;
data TBBW1a(rename=(Births=TBBW1));set TBBW1;if Notes="";keep FIPS Year Births;run;
data TBBB1a(rename=(Births=TBBB1));set TBBB1;if Notes="";keep FIPS Year Births;run;
data TBBA1a(rename=(Births=TBBA1));set TBBA1;if Notes="";keep FIPS Year Births;run;
data TBBN1a(rename=(Births=TBBN1));set TBBN1;if Notes="";keep FIPS Year Births;run;
data TBBP1a(rename=(Births=TBBP1));set TBBP1;if Notes="";keep FIPS Year Births;run;
data TBBO1a(rename=(Births=TBBO1));set TBBO1;if Notes="";keep FIPS Year Births;run;
data TBBH1a(rename=(Births=TBBH1));set TBBH1;if Notes="";keep FIPS Year Births;run;
data TBTT1a(rename=(Births=TBTT1));set TBTT1;if Notes="";keep FIPS Year Births;run;
data TBTM1a(rename=(Births=TBTM1));set TBTM1;if Notes="";keep FIPS Year Births;run;
data TBTF1a(rename=(Births=TBTF1));set TBTF1;if Notes="";keep FIPS Year Births;run;
data TBTW1a(rename=(Births=TBTW1));set TBTW1;if Notes="";keep FIPS Year Births;run;
data TBTB1a(rename=(Births=TBTB1));set TBTB1;if Notes="";keep FIPS Year Births;run;
data TBTA1a(rename=(Births=TBTA1));set TBTA1;if Notes="";keep FIPS Year Births;run;
data TBTN1a(rename=(Births=TBTN1));set TBTN1;if Notes="";keep FIPS Year Births;run;
data TBTP1a(rename=(Births=TBTP1));set TBTP1;if Notes="";keep FIPS Year Births;run;
data TBTO1a(rename=(Births=TBTO1));set TBTO1;if Notes="";keep FIPS Year Births;run;
data TBTH1a(rename=(Births=TBTH1));set TBTH1;if Notes="";keep FIPS Year Births;run;





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Troubleshooting -- Checking 1-Year Data: Year Coverage **********************************************************************************************************************/
/* Troubleshooting -- Checking 1-Year Data: Year Coverage **********************************************************************************************************************/
/* Troubleshooting -- Checking 1-Year Data: Year Coverage **********************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*
proc freq data=BIRT1a;tables Year/noprint out=BIRT1y;run;data BIRT1y;set BIRT1y(rename=(COUNT=BIRT1n));drop PERCENT;run;proc sort data=BIRT1y;by Year;run;
proc freq data=BIRM1a;tables Year/noprint out=BIRM1y;run;data BIRM1y;set BIRM1y(rename=(COUNT=BIRM1n));drop PERCENT;run;proc sort data=BIRM1y;by Year;run;
proc freq data=BIRF1a;tables Year/noprint out=BIRF1y;run;data BIRF1y;set BIRF1y(rename=(COUNT=BIRF1n));drop PERCENT;run;proc sort data=BIRF1y;by Year;run;
proc freq data=BIRW1a;tables Year/noprint out=BIRW1y;run;data BIRW1y;set BIRW1y(rename=(COUNT=BIRW1n));drop PERCENT;run;proc sort data=BIRW1y;by Year;run;
proc freq data=BIRB1a;tables Year/noprint out=BIRB1y;run;data BIRB1y;set BIRB1y(rename=(COUNT=BIRB1n));drop PERCENT;run;proc sort data=BIRB1y;by Year;run;
proc freq data=BIRA1a;tables Year/noprint out=BIRA1y;run;data BIRA1y;set BIRA1y(rename=(COUNT=BIRA1n));drop PERCENT;run;proc sort data=BIRA1y;by Year;run;
proc freq data=BIRN1a;tables Year/noprint out=BIRN1y;run;data BIRN1y;set BIRN1y(rename=(COUNT=BIRN1n));drop PERCENT;run;proc sort data=BIRN1y;by Year;run;
proc freq data=BIRP1a;tables Year/noprint out=BIRP1y;run;data BIRP1y;set BIRP1y(rename=(COUNT=BIRP1n));drop PERCENT;run;proc sort data=BIRP1y;by Year;run;
proc freq data=BIRO1a;tables Year/noprint out=BIRO1y;run;data BIRO1y;set BIRO1y(rename=(COUNT=BIRO1n));drop PERCENT;run;proc sort data=BIRO1y;by Year;run;
proc freq data=BIRH1a;tables Year/noprint out=BIRH1y;run;data BIRH1y;set BIRH1y(rename=(COUNT=BIRH1n));drop PERCENT;run;proc sort data=BIRH1y;by Year;run;
proc freq data=LBWT1a;tables Year/noprint out=LBWT1y;run;data LBWT1y;set LBWT1y(rename=(COUNT=LBWT1n));drop PERCENT;run;proc sort data=LBWT1y;by Year;run;
proc freq data=LBWM1a;tables Year/noprint out=LBWM1y;run;data LBWM1y;set LBWM1y(rename=(COUNT=LBWM1n));drop PERCENT;run;proc sort data=LBWM1y;by Year;run;
proc freq data=LBWF1a;tables Year/noprint out=LBWF1y;run;data LBWF1y;set LBWF1y(rename=(COUNT=LBWF1n));drop PERCENT;run;proc sort data=LBWF1y;by Year;run;
proc freq data=LBWW1a;tables Year/noprint out=LBWW1y;run;data LBWW1y;set LBWW1y(rename=(COUNT=LBWW1n));drop PERCENT;run;proc sort data=LBWW1y;by Year;run;
proc freq data=LBWB1a;tables Year/noprint out=LBWB1y;run;data LBWB1y;set LBWB1y(rename=(COUNT=LBWB1n));drop PERCENT;run;proc sort data=LBWB1y;by Year;run;
proc freq data=LBWA1a;tables Year/noprint out=LBWA1y;run;data LBWA1y;set LBWA1y(rename=(COUNT=LBWA1n));drop PERCENT;run;proc sort data=LBWA1y;by Year;run;
proc freq data=LBWN1a;tables Year/noprint out=LBWN1y;run;data LBWN1y;set LBWN1y(rename=(COUNT=LBWN1n));drop PERCENT;run;proc sort data=LBWN1y;by Year;run;
proc freq data=LBWP1a;tables Year/noprint out=LBWP1y;run;data LBWP1y;set LBWP1y(rename=(COUNT=LBWP1n));drop PERCENT;run;proc sort data=LBWP1y;by Year;run;
proc freq data=LBWO1a;tables Year/noprint out=LBWO1y;run;data LBWO1y;set LBWO1y(rename=(COUNT=LBWO1n));drop PERCENT;run;proc sort data=LBWO1y;by Year;run;
proc freq data=LBWH1a;tables Year/noprint out=LBWH1y;run;data LBWH1y;set LBWH1y(rename=(COUNT=LBWH1n));drop PERCENT;run;proc sort data=LBWH1y;by Year;run;
proc freq data=PTBT1a;tables Year/noprint out=PTBT1y;run;data PTBT1y;set PTBT1y(rename=(COUNT=PTBT1n));drop PERCENT;run;proc sort data=PTBT1y;by Year;run;
proc freq data=PTBM1a;tables Year/noprint out=PTBM1y;run;data PTBM1y;set PTBM1y(rename=(COUNT=PTBM1n));drop PERCENT;run;proc sort data=PTBM1y;by Year;run;
proc freq data=PTBF1a;tables Year/noprint out=PTBF1y;run;data PTBF1y;set PTBF1y(rename=(COUNT=PTBF1n));drop PERCENT;run;proc sort data=PTBF1y;by Year;run;
proc freq data=PTBW1a;tables Year/noprint out=PTBW1y;run;data PTBW1y;set PTBW1y(rename=(COUNT=PTBW1n));drop PERCENT;run;proc sort data=PTBW1y;by Year;run;
proc freq data=PTBB1a;tables Year/noprint out=PTBB1y;run;data PTBB1y;set PTBB1y(rename=(COUNT=PTBB1n));drop PERCENT;run;proc sort data=PTBB1y;by Year;run;
proc freq data=PTBA1a;tables Year/noprint out=PTBA1y;run;data PTBA1y;set PTBA1y(rename=(COUNT=PTBA1n));drop PERCENT;run;proc sort data=PTBA1y;by Year;run;
proc freq data=PTBN1a;tables Year/noprint out=PTBN1y;run;data PTBN1y;set PTBN1y(rename=(COUNT=PTBN1n));drop PERCENT;run;proc sort data=PTBN1y;by Year;run;
proc freq data=PTBP1a;tables Year/noprint out=PTBP1y;run;data PTBP1y;set PTBP1y(rename=(COUNT=PTBP1n));drop PERCENT;run;proc sort data=PTBP1y;by Year;run;
proc freq data=PTBO1a;tables Year/noprint out=PTBO1y;run;data PTBO1y;set PTBO1y(rename=(COUNT=PTBO1n));drop PERCENT;run;proc sort data=PTBO1y;by Year;run;
proc freq data=PTBH1a;tables Year/noprint out=PTBH1y;run;data PTBH1y;set PTBH1y(rename=(COUNT=PTBH1n));drop PERCENT;run;proc sort data=PTBH1y;by Year;run;
proc freq data=PNCT1a;tables Year/noprint out=PNCT1y;run;data PNCT1y;set PNCT1y(rename=(COUNT=PNCT1n));drop PERCENT;run;proc sort data=PNCT1y;by Year;run;
proc freq data=PNCM1a;tables Year/noprint out=PNCM1y;run;data PNCM1y;set PNCM1y(rename=(COUNT=PNCM1n));drop PERCENT;run;proc sort data=PNCM1y;by Year;run;
proc freq data=PNCF1a;tables Year/noprint out=PNCF1y;run;data PNCF1y;set PNCF1y(rename=(COUNT=PNCF1n));drop PERCENT;run;proc sort data=PNCF1y;by Year;run;
proc freq data=PNCW1a;tables Year/noprint out=PNCW1y;run;data PNCW1y;set PNCW1y(rename=(COUNT=PNCW1n));drop PERCENT;run;proc sort data=PNCW1y;by Year;run;
proc freq data=PNCB1a;tables Year/noprint out=PNCB1y;run;data PNCB1y;set PNCB1y(rename=(COUNT=PNCB1n));drop PERCENT;run;proc sort data=PNCB1y;by Year;run;
proc freq data=PNCA1a;tables Year/noprint out=PNCA1y;run;data PNCA1y;set PNCA1y(rename=(COUNT=PNCA1n));drop PERCENT;run;proc sort data=PNCA1y;by Year;run;
proc freq data=PNCN1a;tables Year/noprint out=PNCN1y;run;data PNCN1y;set PNCN1y(rename=(COUNT=PNCN1n));drop PERCENT;run;proc sort data=PNCN1y;by Year;run;
proc freq data=PNCP1a;tables Year/noprint out=PNCP1y;run;data PNCP1y;set PNCP1y(rename=(COUNT=PNCP1n));drop PERCENT;run;proc sort data=PNCP1y;by Year;run;
proc freq data=PNCO1a;tables Year/noprint out=PNCO1y;run;data PNCO1y;set PNCO1y(rename=(COUNT=PNCO1n));drop PERCENT;run;proc sort data=PNCO1y;by Year;run;
proc freq data=PNCH1a;tables Year/noprint out=PNCH1y;run;data PNCH1y;set PNCH1y(rename=(COUNT=PNCH1n));drop PERCENT;run;proc sort data=PNCH1y;by Year;run;
proc freq data=TBBT1a;tables Year/noprint out=TBBT1y;run;data TBBT1y;set TBBT1y(rename=(COUNT=TBBT1n));drop PERCENT;run;proc sort data=TBBT1y;by Year;run;
proc freq data=TBBM1a;tables Year/noprint out=TBBM1y;run;data TBBM1y;set TBBM1y(rename=(COUNT=TBBM1n));drop PERCENT;run;proc sort data=TBBM1y;by Year;run;
proc freq data=TBBF1a;tables Year/noprint out=TBBF1y;run;data TBBF1y;set TBBF1y(rename=(COUNT=TBBF1n));drop PERCENT;run;proc sort data=TBBF1y;by Year;run;
proc freq data=TBBW1a;tables Year/noprint out=TBBW1y;run;data TBBW1y;set TBBW1y(rename=(COUNT=TBBW1n));drop PERCENT;run;proc sort data=TBBW1y;by Year;run;
proc freq data=TBBB1a;tables Year/noprint out=TBBB1y;run;data TBBB1y;set TBBB1y(rename=(COUNT=TBBB1n));drop PERCENT;run;proc sort data=TBBB1y;by Year;run;
proc freq data=TBBA1a;tables Year/noprint out=TBBA1y;run;data TBBA1y;set TBBA1y(rename=(COUNT=TBBA1n));drop PERCENT;run;proc sort data=TBBA1y;by Year;run;
proc freq data=TBBN1a;tables Year/noprint out=TBBN1y;run;data TBBN1y;set TBBN1y(rename=(COUNT=TBBN1n));drop PERCENT;run;proc sort data=TBBN1y;by Year;run;
proc freq data=TBBP1a;tables Year/noprint out=TBBP1y;run;data TBBP1y;set TBBP1y(rename=(COUNT=TBBP1n));drop PERCENT;run;proc sort data=TBBP1y;by Year;run;
proc freq data=TBBO1a;tables Year/noprint out=TBBO1y;run;data TBBO1y;set TBBO1y(rename=(COUNT=TBBO1n));drop PERCENT;run;proc sort data=TBBO1y;by Year;run;
proc freq data=TBBH1a;tables Year/noprint out=TBBH1y;run;data TBBH1y;set TBBH1y(rename=(COUNT=TBBH1n));drop PERCENT;run;proc sort data=TBBH1y;by Year;run;
proc freq data=TBTT1a;tables Year/noprint out=TBTT1y;run;data TBTT1y;set TBTT1y(rename=(COUNT=TBTT1n));drop PERCENT;run;proc sort data=TBTT1y;by Year;run;
proc freq data=TBTM1a;tables Year/noprint out=TBTM1y;run;data TBTM1y;set TBTM1y(rename=(COUNT=TBTM1n));drop PERCENT;run;proc sort data=TBTM1y;by Year;run;
proc freq data=TBTF1a;tables Year/noprint out=TBTF1y;run;data TBTF1y;set TBTF1y(rename=(COUNT=TBTF1n));drop PERCENT;run;proc sort data=TBTF1y;by Year;run;
proc freq data=TBTW1a;tables Year/noprint out=TBTW1y;run;data TBTW1y;set TBTW1y(rename=(COUNT=TBTW1n));drop PERCENT;run;proc sort data=TBTW1y;by Year;run;
proc freq data=TBTB1a;tables Year/noprint out=TBTB1y;run;data TBTB1y;set TBTB1y(rename=(COUNT=TBTB1n));drop PERCENT;run;proc sort data=TBTB1y;by Year;run;
proc freq data=TBTA1a;tables Year/noprint out=TBTA1y;run;data TBTA1y;set TBTA1y(rename=(COUNT=TBTA1n));drop PERCENT;run;proc sort data=TBTA1y;by Year;run;
proc freq data=TBTN1a;tables Year/noprint out=TBTN1y;run;data TBTN1y;set TBTN1y(rename=(COUNT=TBTN1n));drop PERCENT;run;proc sort data=TBTN1y;by Year;run;
proc freq data=TBTP1a;tables Year/noprint out=TBTP1y;run;data TBTP1y;set TBTP1y(rename=(COUNT=TBTP1n));drop PERCENT;run;proc sort data=TBTP1y;by Year;run;
proc freq data=TBTO1a;tables Year/noprint out=TBTO1y;run;data TBTO1y;set TBTO1y(rename=(COUNT=TBTO1n));drop PERCENT;run;proc sort data=TBTO1y;by Year;run;
proc freq data=TBTH1a;tables Year/noprint out=TBTH1y;run;data TBTH1y;set TBTH1y(rename=(COUNT=TBTH1n));drop PERCENT;run;proc sort data=TBTH1y;by Year;run;
data CheckYear_1Yr;merge 
BIRT1y BIRM1y BIRF1y BIRW1y BIRB1y BIRA1y BIRN1y BIRP1y BIRO1y BIRH1y LBWT1y LBWM1y LBWF1y LBWW1y LBWB1y LBWA1y LBWN1y LBWP1y LBWO1y LBWH1y 
PTBT1y PTBM1y PTBF1y PTBW1y PTBB1y PTBA1y PTBN1y PTBP1y PTBO1y PTBH1y PNCT1y PNCM1y PNCF1y PNCW1y PNCB1y PNCA1y PNCN1y PNCP1y PNCO1y PNCH1y 
TBBT1y TBBM1y TBBF1y TBBW1y TBBB1y TBBA1y TBBN1y TBBP1y TBBO1y TBBH1y TBTT1y TBTM1y TBTF1y TBTW1y TBTB1y TBTA1y TBTN1y TBTP1y TBTO1y TBTH1y;
by Year;run;
proc print data=CheckYear_1Yr;run; 
*/





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Troubleshooting -- Checking 1-Year Data: Source *****************************************************************************************************************************/
/* Troubleshooting -- Checking 1-Year Data: Source *****************************************************************************************************************************/
/* Troubleshooting -- Checking 1-Year Data: Source *****************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* "Notes" of txt files have information about query paramters.
   For example, LWBW1 file should have query parameters for ethnicity (non-Hispanic), race (White alone), birth outcome (birth weight), etc.
   The below code will extract "Notes" and create a table to check whether each file is created based on correct query parameters. */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*
data BIRT1x;set BIRT1;File="BIRT1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRM1x;set BIRM1;File="BIRM1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRF1x;set BIRF1;File="BIRF1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRW1x;set BIRW1;File="BIRW1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRB1x;set BIRB1;File="BIRB1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRA1x;set BIRA1;File="BIRA1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRN1x;set BIRN1;File="BIRN1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRP1x;set BIRP1;File="BIRP1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRO1x;set BIRO1;File="BIRO1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRH1x;set BIRH1;File="BIRH1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWT1x;set LBWT1;File="LBWT1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWM1x;set LBWM1;File="LBWM1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWF1x;set LBWF1;File="LBWF1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWW1x;set LBWW1;File="LBWW1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWB1x;set LBWB1;File="LBWB1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWA1x;set LBWA1;File="LBWA1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWN1x;set LBWN1;File="LBWN1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWP1x;set LBWP1;File="LBWP1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWO1x;set LBWO1;File="LBWO1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWH1x;set LBWH1;File="LBWH1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBT1x;set PTBT1;File="PTBT1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBM1x;set PTBM1;File="PTBM1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBF1x;set PTBF1;File="PTBF1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBW1x;set PTBW1;File="PTBW1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBB1x;set PTBB1;File="PTBB1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBA1x;set PTBA1;File="PTBA1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBN1x;set PTBN1;File="PTBN1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBP1x;set PTBP1;File="PTBP1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBO1x;set PTBO1;File="PTBO1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBH1x;set PTBH1;File="PTBH1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCT1x;set PNCT1;File="PNCT1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCM1x;set PNCM1;File="PNCM1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCF1x;set PNCF1;File="PNCF1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCW1x;set PNCW1;File="PNCW1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCB1x;set PNCB1;File="PNCB1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCA1x;set PNCA1;File="PNCA1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCN1x;set PNCN1;File="PNCN1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCP1x;set PNCP1;File="PNCP1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCO1x;set PNCO1;File="PNCO1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCH1x;set PNCH1;File="PNCH1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBT1x;set TBBT1;File="TBBT1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBM1x;set TBBM1;File="TBBM1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBF1x;set TBBF1;File="TBBF1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBW1x;set TBBW1;File="TBBW1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBB1x;set TBBB1;File="TBBB1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBA1x;set TBBA1;File="TBBA1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBN1x;set TBBN1;File="TBBN1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBP1x;set TBBP1;File="TBBP1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBO1x;set TBBO1;File="TBBO1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBH1x;set TBBH1;File="TBBH1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTT1x;set TBTT1;File="TBTT1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTM1x;set TBTM1;File="TBTM1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTF1x;set TBTF1;File="TBTF1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTW1x;set TBTW1;File="TBTW1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTB1x;set TBTB1;File="TBTB1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTA1x;set TBTA1;File="TBTA1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTN1x;set TBTN1;File="TBTN1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTP1x;set TBTP1;File="TBTP1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTO1x;set TBTO1;File="TBTO1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTH1x;set TBTH1;File="TBTH1";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;

data CheckSource_1Yr;retain File Notes;set 
BIRT1x BIRM1x BIRF1x BIRW1x BIRB1x BIRA1x BIRN1x BIRP1x BIRO1x BIRH1x LBWT1x LBWM1x LBWF1x LBWW1x LBWB1x LBWA1x LBWN1x LBWP1x LBWO1x LBWH1x 
PTBT1x PTBM1x PTBF1x PTBW1x PTBB1x PTBA1x PTBN1x PTBP1x PTBO1x PTBH1x PNCT1x PNCM1x PNCF1x PNCW1x PNCB1x PNCA1x PNCN1x PNCP1x PNCO1x PNCH1x 
TBBT1x TBBM1x TBBF1x TBBW1x TBBB1x TBBA1x TBBN1x TBBP1x TBBO1x TBBH1x TBTT1x TBTM1x TBTF1x TBTW1x TBTB1x TBTA1x TBTN1x TBTP1x TBTO1x TBTH1x;
run;
proc print data=CheckSource_1Yr;run; 
*/




 
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Importing 5-Year Data - Total Birth *****************************************************************************************************************************************/
/* Importing 5-Year Data - Total Birth *****************************************************************************************************************************************/
/* Importing 5-Year Data - Total Birth *****************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/

data BIRT11;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_2007_2011.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRT12;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_2008_2012.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRT13;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_2009_2013.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRT14;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_2010_2014.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRT15;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_2011_2015.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRT16;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_2012_2016.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRT17;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_2013_2017.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRT18;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_2014_2018.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRT19;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_2015_2019.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRM11;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_Male_2007_2011.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRM12;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_Male_2008_2012.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRM13;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_Male_2009_2013.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRM14;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_Male_2010_2014.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRM15;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_Male_2011_2015.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRM16;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_Male_2012_2016.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRM17;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_Male_2013_2017.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRM18;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_Male_2014_2018.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRM19;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_Male_2015_2019.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRF11;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_Female_2007_2011.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRF12;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_Female_2008_2012.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRF13;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_Female_2009_2013.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRF14;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_Female_2010_2014.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRF15;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_Female_2011_2015.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRF16;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_Female_2012_2016.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRF17;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_Female_2013_2017.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRF18;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_Female_2014_2018.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRF19;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_Female_2015_2019.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRW11;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_NonHispanicWh_2007_2011.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRW12;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_NonHispanicWh_2008_2012.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRW13;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_NonHispanicWh_2009_2013.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRW14;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_NonHispanicWh_2010_2014.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRW15;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_NonHispanicWh_2011_2015.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRW16;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_NonHispanicWh_2012_2016.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRW17;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_NonHispanicWh_2013_2017.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRW18;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_NonHispanicWh_2014_2018.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRW19;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_NonHispanicWh_2015_2019.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRB11;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_AllHispanicBK_2007_2011.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRB12;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_AllHispanicBK_2008_2012.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRB13;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_AllHispanicBK_2009_2013.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRB14;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_AllHispanicBK_2010_2014.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRB15;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_AllHispanicBK_2011_2015.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRB16;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_AllHispanicBK_2012_2016.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRB17;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_AllHispanicBK_2013_2017.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRB18;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_AllHispanicBK_2014_2018.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRB19;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_AllHispanicBK_2015_2019.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRA11;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_AllHispanicAsian_2007_2011.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRA12;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_AllHispanicAsian_2008_2012.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRA13;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_AllHispanicAsian_2009_2013.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRA14;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_AllHispanicAsian_2010_2014.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRA15;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_AllHispanicAsian_2011_2015.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRA16;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_AllHispanicAsian_2012_2016.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRA17;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_AllHispanicAsian_2013_2017.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRA18;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_AllHispanicAsian_2014_2018.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRA19;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_AllHispanicAsian_2015_2019.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRN11;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_NativeAmerican_2007_2011.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRN12;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_NativeAmerican_2008_2012.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRN13;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_NativeAmerican_2009_2013.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRN14;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_NativeAmerican_2010_2014.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRN15;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_NativeAmerican_2011_2015.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRN16;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_NativeAmerican_2012_2016.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRN17;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_NativeAmerican_2013_2017.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRN18;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_NativeAmerican_2014_2018.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRN19;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_NativeAmerican_2015_2019.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRP11;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_NHPI_2007_2011.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRP12;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_NHPI_2008_2012.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRP13;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_NHPI_2009_2013.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRP14;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_NHPI_2010_2014.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRP15;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_NHPI_2011_2015.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRP16;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_NHPI_2012_2016.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRP17;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_NHPI_2013_2017.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRP18;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_NHPI_2014_2018.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRP19;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_NHPI_2015_2019.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRO11;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_Morerace_2007_2011.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRO12;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_Morerace_2008_2012.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRO13;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_Morerace_2009_2013.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRO14;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_Morerace_2010_2014.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRO15;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_Morerace_2011_2015.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRO16;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_Morerace_2012_2016.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRO17;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_Morerace_2013_2017.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRO18;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_Morerace_2014_2018.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRO19;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_Morerace_2015_2019.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRH11;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_Hispanic_2007_2011.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRH12;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_Hispanic_2008_2012.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRH13;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_Hispanic_2009_2013.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRH14;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_Hispanic_2010_2014.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRH15;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_Hispanic_2011_2015.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRH16;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_Hispanic_2012_2016.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRH17;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_Hispanic_2013_2017.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRH18;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_Hispanic_2014_2018.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data BIRH19;infile "Z:\CDCK01\Data_County\Birth\Total Birth Rate_5Y\Total_Birth_Total_Hispanic_2015_2019.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
 
/* Changing Variable Names & Keeping Necessary Variables */
data BIRT11a(rename=(Births=BIRT5));set BIRT11;if Notes="";Year=2011;keep FIPS Year Births;run;
data BIRT12a(rename=(Births=BIRT5));set BIRT12;if Notes="";Year=2012;keep FIPS Year Births;run;
data BIRT13a(rename=(Births=BIRT5));set BIRT13;if Notes="";Year=2013;keep FIPS Year Births;run;
data BIRT14a(rename=(Births=BIRT5));set BIRT14;if Notes="";Year=2014;keep FIPS Year Births;run;
data BIRT15a(rename=(Births=BIRT5));set BIRT15;if Notes="";Year=2015;keep FIPS Year Births;run;
data BIRT16a(rename=(Births=BIRT5));set BIRT16;if Notes="";Year=2016;keep FIPS Year Births;run;
data BIRT17a(rename=(Births=BIRT5));set BIRT17;if Notes="";Year=2017;keep FIPS Year Births;run;
data BIRT18a(rename=(Births=BIRT5));set BIRT18;if Notes="";Year=2018;keep FIPS Year Births;run;
data BIRT19a(rename=(Births=BIRT5));set BIRT19;if Notes="";Year=2019;keep FIPS Year Births;run;
data BIRM11a(rename=(Births=BIRM5));set BIRM11;if Notes="";Year=2011;keep FIPS Year Births;run;
data BIRM12a(rename=(Births=BIRM5));set BIRM12;if Notes="";Year=2012;keep FIPS Year Births;run;
data BIRM13a(rename=(Births=BIRM5));set BIRM13;if Notes="";Year=2013;keep FIPS Year Births;run;
data BIRM14a(rename=(Births=BIRM5));set BIRM14;if Notes="";Year=2014;keep FIPS Year Births;run;
data BIRM15a(rename=(Births=BIRM5));set BIRM15;if Notes="";Year=2015;keep FIPS Year Births;run;
data BIRM16a(rename=(Births=BIRM5));set BIRM16;if Notes="";Year=2016;keep FIPS Year Births;run;
data BIRM17a(rename=(Births=BIRM5));set BIRM17;if Notes="";Year=2017;keep FIPS Year Births;run;
data BIRM18a(rename=(Births=BIRM5));set BIRM18;if Notes="";Year=2018;keep FIPS Year Births;run;
data BIRM19a(rename=(Births=BIRM5));set BIRM19;if Notes="";Year=2019;keep FIPS Year Births;run;
data BIRF11a(rename=(Births=BIRF5));set BIRF11;if Notes="";Year=2011;keep FIPS Year Births;run;
data BIRF12a(rename=(Births=BIRF5));set BIRF12;if Notes="";Year=2012;keep FIPS Year Births;run;
data BIRF13a(rename=(Births=BIRF5));set BIRF13;if Notes="";Year=2013;keep FIPS Year Births;run;
data BIRF14a(rename=(Births=BIRF5));set BIRF14;if Notes="";Year=2014;keep FIPS Year Births;run;
data BIRF15a(rename=(Births=BIRF5));set BIRF15;if Notes="";Year=2015;keep FIPS Year Births;run;
data BIRF16a(rename=(Births=BIRF5));set BIRF16;if Notes="";Year=2016;keep FIPS Year Births;run;
data BIRF17a(rename=(Births=BIRF5));set BIRF17;if Notes="";Year=2017;keep FIPS Year Births;run;
data BIRF18a(rename=(Births=BIRF5));set BIRF18;if Notes="";Year=2018;keep FIPS Year Births;run;
data BIRF19a(rename=(Births=BIRF5));set BIRF19;if Notes="";Year=2019;keep FIPS Year Births;run;
data BIRW11a(rename=(Births=BIRW5));set BIRW11;if Notes="";Year=2011;keep FIPS Year Births;run;
data BIRW12a(rename=(Births=BIRW5));set BIRW12;if Notes="";Year=2012;keep FIPS Year Births;run;
data BIRW13a(rename=(Births=BIRW5));set BIRW13;if Notes="";Year=2013;keep FIPS Year Births;run;
data BIRW14a(rename=(Births=BIRW5));set BIRW14;if Notes="";Year=2014;keep FIPS Year Births;run;
data BIRW15a(rename=(Births=BIRW5));set BIRW15;if Notes="";Year=2015;keep FIPS Year Births;run;
data BIRW16a(rename=(Births=BIRW5));set BIRW16;if Notes="";Year=2016;keep FIPS Year Births;run;
data BIRW17a(rename=(Births=BIRW5));set BIRW17;if Notes="";Year=2017;keep FIPS Year Births;run;
data BIRW18a(rename=(Births=BIRW5));set BIRW18;if Notes="";Year=2018;keep FIPS Year Births;run;
data BIRW19a(rename=(Births=BIRW5));set BIRW19;if Notes="";Year=2019;keep FIPS Year Births;run;
data BIRB11a(rename=(Births=BIRB5));set BIRB11;if Notes="";Year=2011;keep FIPS Year Births;run;
data BIRB12a(rename=(Births=BIRB5));set BIRB12;if Notes="";Year=2012;keep FIPS Year Births;run;
data BIRB13a(rename=(Births=BIRB5));set BIRB13;if Notes="";Year=2013;keep FIPS Year Births;run;
data BIRB14a(rename=(Births=BIRB5));set BIRB14;if Notes="";Year=2014;keep FIPS Year Births;run;
data BIRB15a(rename=(Births=BIRB5));set BIRB15;if Notes="";Year=2015;keep FIPS Year Births;run;
data BIRB16a(rename=(Births=BIRB5));set BIRB16;if Notes="";Year=2016;keep FIPS Year Births;run;
data BIRB17a(rename=(Births=BIRB5));set BIRB17;if Notes="";Year=2017;keep FIPS Year Births;run;
data BIRB18a(rename=(Births=BIRB5));set BIRB18;if Notes="";Year=2018;keep FIPS Year Births;run;
data BIRB19a(rename=(Births=BIRB5));set BIRB19;if Notes="";Year=2019;keep FIPS Year Births;run;
data BIRA11a(rename=(Births=BIRA5));set BIRA11;if Notes="";Year=2011;keep FIPS Year Births;run;
data BIRA12a(rename=(Births=BIRA5));set BIRA12;if Notes="";Year=2012;keep FIPS Year Births;run;
data BIRA13a(rename=(Births=BIRA5));set BIRA13;if Notes="";Year=2013;keep FIPS Year Births;run;
data BIRA14a(rename=(Births=BIRA5));set BIRA14;if Notes="";Year=2014;keep FIPS Year Births;run;
data BIRA15a(rename=(Births=BIRA5));set BIRA15;if Notes="";Year=2015;keep FIPS Year Births;run;
data BIRA16a(rename=(Births=BIRA5));set BIRA16;if Notes="";Year=2016;keep FIPS Year Births;run;
data BIRA17a(rename=(Births=BIRA5));set BIRA17;if Notes="";Year=2017;keep FIPS Year Births;run;
data BIRA18a(rename=(Births=BIRA5));set BIRA18;if Notes="";Year=2018;keep FIPS Year Births;run;
data BIRA19a(rename=(Births=BIRA5));set BIRA19;if Notes="";Year=2019;keep FIPS Year Births;run;
data BIRN11a(rename=(Births=BIRN5));set BIRN11;if Notes="";Year=2011;keep FIPS Year Births;run;
data BIRN12a(rename=(Births=BIRN5));set BIRN12;if Notes="";Year=2012;keep FIPS Year Births;run;
data BIRN13a(rename=(Births=BIRN5));set BIRN13;if Notes="";Year=2013;keep FIPS Year Births;run;
data BIRN14a(rename=(Births=BIRN5));set BIRN14;if Notes="";Year=2014;keep FIPS Year Births;run;
data BIRN15a(rename=(Births=BIRN5));set BIRN15;if Notes="";Year=2015;keep FIPS Year Births;run;
data BIRN16a(rename=(Births=BIRN5));set BIRN16;if Notes="";Year=2016;keep FIPS Year Births;run;
data BIRN17a(rename=(Births=BIRN5));set BIRN17;if Notes="";Year=2017;keep FIPS Year Births;run;
data BIRN18a(rename=(Births=BIRN5));set BIRN18;if Notes="";Year=2018;keep FIPS Year Births;run;
data BIRN19a(rename=(Births=BIRN5));set BIRN19;if Notes="";Year=2019;keep FIPS Year Births;run;
data BIRP11a(rename=(Births=BIRP5));set BIRP11;if Notes="";Year=2011;keep FIPS Year Births;run;
data BIRP12a(rename=(Births=BIRP5));set BIRP12;if Notes="";Year=2012;keep FIPS Year Births;run;
data BIRP13a(rename=(Births=BIRP5));set BIRP13;if Notes="";Year=2013;keep FIPS Year Births;run;
data BIRP14a(rename=(Births=BIRP5));set BIRP14;if Notes="";Year=2014;keep FIPS Year Births;run;
data BIRP15a(rename=(Births=BIRP5));set BIRP15;if Notes="";Year=2015;keep FIPS Year Births;run;
data BIRP16a(rename=(Births=BIRP5));set BIRP16;if Notes="";Year=2016;keep FIPS Year Births;run;
data BIRP17a(rename=(Births=BIRP5));set BIRP17;if Notes="";Year=2017;keep FIPS Year Births;run;
data BIRP18a(rename=(Births=BIRP5));set BIRP18;if Notes="";Year=2018;keep FIPS Year Births;run;
data BIRP19a(rename=(Births=BIRP5));set BIRP19;if Notes="";Year=2019;keep FIPS Year Births;run;
data BIRO11a(rename=(Births=BIRO5));set BIRO11;if Notes="";Year=2011;keep FIPS Year Births;run;
data BIRO12a(rename=(Births=BIRO5));set BIRO12;if Notes="";Year=2012;keep FIPS Year Births;run;
data BIRO13a(rename=(Births=BIRO5));set BIRO13;if Notes="";Year=2013;keep FIPS Year Births;run;
data BIRO14a(rename=(Births=BIRO5));set BIRO14;if Notes="";Year=2014;keep FIPS Year Births;run;
data BIRO15a(rename=(Births=BIRO5));set BIRO15;if Notes="";Year=2015;keep FIPS Year Births;run;
data BIRO16a(rename=(Births=BIRO5));set BIRO16;if Notes="";Year=2016;keep FIPS Year Births;run;
data BIRO17a(rename=(Births=BIRO5));set BIRO17;if Notes="";Year=2017;keep FIPS Year Births;run;
data BIRO18a(rename=(Births=BIRO5));set BIRO18;if Notes="";Year=2018;keep FIPS Year Births;run;
data BIRO19a(rename=(Births=BIRO5));set BIRO19;if Notes="";Year=2019;keep FIPS Year Births;run;
data BIRH11a(rename=(Births=BIRH5));set BIRH11;if Notes="";Year=2011;keep FIPS Year Births;run;
data BIRH12a(rename=(Births=BIRH5));set BIRH12;if Notes="";Year=2012;keep FIPS Year Births;run;
data BIRH13a(rename=(Births=BIRH5));set BIRH13;if Notes="";Year=2013;keep FIPS Year Births;run;
data BIRH14a(rename=(Births=BIRH5));set BIRH14;if Notes="";Year=2014;keep FIPS Year Births;run;
data BIRH15a(rename=(Births=BIRH5));set BIRH15;if Notes="";Year=2015;keep FIPS Year Births;run;
data BIRH16a(rename=(Births=BIRH5));set BIRH16;if Notes="";Year=2016;keep FIPS Year Births;run;
data BIRH17a(rename=(Births=BIRH5));set BIRH17;if Notes="";Year=2017;keep FIPS Year Births;run;
data BIRH18a(rename=(Births=BIRH5));set BIRH18;if Notes="";Year=2018;keep FIPS Year Births;run;
data BIRH19a(rename=(Births=BIRH5));set BIRH19;if Notes="";Year=2019;keep FIPS Year Births;run;

 
 
 
 
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Troubleshooting -- Checking 5-Year Data - Total Birth: Source ***************************************************************************************************************/
/* Troubleshooting -- Checking 5-Year Data - Total Birth: Source ***************************************************************************************************************/
/* Troubleshooting -- Checking 5-Year Data - Total Birth: Source ***************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* "Notes" of txt files have information about query paramters.
   For example, LWBW1 file should have query parameters for ethnicity (non-Hispanic), race (White alone), birth outcome (birth weight), etc.
   The below code will extract "Notes" and create a table to check whether each file is created based on correct query parameters. */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*
data BIRT11x;set BIRT11;File="BIRT11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRT12x;set BIRT12;File="BIRT12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRT13x;set BIRT13;File="BIRT13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRT14x;set BIRT14;File="BIRT14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRT15x;set BIRT15;File="BIRT15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRT16x;set BIRT16;File="BIRT16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRT17x;set BIRT17;File="BIRT17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRT18x;set BIRT18;File="BIRT18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRT19x;set BIRT19;File="BIRT19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRM11x;set BIRM11;File="BIRM11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRM12x;set BIRM12;File="BIRM12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRM13x;set BIRM13;File="BIRM13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRM14x;set BIRM14;File="BIRM14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRM15x;set BIRM15;File="BIRM15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRM16x;set BIRM16;File="BIRM16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRM17x;set BIRM17;File="BIRM17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRM18x;set BIRM18;File="BIRM18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRM19x;set BIRM19;File="BIRM19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRF11x;set BIRF11;File="BIRF11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRF12x;set BIRF12;File="BIRF12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRF13x;set BIRF13;File="BIRF13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRF14x;set BIRF14;File="BIRF14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRF15x;set BIRF15;File="BIRF15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRF16x;set BIRF16;File="BIRF16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRF17x;set BIRF17;File="BIRF17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRF18x;set BIRF18;File="BIRF18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRF19x;set BIRF19;File="BIRF19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRW11x;set BIRW11;File="BIRW11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRW12x;set BIRW12;File="BIRW12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRW13x;set BIRW13;File="BIRW13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRW14x;set BIRW14;File="BIRW14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRW15x;set BIRW15;File="BIRW15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRW16x;set BIRW16;File="BIRW16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRW17x;set BIRW17;File="BIRW17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRW18x;set BIRW18;File="BIRW18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRW19x;set BIRW19;File="BIRW19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRB11x;set BIRB11;File="BIRB11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRB12x;set BIRB12;File="BIRB12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRB13x;set BIRB13;File="BIRB13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRB14x;set BIRB14;File="BIRB14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRB15x;set BIRB15;File="BIRB15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRB16x;set BIRB16;File="BIRB16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRB17x;set BIRB17;File="BIRB17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRB18x;set BIRB18;File="BIRB18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRB19x;set BIRB19;File="BIRB19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRA11x;set BIRA11;File="BIRA11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRA12x;set BIRA12;File="BIRA12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRA13x;set BIRA13;File="BIRA13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRA14x;set BIRA14;File="BIRA14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRA15x;set BIRA15;File="BIRA15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRA16x;set BIRA16;File="BIRA16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRA17x;set BIRA17;File="BIRA17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRA18x;set BIRA18;File="BIRA18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRA19x;set BIRA19;File="BIRA19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRN11x;set BIRN11;File="BIRN11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRN12x;set BIRN12;File="BIRN12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRN13x;set BIRN13;File="BIRN13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRN14x;set BIRN14;File="BIRN14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRN15x;set BIRN15;File="BIRN15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRN16x;set BIRN16;File="BIRN16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRN17x;set BIRN17;File="BIRN17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRN18x;set BIRN18;File="BIRN18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRN19x;set BIRN19;File="BIRN19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRP11x;set BIRP11;File="BIRP11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRP12x;set BIRP12;File="BIRP12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRP13x;set BIRP13;File="BIRP13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRP14x;set BIRP14;File="BIRP14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRP15x;set BIRP15;File="BIRP15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRP16x;set BIRP16;File="BIRP16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRP17x;set BIRP17;File="BIRP17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRP18x;set BIRP18;File="BIRP18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRP19x;set BIRP19;File="BIRP19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRO11x;set BIRO11;File="BIRO11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRO12x;set BIRO12;File="BIRO12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRO13x;set BIRO13;File="BIRO13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRO14x;set BIRO14;File="BIRO14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRO15x;set BIRO15;File="BIRO15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRO16x;set BIRO16;File="BIRO16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRO17x;set BIRO17;File="BIRO17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRO18x;set BIRO18;File="BIRO18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRO19x;set BIRO19;File="BIRO19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRH11x;set BIRH11;File="BIRH11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRH12x;set BIRH12;File="BIRH12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRH13x;set BIRH13;File="BIRH13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRH14x;set BIRH14;File="BIRH14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRH15x;set BIRH15;File="BIRH15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRH16x;set BIRH16;File="BIRH16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRH17x;set BIRH17;File="BIRH17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRH18x;set BIRH18;File="BIRH18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data BIRH19x;set BIRH19;File="BIRH19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
 
data CheckSource_5Yr;retain File Notes;set 
BIRT11x BIRT12x BIRT13x BIRT14x BIRT15x BIRT16x BIRT17x BIRT18x BIRT19x BIRM11x BIRM12x BIRM13x BIRM14x BIRM15x BIRM16x BIRM17x BIRM18x BIRM19x 
BIRF11x BIRF12x BIRF13x BIRF14x BIRF15x BIRF16x BIRF17x BIRF18x BIRF19x BIRW11x BIRW12x BIRW13x BIRW14x BIRW15x BIRW16x BIRW17x BIRW18x BIRW19x 
BIRB11x BIRB12x BIRB13x BIRB14x BIRB15x BIRB16x BIRB17x BIRB18x BIRB19x BIRA11x BIRA12x BIRA13x BIRA14x BIRA15x BIRA16x BIRA17x BIRA18x BIRA19x 
BIRN11x BIRN12x BIRN13x BIRN14x BIRN15x BIRN16x BIRN17x BIRN18x BIRN19x BIRP11x BIRP12x BIRP13x BIRP14x BIRP15x BIRP16x BIRP17x BIRP18x BIRP19x 
BIRO11x BIRO12x BIRO13x BIRO14x BIRO15x BIRO16x BIRO17x BIRO18x BIRO19x BIRH11x BIRH12x BIRH13x BIRH14x BIRH15x BIRH16x BIRH17x BIRH18x BIRH19x;
run;
proc print data=CheckSource_5Yr;run;
*/
 
 
 
 
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Importing 5-Year Data - Low Birth Weight ************************************************************************************************************************************/
/* Importing 5-Year Data - Low Birth Weight ************************************************************************************************************************************/
/* Importing 5-Year Data - Low Birth Weight ************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/

data LBWT11;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_2007_2011.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWT12;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_2008_2012.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWT13;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_2009_2013.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWT14;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_2010_2014.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWT15;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_2011_2015.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWT16;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_2012_2016.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWT17;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_2013_2017.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWT18;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_2014_2018.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWT19;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_2015_2019.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWM11;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_Male_2007_2011.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWM12;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_Male_2008_2012.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWM13;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_Male_2009_2013.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWM14;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_Male_2010_2014.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWM15;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_Male_2011_2015.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWM16;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_Male_2012_2016.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWM17;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_Male_2013_2017.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWM18;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_Male_2014_2018.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWM19;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_Male_2015_2019.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWF11;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_Female_2007_2011.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWF12;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_Female_2008_2012.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWF13;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_Female_2009_2013.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWF14;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_Female_2010_2014.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWF15;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_Female_2011_2015.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWF16;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_Female_2012_2016.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWF17;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_Female_2013_2017.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWF18;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_Female_2014_2018.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWF19;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_Female_2015_2019.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWW11;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_NonHispanicWh_2007_2011.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWW12;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_NonHispanicWh_2008_2012.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWW13;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_NonHispanicWh_2009_2013.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWW14;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_NonHispanicWh_2010_2014.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWW15;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_NonHispanicWh_2011_2015.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWW16;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_NonHispanicWh_2012_2016.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWW17;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_NonHispanicWh_2013_2017.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWW18;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_NonHispanicWh_2014_2018.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWW19;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_NonHispanicWh_2015_2019.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWB11;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_AllHispanicBK_2007_2011.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWB12;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_AllHispanicBK_2008_2012.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWB13;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_AllHispanicBK_2009_2013.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWB14;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_AllHispanicBK_2010_2014.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWB15;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_AllHispanicBK_2011_2015.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWB16;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_AllHispanicBK_2012_2016.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWB17;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_AllHispanicBK_2013_2017.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWB18;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_AllHispanicBK_2014_2018.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWB19;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_AllHispanicBK_2015_2019.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWA11;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_AllHispanicAsian_2007_2011.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWA12;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_AllHispanicAsian_2008_2012.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWA13;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_AllHispanicAsian_2009_2013.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWA14;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_AllHispanicAsian_2010_2014.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWA15;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_AllHispanicAsian_2011_2015.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWA16;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_AllHispanicAsian_2012_2016.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWA17;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_AllHispanicAsian_2013_2017.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWA18;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_AllHispanicAsian_2014_2018.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWA19;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_AllHispanicAsian_2015_2019.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWN11;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_NativeAmerican_2007_2011.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWN12;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_NativeAmerican_2008_2012.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWN13;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_NativeAmerican_2009_2013.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWN14;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_NativeAmerican_2010_2014.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWN15;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_NativeAmerican_2011_2015.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWN16;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_NativeAmerican_2012_2016.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWN17;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_NativeAmerican_2013_2017.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWN18;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_NativeAmerican_2014_2018.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWN19;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_NativeAmerican_2015_2019.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWP11;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_NHPI_2007_2011.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWP12;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_NHPI_2008_2012.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWP13;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_NHPI_2009_2013.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWP14;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_NHPI_2010_2014.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWP15;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_NHPI_2011_2015.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWP16;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_NHPI_2012_2016.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWP17;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_NHPI_2013_2017.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWP18;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_NHPI_2014_2018.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWP19;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_NHPI_2015_2019.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWO11;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_Morerace_2007_2011.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWO12;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_Morerace_2008_2012.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWO13;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_Morerace_2009_2013.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWO14;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_Morerace_2010_2014.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWO15;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_Morerace_2011_2015.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWO16;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_Morerace_2012_2016.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWO17;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_Morerace_2013_2017.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWO18;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_Morerace_2014_2018.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWO19;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_Morerace_2015_2019.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWH11;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_Hispanic_2007_2011.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWH12;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_Hispanic_2008_2012.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWH13;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_Hispanic_2009_2013.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWH14;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_Hispanic_2010_2014.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWH15;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_Hispanic_2011_2015.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWH16;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_Hispanic_2012_2016.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWH17;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_Hispanic_2013_2017.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWH18;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_Hispanic_2014_2018.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data LBWH19;infile "Z:\CDCK01\Data_County\Birth\LBWBirth_5Y\LBWBirth_Total_Hispanic_2015_2019.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
 
/* Changing Variable Names & Keeping Necessary Variables */
data LBWT11a(rename=(Births=LBWT5));set LBWT11;if Notes="";Year=2011;keep FIPS Year Births;run;
data LBWT12a(rename=(Births=LBWT5));set LBWT12;if Notes="";Year=2012;keep FIPS Year Births;run;
data LBWT13a(rename=(Births=LBWT5));set LBWT13;if Notes="";Year=2013;keep FIPS Year Births;run;
data LBWT14a(rename=(Births=LBWT5));set LBWT14;if Notes="";Year=2014;keep FIPS Year Births;run;
data LBWT15a(rename=(Births=LBWT5));set LBWT15;if Notes="";Year=2015;keep FIPS Year Births;run;
data LBWT16a(rename=(Births=LBWT5));set LBWT16;if Notes="";Year=2016;keep FIPS Year Births;run;
data LBWT17a(rename=(Births=LBWT5));set LBWT17;if Notes="";Year=2017;keep FIPS Year Births;run;
data LBWT18a(rename=(Births=LBWT5));set LBWT18;if Notes="";Year=2018;keep FIPS Year Births;run;
data LBWT19a(rename=(Births=LBWT5));set LBWT19;if Notes="";Year=2019;keep FIPS Year Births;run;
data LBWM11a(rename=(Births=LBWM5));set LBWM11;if Notes="";Year=2011;keep FIPS Year Births;run;
data LBWM12a(rename=(Births=LBWM5));set LBWM12;if Notes="";Year=2012;keep FIPS Year Births;run;
data LBWM13a(rename=(Births=LBWM5));set LBWM13;if Notes="";Year=2013;keep FIPS Year Births;run;
data LBWM14a(rename=(Births=LBWM5));set LBWM14;if Notes="";Year=2014;keep FIPS Year Births;run;
data LBWM15a(rename=(Births=LBWM5));set LBWM15;if Notes="";Year=2015;keep FIPS Year Births;run;
data LBWM16a(rename=(Births=LBWM5));set LBWM16;if Notes="";Year=2016;keep FIPS Year Births;run;
data LBWM17a(rename=(Births=LBWM5));set LBWM17;if Notes="";Year=2017;keep FIPS Year Births;run;
data LBWM18a(rename=(Births=LBWM5));set LBWM18;if Notes="";Year=2018;keep FIPS Year Births;run;
data LBWM19a(rename=(Births=LBWM5));set LBWM19;if Notes="";Year=2019;keep FIPS Year Births;run;
data LBWF11a(rename=(Births=LBWF5));set LBWF11;if Notes="";Year=2011;keep FIPS Year Births;run;
data LBWF12a(rename=(Births=LBWF5));set LBWF12;if Notes="";Year=2012;keep FIPS Year Births;run;
data LBWF13a(rename=(Births=LBWF5));set LBWF13;if Notes="";Year=2013;keep FIPS Year Births;run;
data LBWF14a(rename=(Births=LBWF5));set LBWF14;if Notes="";Year=2014;keep FIPS Year Births;run;
data LBWF15a(rename=(Births=LBWF5));set LBWF15;if Notes="";Year=2015;keep FIPS Year Births;run;
data LBWF16a(rename=(Births=LBWF5));set LBWF16;if Notes="";Year=2016;keep FIPS Year Births;run;
data LBWF17a(rename=(Births=LBWF5));set LBWF17;if Notes="";Year=2017;keep FIPS Year Births;run;
data LBWF18a(rename=(Births=LBWF5));set LBWF18;if Notes="";Year=2018;keep FIPS Year Births;run;
data LBWF19a(rename=(Births=LBWF5));set LBWF19;if Notes="";Year=2019;keep FIPS Year Births;run;
data LBWW11a(rename=(Births=LBWW5));set LBWW11;if Notes="";Year=2011;keep FIPS Year Births;run;
data LBWW12a(rename=(Births=LBWW5));set LBWW12;if Notes="";Year=2012;keep FIPS Year Births;run;
data LBWW13a(rename=(Births=LBWW5));set LBWW13;if Notes="";Year=2013;keep FIPS Year Births;run;
data LBWW14a(rename=(Births=LBWW5));set LBWW14;if Notes="";Year=2014;keep FIPS Year Births;run;
data LBWW15a(rename=(Births=LBWW5));set LBWW15;if Notes="";Year=2015;keep FIPS Year Births;run;
data LBWW16a(rename=(Births=LBWW5));set LBWW16;if Notes="";Year=2016;keep FIPS Year Births;run;
data LBWW17a(rename=(Births=LBWW5));set LBWW17;if Notes="";Year=2017;keep FIPS Year Births;run;
data LBWW18a(rename=(Births=LBWW5));set LBWW18;if Notes="";Year=2018;keep FIPS Year Births;run;
data LBWW19a(rename=(Births=LBWW5));set LBWW19;if Notes="";Year=2019;keep FIPS Year Births;run;
data LBWB11a(rename=(Births=LBWB5));set LBWB11;if Notes="";Year=2011;keep FIPS Year Births;run;
data LBWB12a(rename=(Births=LBWB5));set LBWB12;if Notes="";Year=2012;keep FIPS Year Births;run;
data LBWB13a(rename=(Births=LBWB5));set LBWB13;if Notes="";Year=2013;keep FIPS Year Births;run;
data LBWB14a(rename=(Births=LBWB5));set LBWB14;if Notes="";Year=2014;keep FIPS Year Births;run;
data LBWB15a(rename=(Births=LBWB5));set LBWB15;if Notes="";Year=2015;keep FIPS Year Births;run;
data LBWB16a(rename=(Births=LBWB5));set LBWB16;if Notes="";Year=2016;keep FIPS Year Births;run;
data LBWB17a(rename=(Births=LBWB5));set LBWB17;if Notes="";Year=2017;keep FIPS Year Births;run;
data LBWB18a(rename=(Births=LBWB5));set LBWB18;if Notes="";Year=2018;keep FIPS Year Births;run;
data LBWB19a(rename=(Births=LBWB5));set LBWB19;if Notes="";Year=2019;keep FIPS Year Births;run;
data LBWA11a(rename=(Births=LBWA5));set LBWA11;if Notes="";Year=2011;keep FIPS Year Births;run;
data LBWA12a(rename=(Births=LBWA5));set LBWA12;if Notes="";Year=2012;keep FIPS Year Births;run;
data LBWA13a(rename=(Births=LBWA5));set LBWA13;if Notes="";Year=2013;keep FIPS Year Births;run;
data LBWA14a(rename=(Births=LBWA5));set LBWA14;if Notes="";Year=2014;keep FIPS Year Births;run;
data LBWA15a(rename=(Births=LBWA5));set LBWA15;if Notes="";Year=2015;keep FIPS Year Births;run;
data LBWA16a(rename=(Births=LBWA5));set LBWA16;if Notes="";Year=2016;keep FIPS Year Births;run;
data LBWA17a(rename=(Births=LBWA5));set LBWA17;if Notes="";Year=2017;keep FIPS Year Births;run;
data LBWA18a(rename=(Births=LBWA5));set LBWA18;if Notes="";Year=2018;keep FIPS Year Births;run;
data LBWA19a(rename=(Births=LBWA5));set LBWA19;if Notes="";Year=2019;keep FIPS Year Births;run;
data LBWN11a(rename=(Births=LBWN5));set LBWN11;if Notes="";Year=2011;keep FIPS Year Births;run;
data LBWN12a(rename=(Births=LBWN5));set LBWN12;if Notes="";Year=2012;keep FIPS Year Births;run;
data LBWN13a(rename=(Births=LBWN5));set LBWN13;if Notes="";Year=2013;keep FIPS Year Births;run;
data LBWN14a(rename=(Births=LBWN5));set LBWN14;if Notes="";Year=2014;keep FIPS Year Births;run;
data LBWN15a(rename=(Births=LBWN5));set LBWN15;if Notes="";Year=2015;keep FIPS Year Births;run;
data LBWN16a(rename=(Births=LBWN5));set LBWN16;if Notes="";Year=2016;keep FIPS Year Births;run;
data LBWN17a(rename=(Births=LBWN5));set LBWN17;if Notes="";Year=2017;keep FIPS Year Births;run;
data LBWN18a(rename=(Births=LBWN5));set LBWN18;if Notes="";Year=2018;keep FIPS Year Births;run;
data LBWN19a(rename=(Births=LBWN5));set LBWN19;if Notes="";Year=2019;keep FIPS Year Births;run;
data LBWP11a(rename=(Births=LBWP5));set LBWP11;if Notes="";Year=2011;keep FIPS Year Births;run;
data LBWP12a(rename=(Births=LBWP5));set LBWP12;if Notes="";Year=2012;keep FIPS Year Births;run;
data LBWP13a(rename=(Births=LBWP5));set LBWP13;if Notes="";Year=2013;keep FIPS Year Births;run;
data LBWP14a(rename=(Births=LBWP5));set LBWP14;if Notes="";Year=2014;keep FIPS Year Births;run;
data LBWP15a(rename=(Births=LBWP5));set LBWP15;if Notes="";Year=2015;keep FIPS Year Births;run;
data LBWP16a(rename=(Births=LBWP5));set LBWP16;if Notes="";Year=2016;keep FIPS Year Births;run;
data LBWP17a(rename=(Births=LBWP5));set LBWP17;if Notes="";Year=2017;keep FIPS Year Births;run;
data LBWP18a(rename=(Births=LBWP5));set LBWP18;if Notes="";Year=2018;keep FIPS Year Births;run;
data LBWP19a(rename=(Births=LBWP5));set LBWP19;if Notes="";Year=2019;keep FIPS Year Births;run;
data LBWO11a(rename=(Births=LBWO5));set LBWO11;if Notes="";Year=2011;keep FIPS Year Births;run;
data LBWO12a(rename=(Births=LBWO5));set LBWO12;if Notes="";Year=2012;keep FIPS Year Births;run;
data LBWO13a(rename=(Births=LBWO5));set LBWO13;if Notes="";Year=2013;keep FIPS Year Births;run;
data LBWO14a(rename=(Births=LBWO5));set LBWO14;if Notes="";Year=2014;keep FIPS Year Births;run;
data LBWO15a(rename=(Births=LBWO5));set LBWO15;if Notes="";Year=2015;keep FIPS Year Births;run;
data LBWO16a(rename=(Births=LBWO5));set LBWO16;if Notes="";Year=2016;keep FIPS Year Births;run;
data LBWO17a(rename=(Births=LBWO5));set LBWO17;if Notes="";Year=2017;keep FIPS Year Births;run;
data LBWO18a(rename=(Births=LBWO5));set LBWO18;if Notes="";Year=2018;keep FIPS Year Births;run;
data LBWO19a(rename=(Births=LBWO5));set LBWO19;if Notes="";Year=2019;keep FIPS Year Births;run;
data LBWH11a(rename=(Births=LBWH5));set LBWH11;if Notes="";Year=2011;keep FIPS Year Births;run;
data LBWH12a(rename=(Births=LBWH5));set LBWH12;if Notes="";Year=2012;keep FIPS Year Births;run;
data LBWH13a(rename=(Births=LBWH5));set LBWH13;if Notes="";Year=2013;keep FIPS Year Births;run;
data LBWH14a(rename=(Births=LBWH5));set LBWH14;if Notes="";Year=2014;keep FIPS Year Births;run;
data LBWH15a(rename=(Births=LBWH5));set LBWH15;if Notes="";Year=2015;keep FIPS Year Births;run;
data LBWH16a(rename=(Births=LBWH5));set LBWH16;if Notes="";Year=2016;keep FIPS Year Births;run;
data LBWH17a(rename=(Births=LBWH5));set LBWH17;if Notes="";Year=2017;keep FIPS Year Births;run;
data LBWH18a(rename=(Births=LBWH5));set LBWH18;if Notes="";Year=2018;keep FIPS Year Births;run;
data LBWH19a(rename=(Births=LBWH5));set LBWH19;if Notes="";Year=2019;keep FIPS Year Births;run;

 
 
 

/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Troubleshooting -- Checking 5-Year Data - Low Birth Weight: Source **********************************************************************************************************/
/* Troubleshooting -- Checking 5-Year Data - Low Birth Weight: Source **********************************************************************************************************/
/* Troubleshooting -- Checking 5-Year Data - Low Birth Weight: Source **********************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* "Notes" of txt files have information about query paramters.
   For example, LWBW1 file should have query parameters for ethnicity (non-Hispanic), race (White alone), birth outcome (birth weight), etc.
   The below code will extract "Notes" and create a table to check whether each file is created based on correct query parameters. */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*
data LBWT11x;set LBWT11;File="LBWT11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWT12x;set LBWT12;File="LBWT12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWT13x;set LBWT13;File="LBWT13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWT14x;set LBWT14;File="LBWT14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWT15x;set LBWT15;File="LBWT15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWT16x;set LBWT16;File="LBWT16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWT17x;set LBWT17;File="LBWT17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWT18x;set LBWT18;File="LBWT18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWT19x;set LBWT19;File="LBWT19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWM11x;set LBWM11;File="LBWM11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWM12x;set LBWM12;File="LBWM12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWM13x;set LBWM13;File="LBWM13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWM14x;set LBWM14;File="LBWM14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWM15x;set LBWM15;File="LBWM15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWM16x;set LBWM16;File="LBWM16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWM17x;set LBWM17;File="LBWM17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWM18x;set LBWM18;File="LBWM18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWM19x;set LBWM19;File="LBWM19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWF11x;set LBWF11;File="LBWF11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWF12x;set LBWF12;File="LBWF12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWF13x;set LBWF13;File="LBWF13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWF14x;set LBWF14;File="LBWF14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWF15x;set LBWF15;File="LBWF15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWF16x;set LBWF16;File="LBWF16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWF17x;set LBWF17;File="LBWF17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWF18x;set LBWF18;File="LBWF18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWF19x;set LBWF19;File="LBWF19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWW11x;set LBWW11;File="LBWW11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWW12x;set LBWW12;File="LBWW12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWW13x;set LBWW13;File="LBWW13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWW14x;set LBWW14;File="LBWW14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWW15x;set LBWW15;File="LBWW15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWW16x;set LBWW16;File="LBWW16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWW17x;set LBWW17;File="LBWW17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWW18x;set LBWW18;File="LBWW18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWW19x;set LBWW19;File="LBWW19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWB11x;set LBWB11;File="LBWB11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWB12x;set LBWB12;File="LBWB12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWB13x;set LBWB13;File="LBWB13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWB14x;set LBWB14;File="LBWB14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWB15x;set LBWB15;File="LBWB15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWB16x;set LBWB16;File="LBWB16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWB17x;set LBWB17;File="LBWB17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWB18x;set LBWB18;File="LBWB18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWB19x;set LBWB19;File="LBWB19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWA11x;set LBWA11;File="LBWA11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWA12x;set LBWA12;File="LBWA12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWA13x;set LBWA13;File="LBWA13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWA14x;set LBWA14;File="LBWA14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWA15x;set LBWA15;File="LBWA15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWA16x;set LBWA16;File="LBWA16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWA17x;set LBWA17;File="LBWA17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWA18x;set LBWA18;File="LBWA18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWA19x;set LBWA19;File="LBWA19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWN11x;set LBWN11;File="LBWN11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWN12x;set LBWN12;File="LBWN12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWN13x;set LBWN13;File="LBWN13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWN14x;set LBWN14;File="LBWN14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWN15x;set LBWN15;File="LBWN15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWN16x;set LBWN16;File="LBWN16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWN17x;set LBWN17;File="LBWN17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWN18x;set LBWN18;File="LBWN18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWN19x;set LBWN19;File="LBWN19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWP11x;set LBWP11;File="LBWP11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWP12x;set LBWP12;File="LBWP12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWP13x;set LBWP13;File="LBWP13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWP14x;set LBWP14;File="LBWP14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWP15x;set LBWP15;File="LBWP15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWP16x;set LBWP16;File="LBWP16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWP17x;set LBWP17;File="LBWP17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWP18x;set LBWP18;File="LBWP18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWP19x;set LBWP19;File="LBWP19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWO11x;set LBWO11;File="LBWO11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWO12x;set LBWO12;File="LBWO12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWO13x;set LBWO13;File="LBWO13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWO14x;set LBWO14;File="LBWO14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWO15x;set LBWO15;File="LBWO15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWO16x;set LBWO16;File="LBWO16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWO17x;set LBWO17;File="LBWO17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWO18x;set LBWO18;File="LBWO18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWO19x;set LBWO19;File="LBWO19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWH11x;set LBWH11;File="LBWH11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWH12x;set LBWH12;File="LBWH12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWH13x;set LBWH13;File="LBWH13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWH14x;set LBWH14;File="LBWH14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWH15x;set LBWH15;File="LBWH15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWH16x;set LBWH16;File="LBWH16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWH17x;set LBWH17;File="LBWH17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWH18x;set LBWH18;File="LBWH18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data LBWH19x;set LBWH19;File="LBWH19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
 
data CheckSource_5Yr_LBW;retain File Notes;set 
LBWT11x LBWT12x LBWT13x LBWT14x LBWT15x LBWT16x LBWT17x LBWT18x LBWT19x LBWM11x LBWM12x LBWM13x LBWM14x LBWM15x LBWM16x LBWM17x LBWM18x LBWM19x 
LBWF11x LBWF12x LBWF13x LBWF14x LBWF15x LBWF16x LBWF17x LBWF18x LBWF19x LBWW11x LBWW12x LBWW13x LBWW14x LBWW15x LBWW16x LBWW17x LBWW18x LBWW19x 
LBWB11x LBWB12x LBWB13x LBWB14x LBWB15x LBWB16x LBWB17x LBWB18x LBWB19x LBWA11x LBWA12x LBWA13x LBWA14x LBWA15x LBWA16x LBWA17x LBWA18x LBWA19x 
LBWN11x LBWN12x LBWN13x LBWN14x LBWN15x LBWN16x LBWN17x LBWN18x LBWN19x LBWP11x LBWP12x LBWP13x LBWP14x LBWP15x LBWP16x LBWP17x LBWP18x LBWP19x 
LBWO11x LBWO12x LBWO13x LBWO14x LBWO15x LBWO16x LBWO17x LBWO18x LBWO19x LBWH11x LBWH12x LBWH13x LBWH14x LBWH15x LBWH16x LBWH17x LBWH18x LBWH19x;
run;
proc print data=CheckSource_5Yr_LBW;run;
*/
 
 
 
 
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Importing 5-Year Data - Preterm Birth ***************************************************************************************************************************************/
/* Importing 5-Year Data - Preterm Birth ***************************************************************************************************************************************/
/* Importing 5-Year Data - Preterm Birth ***************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/

data PTBT11;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_2007_2011.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBT12;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_2008_2012.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBT13;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_2009_2013.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBT14;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_2010_2014.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBT15;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_2011_2015.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBT16;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_2012_2016.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBT17;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_2013_2017.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBT18;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_2014_2018.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBT19;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_2015_2019.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBM11;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_Male_2007_2011.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBM12;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_Male_2008_2012.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBM13;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_Male_2009_2013.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBM14;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_Male_2010_2014.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBM15;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_Male_2011_2015.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBM16;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_Male_2012_2016.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBM17;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_Male_2013_2017.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBM18;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_Male_2014_2018.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBM19;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_Male_2015_2019.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBF11;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_Female_2007_2011.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBF12;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_Female_2008_2012.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBF13;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_Female_2009_2013.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBF14;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_Female_2010_2014.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBF15;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_Female_2011_2015.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBF16;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_Female_2012_2016.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBF17;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_Female_2013_2017.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBF18;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_Female_2014_2018.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBF19;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_Female_2015_2019.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBW11;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_NonHispanicWh_2007_2011.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBW12;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_NonHispanicWh_2008_2012.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBW13;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_NonHispanicWh_2009_2013.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBW14;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_NonHispanicWh_2010_2014.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBW15;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_NonHispanicWh_2011_2015.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBW16;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_NonHispanicWh_2012_2016.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBW17;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_NonHispanicWh_2013_2017.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBW18;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_NonHispanicWh_2014_2018.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBW19;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_NonHispanicWh_2015_2019.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBB11;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_AllHispanicBK_2007_2011.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBB12;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_AllHispanicBK_2008_2012.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBB13;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_AllHispanicBK_2009_2013.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBB14;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_AllHispanicBK_2010_2014.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBB15;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_AllHispanicBK_2011_2015.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBB16;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_AllHispanicBK_2012_2016.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBB17;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_AllHispanicBK_2013_2017.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBB18;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_AllHispanicBK_2014_2018.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBB19;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_AllHispanicBK_2015_2019.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBA11;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_AllHispanicAsian_2007_2011.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBA12;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_AllHispanicAsian_2008_2012.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBA13;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_AllHispanicAsian_2009_2013.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBA14;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_AllHispanicAsian_2010_2014.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBA15;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_AllHispanicAsian_2011_2015.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBA16;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_AllHispanicAsian_2012_2016.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBA17;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_AllHispanicAsian_2013_2017.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBA18;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_AllHispanicAsian_2014_2018.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBA19;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_AllHispanicAsian_2015_2019.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBN11;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_NativeAmerican_2007_2011.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBN12;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_NativeAmerican_2008_2012.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBN13;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_NativeAmerican_2009_2013.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBN14;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_NativeAmerican_2010_2014.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBN15;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_NativeAmerican_2011_2015.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBN16;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_NativeAmerican_2012_2016.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBN17;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_NativeAmerican_2013_2017.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBN18;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_NativeAmerican_2014_2018.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBN19;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_NativeAmerican_2015_2019.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBP11;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_NHPI_2007_2011.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBP12;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_NHPI_2008_2012.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBP13;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_NHPI_2009_2013.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBP14;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_NHPI_2010_2014.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBP15;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_NHPI_2011_2015.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBP16;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_NHPI_2012_2016.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBP17;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_NHPI_2013_2017.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBP18;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_NHPI_2014_2018.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBP19;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_NHPI_2015_2019.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBO11;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_Morerace_2007_2011.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBO12;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_Morerace_2008_2012.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBO13;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_Morerace_2009_2013.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBO14;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_Morerace_2010_2014.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBO15;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_Morerace_2011_2015.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBO16;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_Morerace_2012_2016.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBO17;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_Morerace_2013_2017.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBO18;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_Morerace_2014_2018.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBO19;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_Morerace_2015_2019.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBH11;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_Hispanic_2007_2011.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBH12;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_Hispanic_2008_2012.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBH13;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_Hispanic_2009_2013.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBH14;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_Hispanic_2010_2014.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBH15;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_Hispanic_2011_2015.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBH16;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_Hispanic_2012_2016.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBH17;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_Hispanic_2013_2017.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBH18;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_Hispanic_2014_2018.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PTBH19;infile "Z:\CDCK01\Data_County\Birth\Preterm_5Y\Preterm_Total_Hispanic_2015_2019.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
 
/* Changing Variable Names & Keeping Necessary Variables */
data PTBT11a(rename=(Births=PTBT5));set PTBT11;if Notes="";Year=2011;keep FIPS Year Births;run;
data PTBT12a(rename=(Births=PTBT5));set PTBT12;if Notes="";Year=2012;keep FIPS Year Births;run;
data PTBT13a(rename=(Births=PTBT5));set PTBT13;if Notes="";Year=2013;keep FIPS Year Births;run;
data PTBT14a(rename=(Births=PTBT5));set PTBT14;if Notes="";Year=2014;keep FIPS Year Births;run;
data PTBT15a(rename=(Births=PTBT5));set PTBT15;if Notes="";Year=2015;keep FIPS Year Births;run;
data PTBT16a(rename=(Births=PTBT5));set PTBT16;if Notes="";Year=2016;keep FIPS Year Births;run;
data PTBT17a(rename=(Births=PTBT5));set PTBT17;if Notes="";Year=2017;keep FIPS Year Births;run;
data PTBT18a(rename=(Births=PTBT5));set PTBT18;if Notes="";Year=2018;keep FIPS Year Births;run;
data PTBT19a(rename=(Births=PTBT5));set PTBT19;if Notes="";Year=2019;keep FIPS Year Births;run;
data PTBM11a(rename=(Births=PTBM5));set PTBM11;if Notes="";Year=2011;keep FIPS Year Births;run;
data PTBM12a(rename=(Births=PTBM5));set PTBM12;if Notes="";Year=2012;keep FIPS Year Births;run;
data PTBM13a(rename=(Births=PTBM5));set PTBM13;if Notes="";Year=2013;keep FIPS Year Births;run;
data PTBM14a(rename=(Births=PTBM5));set PTBM14;if Notes="";Year=2014;keep FIPS Year Births;run;
data PTBM15a(rename=(Births=PTBM5));set PTBM15;if Notes="";Year=2015;keep FIPS Year Births;run;
data PTBM16a(rename=(Births=PTBM5));set PTBM16;if Notes="";Year=2016;keep FIPS Year Births;run;
data PTBM17a(rename=(Births=PTBM5));set PTBM17;if Notes="";Year=2017;keep FIPS Year Births;run;
data PTBM18a(rename=(Births=PTBM5));set PTBM18;if Notes="";Year=2018;keep FIPS Year Births;run;
data PTBM19a(rename=(Births=PTBM5));set PTBM19;if Notes="";Year=2019;keep FIPS Year Births;run;
data PTBF11a(rename=(Births=PTBF5));set PTBF11;if Notes="";Year=2011;keep FIPS Year Births;run;
data PTBF12a(rename=(Births=PTBF5));set PTBF12;if Notes="";Year=2012;keep FIPS Year Births;run;
data PTBF13a(rename=(Births=PTBF5));set PTBF13;if Notes="";Year=2013;keep FIPS Year Births;run;
data PTBF14a(rename=(Births=PTBF5));set PTBF14;if Notes="";Year=2014;keep FIPS Year Births;run;
data PTBF15a(rename=(Births=PTBF5));set PTBF15;if Notes="";Year=2015;keep FIPS Year Births;run;
data PTBF16a(rename=(Births=PTBF5));set PTBF16;if Notes="";Year=2016;keep FIPS Year Births;run;
data PTBF17a(rename=(Births=PTBF5));set PTBF17;if Notes="";Year=2017;keep FIPS Year Births;run;
data PTBF18a(rename=(Births=PTBF5));set PTBF18;if Notes="";Year=2018;keep FIPS Year Births;run;
data PTBF19a(rename=(Births=PTBF5));set PTBF19;if Notes="";Year=2019;keep FIPS Year Births;run;
data PTBW11a(rename=(Births=PTBW5));set PTBW11;if Notes="";Year=2011;keep FIPS Year Births;run;
data PTBW12a(rename=(Births=PTBW5));set PTBW12;if Notes="";Year=2012;keep FIPS Year Births;run;
data PTBW13a(rename=(Births=PTBW5));set PTBW13;if Notes="";Year=2013;keep FIPS Year Births;run;
data PTBW14a(rename=(Births=PTBW5));set PTBW14;if Notes="";Year=2014;keep FIPS Year Births;run;
data PTBW15a(rename=(Births=PTBW5));set PTBW15;if Notes="";Year=2015;keep FIPS Year Births;run;
data PTBW16a(rename=(Births=PTBW5));set PTBW16;if Notes="";Year=2016;keep FIPS Year Births;run;
data PTBW17a(rename=(Births=PTBW5));set PTBW17;if Notes="";Year=2017;keep FIPS Year Births;run;
data PTBW18a(rename=(Births=PTBW5));set PTBW18;if Notes="";Year=2018;keep FIPS Year Births;run;
data PTBW19a(rename=(Births=PTBW5));set PTBW19;if Notes="";Year=2019;keep FIPS Year Births;run;
data PTBB11a(rename=(Births=PTBB5));set PTBB11;if Notes="";Year=2011;keep FIPS Year Births;run;
data PTBB12a(rename=(Births=PTBB5));set PTBB12;if Notes="";Year=2012;keep FIPS Year Births;run;
data PTBB13a(rename=(Births=PTBB5));set PTBB13;if Notes="";Year=2013;keep FIPS Year Births;run;
data PTBB14a(rename=(Births=PTBB5));set PTBB14;if Notes="";Year=2014;keep FIPS Year Births;run;
data PTBB15a(rename=(Births=PTBB5));set PTBB15;if Notes="";Year=2015;keep FIPS Year Births;run;
data PTBB16a(rename=(Births=PTBB5));set PTBB16;if Notes="";Year=2016;keep FIPS Year Births;run;
data PTBB17a(rename=(Births=PTBB5));set PTBB17;if Notes="";Year=2017;keep FIPS Year Births;run;
data PTBB18a(rename=(Births=PTBB5));set PTBB18;if Notes="";Year=2018;keep FIPS Year Births;run;
data PTBB19a(rename=(Births=PTBB5));set PTBB19;if Notes="";Year=2019;keep FIPS Year Births;run;
data PTBA11a(rename=(Births=PTBA5));set PTBA11;if Notes="";Year=2011;keep FIPS Year Births;run;
data PTBA12a(rename=(Births=PTBA5));set PTBA12;if Notes="";Year=2012;keep FIPS Year Births;run;
data PTBA13a(rename=(Births=PTBA5));set PTBA13;if Notes="";Year=2013;keep FIPS Year Births;run;
data PTBA14a(rename=(Births=PTBA5));set PTBA14;if Notes="";Year=2014;keep FIPS Year Births;run;
data PTBA15a(rename=(Births=PTBA5));set PTBA15;if Notes="";Year=2015;keep FIPS Year Births;run;
data PTBA16a(rename=(Births=PTBA5));set PTBA16;if Notes="";Year=2016;keep FIPS Year Births;run;
data PTBA17a(rename=(Births=PTBA5));set PTBA17;if Notes="";Year=2017;keep FIPS Year Births;run;
data PTBA18a(rename=(Births=PTBA5));set PTBA18;if Notes="";Year=2018;keep FIPS Year Births;run;
data PTBA19a(rename=(Births=PTBA5));set PTBA19;if Notes="";Year=2019;keep FIPS Year Births;run;
data PTBN11a(rename=(Births=PTBN5));set PTBN11;if Notes="";Year=2011;keep FIPS Year Births;run;
data PTBN12a(rename=(Births=PTBN5));set PTBN12;if Notes="";Year=2012;keep FIPS Year Births;run;
data PTBN13a(rename=(Births=PTBN5));set PTBN13;if Notes="";Year=2013;keep FIPS Year Births;run;
data PTBN14a(rename=(Births=PTBN5));set PTBN14;if Notes="";Year=2014;keep FIPS Year Births;run;
data PTBN15a(rename=(Births=PTBN5));set PTBN15;if Notes="";Year=2015;keep FIPS Year Births;run;
data PTBN16a(rename=(Births=PTBN5));set PTBN16;if Notes="";Year=2016;keep FIPS Year Births;run;
data PTBN17a(rename=(Births=PTBN5));set PTBN17;if Notes="";Year=2017;keep FIPS Year Births;run;
data PTBN18a(rename=(Births=PTBN5));set PTBN18;if Notes="";Year=2018;keep FIPS Year Births;run;
data PTBN19a(rename=(Births=PTBN5));set PTBN19;if Notes="";Year=2019;keep FIPS Year Births;run;
data PTBP11a(rename=(Births=PTBP5));set PTBP11;if Notes="";Year=2011;keep FIPS Year Births;run;
data PTBP12a(rename=(Births=PTBP5));set PTBP12;if Notes="";Year=2012;keep FIPS Year Births;run;
data PTBP13a(rename=(Births=PTBP5));set PTBP13;if Notes="";Year=2013;keep FIPS Year Births;run;
data PTBP14a(rename=(Births=PTBP5));set PTBP14;if Notes="";Year=2014;keep FIPS Year Births;run;
data PTBP15a(rename=(Births=PTBP5));set PTBP15;if Notes="";Year=2015;keep FIPS Year Births;run;
data PTBP16a(rename=(Births=PTBP5));set PTBP16;if Notes="";Year=2016;keep FIPS Year Births;run;
data PTBP17a(rename=(Births=PTBP5));set PTBP17;if Notes="";Year=2017;keep FIPS Year Births;run;
data PTBP18a(rename=(Births=PTBP5));set PTBP18;if Notes="";Year=2018;keep FIPS Year Births;run;
data PTBP19a(rename=(Births=PTBP5));set PTBP19;if Notes="";Year=2019;keep FIPS Year Births;run;
data PTBO11a(rename=(Births=PTBO5));set PTBO11;if Notes="";Year=2011;keep FIPS Year Births;run;
data PTBO12a(rename=(Births=PTBO5));set PTBO12;if Notes="";Year=2012;keep FIPS Year Births;run;
data PTBO13a(rename=(Births=PTBO5));set PTBO13;if Notes="";Year=2013;keep FIPS Year Births;run;
data PTBO14a(rename=(Births=PTBO5));set PTBO14;if Notes="";Year=2014;keep FIPS Year Births;run;
data PTBO15a(rename=(Births=PTBO5));set PTBO15;if Notes="";Year=2015;keep FIPS Year Births;run;
data PTBO16a(rename=(Births=PTBO5));set PTBO16;if Notes="";Year=2016;keep FIPS Year Births;run;
data PTBO17a(rename=(Births=PTBO5));set PTBO17;if Notes="";Year=2017;keep FIPS Year Births;run;
data PTBO18a(rename=(Births=PTBO5));set PTBO18;if Notes="";Year=2018;keep FIPS Year Births;run;
data PTBO19a(rename=(Births=PTBO5));set PTBO19;if Notes="";Year=2019;keep FIPS Year Births;run;
data PTBH11a(rename=(Births=PTBH5));set PTBH11;if Notes="";Year=2011;keep FIPS Year Births;run;
data PTBH12a(rename=(Births=PTBH5));set PTBH12;if Notes="";Year=2012;keep FIPS Year Births;run;
data PTBH13a(rename=(Births=PTBH5));set PTBH13;if Notes="";Year=2013;keep FIPS Year Births;run;
data PTBH14a(rename=(Births=PTBH5));set PTBH14;if Notes="";Year=2014;keep FIPS Year Births;run;
data PTBH15a(rename=(Births=PTBH5));set PTBH15;if Notes="";Year=2015;keep FIPS Year Births;run;
data PTBH16a(rename=(Births=PTBH5));set PTBH16;if Notes="";Year=2016;keep FIPS Year Births;run;
data PTBH17a(rename=(Births=PTBH5));set PTBH17;if Notes="";Year=2017;keep FIPS Year Births;run;
data PTBH18a(rename=(Births=PTBH5));set PTBH18;if Notes="";Year=2018;keep FIPS Year Births;run;
data PTBH19a(rename=(Births=PTBH5));set PTBH19;if Notes="";Year=2019;keep FIPS Year Births;run;

 
 
 
 
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Troubleshooting -- Checking 5-Year Data - Preterm Birth: Source *************************************************************************************************************/
/* Troubleshooting -- Checking 5-Year Data - Preterm Birth: Source *************************************************************************************************************/
/* Troubleshooting -- Checking 5-Year Data - Preterm Birth: Source *************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* "Notes" of txt files have information about query paramters.
   For example, LWBW1 file should have query parameters for ethnicity (non-Hispanic), race (White alone), birth outcome (birth weight), etc.
   The below code will extract "Notes" and create a table to check whether each file is created based on correct query parameters. */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*
data PTBT11x;set PTBT11;File="PTBT11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBT12x;set PTBT12;File="PTBT12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBT13x;set PTBT13;File="PTBT13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBT14x;set PTBT14;File="PTBT14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBT15x;set PTBT15;File="PTBT15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBT16x;set PTBT16;File="PTBT16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBT17x;set PTBT17;File="PTBT17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBT18x;set PTBT18;File="PTBT18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBT19x;set PTBT19;File="PTBT19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBM11x;set PTBM11;File="PTBM11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBM12x;set PTBM12;File="PTBM12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBM13x;set PTBM13;File="PTBM13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBM14x;set PTBM14;File="PTBM14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBM15x;set PTBM15;File="PTBM15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBM16x;set PTBM16;File="PTBM16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBM17x;set PTBM17;File="PTBM17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBM18x;set PTBM18;File="PTBM18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBM19x;set PTBM19;File="PTBM19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBF11x;set PTBF11;File="PTBF11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBF12x;set PTBF12;File="PTBF12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBF13x;set PTBF13;File="PTBF13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBF14x;set PTBF14;File="PTBF14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBF15x;set PTBF15;File="PTBF15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBF16x;set PTBF16;File="PTBF16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBF17x;set PTBF17;File="PTBF17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBF18x;set PTBF18;File="PTBF18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBF19x;set PTBF19;File="PTBF19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBW11x;set PTBW11;File="PTBW11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBW12x;set PTBW12;File="PTBW12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBW13x;set PTBW13;File="PTBW13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBW14x;set PTBW14;File="PTBW14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBW15x;set PTBW15;File="PTBW15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBW16x;set PTBW16;File="PTBW16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBW17x;set PTBW17;File="PTBW17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBW18x;set PTBW18;File="PTBW18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBW19x;set PTBW19;File="PTBW19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBB11x;set PTBB11;File="PTBB11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBB12x;set PTBB12;File="PTBB12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBB13x;set PTBB13;File="PTBB13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBB14x;set PTBB14;File="PTBB14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBB15x;set PTBB15;File="PTBB15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBB16x;set PTBB16;File="PTBB16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBB17x;set PTBB17;File="PTBB17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBB18x;set PTBB18;File="PTBB18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBB19x;set PTBB19;File="PTBB19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBA11x;set PTBA11;File="PTBA11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBA12x;set PTBA12;File="PTBA12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBA13x;set PTBA13;File="PTBA13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBA14x;set PTBA14;File="PTBA14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBA15x;set PTBA15;File="PTBA15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBA16x;set PTBA16;File="PTBA16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBA17x;set PTBA17;File="PTBA17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBA18x;set PTBA18;File="PTBA18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBA19x;set PTBA19;File="PTBA19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBN11x;set PTBN11;File="PTBN11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBN12x;set PTBN12;File="PTBN12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBN13x;set PTBN13;File="PTBN13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBN14x;set PTBN14;File="PTBN14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBN15x;set PTBN15;File="PTBN15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBN16x;set PTBN16;File="PTBN16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBN17x;set PTBN17;File="PTBN17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBN18x;set PTBN18;File="PTBN18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBN19x;set PTBN19;File="PTBN19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBP11x;set PTBP11;File="PTBP11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBP12x;set PTBP12;File="PTBP12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBP13x;set PTBP13;File="PTBP13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBP14x;set PTBP14;File="PTBP14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBP15x;set PTBP15;File="PTBP15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBP16x;set PTBP16;File="PTBP16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBP17x;set PTBP17;File="PTBP17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBP18x;set PTBP18;File="PTBP18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBP19x;set PTBP19;File="PTBP19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBO11x;set PTBO11;File="PTBO11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBO12x;set PTBO12;File="PTBO12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBO13x;set PTBO13;File="PTBO13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBO14x;set PTBO14;File="PTBO14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBO15x;set PTBO15;File="PTBO15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBO16x;set PTBO16;File="PTBO16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBO17x;set PTBO17;File="PTBO17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBO18x;set PTBO18;File="PTBO18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBO19x;set PTBO19;File="PTBO19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBH11x;set PTBH11;File="PTBH11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBH12x;set PTBH12;File="PTBH12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBH13x;set PTBH13;File="PTBH13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBH14x;set PTBH14;File="PTBH14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBH15x;set PTBH15;File="PTBH15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBH16x;set PTBH16;File="PTBH16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBH17x;set PTBH17;File="PTBH17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBH18x;set PTBH18;File="PTBH18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PTBH19x;set PTBH19;File="PTBH19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
 
data CheckSource_5Yr_PTB;retain File Notes;set 
PTBT11x PTBT12x PTBT13x PTBT14x PTBT15x PTBT16x PTBT17x PTBT18x PTBT19x PTBM11x PTBM12x PTBM13x PTBM14x PTBM15x PTBM16x PTBM17x PTBM18x PTBM19x 
PTBF11x PTBF12x PTBF13x PTBF14x PTBF15x PTBF16x PTBF17x PTBF18x PTBF19x PTBW11x PTBW12x PTBW13x PTBW14x PTBW15x PTBW16x PTBW17x PTBW18x PTBW19x 
PTBB11x PTBB12x PTBB13x PTBB14x PTBB15x PTBB16x PTBB17x PTBB18x PTBB19x PTBA11x PTBA12x PTBA13x PTBA14x PTBA15x PTBA16x PTBA17x PTBA18x PTBA19x 
PTBN11x PTBN12x PTBN13x PTBN14x PTBN15x PTBN16x PTBN17x PTBN18x PTBN19x PTBP11x PTBP12x PTBP13x PTBP14x PTBP15x PTBP16x PTBP17x PTBP18x PTBP19x 
PTBO11x PTBO12x PTBO13x PTBO14x PTBO15x PTBO16x PTBO17x PTBO18x PTBO19x PTBH11x PTBH12x PTBH13x PTBH14x PTBH15x PTBH16x PTBH17x PTBH18x PTBH19x;
run;
proc print data=CheckSource_5Yr_PTB;run;
*/

 
 
 
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Importing 5-Year Data - Prenatal Care ***************************************************************************************************************************************/
/* Importing 5-Year Data - Prenatal Care ***************************************************************************************************************************************/
/* Importing 5-Year Data - Prenatal Care ***************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/

data PNCT11;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_2007_2011.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCT12;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_2008_2012.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCT13;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_2009_2013.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCT14;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_2010_2014.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCT15;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_2011_2015.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCT16;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_2012_2016.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCT17;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_2013_2017.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCT18;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_2014_2018.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCT19;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_2015_2019.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCM11;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_Male_2007_2011.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCM12;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_Male_2008_2012.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCM13;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_Male_2009_2013.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCM14;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_Male_2010_2014.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCM15;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_Male_2011_2015.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCM16;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_Male_2012_2016.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCM17;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_Male_2013_2017.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCM18;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_Male_2014_2018.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCM19;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_Male_2015_2019.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCF11;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_Female_2007_2011.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCF12;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_Female_2008_2012.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCF13;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_Female_2009_2013.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCF14;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_Female_2010_2014.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCF15;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_Female_2011_2015.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCF16;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_Female_2012_2016.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCF17;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_Female_2013_2017.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCF18;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_Female_2014_2018.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCF19;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_Female_2015_2019.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCW11;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_NonHispanicWh_2007_2011.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCW12;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_NonHispanicWh_2008_2012.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCW13;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_NonHispanicWh_2009_2013.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCW14;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_NonHispanicWh_2010_2014.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCW15;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_NonHispanicWh_2011_2015.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCW16;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_NonHispanicWh_2012_2016.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCW17;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_NonHispanicWh_2013_2017.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCW18;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_NonHispanicWh_2014_2018.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCW19;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_NonHispanicWh_2015_2019.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCB11;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_AllHispanicBK_2007_2011.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCB12;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_AllHispanicBK_2008_2012.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCB13;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_AllHispanicBK_2009_2013.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCB14;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_AllHispanicBK_2010_2014.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCB15;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_AllHispanicBK_2011_2015.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCB16;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_AllHispanicBK_2012_2016.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCB17;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_AllHispanicBK_2013_2017.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCB18;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_AllHispanicBK_2014_2018.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCB19;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_AllHispanicBK_2015_2019.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCA11;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_AllHispanicAsian_2007_2011.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCA12;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_AllHispanicAsian_2008_2012.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCA13;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_AllHispanicAsian_2009_2013.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCA14;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_AllHispanicAsian_2010_2014.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCA15;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_AllHispanicAsian_2011_2015.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCA16;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_AllHispanicAsian_2012_2016.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCA17;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_AllHispanicAsian_2013_2017.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCA18;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_AllHispanicAsian_2014_2018.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCA19;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_AllHispanicAsian_2015_2019.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCN11;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_NativeAmerican_2007_2011.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCN12;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_NativeAmerican_2008_2012.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCN13;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_NativeAmerican_2009_2013.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCN14;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_NativeAmerican_2010_2014.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCN15;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_NativeAmerican_2011_2015.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCN16;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_NativeAmerican_2012_2016.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCN17;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_NativeAmerican_2013_2017.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCN18;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_NativeAmerican_2014_2018.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCN19;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_NativeAmerican_2015_2019.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCP11;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_NHPI_2007_2011.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCP12;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_NHPI_2008_2012.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCP13;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_NHPI_2009_2013.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCP14;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_NHPI_2010_2014.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCP15;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_NHPI_2011_2015.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCP16;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_NHPI_2012_2016.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCP17;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_NHPI_2013_2017.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCP18;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_NHPI_2014_2018.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCP19;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_NHPI_2015_2019.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCO11;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_Morerace_2007_2011.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCO12;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_Morerace_2008_2012.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCO13;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_Morerace_2009_2013.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCO14;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_Morerace_2010_2014.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCO15;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_Morerace_2011_2015.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCO16;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_Morerace_2012_2016.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCO17;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_Morerace_2013_2017.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCO18;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_Morerace_2014_2018.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCO19;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_Morerace_2015_2019.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCH11;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_Hispanic_2007_2011.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCH12;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_Hispanic_2008_2012.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCH13;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_Hispanic_2009_2013.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCH14;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_Hispanic_2010_2014.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCH15;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_Hispanic_2011_2015.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCH16;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_Hispanic_2012_2016.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCH17;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_Hispanic_2013_2017.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCH18;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_Hispanic_2014_2018.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data PNCH19;infile "Z:\CDCK01\Data_County\Birth\Prenatal_Birth_5Y\Prenatal_Birth_Hispanic_2015_2019.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
 
/* Changing Variable Names & Keeping Necessary Variables */
data PNCT11a(rename=(Births=PNCT5));set PNCT11;if Notes="";Year=2011;keep FIPS Year Births;run;
data PNCT12a(rename=(Births=PNCT5));set PNCT12;if Notes="";Year=2012;keep FIPS Year Births;run;
data PNCT13a(rename=(Births=PNCT5));set PNCT13;if Notes="";Year=2013;keep FIPS Year Births;run;
data PNCT14a(rename=(Births=PNCT5));set PNCT14;if Notes="";Year=2014;keep FIPS Year Births;run;
data PNCT15a(rename=(Births=PNCT5));set PNCT15;if Notes="";Year=2015;keep FIPS Year Births;run;
data PNCT16a(rename=(Births=PNCT5));set PNCT16;if Notes="";Year=2016;keep FIPS Year Births;run;
data PNCT17a(rename=(Births=PNCT5));set PNCT17;if Notes="";Year=2017;keep FIPS Year Births;run;
data PNCT18a(rename=(Births=PNCT5));set PNCT18;if Notes="";Year=2018;keep FIPS Year Births;run;
data PNCT19a(rename=(Births=PNCT5));set PNCT19;if Notes="";Year=2019;keep FIPS Year Births;run;
data PNCM11a(rename=(Births=PNCM5));set PNCM11;if Notes="";Year=2011;keep FIPS Year Births;run;
data PNCM12a(rename=(Births=PNCM5));set PNCM12;if Notes="";Year=2012;keep FIPS Year Births;run;
data PNCM13a(rename=(Births=PNCM5));set PNCM13;if Notes="";Year=2013;keep FIPS Year Births;run;
data PNCM14a(rename=(Births=PNCM5));set PNCM14;if Notes="";Year=2014;keep FIPS Year Births;run;
data PNCM15a(rename=(Births=PNCM5));set PNCM15;if Notes="";Year=2015;keep FIPS Year Births;run;
data PNCM16a(rename=(Births=PNCM5));set PNCM16;if Notes="";Year=2016;keep FIPS Year Births;run;
data PNCM17a(rename=(Births=PNCM5));set PNCM17;if Notes="";Year=2017;keep FIPS Year Births;run;
data PNCM18a(rename=(Births=PNCM5));set PNCM18;if Notes="";Year=2018;keep FIPS Year Births;run;
data PNCM19a(rename=(Births=PNCM5));set PNCM19;if Notes="";Year=2019;keep FIPS Year Births;run;
data PNCF11a(rename=(Births=PNCF5));set PNCF11;if Notes="";Year=2011;keep FIPS Year Births;run;
data PNCF12a(rename=(Births=PNCF5));set PNCF12;if Notes="";Year=2012;keep FIPS Year Births;run;
data PNCF13a(rename=(Births=PNCF5));set PNCF13;if Notes="";Year=2013;keep FIPS Year Births;run;
data PNCF14a(rename=(Births=PNCF5));set PNCF14;if Notes="";Year=2014;keep FIPS Year Births;run;
data PNCF15a(rename=(Births=PNCF5));set PNCF15;if Notes="";Year=2015;keep FIPS Year Births;run;
data PNCF16a(rename=(Births=PNCF5));set PNCF16;if Notes="";Year=2016;keep FIPS Year Births;run;
data PNCF17a(rename=(Births=PNCF5));set PNCF17;if Notes="";Year=2017;keep FIPS Year Births;run;
data PNCF18a(rename=(Births=PNCF5));set PNCF18;if Notes="";Year=2018;keep FIPS Year Births;run;
data PNCF19a(rename=(Births=PNCF5));set PNCF19;if Notes="";Year=2019;keep FIPS Year Births;run;
data PNCW11a(rename=(Births=PNCW5));set PNCW11;if Notes="";Year=2011;keep FIPS Year Births;run;
data PNCW12a(rename=(Births=PNCW5));set PNCW12;if Notes="";Year=2012;keep FIPS Year Births;run;
data PNCW13a(rename=(Births=PNCW5));set PNCW13;if Notes="";Year=2013;keep FIPS Year Births;run;
data PNCW14a(rename=(Births=PNCW5));set PNCW14;if Notes="";Year=2014;keep FIPS Year Births;run;
data PNCW15a(rename=(Births=PNCW5));set PNCW15;if Notes="";Year=2015;keep FIPS Year Births;run;
data PNCW16a(rename=(Births=PNCW5));set PNCW16;if Notes="";Year=2016;keep FIPS Year Births;run;
data PNCW17a(rename=(Births=PNCW5));set PNCW17;if Notes="";Year=2017;keep FIPS Year Births;run;
data PNCW18a(rename=(Births=PNCW5));set PNCW18;if Notes="";Year=2018;keep FIPS Year Births;run;
data PNCW19a(rename=(Births=PNCW5));set PNCW19;if Notes="";Year=2019;keep FIPS Year Births;run;
data PNCB11a(rename=(Births=PNCB5));set PNCB11;if Notes="";Year=2011;keep FIPS Year Births;run;
data PNCB12a(rename=(Births=PNCB5));set PNCB12;if Notes="";Year=2012;keep FIPS Year Births;run;
data PNCB13a(rename=(Births=PNCB5));set PNCB13;if Notes="";Year=2013;keep FIPS Year Births;run;
data PNCB14a(rename=(Births=PNCB5));set PNCB14;if Notes="";Year=2014;keep FIPS Year Births;run;
data PNCB15a(rename=(Births=PNCB5));set PNCB15;if Notes="";Year=2015;keep FIPS Year Births;run;
data PNCB16a(rename=(Births=PNCB5));set PNCB16;if Notes="";Year=2016;keep FIPS Year Births;run;
data PNCB17a(rename=(Births=PNCB5));set PNCB17;if Notes="";Year=2017;keep FIPS Year Births;run;
data PNCB18a(rename=(Births=PNCB5));set PNCB18;if Notes="";Year=2018;keep FIPS Year Births;run;
data PNCB19a(rename=(Births=PNCB5));set PNCB19;if Notes="";Year=2019;keep FIPS Year Births;run;
data PNCA11a(rename=(Births=PNCA5));set PNCA11;if Notes="";Year=2011;keep FIPS Year Births;run;
data PNCA12a(rename=(Births=PNCA5));set PNCA12;if Notes="";Year=2012;keep FIPS Year Births;run;
data PNCA13a(rename=(Births=PNCA5));set PNCA13;if Notes="";Year=2013;keep FIPS Year Births;run;
data PNCA14a(rename=(Births=PNCA5));set PNCA14;if Notes="";Year=2014;keep FIPS Year Births;run;
data PNCA15a(rename=(Births=PNCA5));set PNCA15;if Notes="";Year=2015;keep FIPS Year Births;run;
data PNCA16a(rename=(Births=PNCA5));set PNCA16;if Notes="";Year=2016;keep FIPS Year Births;run;
data PNCA17a(rename=(Births=PNCA5));set PNCA17;if Notes="";Year=2017;keep FIPS Year Births;run;
data PNCA18a(rename=(Births=PNCA5));set PNCA18;if Notes="";Year=2018;keep FIPS Year Births;run;
data PNCA19a(rename=(Births=PNCA5));set PNCA19;if Notes="";Year=2019;keep FIPS Year Births;run;
data PNCN11a(rename=(Births=PNCN5));set PNCN11;if Notes="";Year=2011;keep FIPS Year Births;run;
data PNCN12a(rename=(Births=PNCN5));set PNCN12;if Notes="";Year=2012;keep FIPS Year Births;run;
data PNCN13a(rename=(Births=PNCN5));set PNCN13;if Notes="";Year=2013;keep FIPS Year Births;run;
data PNCN14a(rename=(Births=PNCN5));set PNCN14;if Notes="";Year=2014;keep FIPS Year Births;run;
data PNCN15a(rename=(Births=PNCN5));set PNCN15;if Notes="";Year=2015;keep FIPS Year Births;run;
data PNCN16a(rename=(Births=PNCN5));set PNCN16;if Notes="";Year=2016;keep FIPS Year Births;run;
data PNCN17a(rename=(Births=PNCN5));set PNCN17;if Notes="";Year=2017;keep FIPS Year Births;run;
data PNCN18a(rename=(Births=PNCN5));set PNCN18;if Notes="";Year=2018;keep FIPS Year Births;run;
data PNCN19a(rename=(Births=PNCN5));set PNCN19;if Notes="";Year=2019;keep FIPS Year Births;run;
data PNCP11a(rename=(Births=PNCP5));set PNCP11;if Notes="";Year=2011;keep FIPS Year Births;run;
data PNCP12a(rename=(Births=PNCP5));set PNCP12;if Notes="";Year=2012;keep FIPS Year Births;run;
data PNCP13a(rename=(Births=PNCP5));set PNCP13;if Notes="";Year=2013;keep FIPS Year Births;run;
data PNCP14a(rename=(Births=PNCP5));set PNCP14;if Notes="";Year=2014;keep FIPS Year Births;run;
data PNCP15a(rename=(Births=PNCP5));set PNCP15;if Notes="";Year=2015;keep FIPS Year Births;run;
data PNCP16a(rename=(Births=PNCP5));set PNCP16;if Notes="";Year=2016;keep FIPS Year Births;run;
data PNCP17a(rename=(Births=PNCP5));set PNCP17;if Notes="";Year=2017;keep FIPS Year Births;run;
data PNCP18a(rename=(Births=PNCP5));set PNCP18;if Notes="";Year=2018;keep FIPS Year Births;run;
data PNCP19a(rename=(Births=PNCP5));set PNCP19;if Notes="";Year=2019;keep FIPS Year Births;run;
data PNCO11a(rename=(Births=PNCO5));set PNCO11;if Notes="";Year=2011;keep FIPS Year Births;run;
data PNCO12a(rename=(Births=PNCO5));set PNCO12;if Notes="";Year=2012;keep FIPS Year Births;run;
data PNCO13a(rename=(Births=PNCO5));set PNCO13;if Notes="";Year=2013;keep FIPS Year Births;run;
data PNCO14a(rename=(Births=PNCO5));set PNCO14;if Notes="";Year=2014;keep FIPS Year Births;run;
data PNCO15a(rename=(Births=PNCO5));set PNCO15;if Notes="";Year=2015;keep FIPS Year Births;run;
data PNCO16a(rename=(Births=PNCO5));set PNCO16;if Notes="";Year=2016;keep FIPS Year Births;run;
data PNCO17a(rename=(Births=PNCO5));set PNCO17;if Notes="";Year=2017;keep FIPS Year Births;run;
data PNCO18a(rename=(Births=PNCO5));set PNCO18;if Notes="";Year=2018;keep FIPS Year Births;run;
data PNCO19a(rename=(Births=PNCO5));set PNCO19;if Notes="";Year=2019;keep FIPS Year Births;run;
data PNCH11a(rename=(Births=PNCH5));set PNCH11;if Notes="";Year=2011;keep FIPS Year Births;run;
data PNCH12a(rename=(Births=PNCH5));set PNCH12;if Notes="";Year=2012;keep FIPS Year Births;run;
data PNCH13a(rename=(Births=PNCH5));set PNCH13;if Notes="";Year=2013;keep FIPS Year Births;run;
data PNCH14a(rename=(Births=PNCH5));set PNCH14;if Notes="";Year=2014;keep FIPS Year Births;run;
data PNCH15a(rename=(Births=PNCH5));set PNCH15;if Notes="";Year=2015;keep FIPS Year Births;run;
data PNCH16a(rename=(Births=PNCH5));set PNCH16;if Notes="";Year=2016;keep FIPS Year Births;run;
data PNCH17a(rename=(Births=PNCH5));set PNCH17;if Notes="";Year=2017;keep FIPS Year Births;run;
data PNCH18a(rename=(Births=PNCH5));set PNCH18;if Notes="";Year=2018;keep FIPS Year Births;run;
data PNCH19a(rename=(Births=PNCH5));set PNCH19;if Notes="";Year=2019;keep FIPS Year Births;run;

 
 
 

/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Troubleshooting -- Checking 5-Year Data - Prenatal Care: Source *************************************************************************************************************/
/* Troubleshooting -- Checking 5-Year Data - Prenatal Care: Source *************************************************************************************************************/
/* Troubleshooting -- Checking 5-Year Data - Prenatal Care: Source *************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* "Notes" of txt files have information about query paramters.
   For example, LWBW1 file should have query parameters for ethnicity (non-Hispanic), race (White alone), birth outcome (birth weight), etc.
   The below code will extract "Notes" and create a table to check whether each file is created based on correct query parameters. */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*
data PNCT11x;set PNCT11;File="PNCT11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCT12x;set PNCT12;File="PNCT12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCT13x;set PNCT13;File="PNCT13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCT14x;set PNCT14;File="PNCT14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCT15x;set PNCT15;File="PNCT15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCT16x;set PNCT16;File="PNCT16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCT17x;set PNCT17;File="PNCT17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCT18x;set PNCT18;File="PNCT18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCT19x;set PNCT19;File="PNCT19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCM11x;set PNCM11;File="PNCM11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCM12x;set PNCM12;File="PNCM12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCM13x;set PNCM13;File="PNCM13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCM14x;set PNCM14;File="PNCM14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCM15x;set PNCM15;File="PNCM15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCM16x;set PNCM16;File="PNCM16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCM17x;set PNCM17;File="PNCM17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCM18x;set PNCM18;File="PNCM18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCM19x;set PNCM19;File="PNCM19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCF11x;set PNCF11;File="PNCF11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCF12x;set PNCF12;File="PNCF12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCF13x;set PNCF13;File="PNCF13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCF14x;set PNCF14;File="PNCF14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCF15x;set PNCF15;File="PNCF15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCF16x;set PNCF16;File="PNCF16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCF17x;set PNCF17;File="PNCF17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCF18x;set PNCF18;File="PNCF18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCF19x;set PNCF19;File="PNCF19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCW11x;set PNCW11;File="PNCW11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCW12x;set PNCW12;File="PNCW12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCW13x;set PNCW13;File="PNCW13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCW14x;set PNCW14;File="PNCW14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCW15x;set PNCW15;File="PNCW15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCW16x;set PNCW16;File="PNCW16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCW17x;set PNCW17;File="PNCW17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCW18x;set PNCW18;File="PNCW18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCW19x;set PNCW19;File="PNCW19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCB11x;set PNCB11;File="PNCB11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCB12x;set PNCB12;File="PNCB12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCB13x;set PNCB13;File="PNCB13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCB14x;set PNCB14;File="PNCB14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCB15x;set PNCB15;File="PNCB15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCB16x;set PNCB16;File="PNCB16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCB17x;set PNCB17;File="PNCB17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCB18x;set PNCB18;File="PNCB18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCB19x;set PNCB19;File="PNCB19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCA11x;set PNCA11;File="PNCA11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCA12x;set PNCA12;File="PNCA12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCA13x;set PNCA13;File="PNCA13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCA14x;set PNCA14;File="PNCA14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCA15x;set PNCA15;File="PNCA15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCA16x;set PNCA16;File="PNCA16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCA17x;set PNCA17;File="PNCA17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCA18x;set PNCA18;File="PNCA18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCA19x;set PNCA19;File="PNCA19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCN11x;set PNCN11;File="PNCN11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCN12x;set PNCN12;File="PNCN12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCN13x;set PNCN13;File="PNCN13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCN14x;set PNCN14;File="PNCN14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCN15x;set PNCN15;File="PNCN15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCN16x;set PNCN16;File="PNCN16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCN17x;set PNCN17;File="PNCN17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCN18x;set PNCN18;File="PNCN18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCN19x;set PNCN19;File="PNCN19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCP11x;set PNCP11;File="PNCP11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCP12x;set PNCP12;File="PNCP12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCP13x;set PNCP13;File="PNCP13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCP14x;set PNCP14;File="PNCP14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCP15x;set PNCP15;File="PNCP15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCP16x;set PNCP16;File="PNCP16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCP17x;set PNCP17;File="PNCP17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCP18x;set PNCP18;File="PNCP18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCP19x;set PNCP19;File="PNCP19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCO11x;set PNCO11;File="PNCO11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCO12x;set PNCO12;File="PNCO12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCO13x;set PNCO13;File="PNCO13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCO14x;set PNCO14;File="PNCO14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCO15x;set PNCO15;File="PNCO15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCO16x;set PNCO16;File="PNCO16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCO17x;set PNCO17;File="PNCO17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCO18x;set PNCO18;File="PNCO18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCO19x;set PNCO19;File="PNCO19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCH11x;set PNCH11;File="PNCH11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCH12x;set PNCH12;File="PNCH12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCH13x;set PNCH13;File="PNCH13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCH14x;set PNCH14;File="PNCH14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCH15x;set PNCH15;File="PNCH15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCH16x;set PNCH16;File="PNCH16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCH17x;set PNCH17;File="PNCH17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCH18x;set PNCH18;File="PNCH18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data PNCH19x;set PNCH19;File="PNCH19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
 
data CheckSource_5Yr_PNC;retain File Notes;set 
PNCT11x PNCT12x PNCT13x PNCT14x PNCT15x PNCT16x PNCT17x PNCT18x PNCT19x PNCM11x PNCM12x PNCM13x PNCM14x PNCM15x PNCM16x PNCM17x PNCM18x PNCM19x 
PNCF11x PNCF12x PNCF13x PNCF14x PNCF15x PNCF16x PNCF17x PNCF18x PNCF19x PNCW11x PNCW12x PNCW13x PNCW14x PNCW15x PNCW16x PNCW17x PNCW18x PNCW19x 
PNCB11x PNCB12x PNCB13x PNCB14x PNCB15x PNCB16x PNCB17x PNCB18x PNCB19x PNCA11x PNCA12x PNCA13x PNCA14x PNCA15x PNCA16x PNCA17x PNCA18x PNCA19x 
PNCN11x PNCN12x PNCN13x PNCN14x PNCN15x PNCN16x PNCN17x PNCN18x PNCN19x PNCP11x PNCP12x PNCP13x PNCP14x PNCP15x PNCP16x PNCP17x PNCP18x PNCP19x 
PNCO11x PNCO12x PNCO13x PNCO14x PNCO15x PNCO16x PNCO17x PNCO18x PNCO19x PNCH11x PNCH12x PNCH13x PNCH14x PNCH15x PNCH16x PNCH17x PNCH18x PNCH19x;
run;
proc print data=CheckSource_5Yr_PNC;run;
*/

 
 
 
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Importing 5-Year Data - Teen Birth per Live Birth (TBB) *********************************************************************************************************************/
/* Importing 5-Year Data - Teen Birth per Live Birth (TBB) *********************************************************************************************************************/
/* Importing 5-Year Data - Teen Birth per Live Birth (TBB) *********************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/

data TBBT11;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_2007_2011.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBT12;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_2008_2012.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBT13;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_2009_2013.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBT14;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_2010_2014.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBT15;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_2011_2015.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBT16;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_2012_2016.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBT17;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_2013_2017.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBT18;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_2014_2018.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBT19;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_2015_2019.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBM11;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_Male_2007_2011.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBM12;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_Male_2008_2012.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBM13;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_Male_2009_2013.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBM14;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_Male_2010_2014.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBM15;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_Male_2011_2015.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBM16;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_Male_2012_2016.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBM17;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_Male_2013_2017.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBM18;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_Male_2014_2018.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBM19;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_Male_2015_2019.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBF11;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_Female_2007_2011.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBF12;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_Female_2008_2012.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBF13;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_Female_2009_2013.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBF14;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_Female_2010_2014.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBF15;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_Female_2011_2015.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBF16;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_Female_2012_2016.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBF17;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_Female_2013_2017.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBF18;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_Female_2014_2018.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBF19;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_Female_2015_2019.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBW11;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_NonHispanicWh_2007_2011.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBW12;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_NonHispanicWh_2008_2012.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBW13;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_NonHispanicWh_2009_2013.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBW14;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_NonHispanicWh_2010_2014.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBW15;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_NonHispanicWh_2011_2015.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBW16;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_NonHispanicWh_2012_2016.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBW17;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_NonHispanicWh_2013_2017.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBW18;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_NonHispanicWh_2014_2018.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBW19;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_NonHispanicWh_2015_2019.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBB11;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_AllHispanicBK_2007_2011.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBB12;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_AllHispanicBK_2008_2012.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBB13;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_AllHispanicBK_2009_2013.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBB14;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_AllHispanicBK_2010_2014.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBB15;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_AllHispanicBK_2011_2015.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBB16;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_AllHispanicBK_2012_2016.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBB17;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_AllHispanicBK_2013_2017.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBB18;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_AllHispanicBK_2014_2018.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBB19;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_AllHispanicBK_2015_2019.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBA11;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_AllHispanicAsian_2007_2011.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBA12;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_AllHispanicAsian_2008_2012.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBA13;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_AllHispanicAsian_2009_2013.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBA14;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_AllHispanicAsian_2010_2014.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBA15;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_AllHispanicAsian_2011_2015.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBA16;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_AllHispanicAsian_2012_2016.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBA17;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_AllHispanicAsian_2013_2017.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBA18;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_AllHispanicAsian_2014_2018.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBA19;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_AllHispanicAsian_2015_2019.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBN11;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_NativeAmerican_2007_2011.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBN12;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_NativeAmerican_2008_2012.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBN13;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_NativeAmerican_2009_2013.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBN14;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_NativeAmerican_2010_2014.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBN15;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_NativeAmerican_2011_2015.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBN16;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_NativeAmerican_2012_2016.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBN17;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_NativeAmerican_2013_2017.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBN18;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_NativeAmerican_2014_2018.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBN19;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_NativeAmerican_2015_2019.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBP11;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_NHPI_2007_2011.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBP12;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_NHPI_2008_2012.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBP13;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_NHPI_2009_2013.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBP14;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_NHPI_2010_2014.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBP15;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_NHPI_2011_2015.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBP16;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_NHPI_2012_2016.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBP17;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_NHPI_2013_2017.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBP18;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_NHPI_2014_2018.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBP19;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_NHPI_2015_2019.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBO11;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_Morerace_2007_2011.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBO12;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_Morerace_2008_2012.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBO13;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_Morerace_2009_2013.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBO14;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_Morerace_2010_2014.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBO15;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_Morerace_2011_2015.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBO16;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_Morerace_2012_2016.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBO17;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_Morerace_2013_2017.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBO18;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_Morerace_2014_2018.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBO19;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_Morerace_2015_2019.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBH11;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_Hispanic_2007_2011.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBH12;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_Hispanic_2008_2012.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBH13;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_Hispanic_2009_2013.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBH14;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_Hispanic_2010_2014.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBH15;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_Hispanic_2011_2015.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBH16;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_Hispanic_2012_2016.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBH17;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_Hispanic_2013_2017.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBH18;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_Hispanic_2014_2018.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBBH19;infile "Z:\CDCK01\Data_County\Birth\Teen birth (20)_5Y\Teen birth (20)_Hispanic_2015_2019.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
 
/* Changing Variable Names & Keeping Necessary Variables */
data TBBT11a(rename=(Births=TBBT5));set TBBT11;if Notes="";Year=2011;keep FIPS Year Births;run;
data TBBT12a(rename=(Births=TBBT5));set TBBT12;if Notes="";Year=2012;keep FIPS Year Births;run;
data TBBT13a(rename=(Births=TBBT5));set TBBT13;if Notes="";Year=2013;keep FIPS Year Births;run;
data TBBT14a(rename=(Births=TBBT5));set TBBT14;if Notes="";Year=2014;keep FIPS Year Births;run;
data TBBT15a(rename=(Births=TBBT5));set TBBT15;if Notes="";Year=2015;keep FIPS Year Births;run;
data TBBT16a(rename=(Births=TBBT5));set TBBT16;if Notes="";Year=2016;keep FIPS Year Births;run;
data TBBT17a(rename=(Births=TBBT5));set TBBT17;if Notes="";Year=2017;keep FIPS Year Births;run;
data TBBT18a(rename=(Births=TBBT5));set TBBT18;if Notes="";Year=2018;keep FIPS Year Births;run;
data TBBT19a(rename=(Births=TBBT5));set TBBT19;if Notes="";Year=2019;keep FIPS Year Births;run;
data TBBM11a(rename=(Births=TBBM5));set TBBM11;if Notes="";Year=2011;keep FIPS Year Births;run;
data TBBM12a(rename=(Births=TBBM5));set TBBM12;if Notes="";Year=2012;keep FIPS Year Births;run;
data TBBM13a(rename=(Births=TBBM5));set TBBM13;if Notes="";Year=2013;keep FIPS Year Births;run;
data TBBM14a(rename=(Births=TBBM5));set TBBM14;if Notes="";Year=2014;keep FIPS Year Births;run;
data TBBM15a(rename=(Births=TBBM5));set TBBM15;if Notes="";Year=2015;keep FIPS Year Births;run;
data TBBM16a(rename=(Births=TBBM5));set TBBM16;if Notes="";Year=2016;keep FIPS Year Births;run;
data TBBM17a(rename=(Births=TBBM5));set TBBM17;if Notes="";Year=2017;keep FIPS Year Births;run;
data TBBM18a(rename=(Births=TBBM5));set TBBM18;if Notes="";Year=2018;keep FIPS Year Births;run;
data TBBM19a(rename=(Births=TBBM5));set TBBM19;if Notes="";Year=2019;keep FIPS Year Births;run;
data TBBF11a(rename=(Births=TBBF5));set TBBF11;if Notes="";Year=2011;keep FIPS Year Births;run;
data TBBF12a(rename=(Births=TBBF5));set TBBF12;if Notes="";Year=2012;keep FIPS Year Births;run;
data TBBF13a(rename=(Births=TBBF5));set TBBF13;if Notes="";Year=2013;keep FIPS Year Births;run;
data TBBF14a(rename=(Births=TBBF5));set TBBF14;if Notes="";Year=2014;keep FIPS Year Births;run;
data TBBF15a(rename=(Births=TBBF5));set TBBF15;if Notes="";Year=2015;keep FIPS Year Births;run;
data TBBF16a(rename=(Births=TBBF5));set TBBF16;if Notes="";Year=2016;keep FIPS Year Births;run;
data TBBF17a(rename=(Births=TBBF5));set TBBF17;if Notes="";Year=2017;keep FIPS Year Births;run;
data TBBF18a(rename=(Births=TBBF5));set TBBF18;if Notes="";Year=2018;keep FIPS Year Births;run;
data TBBF19a(rename=(Births=TBBF5));set TBBF19;if Notes="";Year=2019;keep FIPS Year Births;run;
data TBBW11a(rename=(Births=TBBW5));set TBBW11;if Notes="";Year=2011;keep FIPS Year Births;run;
data TBBW12a(rename=(Births=TBBW5));set TBBW12;if Notes="";Year=2012;keep FIPS Year Births;run;
data TBBW13a(rename=(Births=TBBW5));set TBBW13;if Notes="";Year=2013;keep FIPS Year Births;run;
data TBBW14a(rename=(Births=TBBW5));set TBBW14;if Notes="";Year=2014;keep FIPS Year Births;run;
data TBBW15a(rename=(Births=TBBW5));set TBBW15;if Notes="";Year=2015;keep FIPS Year Births;run;
data TBBW16a(rename=(Births=TBBW5));set TBBW16;if Notes="";Year=2016;keep FIPS Year Births;run;
data TBBW17a(rename=(Births=TBBW5));set TBBW17;if Notes="";Year=2017;keep FIPS Year Births;run;
data TBBW18a(rename=(Births=TBBW5));set TBBW18;if Notes="";Year=2018;keep FIPS Year Births;run;
data TBBW19a(rename=(Births=TBBW5));set TBBW19;if Notes="";Year=2019;keep FIPS Year Births;run;
data TBBB11a(rename=(Births=TBBB5));set TBBB11;if Notes="";Year=2011;keep FIPS Year Births;run;
data TBBB12a(rename=(Births=TBBB5));set TBBB12;if Notes="";Year=2012;keep FIPS Year Births;run;
data TBBB13a(rename=(Births=TBBB5));set TBBB13;if Notes="";Year=2013;keep FIPS Year Births;run;
data TBBB14a(rename=(Births=TBBB5));set TBBB14;if Notes="";Year=2014;keep FIPS Year Births;run;
data TBBB15a(rename=(Births=TBBB5));set TBBB15;if Notes="";Year=2015;keep FIPS Year Births;run;
data TBBB16a(rename=(Births=TBBB5));set TBBB16;if Notes="";Year=2016;keep FIPS Year Births;run;
data TBBB17a(rename=(Births=TBBB5));set TBBB17;if Notes="";Year=2017;keep FIPS Year Births;run;
data TBBB18a(rename=(Births=TBBB5));set TBBB18;if Notes="";Year=2018;keep FIPS Year Births;run;
data TBBB19a(rename=(Births=TBBB5));set TBBB19;if Notes="";Year=2019;keep FIPS Year Births;run;
data TBBA11a(rename=(Births=TBBA5));set TBBA11;if Notes="";Year=2011;keep FIPS Year Births;run;
data TBBA12a(rename=(Births=TBBA5));set TBBA12;if Notes="";Year=2012;keep FIPS Year Births;run;
data TBBA13a(rename=(Births=TBBA5));set TBBA13;if Notes="";Year=2013;keep FIPS Year Births;run;
data TBBA14a(rename=(Births=TBBA5));set TBBA14;if Notes="";Year=2014;keep FIPS Year Births;run;
data TBBA15a(rename=(Births=TBBA5));set TBBA15;if Notes="";Year=2015;keep FIPS Year Births;run;
data TBBA16a(rename=(Births=TBBA5));set TBBA16;if Notes="";Year=2016;keep FIPS Year Births;run;
data TBBA17a(rename=(Births=TBBA5));set TBBA17;if Notes="";Year=2017;keep FIPS Year Births;run;
data TBBA18a(rename=(Births=TBBA5));set TBBA18;if Notes="";Year=2018;keep FIPS Year Births;run;
data TBBA19a(rename=(Births=TBBA5));set TBBA19;if Notes="";Year=2019;keep FIPS Year Births;run;
data TBBN11a(rename=(Births=TBBN5));set TBBN11;if Notes="";Year=2011;keep FIPS Year Births;run;
data TBBN12a(rename=(Births=TBBN5));set TBBN12;if Notes="";Year=2012;keep FIPS Year Births;run;
data TBBN13a(rename=(Births=TBBN5));set TBBN13;if Notes="";Year=2013;keep FIPS Year Births;run;
data TBBN14a(rename=(Births=TBBN5));set TBBN14;if Notes="";Year=2014;keep FIPS Year Births;run;
data TBBN15a(rename=(Births=TBBN5));set TBBN15;if Notes="";Year=2015;keep FIPS Year Births;run;
data TBBN16a(rename=(Births=TBBN5));set TBBN16;if Notes="";Year=2016;keep FIPS Year Births;run;
data TBBN17a(rename=(Births=TBBN5));set TBBN17;if Notes="";Year=2017;keep FIPS Year Births;run;
data TBBN18a(rename=(Births=TBBN5));set TBBN18;if Notes="";Year=2018;keep FIPS Year Births;run;
data TBBN19a(rename=(Births=TBBN5));set TBBN19;if Notes="";Year=2019;keep FIPS Year Births;run;
data TBBP11a(rename=(Births=TBBP5));set TBBP11;if Notes="";Year=2011;keep FIPS Year Births;run;
data TBBP12a(rename=(Births=TBBP5));set TBBP12;if Notes="";Year=2012;keep FIPS Year Births;run;
data TBBP13a(rename=(Births=TBBP5));set TBBP13;if Notes="";Year=2013;keep FIPS Year Births;run;
data TBBP14a(rename=(Births=TBBP5));set TBBP14;if Notes="";Year=2014;keep FIPS Year Births;run;
data TBBP15a(rename=(Births=TBBP5));set TBBP15;if Notes="";Year=2015;keep FIPS Year Births;run;
data TBBP16a(rename=(Births=TBBP5));set TBBP16;if Notes="";Year=2016;keep FIPS Year Births;run;
data TBBP17a(rename=(Births=TBBP5));set TBBP17;if Notes="";Year=2017;keep FIPS Year Births;run;
data TBBP18a(rename=(Births=TBBP5));set TBBP18;if Notes="";Year=2018;keep FIPS Year Births;run;
data TBBP19a(rename=(Births=TBBP5));set TBBP19;if Notes="";Year=2019;keep FIPS Year Births;run;
data TBBO11a(rename=(Births=TBBO5));set TBBO11;if Notes="";Year=2011;keep FIPS Year Births;run;
data TBBO12a(rename=(Births=TBBO5));set TBBO12;if Notes="";Year=2012;keep FIPS Year Births;run;
data TBBO13a(rename=(Births=TBBO5));set TBBO13;if Notes="";Year=2013;keep FIPS Year Births;run;
data TBBO14a(rename=(Births=TBBO5));set TBBO14;if Notes="";Year=2014;keep FIPS Year Births;run;
data TBBO15a(rename=(Births=TBBO5));set TBBO15;if Notes="";Year=2015;keep FIPS Year Births;run;
data TBBO16a(rename=(Births=TBBO5));set TBBO16;if Notes="";Year=2016;keep FIPS Year Births;run;
data TBBO17a(rename=(Births=TBBO5));set TBBO17;if Notes="";Year=2017;keep FIPS Year Births;run;
data TBBO18a(rename=(Births=TBBO5));set TBBO18;if Notes="";Year=2018;keep FIPS Year Births;run;
data TBBO19a(rename=(Births=TBBO5));set TBBO19;if Notes="";Year=2019;keep FIPS Year Births;run;
data TBBH11a(rename=(Births=TBBH5));set TBBH11;if Notes="";Year=2011;keep FIPS Year Births;run;
data TBBH12a(rename=(Births=TBBH5));set TBBH12;if Notes="";Year=2012;keep FIPS Year Births;run;
data TBBH13a(rename=(Births=TBBH5));set TBBH13;if Notes="";Year=2013;keep FIPS Year Births;run;
data TBBH14a(rename=(Births=TBBH5));set TBBH14;if Notes="";Year=2014;keep FIPS Year Births;run;
data TBBH15a(rename=(Births=TBBH5));set TBBH15;if Notes="";Year=2015;keep FIPS Year Births;run;
data TBBH16a(rename=(Births=TBBH5));set TBBH16;if Notes="";Year=2016;keep FIPS Year Births;run;
data TBBH17a(rename=(Births=TBBH5));set TBBH17;if Notes="";Year=2017;keep FIPS Year Births;run;
data TBBH18a(rename=(Births=TBBH5));set TBBH18;if Notes="";Year=2018;keep FIPS Year Births;run;
data TBBH19a(rename=(Births=TBBH5));set TBBH19;if Notes="";Year=2019;keep FIPS Year Births;run;

 
 
 
 
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Troubleshooting -- Checking 5-Year Data - Teen Birth per Live Birth (TBB): Source *******************************************************************************************/
/* Troubleshooting -- Checking 5-Year Data - Teen Birth per Live Birth (TBB): Source *******************************************************************************************/
/* Troubleshooting -- Checking 5-Year Data - Teen Birth per Live Birth (TBB): Source *******************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* "Notes" of txt files have information about query paramters.
   For example, LWBW1 file should have query parameters for ethnicity (non-Hispanic), race (White alone), birth outcome (birth weight), etc.
   The below code will extract "Notes" and create a table to check whether each file is created based on correct query parameters. */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*
data TBBT11x;set TBBT11;File="TBBT11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBT12x;set TBBT12;File="TBBT12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBT13x;set TBBT13;File="TBBT13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBT14x;set TBBT14;File="TBBT14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBT15x;set TBBT15;File="TBBT15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBT16x;set TBBT16;File="TBBT16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBT17x;set TBBT17;File="TBBT17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBT18x;set TBBT18;File="TBBT18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBT19x;set TBBT19;File="TBBT19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBM11x;set TBBM11;File="TBBM11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBM12x;set TBBM12;File="TBBM12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBM13x;set TBBM13;File="TBBM13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBM14x;set TBBM14;File="TBBM14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBM15x;set TBBM15;File="TBBM15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBM16x;set TBBM16;File="TBBM16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBM17x;set TBBM17;File="TBBM17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBM18x;set TBBM18;File="TBBM18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBM19x;set TBBM19;File="TBBM19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBF11x;set TBBF11;File="TBBF11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBF12x;set TBBF12;File="TBBF12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBF13x;set TBBF13;File="TBBF13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBF14x;set TBBF14;File="TBBF14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBF15x;set TBBF15;File="TBBF15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBF16x;set TBBF16;File="TBBF16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBF17x;set TBBF17;File="TBBF17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBF18x;set TBBF18;File="TBBF18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBF19x;set TBBF19;File="TBBF19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBW11x;set TBBW11;File="TBBW11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBW12x;set TBBW12;File="TBBW12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBW13x;set TBBW13;File="TBBW13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBW14x;set TBBW14;File="TBBW14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBW15x;set TBBW15;File="TBBW15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBW16x;set TBBW16;File="TBBW16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBW17x;set TBBW17;File="TBBW17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBW18x;set TBBW18;File="TBBW18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBW19x;set TBBW19;File="TBBW19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBB11x;set TBBB11;File="TBBB11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBB12x;set TBBB12;File="TBBB12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBB13x;set TBBB13;File="TBBB13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBB14x;set TBBB14;File="TBBB14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBB15x;set TBBB15;File="TBBB15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBB16x;set TBBB16;File="TBBB16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBB17x;set TBBB17;File="TBBB17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBB18x;set TBBB18;File="TBBB18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBB19x;set TBBB19;File="TBBB19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBA11x;set TBBA11;File="TBBA11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBA12x;set TBBA12;File="TBBA12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBA13x;set TBBA13;File="TBBA13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBA14x;set TBBA14;File="TBBA14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBA15x;set TBBA15;File="TBBA15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBA16x;set TBBA16;File="TBBA16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBA17x;set TBBA17;File="TBBA17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBA18x;set TBBA18;File="TBBA18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBA19x;set TBBA19;File="TBBA19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBN11x;set TBBN11;File="TBBN11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBN12x;set TBBN12;File="TBBN12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBN13x;set TBBN13;File="TBBN13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBN14x;set TBBN14;File="TBBN14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBN15x;set TBBN15;File="TBBN15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBN16x;set TBBN16;File="TBBN16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBN17x;set TBBN17;File="TBBN17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBN18x;set TBBN18;File="TBBN18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBN19x;set TBBN19;File="TBBN19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBP11x;set TBBP11;File="TBBP11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBP12x;set TBBP12;File="TBBP12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBP13x;set TBBP13;File="TBBP13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBP14x;set TBBP14;File="TBBP14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBP15x;set TBBP15;File="TBBP15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBP16x;set TBBP16;File="TBBP16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBP17x;set TBBP17;File="TBBP17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBP18x;set TBBP18;File="TBBP18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBP19x;set TBBP19;File="TBBP19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBO11x;set TBBO11;File="TBBO11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBO12x;set TBBO12;File="TBBO12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBO13x;set TBBO13;File="TBBO13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBO14x;set TBBO14;File="TBBO14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBO15x;set TBBO15;File="TBBO15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBO16x;set TBBO16;File="TBBO16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBO17x;set TBBO17;File="TBBO17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBO18x;set TBBO18;File="TBBO18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBO19x;set TBBO19;File="TBBO19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBH11x;set TBBH11;File="TBBH11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBH12x;set TBBH12;File="TBBH12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBH13x;set TBBH13;File="TBBH13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBH14x;set TBBH14;File="TBBH14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBH15x;set TBBH15;File="TBBH15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBH16x;set TBBH16;File="TBBH16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBH17x;set TBBH17;File="TBBH17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBH18x;set TBBH18;File="TBBH18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBBH19x;set TBBH19;File="TBBH19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
 
data CheckSource_5Yr_TBB;retain File Notes;set 
TBBT11x TBBT12x TBBT13x TBBT14x TBBT15x TBBT16x TBBT17x TBBT18x TBBT19x TBBM11x TBBM12x TBBM13x TBBM14x TBBM15x TBBM16x TBBM17x TBBM18x TBBM19x 
TBBF11x TBBF12x TBBF13x TBBF14x TBBF15x TBBF16x TBBF17x TBBF18x TBBF19x TBBW11x TBBW12x TBBW13x TBBW14x TBBW15x TBBW16x TBBW17x TBBW18x TBBW19x 
TBBB11x TBBB12x TBBB13x TBBB14x TBBB15x TBBB16x TBBB17x TBBB18x TBBB19x TBBA11x TBBA12x TBBA13x TBBA14x TBBA15x TBBA16x TBBA17x TBBA18x TBBA19x 
TBBN11x TBBN12x TBBN13x TBBN14x TBBN15x TBBN16x TBBN17x TBBN18x TBBN19x TBBP11x TBBP12x TBBP13x TBBP14x TBBP15x TBBP16x TBBP17x TBBP18x TBBP19x 
TBBO11x TBBO12x TBBO13x TBBO14x TBBO15x TBBO16x TBBO17x TBBO18x TBBO19x TBBH11x TBBH12x TBBH13x TBBH14x TBBH15x TBBH16x TBBH17x TBBH18x TBBH19x;
run;
proc print data=CheckSource_5Yr_TBB;run;
*/

 
 
 
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Importing 5-Year Data - Teen Birth per Teen (TBT) ***************************************************************************************************************************/
/* Importing 5-Year Data - Teen Birth per Teen (TBT) ***************************************************************************************************************************/
/* Importing 5-Year Data - Teen Birth per Teen (TBT) ***************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* "Notes" of txt files have information about query paramters.
   For example, LWBW1 file should have query parameters for ethnicity (non-Hispanic), race (White alone), birth outcome (birth weight), etc.
   The below code will extract "Notes" and create a table to check whether each file is created based on correct query parameters. */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/

data TBTT11;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_2007_2011.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTT12;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_2008_2012.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTT13;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_2009_2013.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTT14;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_2010_2014.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTT15;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_2011_2015.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTT16;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_2012_2016.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTT17;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_2013_2017.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTT18;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_2014_2018.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTT19;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_2015_2019.txt"                  dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTM11;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_Male_2007_2011.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTM12;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_Male_2008_2012.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTM13;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_Male_2009_2013.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTM14;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_Male_2010_2014.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTM15;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_Male_2011_2015.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTM16;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_Male_2012_2016.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTM17;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_Male_2013_2017.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTM18;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_Male_2014_2018.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTM19;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_Male_2015_2019.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTF11;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_Female_2007_2011.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTF12;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_Female_2008_2012.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTF13;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_Female_2009_2013.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTF14;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_Female_2010_2014.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTF15;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_Female_2011_2015.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTF16;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_Female_2012_2016.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTF17;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_Female_2013_2017.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTF18;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_Female_2014_2018.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTF19;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_Female_2015_2019.txt"           dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTW11;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_NonHispanicWh_2007_2011.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTW12;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_NonHispanicWh_2008_2012.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTW13;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_NonHispanicWh_2009_2013.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTW14;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_NonHispanicWh_2010_2014.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTW15;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_NonHispanicWh_2011_2015.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTW16;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_NonHispanicWh_2012_2016.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTW17;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_NonHispanicWh_2013_2017.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTW18;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_NonHispanicWh_2014_2018.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTW19;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_NonHispanicWh_2015_2019.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTB11;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_AllHispanicBK_2007_2011.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTB12;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_AllHispanicBK_2008_2012.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTB13;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_AllHispanicBK_2009_2013.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTB14;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_AllHispanicBK_2010_2014.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTB15;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_AllHispanicBK_2011_2015.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTB16;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_AllHispanicBK_2012_2016.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTB17;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_AllHispanicBK_2013_2017.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTB18;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_AllHispanicBK_2014_2018.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTB19;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_AllHispanicBK_2015_2019.txt"    dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTA11;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_AllHispanicAsian_2007_2011.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTA12;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_AllHispanicAsian_2008_2012.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTA13;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_AllHispanicAsian_2009_2013.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTA14;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_AllHispanicAsian_2010_2014.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTA15;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_AllHispanicAsian_2011_2015.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTA16;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_AllHispanicAsian_2012_2016.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTA17;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_AllHispanicAsian_2013_2017.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTA18;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_AllHispanicAsian_2014_2018.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTA19;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_AllHispanicAsian_2015_2019.txt" dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTN11;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_NativeAmerican_2007_2011.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTN12;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_NativeAmerican_2008_2012.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTN13;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_NativeAmerican_2009_2013.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTN14;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_NativeAmerican_2010_2014.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTN15;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_NativeAmerican_2011_2015.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTN16;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_NativeAmerican_2012_2016.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTN17;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_NativeAmerican_2013_2017.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTN18;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_NativeAmerican_2014_2018.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTN19;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_NativeAmerican_2015_2019.txt"   dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTP11;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_NHPI_2007_2011.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTP12;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_NHPI_2008_2012.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTP13;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_NHPI_2009_2013.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTP14;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_NHPI_2010_2014.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTP15;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_NHPI_2011_2015.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTP16;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_NHPI_2012_2016.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTP17;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_NHPI_2013_2017.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTP18;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_NHPI_2014_2018.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTP19;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_NHPI_2015_2019.txt"             dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTO11;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_Morerace_2007_2011.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTO12;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_Morerace_2008_2012.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTO13;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_Morerace_2009_2013.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTO14;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_Morerace_2010_2014.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTO15;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_Morerace_2011_2015.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTO16;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_Morerace_2012_2016.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTO17;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_Morerace_2013_2017.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTO18;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_Morerace_2014_2018.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTO19;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_Morerace_2015_2019.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTH11;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_Hispanic_2007_2011.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTH12;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_Hispanic_2008_2012.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTH13;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_Hispanic_2009_2013.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTH14;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_Hispanic_2010_2014.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTH15;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_Hispanic_2011_2015.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTH16;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_Hispanic_2012_2016.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTH17;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_Hispanic_2013_2017.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTH18;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_Hispanic_2014_2018.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
data TBTH19;infile "Z:\CDCK01\Data_County\Birth\Teen birth (15-19)_5Y\Teen birth (15-19)_Hispanic_2015_2019.txt"         dlm='09'x dsd lrecl=2000 truncover firstobs=2;length Notes $200 County $50 FIPS $5 Births $20;input Notes $ County $ FIPS $ Births $;run;
 
/* Changing Variable Names & Keeping Necessary Variables */
data TBTT11a(rename=(Births=TBTT5));set TBTT11;if Notes="";Year=2011;keep FIPS Year Births;run;
data TBTT12a(rename=(Births=TBTT5));set TBTT12;if Notes="";Year=2012;keep FIPS Year Births;run;
data TBTT13a(rename=(Births=TBTT5));set TBTT13;if Notes="";Year=2013;keep FIPS Year Births;run;
data TBTT14a(rename=(Births=TBTT5));set TBTT14;if Notes="";Year=2014;keep FIPS Year Births;run;
data TBTT15a(rename=(Births=TBTT5));set TBTT15;if Notes="";Year=2015;keep FIPS Year Births;run;
data TBTT16a(rename=(Births=TBTT5));set TBTT16;if Notes="";Year=2016;keep FIPS Year Births;run;
data TBTT17a(rename=(Births=TBTT5));set TBTT17;if Notes="";Year=2017;keep FIPS Year Births;run;
data TBTT18a(rename=(Births=TBTT5));set TBTT18;if Notes="";Year=2018;keep FIPS Year Births;run;
data TBTT19a(rename=(Births=TBTT5));set TBTT19;if Notes="";Year=2019;keep FIPS Year Births;run;
data TBTM11a(rename=(Births=TBTM5));set TBTM11;if Notes="";Year=2011;keep FIPS Year Births;run;
data TBTM12a(rename=(Births=TBTM5));set TBTM12;if Notes="";Year=2012;keep FIPS Year Births;run;
data TBTM13a(rename=(Births=TBTM5));set TBTM13;if Notes="";Year=2013;keep FIPS Year Births;run;
data TBTM14a(rename=(Births=TBTM5));set TBTM14;if Notes="";Year=2014;keep FIPS Year Births;run;
data TBTM15a(rename=(Births=TBTM5));set TBTM15;if Notes="";Year=2015;keep FIPS Year Births;run;
data TBTM16a(rename=(Births=TBTM5));set TBTM16;if Notes="";Year=2016;keep FIPS Year Births;run;
data TBTM17a(rename=(Births=TBTM5));set TBTM17;if Notes="";Year=2017;keep FIPS Year Births;run;
data TBTM18a(rename=(Births=TBTM5));set TBTM18;if Notes="";Year=2018;keep FIPS Year Births;run;
data TBTM19a(rename=(Births=TBTM5));set TBTM19;if Notes="";Year=2019;keep FIPS Year Births;run;
data TBTF11a(rename=(Births=TBTF5));set TBTF11;if Notes="";Year=2011;keep FIPS Year Births;run;
data TBTF12a(rename=(Births=TBTF5));set TBTF12;if Notes="";Year=2012;keep FIPS Year Births;run;
data TBTF13a(rename=(Births=TBTF5));set TBTF13;if Notes="";Year=2013;keep FIPS Year Births;run;
data TBTF14a(rename=(Births=TBTF5));set TBTF14;if Notes="";Year=2014;keep FIPS Year Births;run;
data TBTF15a(rename=(Births=TBTF5));set TBTF15;if Notes="";Year=2015;keep FIPS Year Births;run;
data TBTF16a(rename=(Births=TBTF5));set TBTF16;if Notes="";Year=2016;keep FIPS Year Births;run;
data TBTF17a(rename=(Births=TBTF5));set TBTF17;if Notes="";Year=2017;keep FIPS Year Births;run;
data TBTF18a(rename=(Births=TBTF5));set TBTF18;if Notes="";Year=2018;keep FIPS Year Births;run;
data TBTF19a(rename=(Births=TBTF5));set TBTF19;if Notes="";Year=2019;keep FIPS Year Births;run;
data TBTW11a(rename=(Births=TBTW5));set TBTW11;if Notes="";Year=2011;keep FIPS Year Births;run;
data TBTW12a(rename=(Births=TBTW5));set TBTW12;if Notes="";Year=2012;keep FIPS Year Births;run;
data TBTW13a(rename=(Births=TBTW5));set TBTW13;if Notes="";Year=2013;keep FIPS Year Births;run;
data TBTW14a(rename=(Births=TBTW5));set TBTW14;if Notes="";Year=2014;keep FIPS Year Births;run;
data TBTW15a(rename=(Births=TBTW5));set TBTW15;if Notes="";Year=2015;keep FIPS Year Births;run;
data TBTW16a(rename=(Births=TBTW5));set TBTW16;if Notes="";Year=2016;keep FIPS Year Births;run;
data TBTW17a(rename=(Births=TBTW5));set TBTW17;if Notes="";Year=2017;keep FIPS Year Births;run;
data TBTW18a(rename=(Births=TBTW5));set TBTW18;if Notes="";Year=2018;keep FIPS Year Births;run;
data TBTW19a(rename=(Births=TBTW5));set TBTW19;if Notes="";Year=2019;keep FIPS Year Births;run;
data TBTB11a(rename=(Births=TBTB5));set TBTB11;if Notes="";Year=2011;keep FIPS Year Births;run;
data TBTB12a(rename=(Births=TBTB5));set TBTB12;if Notes="";Year=2012;keep FIPS Year Births;run;
data TBTB13a(rename=(Births=TBTB5));set TBTB13;if Notes="";Year=2013;keep FIPS Year Births;run;
data TBTB14a(rename=(Births=TBTB5));set TBTB14;if Notes="";Year=2014;keep FIPS Year Births;run;
data TBTB15a(rename=(Births=TBTB5));set TBTB15;if Notes="";Year=2015;keep FIPS Year Births;run;
data TBTB16a(rename=(Births=TBTB5));set TBTB16;if Notes="";Year=2016;keep FIPS Year Births;run;
data TBTB17a(rename=(Births=TBTB5));set TBTB17;if Notes="";Year=2017;keep FIPS Year Births;run;
data TBTB18a(rename=(Births=TBTB5));set TBTB18;if Notes="";Year=2018;keep FIPS Year Births;run;
data TBTB19a(rename=(Births=TBTB5));set TBTB19;if Notes="";Year=2019;keep FIPS Year Births;run;
data TBTA11a(rename=(Births=TBTA5));set TBTA11;if Notes="";Year=2011;keep FIPS Year Births;run;
data TBTA12a(rename=(Births=TBTA5));set TBTA12;if Notes="";Year=2012;keep FIPS Year Births;run;
data TBTA13a(rename=(Births=TBTA5));set TBTA13;if Notes="";Year=2013;keep FIPS Year Births;run;
data TBTA14a(rename=(Births=TBTA5));set TBTA14;if Notes="";Year=2014;keep FIPS Year Births;run;
data TBTA15a(rename=(Births=TBTA5));set TBTA15;if Notes="";Year=2015;keep FIPS Year Births;run;
data TBTA16a(rename=(Births=TBTA5));set TBTA16;if Notes="";Year=2016;keep FIPS Year Births;run;
data TBTA17a(rename=(Births=TBTA5));set TBTA17;if Notes="";Year=2017;keep FIPS Year Births;run;
data TBTA18a(rename=(Births=TBTA5));set TBTA18;if Notes="";Year=2018;keep FIPS Year Births;run;
data TBTA19a(rename=(Births=TBTA5));set TBTA19;if Notes="";Year=2019;keep FIPS Year Births;run;
data TBTN11a(rename=(Births=TBTN5));set TBTN11;if Notes="";Year=2011;keep FIPS Year Births;run;
data TBTN12a(rename=(Births=TBTN5));set TBTN12;if Notes="";Year=2012;keep FIPS Year Births;run;
data TBTN13a(rename=(Births=TBTN5));set TBTN13;if Notes="";Year=2013;keep FIPS Year Births;run;
data TBTN14a(rename=(Births=TBTN5));set TBTN14;if Notes="";Year=2014;keep FIPS Year Births;run;
data TBTN15a(rename=(Births=TBTN5));set TBTN15;if Notes="";Year=2015;keep FIPS Year Births;run;
data TBTN16a(rename=(Births=TBTN5));set TBTN16;if Notes="";Year=2016;keep FIPS Year Births;run;
data TBTN17a(rename=(Births=TBTN5));set TBTN17;if Notes="";Year=2017;keep FIPS Year Births;run;
data TBTN18a(rename=(Births=TBTN5));set TBTN18;if Notes="";Year=2018;keep FIPS Year Births;run;
data TBTN19a(rename=(Births=TBTN5));set TBTN19;if Notes="";Year=2019;keep FIPS Year Births;run;
data TBTP11a(rename=(Births=TBTP5));set TBTP11;if Notes="";Year=2011;keep FIPS Year Births;run;
data TBTP12a(rename=(Births=TBTP5));set TBTP12;if Notes="";Year=2012;keep FIPS Year Births;run;
data TBTP13a(rename=(Births=TBTP5));set TBTP13;if Notes="";Year=2013;keep FIPS Year Births;run;
data TBTP14a(rename=(Births=TBTP5));set TBTP14;if Notes="";Year=2014;keep FIPS Year Births;run;
data TBTP15a(rename=(Births=TBTP5));set TBTP15;if Notes="";Year=2015;keep FIPS Year Births;run;
data TBTP16a(rename=(Births=TBTP5));set TBTP16;if Notes="";Year=2016;keep FIPS Year Births;run;
data TBTP17a(rename=(Births=TBTP5));set TBTP17;if Notes="";Year=2017;keep FIPS Year Births;run;
data TBTP18a(rename=(Births=TBTP5));set TBTP18;if Notes="";Year=2018;keep FIPS Year Births;run;
data TBTP19a(rename=(Births=TBTP5));set TBTP19;if Notes="";Year=2019;keep FIPS Year Births;run;
data TBTO11a(rename=(Births=TBTO5));set TBTO11;if Notes="";Year=2011;keep FIPS Year Births;run;
data TBTO12a(rename=(Births=TBTO5));set TBTO12;if Notes="";Year=2012;keep FIPS Year Births;run;
data TBTO13a(rename=(Births=TBTO5));set TBTO13;if Notes="";Year=2013;keep FIPS Year Births;run;
data TBTO14a(rename=(Births=TBTO5));set TBTO14;if Notes="";Year=2014;keep FIPS Year Births;run;
data TBTO15a(rename=(Births=TBTO5));set TBTO15;if Notes="";Year=2015;keep FIPS Year Births;run;
data TBTO16a(rename=(Births=TBTO5));set TBTO16;if Notes="";Year=2016;keep FIPS Year Births;run;
data TBTO17a(rename=(Births=TBTO5));set TBTO17;if Notes="";Year=2017;keep FIPS Year Births;run;
data TBTO18a(rename=(Births=TBTO5));set TBTO18;if Notes="";Year=2018;keep FIPS Year Births;run;
data TBTO19a(rename=(Births=TBTO5));set TBTO19;if Notes="";Year=2019;keep FIPS Year Births;run;
data TBTH11a(rename=(Births=TBTH5));set TBTH11;if Notes="";Year=2011;keep FIPS Year Births;run;
data TBTH12a(rename=(Births=TBTH5));set TBTH12;if Notes="";Year=2012;keep FIPS Year Births;run;
data TBTH13a(rename=(Births=TBTH5));set TBTH13;if Notes="";Year=2013;keep FIPS Year Births;run;
data TBTH14a(rename=(Births=TBTH5));set TBTH14;if Notes="";Year=2014;keep FIPS Year Births;run;
data TBTH15a(rename=(Births=TBTH5));set TBTH15;if Notes="";Year=2015;keep FIPS Year Births;run;
data TBTH16a(rename=(Births=TBTH5));set TBTH16;if Notes="";Year=2016;keep FIPS Year Births;run;
data TBTH17a(rename=(Births=TBTH5));set TBTH17;if Notes="";Year=2017;keep FIPS Year Births;run;
data TBTH18a(rename=(Births=TBTH5));set TBTH18;if Notes="";Year=2018;keep FIPS Year Births;run;
data TBTH19a(rename=(Births=TBTH5));set TBTH19;if Notes="";Year=2019;keep FIPS Year Births;run;

 
 
 
 
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Troubleshooting -- Checking 5-Year Data - Teen Birth per Teen (TBT): Source *************************************************************************************************/
/* Troubleshooting -- Checking 5-Year Data - Teen Birth per Teen (TBT): Source *************************************************************************************************/
/* Troubleshooting -- Checking 5-Year Data - Teen Birth per Teen (TBT): Source *************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* "Notes" of txt files have information about query paramters.
   For example, LWBW1 file should have query parameters for ethnicity (non-Hispanic), race (White alone), birth outcome (birth weight), etc.
   The below code will extract "Notes" and create a table to check whether each file is created based on correct query parameters. */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*
data TBTT11x;set TBTT11;File="TBTT11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTT12x;set TBTT12;File="TBTT12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTT13x;set TBTT13;File="TBTT13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTT14x;set TBTT14;File="TBTT14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTT15x;set TBTT15;File="TBTT15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTT16x;set TBTT16;File="TBTT16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTT17x;set TBTT17;File="TBTT17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTT18x;set TBTT18;File="TBTT18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTT19x;set TBTT19;File="TBTT19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTM11x;set TBTM11;File="TBTM11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTM12x;set TBTM12;File="TBTM12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTM13x;set TBTM13;File="TBTM13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTM14x;set TBTM14;File="TBTM14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTM15x;set TBTM15;File="TBTM15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTM16x;set TBTM16;File="TBTM16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTM17x;set TBTM17;File="TBTM17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTM18x;set TBTM18;File="TBTM18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTM19x;set TBTM19;File="TBTM19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTF11x;set TBTF11;File="TBTF11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTF12x;set TBTF12;File="TBTF12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTF13x;set TBTF13;File="TBTF13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTF14x;set TBTF14;File="TBTF14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTF15x;set TBTF15;File="TBTF15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTF16x;set TBTF16;File="TBTF16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTF17x;set TBTF17;File="TBTF17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTF18x;set TBTF18;File="TBTF18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTF19x;set TBTF19;File="TBTF19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTW11x;set TBTW11;File="TBTW11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTW12x;set TBTW12;File="TBTW12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTW13x;set TBTW13;File="TBTW13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTW14x;set TBTW14;File="TBTW14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTW15x;set TBTW15;File="TBTW15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTW16x;set TBTW16;File="TBTW16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTW17x;set TBTW17;File="TBTW17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTW18x;set TBTW18;File="TBTW18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTW19x;set TBTW19;File="TBTW19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTB11x;set TBTB11;File="TBTB11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTB12x;set TBTB12;File="TBTB12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTB13x;set TBTB13;File="TBTB13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTB14x;set TBTB14;File="TBTB14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTB15x;set TBTB15;File="TBTB15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTB16x;set TBTB16;File="TBTB16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTB17x;set TBTB17;File="TBTB17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTB18x;set TBTB18;File="TBTB18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTB19x;set TBTB19;File="TBTB19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTA11x;set TBTA11;File="TBTA11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTA12x;set TBTA12;File="TBTA12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTA13x;set TBTA13;File="TBTA13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTA14x;set TBTA14;File="TBTA14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTA15x;set TBTA15;File="TBTA15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTA16x;set TBTA16;File="TBTA16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTA17x;set TBTA17;File="TBTA17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTA18x;set TBTA18;File="TBTA18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTA19x;set TBTA19;File="TBTA19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTN11x;set TBTN11;File="TBTN11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTN12x;set TBTN12;File="TBTN12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTN13x;set TBTN13;File="TBTN13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTN14x;set TBTN14;File="TBTN14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTN15x;set TBTN15;File="TBTN15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTN16x;set TBTN16;File="TBTN16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTN17x;set TBTN17;File="TBTN17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTN18x;set TBTN18;File="TBTN18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTN19x;set TBTN19;File="TBTN19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTP11x;set TBTP11;File="TBTP11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTP12x;set TBTP12;File="TBTP12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTP13x;set TBTP13;File="TBTP13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTP14x;set TBTP14;File="TBTP14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTP15x;set TBTP15;File="TBTP15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTP16x;set TBTP16;File="TBTP16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTP17x;set TBTP17;File="TBTP17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTP18x;set TBTP18;File="TBTP18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTP19x;set TBTP19;File="TBTP19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTO11x;set TBTO11;File="TBTO11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTO12x;set TBTO12;File="TBTO12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTO13x;set TBTO13;File="TBTO13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTO14x;set TBTO14;File="TBTO14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTO15x;set TBTO15;File="TBTO15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTO16x;set TBTO16;File="TBTO16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTO17x;set TBTO17;File="TBTO17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTO18x;set TBTO18;File="TBTO18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTO19x;set TBTO19;File="TBTO19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTH11x;set TBTH11;File="TBTH11";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTH12x;set TBTH12;File="TBTH12";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTH13x;set TBTH13;File="TBTH13";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTH14x;set TBTH14;File="TBTH14";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTH15x;set TBTH15;File="TBTH15";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTH16x;set TBTH16;File="TBTH16";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTH17x;set TBTH17;File="TBTH17";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTH18x;set TBTH18;File="TBTH18";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
data TBTH19x;set TBTH19;File="TBTH19";if substr(Notes,1,7)="Dataset"|substr(Notes,1,4)="Year"|substr(Notes,1,8)="Group By"|substr(Notes,1,22)="Infant Birth Weight 12"|substr(Notes,1,21)="OE Gestational Age 11"|substr(Notes,1,25)="Month Prenatal Care Began"|substr(Notes,1,15)="Age of Mother 9"|substr(Notes,1,6)="Gender"|substr(Notes,1,24)="Mother's Hispanic Origin"|substr(Notes,1,20)="Mother's Single Race";keep File Notes;run;
 
data CheckSource_5Yr_TBT;retain File Notes;set 
TBTT11x TBTT12x TBTT13x TBTT14x TBTT15x TBTT16x TBTT17x TBTT18x TBTT19x TBTM11x TBTM12x TBTM13x TBTM14x TBTM15x TBTM16x TBTM17x TBTM18x TBTM19x 
TBTF11x TBTF12x TBTF13x TBTF14x TBTF15x TBTF16x TBTF17x TBTF18x TBTF19x TBTW11x TBTW12x TBTW13x TBTW14x TBTW15x TBTW16x TBTW17x TBTW18x TBTW19x 
TBTB11x TBTB12x TBTB13x TBTB14x TBTB15x TBTB16x TBTB17x TBTB18x TBTB19x TBTA11x TBTA12x TBTA13x TBTA14x TBTA15x TBTA16x TBTA17x TBTA18x TBTA19x 
TBTN11x TBTN12x TBTN13x TBTN14x TBTN15x TBTN16x TBTN17x TBTN18x TBTN19x TBTP11x TBTP12x TBTP13x TBTP14x TBTP15x TBTP16x TBTP17x TBTP18x TBTP19x 
TBTO11x TBTO12x TBTO13x TBTO14x TBTO15x TBTO16x TBTO17x TBTO18x TBTO19x TBTH11x TBTH12x TBTH13x TBTH14x TBTH15x TBTH16x TBTH17x TBTH18x TBTH19x;
run;
proc print data=CheckSource_5Yr_TBT;run;
*/
 
 
 

/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Merging 1-Year Data *********************************************************************************************************************************************************/
/* Merging 1-Year Data *********************************************************************************************************************************************************/
/* Merging 1-Year Data *********************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/

proc sort data=BIRT1a;by Year FIPS;run;
proc sort data=BIRM1a;by Year FIPS;run;
proc sort data=BIRF1a;by Year FIPS;run;
proc sort data=BIRW1a;by Year FIPS;run;
proc sort data=BIRB1a;by Year FIPS;run;
proc sort data=BIRA1a;by Year FIPS;run;
proc sort data=BIRN1a;by Year FIPS;run;
proc sort data=BIRP1a;by Year FIPS;run;
proc sort data=BIRO1a;by Year FIPS;run;
proc sort data=BIRH1a;by Year FIPS;run;
proc sort data=LBWT1a;by Year FIPS;run;
proc sort data=LBWM1a;by Year FIPS;run;
proc sort data=LBWF1a;by Year FIPS;run;
proc sort data=LBWW1a;by Year FIPS;run;
proc sort data=LBWB1a;by Year FIPS;run;
proc sort data=LBWA1a;by Year FIPS;run;
proc sort data=LBWN1a;by Year FIPS;run;
proc sort data=LBWP1a;by Year FIPS;run;
proc sort data=LBWO1a;by Year FIPS;run;
proc sort data=LBWH1a;by Year FIPS;run;
proc sort data=PTBT1a;by Year FIPS;run;
proc sort data=PTBM1a;by Year FIPS;run;
proc sort data=PTBF1a;by Year FIPS;run;
proc sort data=PTBW1a;by Year FIPS;run;
proc sort data=PTBB1a;by Year FIPS;run;
proc sort data=PTBA1a;by Year FIPS;run;
proc sort data=PTBN1a;by Year FIPS;run;
proc sort data=PTBP1a;by Year FIPS;run;
proc sort data=PTBO1a;by Year FIPS;run;
proc sort data=PTBH1a;by Year FIPS;run;
proc sort data=PNCT1a;by Year FIPS;run;
proc sort data=PNCM1a;by Year FIPS;run;
proc sort data=PNCF1a;by Year FIPS;run;
proc sort data=PNCW1a;by Year FIPS;run;
proc sort data=PNCB1a;by Year FIPS;run;
proc sort data=PNCA1a;by Year FIPS;run;
proc sort data=PNCN1a;by Year FIPS;run;
proc sort data=PNCP1a;by Year FIPS;run;
proc sort data=PNCO1a;by Year FIPS;run;
proc sort data=PNCH1a;by Year FIPS;run;
proc sort data=TBBT1a;by Year FIPS;run;
proc sort data=TBBM1a;by Year FIPS;run;
proc sort data=TBBF1a;by Year FIPS;run;
proc sort data=TBBW1a;by Year FIPS;run;
proc sort data=TBBB1a;by Year FIPS;run;
proc sort data=TBBA1a;by Year FIPS;run;
proc sort data=TBBN1a;by Year FIPS;run;
proc sort data=TBBP1a;by Year FIPS;run;
proc sort data=TBBO1a;by Year FIPS;run;
proc sort data=TBBH1a;by Year FIPS;run;
proc sort data=TBTT1a;by Year FIPS;run;
proc sort data=TBTM1a;by Year FIPS;run;
proc sort data=TBTF1a;by Year FIPS;run;
proc sort data=TBTW1a;by Year FIPS;run;
proc sort data=TBTB1a;by Year FIPS;run;
proc sort data=TBTA1a;by Year FIPS;run;
proc sort data=TBTN1a;by Year FIPS;run;
proc sort data=TBTP1a;by Year FIPS;run;
proc sort data=TBTO1a;by Year FIPS;run;
proc sort data=TBTH1a;by Year FIPS;run;

data BIR1Yr;merge 
BIRT1a BIRM1a BIRF1a BIRW1a BIRB1a BIRA1a BIRN1a BIRP1a BIRO1a BIRH1a LBWT1a LBWM1a LBWF1a LBWW1a LBWB1a LBWA1a LBWN1a LBWP1a LBWO1a LBWH1a 
PTBT1a PTBM1a PTBF1a PTBW1a PTBB1a PTBA1a PTBN1a PTBP1a PTBO1a PTBH1a PNCT1a PNCM1a PNCF1a PNCW1a PNCB1a PNCA1a PNCN1a PNCP1a PNCO1a PNCH1a 
TBBT1a TBBM1a TBBF1a TBBW1a TBBB1a TBBA1a TBBN1a TBBP1a TBBO1a TBBH1a TBTT1a TBTM1a TBTF1a TBTW1a TBTB1a TBTA1a TBTN1a TBTP1a TBTO1a TBTH1a;
by Year FIPS;run;

 
 
 
 
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Stacking Up 5-Year Data from 2011 to 2019 (creating long-form data) AND Merge 5-Year Data ***********************************************************************************/
/* Stacking Up 5-Year Data from 2011 to 2019 (creating long-form data) AND Merge 5-Year Data ***********************************************************************************/
/* Stacking Up 5-Year Data from 2011 to 2019 (creating long-form data) AND Merge 5-Year Data ***********************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/

data BIRT5;set BIRT11a BIRT12a BIRT13a BIRT14a BIRT15a BIRT16a BIRT17a BIRT18a BIRT19a;run;
data BIRM5;set BIRM11a BIRM12a BIRM13a BIRM14a BIRM15a BIRM16a BIRM17a BIRM18a BIRM19a;run;
data BIRF5;set BIRF11a BIRF12a BIRF13a BIRF14a BIRF15a BIRF16a BIRF17a BIRF18a BIRF19a;run;
data BIRW5;set BIRW11a BIRW12a BIRW13a BIRW14a BIRW15a BIRW16a BIRW17a BIRW18a BIRW19a;run;
data BIRB5;set BIRB11a BIRB12a BIRB13a BIRB14a BIRB15a BIRB16a BIRB17a BIRB18a BIRB19a;run;
data BIRA5;set BIRA11a BIRA12a BIRA13a BIRA14a BIRA15a BIRA16a BIRA17a BIRA18a BIRA19a;run;
data BIRN5;set BIRN11a BIRN12a BIRN13a BIRN14a BIRN15a BIRN16a BIRN17a BIRN18a BIRN19a;run;
data BIRP5;set BIRP11a BIRP12a BIRP13a BIRP14a BIRP15a BIRP16a BIRP17a BIRP18a BIRP19a;run;
data BIRO5;set BIRO11a BIRO12a BIRO13a BIRO14a BIRO15a BIRO16a BIRO17a BIRO18a BIRO19a;run;
data BIRH5;set BIRH11a BIRH12a BIRH13a BIRH14a BIRH15a BIRH16a BIRH17a BIRH18a BIRH19a;run;
data LBWT5;set LBWT11a LBWT12a LBWT13a LBWT14a LBWT15a LBWT16a LBWT17a LBWT18a LBWT19a;run;
data LBWM5;set LBWM11a LBWM12a LBWM13a LBWM14a LBWM15a LBWM16a LBWM17a LBWM18a LBWM19a;run;
data LBWF5;set LBWF11a LBWF12a LBWF13a LBWF14a LBWF15a LBWF16a LBWF17a LBWF18a LBWF19a;run;
data LBWW5;set LBWW11a LBWW12a LBWW13a LBWW14a LBWW15a LBWW16a LBWW17a LBWW18a LBWW19a;run;
data LBWB5;set LBWB11a LBWB12a LBWB13a LBWB14a LBWB15a LBWB16a LBWB17a LBWB18a LBWB19a;run;
data LBWA5;set LBWA11a LBWA12a LBWA13a LBWA14a LBWA15a LBWA16a LBWA17a LBWA18a LBWA19a;run;
data LBWN5;set LBWN11a LBWN12a LBWN13a LBWN14a LBWN15a LBWN16a LBWN17a LBWN18a LBWN19a;run;
data LBWP5;set LBWP11a LBWP12a LBWP13a LBWP14a LBWP15a LBWP16a LBWP17a LBWP18a LBWP19a;run;
data LBWO5;set LBWO11a LBWO12a LBWO13a LBWO14a LBWO15a LBWO16a LBWO17a LBWO18a LBWO19a;run;
data LBWH5;set LBWH11a LBWH12a LBWH13a LBWH14a LBWH15a LBWH16a LBWH17a LBWH18a LBWH19a;run;
data PTBT5;set PTBT11a PTBT12a PTBT13a PTBT14a PTBT15a PTBT16a PTBT17a PTBT18a PTBT19a;run;
data PTBM5;set PTBM11a PTBM12a PTBM13a PTBM14a PTBM15a PTBM16a PTBM17a PTBM18a PTBM19a;run;
data PTBF5;set PTBF11a PTBF12a PTBF13a PTBF14a PTBF15a PTBF16a PTBF17a PTBF18a PTBF19a;run;
data PTBW5;set PTBW11a PTBW12a PTBW13a PTBW14a PTBW15a PTBW16a PTBW17a PTBW18a PTBW19a;run;
data PTBB5;set PTBB11a PTBB12a PTBB13a PTBB14a PTBB15a PTBB16a PTBB17a PTBB18a PTBB19a;run;
data PTBA5;set PTBA11a PTBA12a PTBA13a PTBA14a PTBA15a PTBA16a PTBA17a PTBA18a PTBA19a;run;
data PTBN5;set PTBN11a PTBN12a PTBN13a PTBN14a PTBN15a PTBN16a PTBN17a PTBN18a PTBN19a;run;
data PTBP5;set PTBP11a PTBP12a PTBP13a PTBP14a PTBP15a PTBP16a PTBP17a PTBP18a PTBP19a;run;
data PTBO5;set PTBO11a PTBO12a PTBO13a PTBO14a PTBO15a PTBO16a PTBO17a PTBO18a PTBO19a;run;
data PTBH5;set PTBH11a PTBH12a PTBH13a PTBH14a PTBH15a PTBH16a PTBH17a PTBH18a PTBH19a;run;
data PNCT5;set PNCT11a PNCT12a PNCT13a PNCT14a PNCT15a PNCT16a PNCT17a PNCT18a PNCT19a;run;
data PNCM5;set PNCM11a PNCM12a PNCM13a PNCM14a PNCM15a PNCM16a PNCM17a PNCM18a PNCM19a;run;
data PNCF5;set PNCF11a PNCF12a PNCF13a PNCF14a PNCF15a PNCF16a PNCF17a PNCF18a PNCF19a;run;
data PNCW5;set PNCW11a PNCW12a PNCW13a PNCW14a PNCW15a PNCW16a PNCW17a PNCW18a PNCW19a;run;
data PNCB5;set PNCB11a PNCB12a PNCB13a PNCB14a PNCB15a PNCB16a PNCB17a PNCB18a PNCB19a;run;
data PNCA5;set PNCA11a PNCA12a PNCA13a PNCA14a PNCA15a PNCA16a PNCA17a PNCA18a PNCA19a;run;
data PNCN5;set PNCN11a PNCN12a PNCN13a PNCN14a PNCN15a PNCN16a PNCN17a PNCN18a PNCN19a;run;
data PNCP5;set PNCP11a PNCP12a PNCP13a PNCP14a PNCP15a PNCP16a PNCP17a PNCP18a PNCP19a;run;
data PNCO5;set PNCO11a PNCO12a PNCO13a PNCO14a PNCO15a PNCO16a PNCO17a PNCO18a PNCO19a;run;
data PNCH5;set PNCH11a PNCH12a PNCH13a PNCH14a PNCH15a PNCH16a PNCH17a PNCH18a PNCH19a;run;
data TBBT5;set TBBT11a TBBT12a TBBT13a TBBT14a TBBT15a TBBT16a TBBT17a TBBT18a TBBT19a;run;
data TBBM5;set TBBM11a TBBM12a TBBM13a TBBM14a TBBM15a TBBM16a TBBM17a TBBM18a TBBM19a;run;
data TBBF5;set TBBF11a TBBF12a TBBF13a TBBF14a TBBF15a TBBF16a TBBF17a TBBF18a TBBF19a;run;
data TBBW5;set TBBW11a TBBW12a TBBW13a TBBW14a TBBW15a TBBW16a TBBW17a TBBW18a TBBW19a;run;
data TBBB5;set TBBB11a TBBB12a TBBB13a TBBB14a TBBB15a TBBB16a TBBB17a TBBB18a TBBB19a;run;
data TBBA5;set TBBA11a TBBA12a TBBA13a TBBA14a TBBA15a TBBA16a TBBA17a TBBA18a TBBA19a;run;
data TBBN5;set TBBN11a TBBN12a TBBN13a TBBN14a TBBN15a TBBN16a TBBN17a TBBN18a TBBN19a;run;
data TBBP5;set TBBP11a TBBP12a TBBP13a TBBP14a TBBP15a TBBP16a TBBP17a TBBP18a TBBP19a;run;
data TBBO5;set TBBO11a TBBO12a TBBO13a TBBO14a TBBO15a TBBO16a TBBO17a TBBO18a TBBO19a;run;
data TBBH5;set TBBH11a TBBH12a TBBH13a TBBH14a TBBH15a TBBH16a TBBH17a TBBH18a TBBH19a;run;
data TBTT5;set TBTT11a TBTT12a TBTT13a TBTT14a TBTT15a TBTT16a TBTT17a TBTT18a TBTT19a;run;
data TBTM5;set TBTM11a TBTM12a TBTM13a TBTM14a TBTM15a TBTM16a TBTM17a TBTM18a TBTM19a;run;
data TBTF5;set TBTF11a TBTF12a TBTF13a TBTF14a TBTF15a TBTF16a TBTF17a TBTF18a TBTF19a;run;
data TBTW5;set TBTW11a TBTW12a TBTW13a TBTW14a TBTW15a TBTW16a TBTW17a TBTW18a TBTW19a;run;
data TBTB5;set TBTB11a TBTB12a TBTB13a TBTB14a TBTB15a TBTB16a TBTB17a TBTB18a TBTB19a;run;
data TBTA5;set TBTA11a TBTA12a TBTA13a TBTA14a TBTA15a TBTA16a TBTA17a TBTA18a TBTA19a;run;
data TBTN5;set TBTN11a TBTN12a TBTN13a TBTN14a TBTN15a TBTN16a TBTN17a TBTN18a TBTN19a;run;
data TBTP5;set TBTP11a TBTP12a TBTP13a TBTP14a TBTP15a TBTP16a TBTP17a TBTP18a TBTP19a;run;
data TBTO5;set TBTO11a TBTO12a TBTO13a TBTO14a TBTO15a TBTO16a TBTO17a TBTO18a TBTO19a;run;
data TBTH5;set TBTH11a TBTH12a TBTH13a TBTH14a TBTH15a TBTH16a TBTH17a TBTH18a TBTH19a;run;
 
proc sort data=BIRT5;by Year FIPS;run;
proc sort data=BIRM5;by Year FIPS;run;
proc sort data=BIRF5;by Year FIPS;run;
proc sort data=BIRW5;by Year FIPS;run;
proc sort data=BIRB5;by Year FIPS;run;
proc sort data=BIRA5;by Year FIPS;run;
proc sort data=BIRN5;by Year FIPS;run;
proc sort data=BIRP5;by Year FIPS;run;
proc sort data=BIRO5;by Year FIPS;run;
proc sort data=BIRH5;by Year FIPS;run;
proc sort data=LBWT5;by Year FIPS;run;
proc sort data=LBWM5;by Year FIPS;run;
proc sort data=LBWF5;by Year FIPS;run;
proc sort data=LBWW5;by Year FIPS;run;
proc sort data=LBWB5;by Year FIPS;run;
proc sort data=LBWA5;by Year FIPS;run;
proc sort data=LBWN5;by Year FIPS;run;
proc sort data=LBWP5;by Year FIPS;run;
proc sort data=LBWO5;by Year FIPS;run;
proc sort data=LBWH5;by Year FIPS;run;
proc sort data=PTBT5;by Year FIPS;run;
proc sort data=PTBM5;by Year FIPS;run;
proc sort data=PTBF5;by Year FIPS;run;
proc sort data=PTBW5;by Year FIPS;run;
proc sort data=PTBB5;by Year FIPS;run;
proc sort data=PTBA5;by Year FIPS;run;
proc sort data=PTBN5;by Year FIPS;run;
proc sort data=PTBP5;by Year FIPS;run;
proc sort data=PTBO5;by Year FIPS;run;
proc sort data=PTBH5;by Year FIPS;run;
proc sort data=PNCT5;by Year FIPS;run;
proc sort data=PNCM5;by Year FIPS;run;
proc sort data=PNCF5;by Year FIPS;run;
proc sort data=PNCW5;by Year FIPS;run;
proc sort data=PNCB5;by Year FIPS;run;
proc sort data=PNCA5;by Year FIPS;run;
proc sort data=PNCN5;by Year FIPS;run;
proc sort data=PNCP5;by Year FIPS;run;
proc sort data=PNCO5;by Year FIPS;run;
proc sort data=PNCH5;by Year FIPS;run;
proc sort data=TBBT5;by Year FIPS;run;
proc sort data=TBBM5;by Year FIPS;run;
proc sort data=TBBF5;by Year FIPS;run;
proc sort data=TBBW5;by Year FIPS;run;
proc sort data=TBBB5;by Year FIPS;run;
proc sort data=TBBA5;by Year FIPS;run;
proc sort data=TBBN5;by Year FIPS;run;
proc sort data=TBBP5;by Year FIPS;run;
proc sort data=TBBO5;by Year FIPS;run;
proc sort data=TBBH5;by Year FIPS;run;
proc sort data=TBTT5;by Year FIPS;run;
proc sort data=TBTM5;by Year FIPS;run;
proc sort data=TBTF5;by Year FIPS;run;
proc sort data=TBTW5;by Year FIPS;run;
proc sort data=TBTB5;by Year FIPS;run;
proc sort data=TBTA5;by Year FIPS;run;
proc sort data=TBTN5;by Year FIPS;run;
proc sort data=TBTP5;by Year FIPS;run;
proc sort data=TBTO5;by Year FIPS;run;
proc sort data=TBTH5;by Year FIPS;run;

data BIR5Yr;merge 
BIRT5 BIRM5 BIRF5 BIRW5 BIRB5 BIRA5 BIRN5 BIRP5 BIRO5 BIRH5 LBWT5 LBWM5 LBWF5 LBWW5 LBWB5 LBWA5 LBWN5 LBWP5 LBWO5 LBWH5 
PTBT5 PTBM5 PTBF5 PTBW5 PTBB5 PTBA5 PTBN5 PTBP5 PTBO5 PTBH5 PNCT5 PNCM5 PNCF5 PNCW5 PNCB5 PNCA5 PNCN5 PNCP5 PNCO5 PNCH5 
TBBT5 TBBM5 TBBF5 TBBW5 TBBB5 TBBA5 TBBN5 TBBP5 TBBO5 TBBH5 TBTT5 TBTM5 TBTF5 TBTW5 TBTB5 TBTA5 TBTN5 TBTP5 TBTO5 TBTH5;
by Year FIPS;run;





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Merging 1-Year Data and 5-Year Data *****************************************************************************************************************************************/
/* Merging 1-Year Data and 5-Year Data *****************************************************************************************************************************************/
/* Merging 1-Year Data and 5-Year Data *****************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/

proc sort data=BIR1Yr;by Year FIPS;run;
proc sort data=BIR5Yr;by Year FIPS;run;
data Birth01;merge BIR1Yr BIR5Yr;by Year FIPS;run;
 
 

 
 
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Managing Data & Saving a Permanent Data *************************************************************************************************************************************/
/* Managing Data & Saving a Permanent Data *************************************************************************************************************************************/
/* Managing Data & Saving a Permanent Data *************************************************************************************************************************************/
/********************************************************************************************************************************************************************************
   - Rename FIPS (County FIPS Code)
   - Convert character variables to numeric variables (by adding "0")
   - Label variables
********************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/

data a.Birth;retain Year CountyFIPS;set Birth01(rename=(
BIRT1=BIRT1a BIRM1=BIRM1a BIRF1=BIRF1a BIRW1=BIRW1a BIRB1=BIRB1a BIRA1=BIRA1a BIRN1=BIRN1a BIRP1=BIRP1a BIRO1=BIRO1a BIRH1=BIRH1a LBWT1=LBWT1a LBWM1=LBWM1a LBWF1=LBWF1a 
LBWW1=LBWW1a LBWB1=LBWB1a LBWA1=LBWA1a LBWN1=LBWN1a LBWP1=LBWP1a LBWO1=LBWO1a LBWH1=LBWH1a PTBT1=PTBT1a PTBM1=PTBM1a PTBF1=PTBF1a PTBW1=PTBW1a PTBB1=PTBB1a PTBA1=PTBA1a 
PTBN1=PTBN1a PTBP1=PTBP1a PTBO1=PTBO1a PTBH1=PTBH1a PNCT1=PNCT1a PNCM1=PNCM1a PNCF1=PNCF1a PNCW1=PNCW1a PNCB1=PNCB1a PNCA1=PNCA1a PNCN1=PNCN1a PNCP1=PNCP1a PNCO1=PNCO1a 
PNCH1=PNCH1a TBBT1=TBBT1a TBBM1=TBBM1a TBBF1=TBBF1a TBBW1=TBBW1a TBBB1=TBBB1a TBBA1=TBBA1a TBBN1=TBBN1a TBBP1=TBBP1a TBBO1=TBBO1a TBBH1=TBBH1a TBTT1=TBTT1a TBTM1=TBTM1a 
TBTF1=TBTF1a TBTW1=TBTW1a TBTB1=TBTB1a TBTA1=TBTA1a TBTN1=TBTN1a TBTP1=TBTP1a TBTO1=TBTO1a TBTH1=TBTH1a BIRT5=BIRT5a BIRM5=BIRM5a BIRF5=BIRF5a BIRW5=BIRW5a BIRB5=BIRB5a 
BIRA5=BIRA5a BIRN5=BIRN5a BIRP5=BIRP5a BIRO5=BIRO5a BIRH5=BIRH5a LBWT5=LBWT5a LBWM5=LBWM5a LBWF5=LBWF5a LBWW5=LBWW5a LBWB5=LBWB5a LBWA5=LBWA5a LBWN5=LBWN5a LBWP5=LBWP5a 
LBWO5=LBWO5a LBWH5=LBWH5a PTBT5=PTBT5a PTBM5=PTBM5a PTBF5=PTBF5a PTBW5=PTBW5a PTBB5=PTBB5a PTBA5=PTBA5a PTBN5=PTBN5a PTBP5=PTBP5a PTBO5=PTBO5a PTBH5=PTBH5a PNCT5=PNCT5a 
PNCM5=PNCM5a PNCF5=PNCF5a PNCW5=PNCW5a PNCB5=PNCB5a PNCA5=PNCA5a PNCN5=PNCN5a PNCP5=PNCP5a PNCO5=PNCO5a PNCH5=PNCH5a TBBT5=TBBT5a TBBM5=TBBM5a TBBF5=TBBF5a TBBW5=TBBW5a 
TBBB5=TBBB5a TBBA5=TBBA5a TBBN5=TBBN5a TBBP5=TBBP5a TBBO5=TBBO5a TBBH5=TBBH5a TBTT5=TBTT5a TBTM5=TBTM5a TBTF5=TBTF5a TBTW5=TBTW5a TBTB5=TBTB5a TBTA5=TBTA5a TBTN5=TBTN5a 
TBTP5=TBTP5a TBTO5=TBTO5a TBTH5=TBTH5a));
CountyFIPS=FIPS+0;
CountyYear=CountyFIPS*10000+year;
BIRT1=BIRT1a+0;BIRM1=BIRM1a+0;BIRF1=BIRF1a+0;BIRW1=BIRW1a+0;BIRB1=BIRB1a+0;BIRA1=BIRA1a+0;BIRN1=BIRN1a+0;BIRP1=BIRP1a+0;BIRO1=BIRO1a+0;BIRH1=BIRH1a+0;LBWT1=LBWT1a+0;
LBWM1=LBWM1a+0;LBWF1=LBWF1a+0;LBWW1=LBWW1a+0;LBWB1=LBWB1a+0;LBWA1=LBWA1a+0;LBWN1=LBWN1a+0;LBWP1=LBWP1a+0;LBWO1=LBWO1a+0;LBWH1=LBWH1a+0;PTBT1=PTBT1a+0;PTBM1=PTBM1a+0;
PTBF1=PTBF1a+0;PTBW1=PTBW1a+0;PTBB1=PTBB1a+0;PTBA1=PTBA1a+0;PTBN1=PTBN1a+0;PTBP1=PTBP1a+0;PTBO1=PTBO1a+0;PTBH1=PTBH1a+0;PNCT1=PNCT1a+0;PNCM1=PNCM1a+0;PNCF1=PNCF1a+0;
PNCW1=PNCW1a+0;PNCB1=PNCB1a+0;PNCA1=PNCA1a+0;PNCN1=PNCN1a+0;PNCP1=PNCP1a+0;PNCO1=PNCO1a+0;PNCH1=PNCH1a+0;TBBT1=TBBT1a+0;TBBM1=TBBM1a+0;TBBF1=TBBF1a+0;TBBW1=TBBW1a+0;
TBBB1=TBBB1a+0;TBBA1=TBBA1a+0;TBBN1=TBBN1a+0;TBBP1=TBBP1a+0;TBBO1=TBBO1a+0;TBBH1=TBBH1a+0;TBTT1=TBTT1a+0;TBTM1=TBTM1a+0;TBTF1=TBTF1a+0;TBTW1=TBTW1a+0;TBTB1=TBTB1a+0;
TBTA1=TBTA1a+0;TBTN1=TBTN1a+0;TBTP1=TBTP1a+0;TBTO1=TBTO1a+0;TBTH1=TBTH1a+0;BIRT5=BIRT5a+0;BIRM5=BIRM5a+0;BIRF5=BIRF5a+0;BIRW5=BIRW5a+0;BIRB5=BIRB5a+0;BIRA5=BIRA5a+0;
BIRN5=BIRN5a+0;BIRP5=BIRP5a+0;BIRO5=BIRO5a+0;BIRH5=BIRH5a+0;LBWT5=LBWT5a+0;LBWM5=LBWM5a+0;LBWF5=LBWF5a+0;LBWW5=LBWW5a+0;LBWB5=LBWB5a+0;LBWA5=LBWA5a+0;LBWN5=LBWN5a+0;
LBWP5=LBWP5a+0;LBWO5=LBWO5a+0;LBWH5=LBWH5a+0;PTBT5=PTBT5a+0;PTBM5=PTBM5a+0;PTBF5=PTBF5a+0;PTBW5=PTBW5a+0;PTBB5=PTBB5a+0;PTBA5=PTBA5a+0;PTBN5=PTBN5a+0;PTBP5=PTBP5a+0;
PTBO5=PTBO5a+0;PTBH5=PTBH5a+0;PNCT5=PNCT5a+0;PNCM5=PNCM5a+0;PNCF5=PNCF5a+0;PNCW5=PNCW5a+0;PNCB5=PNCB5a+0;PNCA5=PNCA5a+0;PNCN5=PNCN5a+0;PNCP5=PNCP5a+0;PNCO5=PNCO5a+0;
PNCH5=PNCH5a+0;TBBT5=TBBT5a+0;TBBM5=TBBM5a+0;TBBF5=TBBF5a+0;TBBW5=TBBW5a+0;TBBB5=TBBB5a+0;TBBA5=TBBA5a+0;TBBN5=TBBN5a+0;TBBP5=TBBP5a+0;TBBO5=TBBO5a+0;TBBH5=TBBH5a+0;
TBTT5=TBTT5a+0;TBTM5=TBTM5a+0;TBTF5=TBTF5a+0;TBTW5=TBTW5a+0;TBTB5=TBTB5a+0;TBTA5=TBTA5a+0;TBTN5=TBTN5a+0;TBTP5=TBTP5a+0;TBTO5=TBTO5a+0;TBTH5=TBTH5a+0;
label
CountyFIPS="County FIPS code"
CountyYear="CountyFIPS & Year (CCCCCYYYY)"
BIRT1="# live births,1-year estimates,Total"
BIRM1="# live births,1-year estimates,Male"
BIRF1="# live births,1-year estimates,Female"
BIRW1="# live births,1-year estimates,Non-Hispanic White alone"
BIRB1="# live births,1-year estimates,Black alone"
BIRA1="# live births,1-year estimates,Asian alone"
BIRN1="# live births,1-year estimates,AI/AN alone"
BIRP1="# live births,1-year estimates,NH/PI alone"
BIRO1="# live births,1-year estimates,Two or more race"
BIRH1="# live births,1-year estimates,Hispanic or Latino"
LBWT1="# low birth weight(<2.5kg) live births,1-year estimates,Total"
LBWM1="# low birth weight(<2.5kg) live births,1-year estimates,Male"
LBWF1="# low birth weight(<2.5kg) live births,1-year estimates,Female"
LBWW1="# low birth weight(<2.5kg) live births,1-year estimates,Non-Hispanic White alone"
LBWB1="# low birth weight(<2.5kg) live births,1-year estimates,Black alone"
LBWA1="# low birth weight(<2.5kg) live births,1-year estimates,Asian alone"
LBWN1="# low birth weight(<2.5kg) live births,1-year estimates,AI/AN alone"
LBWP1="# low birth weight(<2.5kg) live births,1-year estimates,NH/PI alone"
LBWO1="# low birth weight(<2.5kg) live births,1-year estimates,Two or more race"
LBWH1="# low birth weight(<2.5kg) live births,1-year estimates,Hispanic or Latino"
PTBT1="# preterm(OE gestational age<37weeks) live births,1-year estimates,Total"
PTBM1="# preterm(OE gestational age<37weeks) live births,1-year estimates,Male"
PTBF1="# preterm(OE gestational age<37weeks) live births,1-year estimates,Female"
PTBW1="# preterm(OE gestational age<37weeks) live births,1-year estimates,Non-Hispanic White alone"
PTBB1="# preterm(OE gestational age<37weeks) live births,1-year estimates,Black alone"
PTBA1="# preterm(OE gestational age<37weeks) live births,1-year estimates,Asian alone"
PTBN1="# preterm(OE gestational age<37weeks) live births,1-year estimates,AI/AN alone"
PTBP1="# preterm(OE gestational age<37weeks) live births,1-year estimates,NH/PI alone"
PTBO1="# preterm(OE gestational age<37weeks) live births,1-year estimates,Two or more race"
PTBH1="# preterm(OE gestational age<37weeks) live births,1-year estimates,Hispanic or Latino"
PNCT1="# live births beginning prenatal care in the first trimester,1-year estimates,Total"
PNCM1="# live births beginning prenatal care in the first trimester,1-year estimates,Male"
PNCF1="# live births beginning prenatal care in the first trimester,1-year estimates,Female"
PNCW1="# live births beginning prenatal care in the first trimester,1-year estimates,Non-Hispanic White alone"
PNCB1="# live births beginning prenatal care in the first trimester,1-year estimates,Black alone"
PNCA1="# live births beginning prenatal care in the first trimester,1-year estimates,Asian alone"
PNCN1="# live births beginning prenatal care in the first trimester,1-year estimates,AI/AN alone"
PNCP1="# live births beginning prenatal care in the first trimester,1-year estimates,NH/PI alone"
PNCO1="# live births beginning prenatal care in the first trimester,1-year estimates,Two or more race"
PNCH1="# live births beginning prenatal care in the first trimester,1-year estimates,Hispanic or Latino"
TBBT1="# live births w/mother's age<20,1-year estimates,Total"
TBBM1="# live births w/mother's age<20,1-year estimates,Male"
TBBF1="# live births w/mother's age<20,1-year estimates,Female"
TBBW1="# live births w/mother's age<20,1-year estimates,Non-Hispanic White alone"
TBBB1="# live births w/mother's age<20,1-year estimates,Black alone"
TBBA1="# live births w/mother's age<20,1-year estimates,Asian alone"
TBBN1="# live births w/mother's age<20,1-year estimates,AI/AN alone"
TBBP1="# live births w/mother's age<20,1-year estimates,NH/PI alone"
TBBO1="# live births w/mother's age<20,1-year estimates,Two or more race"
TBBH1="# live births w/mother's age<20,1-year estimates,Hispanic or Latino"
TBTT1="# live births w/mother's age 15-19,1-year estimates,Total"
TBTM1="# live births w/mother's age 15-19,1-year estimates,Male"
TBTF1="# live births w/mother's age 15-19,1-year estimates,Female"
TBTW1="# live births w/mother's age 15-19,1-year estimates,Non-Hispanic White alone"
TBTB1="# live births w/mother's age 15-19,1-year estimates,Black alone"
TBTA1="# live births w/mother's age 15-19,1-year estimates,Asian alone"
TBTN1="# live births w/mother's age 15-19,1-year estimates,AI/AN alone"
TBTP1="# live births w/mother's age 15-19,1-year estimates,NH/PI alone"
TBTO1="# live births w/mother's age 15-19,1-year estimates,Two or more race"
TBTH1="# live births w/mother's age 15-19,1-year estimates,Hispanic or Latino"
BIRT5="# live births,5-year estimates,Total"
BIRM5="# live births,5-year estimates,Male"
BIRF5="# live births,5-year estimates,Female"
BIRW5="# live births,5-year estimates,Non-Hispanic White alone"
BIRB5="# live births,5-year estimates,Black alone"
BIRA5="# live births,5-year estimates,Asian alone"
BIRN5="# live births,5-year estimates,AI/AN alone"
BIRP5="# live births,5-year estimates,NH/PI alone"
BIRO5="# live births,5-year estimates,Two or more race"
BIRH5="# live births,5-year estimates,Hispanic or Latino"
LBWT5="# low birth weight(<2.5kg) live births,5-year estimates,Total"
LBWM5="# low birth weight(<2.5kg) live births,5-year estimates,Male"
LBWF5="# low birth weight(<2.5kg) live births,5-year estimates,Female"
LBWW5="# low birth weight(<2.5kg) live births,5-year estimates,Non-Hispanic White alone"
LBWB5="# low birth weight(<2.5kg) live births,5-year estimates,Black alone"
LBWA5="# low birth weight(<2.5kg) live births,5-year estimates,Asian alone"
LBWN5="# low birth weight(<2.5kg) live births,5-year estimates,AI/AN alone"
LBWP5="# low birth weight(<2.5kg) live births,5-year estimates,NH/PI alone"
LBWO5="# low birth weight(<2.5kg) live births,5-year estimates,Two or more race"
LBWH5="# low birth weight(<2.5kg) live births,5-year estimates,Hispanic or Latino"
PTBT5="# preterm(OE gestational age<37weeks) live births,5-year estimates,Total"
PTBM5="# preterm(OE gestational age<37weeks) live births,5-year estimates,Male"
PTBF5="# preterm(OE gestational age<37weeks) live births,5-year estimates,Female"
PTBW5="# preterm(OE gestational age<37weeks) live births,5-year estimates,Non-Hispanic White alone"
PTBB5="# preterm(OE gestational age<37weeks) live births,5-year estimates,Black alone"
PTBA5="# preterm(OE gestational age<37weeks) live births,5-year estimates,Asian alone"
PTBN5="# preterm(OE gestational age<37weeks) live births,5-year estimates,AI/AN alone"
PTBP5="# preterm(OE gestational age<37weeks) live births,5-year estimates,NH/PI alone"
PTBO5="# preterm(OE gestational age<37weeks) live births,5-year estimates,Two or more race"
PTBH5="# preterm(OE gestational age<37weeks) live births,5-year estimates,Hispanic or Latino"
PNCT5="# live births beginning prenatal care in the first trimester,5-year estimates,Total"
PNCM5="# live births beginning prenatal care in the first trimester,5-year estimates,Male"
PNCF5="# live births beginning prenatal care in the first trimester,5-year estimates,Female"
PNCW5="# live births beginning prenatal care in the first trimester,5-year estimates,Non-Hispanic White alone"
PNCB5="# live births beginning prenatal care in the first trimester,5-year estimates,Black alone"
PNCA5="# live births beginning prenatal care in the first trimester,5-year estimates,Asian alone"
PNCN5="# live births beginning prenatal care in the first trimester,5-year estimates,AI/AN alone"
PNCP5="# live births beginning prenatal care in the first trimester,5-year estimates,NH/PI alone"
PNCO5="# live births beginning prenatal care in the first trimester,5-year estimates,Two or more race"
PNCH5="# live births beginning prenatal care in the first trimester,5-year estimates,Hispanic or Latino"
TBBT5="# live births w/mother's age<20,5-year estimates,Total"
TBBM5="# live births w/mother's age<20,5-year estimates,Male"
TBBF5="# live births w/mother's age<20,5-year estimates,Female"
TBBW5="# live births w/mother's age<20,5-year estimates,Non-Hispanic White alone"
TBBB5="# live births w/mother's age<20,5-year estimates,Black alone"
TBBA5="# live births w/mother's age<20,5-year estimates,Asian alone"
TBBN5="# live births w/mother's age<20,5-year estimates,AI/AN alone"
TBBP5="# live births w/mother's age<20,5-year estimates,NH/PI alone"
TBBO5="# live births w/mother's age<20,5-year estimates,Two or more race"
TBBH5="# live births w/mother's age<20,5-year estimates,Hispanic or Latino"
TBTT5="# live births w/mother's age 15-19,5-year estimates,Total"
TBTM5="# live births w/mother's age 15-19,5-year estimates,Male"
TBTF5="# live births w/mother's age 15-19,5-year estimates,Female"
TBTW5="# live births w/mother's age 15-19,5-year estimates,Non-Hispanic White alone"
TBTB5="# live births w/mother's age 15-19,5-year estimates,Black alone"
TBTA5="# live births w/mother's age 15-19,5-year estimates,Asian alone"
TBTN5="# live births w/mother's age 15-19,5-year estimates,AI/AN alone"
TBTP5="# live births w/mother's age 15-19,5-year estimates,NH/PI alone"
TBTO5="# live births w/mother's age 15-19,5-year estimates,Two or more race"
TBTH5="# live births w/mother's age 15-19,5-year estimates,Hispanic or Latino";
drop 
FIPS
BIRT1a BIRM1a BIRF1a BIRW1a BIRB1a BIRA1a BIRN1a BIRP1a BIRO1a BIRH1a LBWT1a LBWM1a LBWF1a LBWW1a LBWB1a LBWA1a LBWN1a LBWP1a LBWO1a LBWH1a PTBT1a PTBM1a PTBF1a PTBW1a PTBB1a 
PTBA1a PTBN1a PTBP1a PTBO1a PTBH1a PNCT1a PNCM1a PNCF1a PNCW1a PNCB1a PNCA1a PNCN1a PNCP1a PNCO1a PNCH1a TBBT1a TBBM1a TBBF1a TBBW1a TBBB1a TBBA1a TBBN1a TBBP1a TBBO1a TBBH1a 
TBTT1a TBTM1a TBTF1a TBTW1a TBTB1a TBTA1a TBTN1a TBTP1a TBTO1a TBTH1a BIRT5a BIRM5a BIRF5a BIRW5a BIRB5a BIRA5a BIRN5a BIRP5a BIRO5a BIRH5a LBWT5a LBWM5a LBWF5a LBWW5a LBWB5a 
LBWA5a LBWN5a LBWP5a LBWO5a LBWH5a PTBT5a PTBM5a PTBF5a PTBW5a PTBB5a PTBA5a PTBN5a PTBP5a PTBO5a PTBH5a PNCT5a PNCM5a PNCF5a PNCW5a PNCB5a PNCA5a PNCN5a PNCP5a PNCO5a PNCH5a 
TBBT5a TBBM5a TBBF5a TBBW5a TBBB5a TBBA5a TBBN5a TBBP5a TBBO5a TBBH5a TBTT5a TBTM5a TBTF5a TBTW5a TBTB5a TBTA5a TBTN5a TBTP5a TBTO5a TBTH5a;
run;

proc contents data=a.Birth varnum;run;
