




/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* CDCK01 Project - 09/30/2020-09/29/2023 */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* This SAS program is to import and manage County Health Rankings (CHR) data from 2010 to 2020.
   Source: https://www.countyhealthrankings.org/explore-health-rankings/rankings-data-documentation
   The source provides SAS data files (*.sas7bdat).
   NOTE: CHR data file year (e.g., CHR 2010 file) is not consistent with measurement years of variables (e.g., adult obesity in 2006-2008) within the file.
         This SAS program will construct longitudinal data based on measurement years of variables.
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Counties in 50 US States and DC, 2009-2018 */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Hyunil Kim, 02/05/2021 */
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/





ods html newfile=proc path="E:\SASWork\Output";
libname a "Z:\CDCK01\Data_County\CHR";





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/********************************* Importing CHR Data **************************************************************************************************************************/
/********************************* Importing CHR Data **************************************************************************************************************************/
/********************************* Importing CHR Data **************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* countycode="000" is assigned for summary records for US national and each state rather than for records of a county.
   SOLUTION: exclude these records.
*/;
data A;set a.analytic_data2010  ;if countycode^="000";run; /*N=3141, 198 variables*/
data B;set a.analytic_data2011  ;if countycode^="000";run; /*N=3141, 379 variables*/
data C;set a.analytic_data2012  ;if countycode^="000";run; /*N=3141, 330 variables*/
data D;set a.analytic_data2013  ;if countycode^="000";run; /*N=3141, 466 variables*/
data E;set a.analytic_data2014  ;if countycode^="000";run; /*N=3141, 487 variables*/
data F;set a.analytic_data2015  ;if countycode^="000";run; /*N=3141, 462 variables*/
data G;set a.analytic_data2016  ;if countycode^="000";run; /*N=3141, 482 variables*/
data H;set a.analytic_data2017  ;if countycode^="000";run; /*N=3137, 492 variables*/
data I;set a.analytic_data2018_0;if countycode^="000";run; /*N=3142, 508 variables*/
data J;set a.analytic_data2019  ;if countycode^="000";run; /*N=3142, 534 variables*/
data K;set a.analytic_data2020_0;if countycode^="000";run; /*N=3142, 786 variables*/





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/********************************* Creating Yearly Datasets based on Measurement Years *****************************************************************************************/
/********************************* Creating Yearly Datasets based on Measurement Years *****************************************************************************************/
/********************************* Creating Yearly Datasets based on Measurement Years *****************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* CHR data years (release years) and measurement years of variables are inconsistent. 
   For example, CHR 2010 data have variables measured in 2004-2006 (e.g., premature death) and variables measured in 2002-2008 (e.g., adult smoking).
   Due to this inconsistency, creating longitudinal data based on CHR yearly data requires the following steps:
     (1) Creating Yearly Datasets based on Measurement Years
     (2) Merging Yearly Datasets by Measurement Year
     (3) Checking Duplicate Variables and Cleaning Them Up
     (4) Creating Longitudinal Data
***
   This section will re-arrange data based on measurement years (i.e., the step (1)).
   For variables measured over multiple years, the ending year (e.g., 2008 for 2002-2008) was used to create longitudinal data.
   This is to estimate the relationship between IV (in the last XX years) and DV (in the current year). 
*/
/***/;
data A2005;set A(rename=(fipscode=CountyFIPS));
InsuredA_A2=v003_rawvalue;
Hospice_A2=v038_rawvalue;
Hospice_d_A2=v038_denominator;
AirPM2_A2=v046_rawvalue;
AirO3_A2=v029_rawvalue;
keep 
CountyFIPS
InsuredA_A2
Hospice_A2
Hospice_d_A2
AirPM2_A2
AirO3_A2
;run;
/*N=3141, 6 variables*/
/***/;
data A2006;set A(rename=(fipscode=CountyFIPS));
PrmDeath_A2=v001_rawvalue;
PrmDeath_n_A2=v001_numerator;
PrmDeath_d_A2=v001_denominator;
LowBW_A2=v037_rawvalue;
LowBW_n_A2=v037_numerator;
LowBW_d_A2=v037_denominator;
CarDeath_A2=v039_rawvalue;
STD_CT_d_A2=v045_denominator;
TeenBth_A2=v014_rawvalue;
TeenBth_n_A2=v014_numerator;
PCP_A2=v004_rawvalue;
PCP_n_A2=v004_numerator;
PCP_d_A2=v004_denominator;
PCP_r_A2=v004_other_data_1;
PrvtHosp_A2=v005_rawvalue;
PrvtHosp_n_A2=v005_numerator;
PrvtHosp_d_A2=v005_denominator;
DiabetM_A2=v007_rawvalue;
DiabetM_d_A2=v007_denominator;
Murder_A2=v015_rawvalue;
AccFood_A2=v030_rawvalue;
AccFood_n_A2=v030_numerator;
AccFood_d_A2=v030_denominator;
Liquor_A2=v041_rawvalue;
Liquor_n_A2=v041_numerator;
Liquor_d_A2=v041_denominator;
keep
CountyFIPs
PrmDeath_A2
PrmDeath_n_A2
PrmDeath_d_A2
LowBW_A2
LowBW_n_A2
LowBW_d_A2
CarDeath_A2
STD_CT_d_A2
TeenBth_A2
TeenBth_n_A2
PCP_A2
PCP_n_A2
PCP_d_A2
PCP_r_A2
PrvtHosp_A2
PrvtHosp_n_A2
PrvtHosp_d_A2
DiabetM_A2
DiabetM_d_A2
Murder_A2
AccFood_A2
AccFood_n_A2
AccFood_d_A2
Liquor_A2
Liquor_n_A2
Liquor_d_A2
;run;
/*N=3141, 27 variables*/
/***/;
data A2007;set A(rename=(fipscode=CountyFIPS));
STD_CT_A2=v045_rawvalue;
STD_CT_n_A2=v045_numerator;
Violent_A2=v043_rawvalue;
Violent_n_A2=v043_numerator;
Violent_d_A2=v043_denominator;
keep
CountyFIPS
STD_CT_A2
STD_CT_n_A2
Violent_A2
Violent_n_A2
Violent_d_A2
;run;
/*N=3141, 6 variables*/
/***/;
data A2008;set A(rename=(fipscode=CountyFIPS));
PoorHlth_A2=v002_rawvalue;
PoorHlth_n_A2=v002_numerator;
PoorHlth_d_A2=v002_denominator;
PoorPhy_A2=v036_rawvalue;
PoorPhy_d_A2=v036_denominator;
PoorMH_A2=v042_rawvalue;
PoorMH_d_A2=v042_denominator;
Smoke_A2=v009_rawvalue;
Smoke_n_A2=v009_numerator;
Smoke_d_A2=v009_denominator;
Obesity_A2=v011_rawvalue;
BDrink_A2=v012_rawvalue;
BDrink_n_A2=v012_numerator;
BDrink_d_A2=v012_denominator;
SocSupp_A2=v040_rawvalue;
SocSupp_n_A2=v040_numerator;
SocSupp_d_A2=v040_denominator;
keep
CountyFIPS
PoorHlth_A2
PoorHlth_n_A2
PoorHlth_d_A2
PoorPhy_A2
PoorPhy_d_A2
PoorMH_A2
PoorMH_d_A2
Smoke_A2
Smoke_n_A2
Smoke_d_A2
Obesity_A2
BDrink_A2
BDrink_n_A2
BDrink_d_A2
SocSupp_A2
SocSupp_n_A2
SocSupp_d_A2
;run;
/*N=3141, 18 variables*/
/***/;
data B2006;set B(rename=(fipscode=CountyFIPS));
AirPM2_B2=v046_rawvalue;
AirO3_B2=v029_rawvalue;
FrLunch_B2=v065_rawvalue;
keep
CountyFIPS
AirPM2_B2
AirO3_B2
FrLunch_B2
;run;
/*N=3141, 4 variables*/
/***/;
data B2007;set B(rename=(fipscode=CountyFIPS));
PrmDeath_B2=v001_rawvalue;
PrmDeath_n_B2=v001_numerator;
LowBW_B2=v037_rawvalue;
LowBW_n_B2=v037_numerator;
LowBW_d_B2=v037_denominator;
CarDeath_B2=v039_rawvalue;
CarDeath_n_B2=v039_numerator;
TeenBth_B2=v014_rawvalue;
TeenBth_n_B2=v014_numerator;
InsuredA_B2=v003_rawvalue;
InsuredA_n_B2=v003_numerator;
InsuredA_d_B2=v003_denominator;
PrvtHosp_B2=v005_rawvalue;
PrvtHosp_d_B2=v005_denominator;
DiabetM_B2=v007_rawvalue;
DiabetM_d_B2=v007_denominator;
Mammo_B2=v050_rawvalue;
Mammo_d_B2=v050_denominator;
Murder_B2=v015_rawvalue;
Murder_n_B2=v015_numerator;
Murder_d_B2=v015_denominator;
HIV_B2=v061_rawvalue;
HIV_d_B2=v061_denominator;
keep
CountyFIPS
PrmDeath_B2
PrmDeath_n_B2
LowBW_B2
LowBW_n_B2
LowBW_d_B2
CarDeath_B2
CarDeath_n_B2
TeenBth_B2
TeenBth_n_B2
InsuredA_B2
InsuredA_n_B2
InsuredA_d_B2
PrvtHosp_B2
PrvtHosp_d_B2
DiabetM_B2
DiabetM_d_B2
Mammo_B2
Mammo_d_B2
Murder_B2
Murder_n_B2
Murder_d_B2
HIV_B2
HIV_d_B2
;run;
/*N=3141, 24 variables*/
/***/;
data B2008;set B(rename=(fipscode=CountyFIPS));
Obesity_B2=v011_rawvalue;
STD_CT_B2=v045_rawvalue;
STD_CT_n_B2=v045_numerator;
STD_CT_d_B2=v045_denominator;
PCP_B2=v004_rawvalue;
PCP_n_B2=v004_numerator;
PCP_d_B2=v004_denominator;
PCP_r_B2=v004_other_data_1;
Violent_B2=v043_rawvalue;
Violent_n_B2=v043_numerator;
Violent_d_B2=v043_denominator;
AccFood_B2=v030_rawvalue;
AccFood_n_B2=v030_numerator;
AccFood_d_B2=v030_denominator;
Liquor_B2=v041_rawvalue;
Gym_B2=v068_rawvalue;
Gym_n_B2=v068_numerator;
Gym_d_B2=v068_denominator;
Diabet_B2=v060_rawvalue;
Inactive_B2=v070_rawvalue;
MHPrvd_B2=v062_rawvalue;
MHPrvd_r_B2=v062_other_data_1;
keep
CountyFIPS
Obesity_B2
STD_CT_B2
STD_CT_n_B2
STD_CT_d_B2
PCP_B2
PCP_n_B2
PCP_d_B2
PCP_r_B2
Violent_B2
Violent_n_B2
Violent_d_B2
AccFood_B2
AccFood_n_B2
AccFood_d_B2
Liquor_B2
Gym_B2
Gym_n_B2
Gym_d_B2
Diabet_B2
Inactive_B2
MHPrvd_B2
MHPrvd_r_B2
;run;
/*N=3141, 23 variables*/
/***/;
data B2009;set B(rename=(fipscode=CountyFIPS));
PoorHlth_B2=v002_rawvalue;
PoorHlth_d_B2=v002_denominator;
PoorPhy_B2=v036_rawvalue;
PoorPhy_d_B2=v036_denominator;
PoorMH_B2=v042_rawvalue;
PoorMH_d_B2=v042_denominator;
Smoke_B2=v009_rawvalue;
Smoke_d_B2=v009_denominator;
BDrink_B2=v012_rawvalue;
BDrink_d_B2=v012_denominator;
EDrink_B2=v049_rawvalue;
EDrink_d_B2=v049_denominator;
SocSupp_B2=v040_rawvalue;
SocSupp_d_B2=v040_denominator;
keep
CountyFIPS
PoorHlth_B2
PoorHlth_d_B2
PoorPhy_B2
PoorPhy_d_B2
PoorMH_B2
PoorMH_d_B2
Smoke_B2
Smoke_d_B2
BDrink_B2
BDrink_d_B2
EDrink_B2
EDrink_d_B2
SocSupp_B2
SocSupp_d_B2
;run;
/*N=3141, 15 variables*/
/***/;
data C2006;set C(rename=(fipscode=CountyFIPS));
LAccFood_C2=v083_rawvalue;
LAccFood_n_C2=v083_numerator;
FrLunch_C2=v065_rawvalue;
keep
CountyFIPS
LAccFood_C2
LAccFood_n_C2
FrLunch_C2
;run;
/*N=3141, 4 variables*/
/***/;
data C2007;set C(rename=(fipscode=CountyFIPS));
AirPM2_C2=v046_rawvalue;
AirO3_C2=v029_rawvalue;
MHPrvd_C2=v062_rawvalue;
MHPrvd_n_C2=v062_numerator;
MHPrvd_d_C2=v062_denominator;
MHPrvd_r_C2=v062_other_data_1;
HlthCost_C2=v086_rawvalue;
HlthCost_n_C2=v086_numerator;
Dentist_C2=v088_rawvalue;
Dentist_n_C2=v088_numerator;
Dentist_d_C2=v088_denominator;
Dentist_r_C2=v088_other_data_1;
keep
CountyFIPS
AirPM2_C2
AirO3_C2
MHPrvd_C2
MHPrvd_n_C2
MHPrvd_d_C2
MHPrvd_r_C2
HlthCost_C2
HlthCost_n_C2
Dentist_C2
Dentist_n_C2
Dentist_d_C2
Dentist_r_C2
;run;
/*N=3141, 13 variables*/
/***/;
data C2008;set C(rename=(fipscode=CountyFIPS));
PrmDeath_C2=v001_rawvalue;
PrmDeath_n_C2=v001_numerator;
LowBW_C2=v037_rawvalue;
LowBW_n_C2=v037_numerator;
LowBW_d_C2=v037_denominator;
CarDeath_C2=v039_rawvalue;
CarDeath_n_C2=v039_numerator;
CarDeath_d_C2=v039_denominator;
TeenBth_C2=v014_rawvalue;
TeenBth_n_C2=v014_numerator;
TeenBth_d_C2=v014_denominator;
Murder_C2=v015_rawvalue;
Murder_n_C2=v015_numerator;
Murder_d_C2=v015_denominator;
HIV_C2=v061_rawvalue;
HIV_d_C2=v061_denominator;
keep
CountyFIPS
PrmDeath_C2
PrmDeath_n_C2
LowBW_C2
LowBW_n_C2
LowBW_d_C2
CarDeath_C2
CarDeath_n_C2
CarDeath_d_C2
TeenBth_C2
TeenBth_n_C2
TeenBth_d_C2
Murder_C2
Murder_n_C2
Murder_d_C2
HIV_C2
HIV_d_C2
;run;
/*N=3141, 17 variables*/
/***/;
data C2009;set C(rename=(fipscode=CountyFIPS));
Obesity_C2=v011_rawvalue;
STD_CT_C2=v045_rawvalue;
STD_CT_n_C2=v045_numerator;
STD_CT_d_C2=v045_denominator;
InsuredA_C2=v003_rawvalue;
InsuredA_n_C2=v003_numerator;
InsuredA_d_C2=v003_denominator;
Insured_C2=v085_rawvalue;
Insured_n_C2=v085_numerator;
Insured_d_C2=v085_denominator;
PCP_C2=v004_rawvalue;
PCP_n_C2=v004_numerator;
PCP_d_C2=v004_denominator;
PCP_r_C2=v004_other_data_1;
PrvtHosp_C2=v005_rawvalue;
PrvtHosp_d_C2=v005_denominator;
DiabetM_C2=v007_rawvalue;
DiabetM_d_C2=v007_denominator;
Mammo_C2=v050_rawvalue;
Mammo_d_C2=v050_denominator;
Violent_C2=v043_rawvalue;
Violent_n_C2=v043_numerator;
Violent_d_C2=v043_denominator;
AccFood_C2=v096_rawvalue;
AccFood_n_C2=v096_numerator;
AccFood_d_C2=v096_denominator;
FastFood_C2=v084_rawvalue;
FastFood_n_C2=v084_numerator;
FastFood_d_C2=v084_denominator;
Gym_C2=v068_rawvalue;
Gym_n_C2=v068_numerator;
Gym_d_C2=v068_denominator;
Diabet_C2=v060_rawvalue;
Inactive_C2=v070_rawvalue;
keep
CountyFIPS
Obesity_C2
STD_CT_C2
STD_CT_n_C2
STD_CT_d_C2
InsuredA_C2
InsuredA_n_C2
InsuredA_d_C2
Insured_C2
Insured_n_C2
Insured_d_C2
PCP_C2
PCP_n_C2
PCP_d_C2
PCP_r_C2
PrvtHosp_C2
PrvtHosp_d_C2
DiabetM_C2
DiabetM_d_C2
Mammo_C2
Mammo_d_C2
Violent_C2
Violent_n_C2
Violent_d_C2
AccFood_C2
AccFood_n_C2
AccFood_d_C2
FastFood_C2
FastFood_n_C2
FastFood_d_C2
Gym_C2
Gym_n_C2
Gym_d_C2
Diabet_C2
Inactive_C2
;run;
/*N=3141, 35 variables*/
/***/;
data C2010;set C(rename=(fipscode=CountyFIPS));
PoorHlth_C2=v002_rawvalue;
PoorHlth_n_C2=v002_numerator;
PoorHlth_d_C2=v002_denominator;
PoorPhy_C2=v036_rawvalue;
PoorPhy_d_C2=v036_denominator;
PoorMH_C2=v042_rawvalue;
PoorMH_d_C2=v042_denominator;
Smoke_C2=v009_rawvalue;
Smoke_n_C2=v009_numerator;
Smoke_d_C2=v009_denominator;
EDrink_C2=v049_rawvalue;
EDrink_n_C2=v049_numerator;
EDrink_d_C2=v049_denominator;
SocSupp_C2=v040_rawvalue;
SocSupp_n_C2=v040_numerator;
SocSupp_d_C2=v040_denominator;
DrCost_C2=v087_rawvalue;
DrCost_n_C2=v087_numerator;
DrCost_d_C2=v087_denominator;
keep
CountyFIPS
PoorHlth_C2
PoorHlth_n_C2
PoorHlth_d_C2
PoorPhy_C2
PoorPhy_d_C2
PoorMH_C2
PoorMH_d_C2
Smoke_C2
Smoke_n_C2
Smoke_d_C2
EDrink_C2
EDrink_n_C2
EDrink_d_C2
SocSupp_C2
SocSupp_n_C2
SocSupp_d_C2
DrCost_C2
DrCost_n_C2
DrCost_d_C2
;run;
/*N=3141, 20 variables*/
/***/;
data D2008;set D(rename=(fipscode=CountyFIPS));
AirPM_D2=v125_rawvalue;
keep
CountyFIPS
AirPM_D2
;run;
/*N=3141, 2 variables*/
/***/;
data D2009;set D(rename=(fipscode=CountyFIPS));
Obesity_D2=v011_rawvalue;
Diabet_D2=v060_rawvalue;
HIV_D2=v061_rawvalue;
HIV_n_D2=v061_numerator;
Inactive_D2=v070_rawvalue;
HlthCost_D2=v086_rawvalue;
HlthCost_d_D2=v086_denominator;
keep
CountyFIPS
Obesity_D2
Diabet_D2
HIV_D2
HIV_n_D2
Inactive_D2
HlthCost_D2
HlthCost_d_D2
;run;
/*N=3141, 8 variables*/
/***/;
data D2010;set D(rename=(fipscode=CountyFIPS));
PrmDeath_D2=v001_rawvalue;
PrmDeath_n_D2=v001_numerator;
PrmDeath_d_D2=v001_denominator;
LowBW_D2=v037_rawvalue;
LowBW_n_D2=v037_numerator;
LowBW_d_D2=v037_denominator;
CarDeath_D2=v039_rawvalue;
CarDeath_n_D2=v039_numerator;
CarDeath_d_D2=v039_denominator;
STD_CT_D2=v045_rawvalue;
STD_CT_n_D2=v045_numerator;
STD_CT_d_D2=v045_denominator;
TeenBth_D2=v014_rawvalue;
TeenBth_n_D2=v014_numerator;
TeenBth_d_D2=v014_denominator;
InsuredA_D2=v003_rawvalue;
InsuredA_n_D2=v003_numerator;
InsuredA_d_D2=v003_denominator;
Insured_D2=v085_rawvalue;
Insured_n_D2=v085_numerator;
Insured_d_D2=v085_denominator;
InsuredC_D2=v122_rawvalue;
InsuredC_n_D2=v122_numerator;
InsuredC_d_D2=v122_denominator;
PrvtHosp_D2=v005_rawvalue;
PrvtHosp_d_D2=v005_denominator;
DiabetM_D2=v007_rawvalue;
DiabetM_d_D2=v007_denominator;
Mammo_D2=v050_rawvalue;
Mammo_d_D2=v050_denominator;
SocSupp_D2=v040_rawvalue;
SocSupp_n_D2=v040_numerator;
SocSupp_d_D2=v040_denominator;
Violent_D2=v043_rawvalue;
Violent_n_D2=v043_numerator;
Violent_d_D2=v043_denominator;
Murder_D2=v015_rawvalue;
Murder_n_D2=v015_numerator;
Murder_d_D2=v015_denominator;
FastFood_D2=v084_rawvalue;
FastFood_n_D2=v084_numerator;
FastFood_d_D2=v084_denominator;
Gym_D2=v068_rawvalue;
Gym_n_D2=v068_numerator;
PrmDeath2_D2=v127_rawvalue;
PrmDeath2_n_D2=v127_numerator;
PrmDeath2_d_D2=v127_denominator;
ChdDeath_D2=v128_rawvalue;
ChdDeath_n_D2=v128_numerator;
ChdDeath_d_D2=v128_denominator;
InfDeath_D2=v129_rawvalue;
InfDeath_n_D2=v129_numerator;
InfDeath_d_D2=v129_denominator;
Park_D2=v130_rawvalue;
keep
CountyFIPS
PrmDeath_D2
PrmDeath_n_D2
PrmDeath_d_D2
LowBW_D2
LowBW_n_D2
LowBW_d_D2
CarDeath_D2
CarDeath_n_D2
CarDeath_d_D2
STD_CT_D2
STD_CT_n_D2
STD_CT_d_D2
TeenBth_D2
TeenBth_n_D2
TeenBth_d_D2
InsuredA_D2
InsuredA_n_D2
InsuredA_d_D2
Insured_D2
Insured_n_D2
Insured_d_D2
InsuredC_D2
InsuredC_n_D2
InsuredC_d_D2
PrvtHosp_D2
PrvtHosp_d_D2
DiabetM_D2
DiabetM_d_D2
Mammo_D2
Mammo_d_D2
SocSupp_D2
SocSupp_n_D2
SocSupp_d_D2
Violent_D2
Violent_n_D2
Violent_d_D2
Murder_D2
Murder_n_D2
Murder_d_D2
FastFood_D2
FastFood_n_D2
FastFood_d_D2
Gym_D2
Gym_n_D2
PrmDeath2_D2
PrmDeath2_n_D2
PrmDeath2_d_D2
ChdDeath_D2
ChdDeath_n_D2
ChdDeath_d_D2
InfDeath_D2
InfDeath_n_D2
InfDeath_d_D2
Park_D2
;run;
/*N=3141, 55 variables*/
/***/;
data D2011;set D(rename=(fipscode=CountyFIPS));
PoorHlth_D2=v002_rawvalue;
PoorHlth_n_D2=v002_numerator;
PoorHlth_d_D2=v002_denominator;
PoorPhy_D2=v036_rawvalue;
PoorPhy_d_D2=v036_denominator;
PoorMH_D2=v042_rawvalue;
PoorMH_d_D2=v042_denominator;
Smoke_D2=v009_rawvalue;
Smoke_n_D2=v009_numerator;
Smoke_d_D2=v009_denominator;
EDrink_D2=v049_rawvalue;
EDrink_n_D2=v049_numerator;
EDrink_d_D2=v049_denominator;
FrLunch_D2=v065_rawvalue;
FrLunch_n_D2=v065_numerator;
FrLunch_d_D2=v065_denominator;
DrCost_D2=v087_rawvalue;
DrCost_n_D2=v087_numerator;
DrCost_d_D2=v087_denominator;
keep
CountyFIPS
PoorHlth_D2
PoorHlth_n_D2
PoorHlth_d_D2
PoorPhy_D2
PoorPhy_d_D2
PoorMH_D2
PoorMH_d_D2
Smoke_D2
Smoke_n_D2
Smoke_d_D2
EDrink_D2
EDrink_n_D2
EDrink_d_D2
FrLunch_D2
FrLunch_n_D2
FrLunch_d_D2
DrCost_D2
DrCost_n_D2
DrCost_d_D2
;run;
/*N=3141, 20 variables*/
/***/;
data D2012;set D(rename=(fipscode=CountyFIPS));
PCP_D2=v004_rawvalue;
PCP_n_D2=v004_numerator;
PCP_d_D2=v004_denominator;
PCP_r_D2=v004_other_data_1;
Water_D2=v124_rawvalue;
Water_n_D2=v124_numerator;
Water_d_D2=v124_denominator;
LAccFood_D2=v083_rawvalue;
LAccFood_n_D2=v083_numerator;
MHPrvd_D2=v062_rawvalue;
MHPrvd_n_D2=v062_numerator;
MHPrvd_d_D2=v062_denominator;
MHPrvd_r_D2=v062_other_data_1;
Dentist_D2=v088_rawvalue;
Dentist_n_D2=v088_numerator;
Dentist_d_D2=v088_denominator;
Dentist_r_D2=v088_other_data_1;
keep
CountyFIPS
PCP_D2
PCP_n_D2
PCP_d_D2
PCP_r_D2
Water_D2
Water_n_D2
Water_d_D2
LAccFood_D2
LAccFood_n_D2
MHPrvd_D2
MHPrvd_n_D2
MHPrvd_d_D2
MHPrvd_r_D2
Dentist_D2
Dentist_n_D2
Dentist_d_D2
Dentist_r_D2
;run;
/*N=3141, 18 variables*/
/***/;
data E2008;set E(rename=(fipscode=CountyFIPS));
InfDeath_E2=v129_rawvalue;
keep 
CountyFIPS
InfDeath_E2
;run;
/*N=3141, 2 variables*/
/***/;
data E2010;set E(rename=(fipscode=CountyFIPS));
PrmDeath_E2=v001_rawvalue;
PrmDeath_n_E2=v001_numerator;
PrmDeath_d_E2=v001_denominator;
Obesity_E2=v011_rawvalue;
CarDeath_E2=v039_rawvalue;
CarDeath_n_E2=v039_numerator;
CarDeath_d_E2=v039_denominator;
SocSupp_E2=v040_rawvalue;
SocSupp_n_E2=v040_numerator;
SocSupp_d_E2=v040_denominator;
Murder_E2=v015_rawvalue;
Murder_n_E2=v015_numerator;
Murder_d_E2=v015_denominator;
Diabet_E2=v060_rawvalue;
Diabet_n_E2=v060_numerator;
Diabet_d_E2=v060_denominator;
HIV_E2=v061_rawvalue;
HIV_n_E2=v061_numerator;
HIV_d_E2=v061_denominator;
Inactive_E2=v070_rawvalue;
Inactive_n_E2=v070_numerator;
Inactive_d_E2=v070_denominator;
PrmDeath2_E2=v127_rawvalue;
PrmDeath2_n_E2=v127_numerator;
PrmDeath2_d_E2=v127_denominator;
ChdDeath_E2=v128_rawvalue;
ChdDeath_n_E2=v128_numerator;
ChdDeath_d_E2=v128_denominator;
Injury_E2=v135_rawvalue;
Injury_n_E2=v135_numerator;
Injury_d_E2=v135_denominator;
Housing_E2=v136_rawvalue;
Housing_n_E2=v136_numerator;
Housing_d_E2=v136_denominator;
DrugOd_E2=v138_rawvalue;
DrugOd_n_E2=v138_numerator;
DrugOd_d_E2=v138_denominator;
keep
CountyFIPS
PrmDeath_E2
PrmDeath_n_E2
PrmDeath_d_E2
Obesity_E2
CarDeath_E2
CarDeath_n_E2
CarDeath_d_E2
SocSupp_E2
SocSupp_n_E2
SocSupp_d_E2
Murder_E2
Murder_n_E2
Murder_d_E2
Diabet_E2
Diabet_n_E2
Diabet_d_E2
HIV_E2
HIV_n_E2
HIV_d_E2
Inactive_E2
Inactive_n_E2
Inactive_d_E2
PrmDeath2_E2
PrmDeath2_n_E2
PrmDeath2_d_E2
ChdDeath_E2
ChdDeath_n_E2
ChdDeath_d_E2
Injury_E2
Injury_n_E2
Injury_d_E2
Housing_E2
Housing_n_E2
Housing_d_E2
DrugOd_E2
DrugOd_n_E2
DrugOd_d_E2
;run;
/*N=3141, 38 variables*/
/***/;
data E2011;set E(rename=(fipscode=CountyFIPS));
LowBW_E2=v037_rawvalue;
LowBW_n_E2=v037_numerator;
LowBW_d_E2=v037_denominator;
STD_CT_E2=v045_rawvalue;
STD_CT_n_E2=v045_numerator;
STD_CT_d_E2=v045_denominator;
TeenBth_E2=v014_rawvalue;
TeenBth_n_E2=v014_numerator;
TeenBth_d_E2=v014_denominator;
InsuredA_E2=v003_rawvalue;
InsuredA_n_E2=v003_numerator;
InsuredA_d_E2=v003_denominator;
Insured_E2=v085_rawvalue;
Insured_n_E2=v085_numerator;
Insured_d_E2=v085_denominator;
InsuredC_E2=v122_rawvalue;
InsuredC_n_E2=v122_numerator;
InsuredC_d_E2=v122_denominator;
PCP_E2=v004_rawvalue;
PCP_n_E2=v004_numerator;
PCP_d_E2=v004_denominator;
PCP_r_E2=v004_other_data_1;
PrvtHosp_E2=v005_rawvalue;
PrvtHosp_d_E2=v005_denominator;
DiabetM_E2=v007_rawvalue;
DiabetM_d_E2=v007_denominator;
Mammo_E2=v050_rawvalue;
Mammo_d_E2=v050_denominator;
Violent_E2=v043_rawvalue;
Violent_n_E2=v043_numerator;
Violent_d_E2=v043_denominator;
AirPM_E2=v125_rawvalue;
FoodEnv_E2=v133_rawvalue;
FoodEnv_n_E2=v133_numerator;
FoodEnv_d_E2=v133_denominator;
HlthCost_E2=v086_rawvalue;
HlthCost_d_E2=v086_denominator;
FrLunch_E2=v065_rawvalue;
FrLunch_n_E2=v065_numerator;
FrLunch_d_E2=v065_denominator;
FoodIns_E2=v139_rawvalue;
FoodIns_n_E2=v139_numerator;
FoodIns_d_E2=v139_denominator;
keep
CountyFIPS
LowBW_E2
LowBW_n_E2
LowBW_d_E2
STD_CT_E2
STD_CT_n_E2
STD_CT_d_E2
TeenBth_E2
TeenBth_n_E2
TeenBth_d_E2
InsuredA_E2
InsuredA_n_E2
InsuredA_d_E2
Insured_E2
Insured_n_E2
Insured_d_E2
InsuredC_E2
InsuredC_n_E2
InsuredC_d_E2
PCP_E2
PCP_n_E2
PCP_d_E2
PCP_r_E2
PrvtHosp_E2
PrvtHosp_d_E2
DiabetM_E2
DiabetM_d_E2
Mammo_E2
Mammo_d_E2
Violent_E2
Violent_n_E2
Violent_d_E2
AirPM_E2
FoodEnv_E2
FoodEnv_n_E2
FoodEnv_d_E2
HlthCost_E2
HlthCost_d_E2
FrLunch_E2
FrLunch_n_E2
FrLunch_d_E2
FoodIns_E2
FoodIns_n_E2
FoodIns_d_E2
;run;
/*N=3141, 44 variables*/
/***/;
data E2012;set E(rename=(fipscode=CountyFIPS));
PoorHlth_E2=v002_rawvalue;
PoorHlth_n_E2=v002_numerator;
PoorHlth_d_E2=v002_denominator;
PoorPhy_E2=v036_rawvalue;
PoorPhy_d_E2=v036_denominator;
PoorMH_E2=v042_rawvalue;
PoorMH_d_E2=v042_denominator;
Smoke_E2=v009_rawvalue;
Smoke_n_E2=v009_numerator;
Smoke_d_E2=v009_denominator;
EDrink_E2=v049_rawvalue;
EDrink_n_E2=v049_numerator;
EDrink_d_E2=v049_denominator;
DWIDeath_E2=v134_rawvalue;
DWIDeath_n_E2=v134_numerator;
DWIDeath_d_E2=v134_denominator;
LAccFood_E2=v083_rawvalue;
LAccFood_n_E2=v083_numerator;
Gym2_E2=v132_rawvalue;
DrCost_E2=v087_rawvalue;
DrCost_n_E2=v087_numerator;
DrCost_d_E2=v087_denominator;
Dentist_E2=v088_rawvalue;
Dentist_n_E2=v088_numerator;
Dentist_d_E2=v088_denominator;
Dentist_r_E2=v088_other_data_1;
LongComm_E2=v137_rawvalue;
LongComm_d_E2=v137_denominator;
keep
CountyFIPS
PoorHlth_E2
PoorHlth_n_E2
PoorHlth_d_E2
PoorPhy_E2
PoorPhy_d_E2
PoorMH_E2
PoorMH_d_E2
Smoke_E2
Smoke_n_E2
Smoke_d_E2
EDrink_E2
EDrink_n_E2
EDrink_d_E2
DWIDeath_E2
DWIDeath_n_E2
DWIDeath_d_E2
LAccFood_E2
LAccFood_n_E2
Gym2_E2
DrCost_E2
DrCost_n_E2
DrCost_d_E2
Dentist_E2
Dentist_n_E2
Dentist_d_E2
Dentist_r_E2
LongComm_E2
LongComm_d_E2
;run;
/*N=3141, 29 variables*/
/***/;
data E2013;set E(rename=(fipscode=CountyFIPS));
PCP2_d_E2=v131_denominator;
Water_E2=v124_rawvalue;
Water_n_E2=v124_numerator;
Water_d_E2=v124_denominator;
MHPrvd_E2=v062_rawvalue;
MHPrvd_n_E2=v062_numerator;
MHPrvd_d_E2=v062_denominator;
MHPrvd_r_E2=v062_other_data_1;
keep
CountyFIPS
PCP2_d_E2
Water_E2
Water_n_E2
Water_d_E2
MHPrvd_E2
MHPrvd_n_E2
MHPrvd_d_E2
MHPrvd_r_E2
;run;
/*N=3141, 9 variables*/
/***/;
data F2010;set F(rename=(fipscode=CountyFIPS));
LAccFood_F2=v083_rawvalue;
LAccFood_n_F2=v083_numerator;
HIV_F2=v061_rawvalue;
HIV_n_F2=v061_numerator;
HIV_d_F2=v061_denominator;
InfDeath_F2=v129_rawvalue;
InfDeath_n_F2=v129_numerator;
InfDeath_d_F2=v129_denominator;
keep
CountyFIPS
LAccFood_F2
LAccFood_n_F2
HIV_F2
HIV_n_F2
HIV_d_F2
InfDeath_F2
InfDeath_n_F2
InfDeath_d_F2
;run;
/*N=3141, 9 variables*/
/***/;
data F2011;set F(rename=(fipscode=CountyFIPS));
Obesity_F2=v011_rawvalue;
Obesity_n_F2=v011_numerator;
Obesity_d_F2=v011_denominator;
AirPM_F2=v125_rawvalue;
Diabet_F2=v060_rawvalue;
Diabet_n_F2=v060_numerator;
Diabet_d_F2=v060_denominator;
Inactive_F2=v070_rawvalue;
Inactive_n_F2=v070_numerator;
Inactive_d_F2=v070_denominator;
Housing_F2=v136_rawvalue;
Housing_n_F2=v136_numerator;
Housing_d_F2=v136_denominator;
keep
CountyFIPS
Obesity_F2
Obesity_n_F2
Obesity_d_F2
AirPM_F2
Diabet_F2
Diabet_n_F2
Diabet_d_F2
Inactive_F2
Inactive_n_F2
Inactive_d_F2
Housing_F2
Housing_n_F2
Housing_d_F2
;run;
/*N=3141, 14 variables*/
/***/;
data F2012;set F(rename=(fipscode=CountyFIPS));
PrmDeath_F2=v001_rawvalue;
PrmDeath_n_F2=v001_numerator;
PrmDeath_d_F2=v001_denominator;
PoorHlth_F2=v002_rawvalue;
PoorHlth_n_F2=v002_numerator;
PoorHlth_d_F2=v002_denominator;
PoorPhy_F2=v036_rawvalue;
PoorPhy_d_F2=v036_denominator;
PoorMH_F2=v042_rawvalue;
PoorMH_d_F2=v042_denominator;
LowBW_F2=v037_rawvalue;
LowBW_n_F2=v037_numerator;
LowBW_d_F2=v037_denominator;
Smoke_F2=v009_rawvalue;
Smoke_n_F2=v009_numerator;
Smoke_d_F2=v009_denominator;
EDrink_F2=v049_rawvalue;
EDrink_n_F2=v049_numerator;
EDrink_d_F2=v049_denominator;
CarDeath_F2=v039_rawvalue;
CarDeath_n_F2=v039_numerator;
CarDeath_d_F2=v039_denominator;
STD_CT_F2=v045_rawvalue;
STD_CT_n_F2=v045_numerator;
STD_CT_d_F2=v045_denominator;
TeenBth_F2=v014_rawvalue;
TeenBth_n_F2=v014_numerator;
TeenBth_d_F2=v014_denominator;
InsuredA_F2=v003_rawvalue;
InsuredA_n_F2=v003_numerator;
InsuredA_d_F2=v003_denominator;
Insured_F2=v085_rawvalue;
Insured_n_F2=v085_numerator;
Insured_d_F2=v085_denominator;
InsuredC_F2=v122_rawvalue;
InsuredC_n_F2=v122_numerator;
InsuredC_d_F2=v122_denominator;
PCP_F2=v004_rawvalue;
PCP_n_F2=v004_numerator;
PCP_d_F2=v004_denominator;
PCP_r_F2=v004_other_data_1;
PrvtHosp_F2=v005_rawvalue;
PrvtHosp_d_F2=v005_denominator;
DiabetM_F2=v007_rawvalue;
DiabetM_d_F2=v007_denominator;
Mammo_F2=v050_rawvalue;
Mammo_d_F2=v050_denominator;
SocAsso_F2=v140_rawvalue;
SocAsso_n_F2=v140_numerator;
SocAsso_d_F2=v140_denominator;
Violent_F2=v043_rawvalue;
Violent_n_F2=v043_numerator;
Violent_d_F2=v043_denominator;
Murder_F2=v015_rawvalue;
Murder_n_F2=v015_numerator;
Murder_d_F2=v015_denominator;
FoodEnv_F2=v133_rawvalue;
FoodEnv_n_F2=v133_numerator;
FoodEnv_d_F2=v133_denominator;
HlthCost_F2=v086_rawvalue;
HlthCost_d_F2=v086_denominator;
FrLunch_F2=v065_rawvalue;
FrLunch_n_F2=v065_numerator;
FrLunch_d_F2=v065_denominator;
DrCost_F2=v087_rawvalue;
DrCost_n_F2=v087_numerator;
DrCost_d_F2=v087_denominator;
PrmDeath2_F2=v127_rawvalue;
PrmDeath2_n_F2=v127_numerator;
PrmDeath2_d_F2=v127_denominator;
ChdDeath_F2=v128_rawvalue;
ChdDeath_n_F2=v128_numerator;
ChdDeath_d_F2=v128_denominator;
Injury_F2=v135_rawvalue;
Injury_n_F2=v135_numerator;
Injury_d_F2=v135_denominator;
FoodIns_F2=v139_rawvalue;
FoodIns_n_F2=v139_numerator;
DrugOd_F2=v138_rawvalue;
DrugOd_n_F2=v138_numerator;
DrugOd_d_F2=v138_denominator;
keep
CountyFIPS
PrmDeath_F2
PrmDeath_n_F2
PrmDeath_d_F2
PoorHlth_F2
PoorHlth_n_F2
PoorHlth_d_F2
PoorPhy_F2
PoorPhy_d_F2
PoorMH_F2
PoorMH_d_F2
LowBW_F2
LowBW_n_F2
LowBW_d_F2
Smoke_F2
Smoke_n_F2
Smoke_d_F2
EDrink_F2
EDrink_n_F2
EDrink_d_F2
CarDeath_F2
CarDeath_n_F2
CarDeath_d_F2
STD_CT_F2
STD_CT_n_F2
STD_CT_d_F2
TeenBth_F2
TeenBth_n_F2
TeenBth_d_F2
InsuredA_F2
InsuredA_n_F2
InsuredA_d_F2
Insured_F2
Insured_n_F2
Insured_d_F2
InsuredC_F2
InsuredC_n_F2
InsuredC_d_F2
PCP_F2
PCP_n_F2
PCP_d_F2
PCP_r_F2
PrvtHosp_F2
PrvtHosp_d_F2
DiabetM_F2
DiabetM_d_F2
Mammo_F2
Mammo_d_F2
SocAsso_F2
SocAsso_n_F2
SocAsso_d_F2
Violent_F2
Violent_n_F2
Violent_d_F2
Murder_F2
Murder_n_F2
Murder_d_F2
FoodEnv_F2
FoodEnv_n_F2
FoodEnv_d_F2
HlthCost_F2
HlthCost_d_F2
FrLunch_F2
FrLunch_n_F2
FrLunch_d_F2
DrCost_F2
DrCost_n_F2
DrCost_d_F2
PrmDeath2_F2
PrmDeath2_n_F2
PrmDeath2_d_F2
ChdDeath_F2
ChdDeath_n_F2
ChdDeath_d_F2
Injury_F2
Injury_n_F2
Injury_d_F2
FoodIns_F2
FoodIns_n_F2
DrugOd_F2
DrugOd_n_F2
DrugOd_d_F2
;run;
/*N=3141, 82 variables*/
/***/;
data F2013;set F(rename=(fipscode=CountyFIPS));
DWIDeath_F2=v134_rawvalue;
DWIDeath_n_F2=v134_numerator;
DWIDeath_d_F2=v134_denominator;
Gym2_F2=v132_rawvalue;
Gym2_n_F2=v132_numerator;
Gym2_d_F2=v132_denominator;
Dentist_F2=v088_rawvalue;
Dentist_n_F2=v088_numerator;
Dentist_d_F2=v088_denominator;
Dentist_r_F2=v088_other_data_1;
LongComm_F2=v137_rawvalue;
LongComm_d_F2=v137_denominator;
keep
CountyFIPS
DWIDeath_F2
DWIDeath_n_F2
DWIDeath_d_F2
Gym2_F2
Gym2_n_F2
Gym2_d_F2
Dentist_F2
Dentist_n_F2
Dentist_d_F2
Dentist_r_F2
LongComm_F2
LongComm_d_F2
;run;
/*N=3141, 13 variables*/
/***/;
data F2014;set F(rename=(fipscode=CountyFIPS));
PCP2_F2=v131_rawvalue;
PCP2_n_F2=v131_numerator;
PCP2_d_F2=v131_denominator;
PCP2_r_F2=v131_other_data_1;
Water_F2=v124_rawvalue;
Water_n_F2=v124_numerator;
Water_d_F2=v124_denominator;
MHPrvd_F2=v062_rawvalue;
MHPrvd_n_F2=v062_numerator;
MHPrvd_d_F2=v062_denominator;
MHPrvd_r_F2=v062_other_data_1;
keep
CountyFIPS
PCP2_F2
PCP2_n_F2
PCP2_d_F2
PCP2_r_F2
Water_F2
Water_n_F2
Water_d_F2
MHPrvd_F2
MHPrvd_n_F2
MHPrvd_d_F2
MHPrvd_r_F2
;run;
/*N=3141, 12 variables*/
/***/;
data G2010;set G(rename=(fipscode=CountyFIPS));
LAccFood_G2=v083_rawvalue;
LAccFood_n_G2=v083_numerator;
keep
CountyFIPS
LAccFood_G2
LAccFood_n_G2
;run;
/*N=3141, 3 variables*/
/***/;
data G2011;set G(rename=(fipscode=CountyFIPS));
AirPM_G2=v125_rawvalue;
keep
CountyFIPS
AirPM_G2
;run;
/*N=3141, 2 variables*/
/***/;
data G2012;set G(rename=(fipscode=CountyFIPS));
Obesity_G2=v011_rawvalue;
Obesity_n_G2=v011_numerator;
Obesity_d_G2=v011_denominator;
Violent_G2=v043_rawvalue;
Violent_n_G2=v043_numerator;
Violent_d_G2=v043_denominator;
Diabet_G2=v060_rawvalue;
HIV_G2=v061_rawvalue;
HIV_n_G2=v061_numerator;
HIV_d_G2=v061_denominator;
Inactive_G2=v070_rawvalue;
Inactive_n_G2=v070_numerator;
Inactive_d_G2=v070_denominator;
InfDeath_G2=v129_rawvalue;
InfDeath_n_G2=v129_numerator;
InfDeath_d_G2=v129_denominator;
Housing_G2=v136_rawvalue;
Housing_n_G2=v136_numerator;
Housing_d_G2=v136_denominator;
keep
CountyFIPS
Obesity_G2
Obesity_n_G2
Obesity_d_G2
Violent_G2
Violent_n_G2
Violent_d_G2
Diabet_G2
HIV_G2
HIV_n_G2
HIV_d_G2
Inactive_G2
Inactive_n_G2
Inactive_d_G2
InfDeath_G2
InfDeath_n_G2
InfDeath_d_G2
Housing_G2
Housing_n_G2
Housing_d_G2
;run;
/*N=3141, 20 variables*/
/***/;
data G2013;set G(rename=(fipscode=CountyFIPS));
PrmDeath_G2=v001_rawvalue;
PrmDeath_n_G2=v001_numerator;
PrmDeath_d_G2=v001_denominator;
LowBW_G2=v037_rawvalue;
LowBW_n_G2=v037_numerator;
LowBW_d_G2=v037_denominator;
CarDeath_G2=v039_rawvalue;
CarDeath_n_G2=v039_numerator;
CarDeath_d_G2=v039_denominator;
STD_CT_G2=v045_rawvalue;
STD_CT_n_G2=v045_numerator;
STD_CT_d_G2=v045_denominator;
TeenBth_G2=v014_rawvalue;
TeenBth_n_G2=v014_numerator;
TeenBth_d_G2=v014_denominator;
InsuredA_G2=v003_rawvalue;
InsuredA_n_G2=v003_numerator;
InsuredA_d_G2=v003_denominator;
Insured_G2=v085_rawvalue;
Insured_n_G2=v085_numerator;
Insured_d_G2=v085_denominator;
InsuredC_G2=v122_rawvalue;
InsuredC_n_G2=v122_numerator;
InsuredC_d_G2=v122_denominator;
PCP_G2=v004_rawvalue;
PCP_n_G2=v004_numerator;
PCP_d_G2=v004_denominator;
PCP_r_G2=v004_other_data_1;
PrvtHosp_G2=v005_rawvalue;
PrvtHosp_d_G2=v005_denominator;
DiabetM_G2=v007_rawvalue;
DiabetM_d_G2=v007_denominator;
Mammo_G2=v050_rawvalue;
Mammo_d_G2=v050_denominator;
SocAsso_G2=v140_rawvalue;
SocAsso_n_G2=v140_numerator;
SocAsso_d_G2=v140_denominator;
Murder_G2=v015_rawvalue;
Murder_n_G2=v015_numerator;
Murder_d_G2=v015_denominator;
FoodEnv_G2=v133_rawvalue;
FoodEnv_n_G2=v133_numerator;
FoodEnv_d_G2=v133_denominator;
HlthCost_G2=v086_rawvalue;
HlthCost_d_G2=v086_denominator;
FrLunch_G2=v065_rawvalue;
FrLunch_n_G2=v065_numerator;
FrLunch_d_G2=v065_denominator;
PrmDeath2_G2=v127_rawvalue;
PrmDeath2_n_G2=v127_numerator;
PrmDeath2_d_G2=v127_denominator;
ChdDeath_G2=v128_rawvalue;
ChdDeath_n_G2=v128_numerator;
ChdDeath_d_G2=v128_denominator;
Injury_G2=v135_rawvalue;
Injury_n_G2=v135_numerator;
Injury_d_G2=v135_denominator;
FoodIns_G2=v139_rawvalue;
FoodIns_n_G2=v139_numerator;
keep
CountyFIPS
PrmDeath_G2
PrmDeath_n_G2
PrmDeath_d_G2
LowBW_G2
LowBW_n_G2
LowBW_d_G2
CarDeath_G2
CarDeath_n_G2
CarDeath_d_G2
STD_CT_G2
STD_CT_n_G2
STD_CT_d_G2
TeenBth_G2
TeenBth_n_G2
TeenBth_d_G2
InsuredA_G2
InsuredA_n_G2
InsuredA_d_G2
Insured_G2
Insured_n_G2
Insured_d_G2
InsuredC_G2
InsuredC_n_G2
InsuredC_d_G2
PCP_G2
PCP_n_G2
PCP_d_G2
PCP_r_G2
PrvtHosp_G2
PrvtHosp_d_G2
DiabetM_G2
DiabetM_d_G2
Mammo_G2
Mammo_d_G2
SocAsso_G2
SocAsso_n_G2
SocAsso_d_G2
Murder_G2
Murder_n_G2
Murder_d_G2
FoodEnv_G2
FoodEnv_n_G2
FoodEnv_d_G2
HlthCost_G2
HlthCost_d_G2
FrLunch_G2
FrLunch_n_G2
FrLunch_d_G2
PrmDeath2_G2
PrmDeath2_n_G2
PrmDeath2_d_G2
ChdDeath_G2
ChdDeath_n_G2
ChdDeath_d_G2
Injury_G2
Injury_n_G2
Injury_d_G2
FoodIns_G2
FoodIns_n_G2
;run;
/*N=3141, 60 variables*/
/***/;
data G2014;set G(rename=(fipscode=CountyFIPS));
PoorHlth_G2=v002_rawvalue;
PoorPhy_G2=v036_rawvalue;
PoorMH_G2=v042_rawvalue;
Smoke_G2=v009_rawvalue;
EDrink_G2=v049_rawvalue;
DWIDeath_G2=v134_rawvalue;
DWIDeath_n_G2=v134_numerator;
DWIDeath_d_G2=v134_denominator;
Water2_G2=v124_rawvalue;
Gym2_G2=v132_rawvalue;
Dentist_G2=v088_rawvalue;
Dentist_n_G2=v088_numerator;
Dentist_d_G2=v088_denominator;
Dentist_r_G2=v088_other_data_1;
LongComm_G2=v137_rawvalue;
LongComm_d_G2=v137_denominator;
DrugOd_G2=v138_rawvalue;
DrugOd_n_G2=v138_numerator;
DrugOd_d_G2=v138_denominator;
DrugOdm_G2=v146_rawvalue;
Physical_G2=v144_rawvalue;
Mental_G2=v145_rawvalue;
Sleep_G2=v143_rawvalue;
SegBW_G2=v141_rawvalue;
SegNW_G2=v142_rawvalue;
keep
CountyFIPS
PoorHlth_G2
PoorPhy_G2
PoorMH_G2
Smoke_G2
EDrink_G2
DWIDeath_G2
DWIDeath_n_G2
DWIDeath_d_G2
Water2_G2
Gym2_G2
Dentist_G2
Dentist_n_G2
Dentist_d_G2
Dentist_r_G2
LongComm_G2
LongComm_d_G2
DrugOd_G2
DrugOd_n_G2
DrugOd_d_G2
DrugOdm_G2
Physical_G2
Mental_G2
Sleep_G2
SegBW_G2
SegNW_G2
;run;
/*N=3141, 26 variables*/
/***/;
data G2015;set G(rename=(fipscode=CountyFIPS));
PCP2_G2=v131_rawvalue;
PCP2_n_G2=v131_numerator;
PCP2_d_G2=v131_denominator;
PCP2_r_G2=v131_other_data_1;
MHPrvd_G2=v062_rawvalue;
MHPrvd_n_G2=v062_numerator;
MHPrvd_d_G2=v062_denominator;
MHPrvd_r_G2=v062_other_data_1;
keep
CountyFIPS
PCP2_G2
PCP2_n_G2
PCP2_d_G2
PCP2_r_G2
MHPrvd_G2
MHPrvd_n_G2
MHPrvd_d_G2
MHPrvd_r_G2
;run;
/*N=3141, 9 variables*/
/***/;
data H2010;set H(rename=(fipscode=CountyFIPS));
LAccFood_H2=v083_rawvalue;
LAccFood_n_H2=v083_numerator;
keep
CountyFIPS
LAccFood_H2
LAccFood_n_H2
;run;
/*N=3137, 3 variables*/
/***/;
data H2012;set H(rename=(fipscode=CountyFIPS));
AirPM_H2=v125_rawvalue;
DcYouth_H2=v149_rawvalue;
keep
CountyFIPS
AirPM_H2
DcYouth_H2
;run;
/*N=3137, 3 variables*/
/***/;
data H2013;set H(rename=(fipscode=CountyFIPS));
Obesity_H2=v011_rawvalue;
Obesity_n_H2=v011_numerator;
Obesity_d_H2=v011_denominator;
Diabet_H2=v060_rawvalue;
Diabet_n_H2=v060_numerator;
Diabet_d_H2=v060_denominator;
HIV_H2=v061_rawvalue;
HIV_n_H2=v061_numerator;
HIV_d_H2=v061_denominator;
Inactive_H2=v070_rawvalue;
Inactive_n_H2=v070_numerator;
Inactive_d_H2=v070_denominator;
InfDeath_H2=v129_rawvalue;
InfDeath_n_H2=v129_numerator;
InfDeath_d_H2=v129_denominator;
Housing_H2=v136_rawvalue;
Housing_n_H2=v136_numerator;
Housing_d_H2=v136_denominator;
keep
CountyFIPS
Obesity_H2
Obesity_n_H2
Obesity_d_H2
Diabet_H2
Diabet_n_H2
Diabet_d_H2
HIV_H2
HIV_n_H2
HIV_d_H2
Inactive_H2
Inactive_n_H2
Inactive_d_H2
InfDeath_H2
InfDeath_n_H2
InfDeath_d_H2
Housing_H2
Housing_n_H2
Housing_d_H2
;run;
/*N=3137, 19 variables*/
/***/;
data H2014;set H(rename=(fipscode=CountyFIPS));
PrmDeath_H2=v001_rawvalue;
PrmDeath_n_H2=v001_numerator;
PrmDeath_d_H2=v001_denominator;
LowBW_H2=v037_rawvalue;
LowBW_n_H2=v037_numerator;
LowBW_d_H2=v037_denominator;
STD_CT_H2=v045_rawvalue;
STD_CT_n_H2=v045_numerator;
STD_CT_d_H2=v045_denominator;
TeenBth_H2=v014_rawvalue;
TeenBth_n_H2=v014_numerator;
TeenBth_d_H2=v014_denominator;
InsuredA_H2=v003_rawvalue;
InsuredA_n_H2=v003_numerator;
InsuredA_d_H2=v003_denominator;
Insured_H2=v085_rawvalue;
Insured_n_H2=v085_numerator;
Insured_d_H2=v085_denominator;
InsuredC_H2=v122_rawvalue;
InsuredC_n_H2=v122_numerator;
InsuredC_d_H2=v122_denominator;
PCP_H2=v004_rawvalue;
PCP_n_H2=v004_numerator;
PCP_d_H2=v004_denominator;
PCP_r_H2=v004_other_data_1;
PrvtHosp_H2=v005_rawvalue;
PrvtHosp_d_H2=v005_denominator;
DiabetM_H2=v007_rawvalue;
DiabetM_d_H2=v007_denominator;
Mammo_H2=v050_rawvalue;
Mammo_d_H2=v050_denominator;
SocAsso_H2=v140_rawvalue;
SocAsso_n_H2=v140_numerator;
SocAsso_d_H2=v140_denominator;
Violent_H2=v043_rawvalue;
Violent_n_H2=v043_numerator;
Violent_d_H2=v043_denominator;
Water2_H2=v124_rawvalue;
FoodEnv_H2=v133_rawvalue;
FoodEnv_n_H2=v133_numerator;
FoodEnv_d_H2=v133_denominator;
Gym2_H2=v132_rawvalue;
HlthCost_H2=v086_rawvalue;
HlthCost_d_H2=v086_denominator;
FoodIns_H2=v139_rawvalue;
FoodIns_n_H2=v139_numerator;
Sleep_H2=v143_rawvalue;
keep
CountyFIPS
PrmDeath_H2
PrmDeath_n_H2
PrmDeath_d_H2
LowBW_H2
LowBW_n_H2
LowBW_d_H2
STD_CT_H2
STD_CT_n_H2
STD_CT_d_H2
TeenBth_H2
TeenBth_n_H2
TeenBth_d_H2
InsuredA_H2
InsuredA_n_H2
InsuredA_d_H2
Insured_H2
Insured_n_H2
Insured_d_H2
InsuredC_H2
InsuredC_n_H2
InsuredC_d_H2
PCP_H2
PCP_n_H2
PCP_d_H2
PCP_r_H2
PrvtHosp_H2
PrvtHosp_d_H2
DiabetM_H2
DiabetM_d_H2
Mammo_H2
Mammo_d_H2
SocAsso_H2
SocAsso_n_H2
SocAsso_d_H2
Violent_H2
Violent_n_H2
Violent_d_H2
Water2_H2
FoodEnv_H2
FoodEnv_n_H2
FoodEnv_d_H2
Gym2_H2
HlthCost_H2
HlthCost_d_H2
FoodIns_H2
FoodIns_n_H2
Sleep_H2
;run;
/*N=3137, 48 variables*/
/***/;
data H2015;set H(rename=(fipscode=CountyFIPS));
PoorHlth_H2=v002_rawvalue;
PoorPhy_H2=v036_rawvalue;
PoorMH_H2=v042_rawvalue;
Smoke_H2=v009_rawvalue;
EDrink_H2=v049_rawvalue;
DWIDeath_H2=v134_rawvalue;
DWIDeath_n_H2=v134_numerator;
DWIDeath_d_H2=v134_denominator;
CarDeath_H2=v039_rawvalue;
CarDeath_n_H2=v039_numerator;
CarDeath_d_H2=v039_denominator;
Murder_H2=v015_rawvalue;
Murder_n_H2=v015_numerator;
Murder_d_H2=v015_denominator;
FrLunch_H2=v065_rawvalue;
FrLunch_n_H2=v065_numerator;
FrLunch_d_H2=v065_denominator;
Dentist_H2=v088_rawvalue;
Dentist_n_H2=v088_numerator;
Dentist_d_H2=v088_denominator;
Dentist_r_H2=v088_other_data_1;
PrmDeath2_H2=v127_rawvalue;
PrmDeath2_n_H2=v127_numerator;
PrmDeath2_d_H2=v127_denominator;
ChdDeath_H2=v128_rawvalue;
ChdDeath_n_H2=v128_numerator;
ChdDeath_d_H2=v128_denominator;
Injury_H2=v135_rawvalue;
Injury_n_H2=v135_numerator;
Injury_d_H2=v135_denominator;
LongComm_H2=v137_rawvalue;
LongComm_d_H2=v137_denominator;
DrugOd_H2=v138_rawvalue;
DrugOd_n_H2=v138_numerator;
DrugOd_d_H2=v138_denominator;
Physical_H2=v144_rawvalue;
Mental_H2=v145_rawvalue;
SegBW_H2=v141_rawvalue;
SegNW_H2=v142_rawvalue;
GunDeath_H2=v148_rawvalue;
GunDeath_n_H2=v148_numerator;
GunDeath_d_H2=v148_denominator;
keep
CountyFIPS
PoorHlth_H2
PoorPhy_H2
PoorMH_H2
Smoke_H2
EDrink_H2
DWIDeath_H2
DWIDeath_n_H2
DWIDeath_d_H2
CarDeath_H2
CarDeath_n_H2
CarDeath_d_H2
Murder_H2
Murder_n_H2
Murder_d_H2
FrLunch_H2
FrLunch_n_H2
FrLunch_d_H2
Dentist_H2
Dentist_n_H2
Dentist_d_H2
Dentist_r_H2
PrmDeath2_H2
PrmDeath2_n_H2
PrmDeath2_d_H2
ChdDeath_H2
ChdDeath_n_H2
ChdDeath_d_H2
Injury_H2
Injury_n_H2
Injury_d_H2
LongComm_H2
LongComm_d_H2
DrugOd_H2
DrugOd_n_H2
DrugOd_d_H2
Physical_H2
Mental_H2
SegBW_H2
SegNW_H2
GunDeath_H2
GunDeath_n_H2
GunDeath_d_H2
;run;
/*N=3137, 43 variables*/
/***/;
data H2016;set H(rename=(fipscode=CountyFIPS));
PCP2_H2=v131_rawvalue;
PCP2_n_H2=v131_numerator;
PCP2_d_H2=v131_denominator;
PCP2_r_H2=v131_other_data_1;
MHPrvd_H2=v062_rawvalue;
MHPrvd_n_H2=v062_numerator;
MHPrvd_d_H2=v062_denominator;
MHPrvd_r_H2=v062_other_data_1;
keep
CountyFIPS
PCP2_H2
PCP2_n_H2
PCP2_d_H2
PCP2_r_H2
MHPrvd_H2
MHPrvd_n_H2
MHPrvd_d_H2
MHPrvd_r_H2
;run;
/*N=3137, 9 variables*/
/***/;
data I2012;set I(rename=(fipscode=CountyFIPS));
AirPM_I2=v125_rawvalue;
keep
CountyFIPS
AirPM_I2
;run;
/*N=3142, 2 variables*/
/***/;
data I2014;set I(rename=(fipscode=CountyFIPS));
Obesity_I2=v011_rawvalue;
Obesity_n_I2=v011_numerator;
Obesity_d_I2=v011_denominator;
DiabetM_I2=v007_rawvalue;
DiabetM_d_I2=v007_denominator;
DiabetW_I2=v007_other_data_1;
DiabetB_I2=v007_other_data_2;
Mammo_I2=v050_rawvalue;
Mammo_d_I2=v050_denominator;
MammoW_I2=v050_other_data_1;
MammoB_I2=v050_other_data_2;
Violent_I2=v043_rawvalue;
Violent_n_I2=v043_numerator;
Violent_d_I2=v043_denominator;
Diabet_I2=v060_rawvalue;
Diabet_n_I2=v060_numerator;
Diabet_d_I2=v060_denominator;
Inactive_I2=v070_rawvalue;
Inactive_n_I2=v070_numerator;
Inactive_d_I2=v070_denominator;
Housing_I2=v136_rawvalue;
Housing_n_I2=v136_numerator;
Housing_d_I2=v136_denominator;
DcYouth_I2=v149_rawvalue;
DcYouth_n_I2=v149_numerator;
keep
CountyFIPS
Obesity_I2
Obesity_n_I2
Obesity_d_I2
DiabetM_I2
DiabetM_d_I2
DiabetW_I2
DiabetB_I2
Mammo_I2
Mammo_d_I2
MammoW_I2
MammoB_I2
Violent_I2
Violent_n_I2
Violent_d_I2
Diabet_I2
Diabet_n_I2
Diabet_d_I2
Inactive_I2
Inactive_n_I2
Inactive_d_I2
Housing_I2
Housing_n_I2
Housing_d_I2
DcYouth_I2
DcYouth_n_I2
;run;
/*N=3142, 26 variables*/
/***/;
data I2015;set I(rename=(fipscode=CountyFIPS));
STD_CT_I2=v045_rawvalue;
STD_CT_n_I2=v045_numerator;
STD_CT_d_I2=v045_denominator;
InsuredA_I2=v003_rawvalue;
InsuredA_n_I2=v003_numerator;
InsuredA_d_I2=v003_denominator;
Insured_I2=v085_rawvalue;
Insured_n_I2=v085_numerator;
Insured_d_I2=v085_denominator;
InsuredC_I2=v122_rawvalue;
InsuredC_n_I2=v122_numerator;
InsuredC_d_I2=v122_denominator;
PCP_I2=v004_rawvalue;
PCP_n_I2=v004_numerator;
PCP_d_I2=v004_denominator;
PCP_r_I2=v004_other_data_1;
PrvtHosp_I2=v005_rawvalue;
PrvtHosp_d_I2=v005_denominator;
SocAsso_I2=v140_rawvalue;
SocAsso_n_I2=v140_numerator;
SocAsso_d_I2=v140_denominator;
LAccFood_I2=v083_rawvalue;
LAccFood_n_I2=v083_numerator;
LAccFood_d_I2=v083_denominator;
FoodEnv_I2=v133_rawvalue;
FoodEnv_n_I2=v133_numerator;
FoodEnv_d_I2=v133_denominator;
HIV_I2=v061_rawvalue;
HIV_n_I2=v061_numerator;
HIV_d_I2=v061_denominator;
HlthCost_I2=v086_rawvalue;
HlthCost_d_I2=v086_denominator;
FoodIns_I2=v139_rawvalue;
FoodIns_n_I2=v139_numerator;
keep
CountyFIPS
STD_CT_I2
STD_CT_n_I2
STD_CT_d_I2
InsuredA_I2
InsuredA_n_I2
InsuredA_d_I2
Insured_I2
Insured_n_I2
Insured_d_I2
InsuredC_I2
InsuredC_n_I2
InsuredC_d_I2
PCP_I2
PCP_n_I2
PCP_d_I2
PCP_r_I2
PrvtHosp_I2
PrvtHosp_d_I2
SocAsso_I2
SocAsso_n_I2
SocAsso_d_I2
LAccFood_I2
LAccFood_n_I2
LAccFood_d_I2
FoodEnv_I2
FoodEnv_n_I2
FoodEnv_d_I2
HIV_I2
HIV_n_I2
HIV_d_I2
HlthCost_I2
HlthCost_d_I2
FoodIns_I2
FoodIns_n_I2
;run;
/*N=3142, 35 variables*/
/***/;
data I2016;set I(rename=(fipscode=CountyFIPS));
PrmDeath_I2=v001_rawvalue;
PrmDeath_n_I2=v001_numerator;
PrmDeath_d_I2=v001_denominator;
PrmDeathW_I2=v001_other_data_1;
PrmDeathB_I2=v001_other_data_2;
PrmDeathH_I2=v001_other_data_3;
PoorHlth_I2=v002_rawvalue;
PoorPhy_I2=v036_rawvalue;
PoorMH_I2=v042_rawvalue;
LowBW_I2=v037_rawvalue;
LowBW_n_I2=v037_numerator;
LowBW_d_I2=v037_denominator;
LowBWW_I2=v037_other_data_1;
LowBWB_I2=v037_other_data_2;
LowBWH_I2=v037_other_data_3;
Smoke_I2=v009_rawvalue;
EDrink_I2=v049_rawvalue;
DWIDeath_I2=v134_rawvalue;
DWIDeath_n_I2=v134_numerator;
DWIDeath_d_I2=v134_denominator;
CarDeath_I2=v039_rawvalue;
CarDeath_n_I2=v039_numerator;
CarDeath_d_I2=v039_denominator;
TeenBth_I2=v014_rawvalue;
TeenBth_n_I2=v014_numerator;
TeenBth_d_I2=v014_denominator;
TeenBthW_I2=v014_other_data_1;
TeenBthB_I2=v014_other_data_2;
TeenBthH_I2=v014_other_data_3;
Murder_I2=v015_rawvalue;
Murder_n_I2=v015_numerator;
Murder_d_I2=v015_denominator;
Water2_I2=v124_rawvalue;
Gym2_I2=v132_rawvalue;
Gym2_n_I2=v132_numerator;
Gym2_d_I2=v132_denominator;
FrLunch_I2=v065_rawvalue;
FrLunch_n_I2=v065_numerator;
FrLunch_d_I2=v065_denominator;
Dentist_I2=v088_rawvalue;
Dentist_n_I2=v088_numerator;
Dentist_d_I2=v088_denominator;
Dentist_r_I2=v088_other_data_1;
PrmDeath2_I2=v127_rawvalue;
PrmDeath2_n_I2=v127_numerator;
PrmDeath2_d_I2=v127_denominator;
PrmDeath2W_I2=v127_other_data_1;
PrmDeath2B_I2=v127_other_data_2;
PrmDeath2H_I2=v127_other_data_3;
ChdDeath_I2=v128_rawvalue;
ChdDeath_n_I2=v128_numerator;
ChdDeath_d_I2=v128_denominator;
ChdDeathW_I2=v128_other_data_1;
ChdDeathB_I2=v128_other_data_2;
ChdDeathH_I2=v128_other_data_3;
InfDeath_I2=v129_rawvalue;
InfDeath_n_I2=v129_numerator;
InfDeath_d_I2=v129_denominator;
InfDeathW_I2=v129_other_data_1;
InfDeathB_I2=v129_other_data_2;
InfDeathH_I2=v129_other_data_3;
Injury_I2=v135_rawvalue;
Injury_n_I2=v135_numerator;
Injury_d_I2=v135_denominator;
LongComm_I2=v137_rawvalue;
LongComm_d_I2=v137_denominator;
DrugOd_I2=v138_rawvalue;
DrugOd_n_I2=v138_numerator;
DrugOd_d_I2=v138_denominator;
DrugOdm_I2=v146_rawvalue;
DrugOdm_d_I2=v146_denominator;
Physical_I2=v144_rawvalue;
Mental_I2=v145_rawvalue;
Sleep_I2=v143_rawvalue;
SegBW_I2=v141_rawvalue;
SegNW_I2=v142_rawvalue;
GunDeath_I2=v148_rawvalue;
GunDeath_n_I2=v148_numerator;
GunDeath_d_I2=v148_denominator;
keep
CountyFIPS
PrmDeath_I2
PrmDeath_n_I2
PrmDeath_d_I2
PrmDeathW_I2
PrmDeathB_I2
PrmDeathH_I2
PoorHlth_I2
PoorPhy_I2
PoorMH_I2
LowBW_I2
LowBW_n_I2
LowBW_d_I2
LowBWW_I2
LowBWB_I2
LowBWH_I2
Smoke_I2
EDrink_I2
DWIDeath_I2
DWIDeath_n_I2
DWIDeath_d_I2
CarDeath_I2
CarDeath_n_I2
CarDeath_d_I2
TeenBth_I2
TeenBth_n_I2
TeenBth_d_I2
TeenBthW_I2
TeenBthB_I2
TeenBthH_I2
Murder_I2
Murder_n_I2
Murder_d_I2
Water2_I2
Gym2_I2
Gym2_n_I2
Gym2_d_I2
FrLunch_I2
FrLunch_n_I2
FrLunch_d_I2
Dentist_I2
Dentist_n_I2
Dentist_d_I2
Dentist_r_I2
PrmDeath2_I2
PrmDeath2_n_I2
PrmDeath2_d_I2
PrmDeath2W_I2
PrmDeath2B_I2
PrmDeath2H_I2
ChdDeath_I2
ChdDeath_n_I2
ChdDeath_d_I2
ChdDeathW_I2
ChdDeathB_I2
ChdDeathH_I2
InfDeath_I2
InfDeath_n_I2
InfDeath_d_I2
InfDeathW_I2
InfDeathB_I2
InfDeathH_I2
Injury_I2
Injury_n_I2
Injury_d_I2
LongComm_I2
LongComm_d_I2
DrugOd_I2
DrugOd_n_I2
DrugOd_d_I2
DrugOdm_I2
DrugOdm_d_I2
Physical_I2
Mental_I2
Sleep_I2
SegBW_I2
SegNW_I2
GunDeath_I2
GunDeath_n_I2
GunDeath_d_I2
;run;
/*N=3142, 80 variables*/
/***/;
data I2017;set I(rename=(fipscode=CountyFIPS));
PCP2_I2=v131_rawvalue;
PCP2_n_I2=v131_numerator;
PCP2_d_I2=v131_denominator;
PCP2_r_I2=v131_other_data_1;
MHPrvd_I2=v062_rawvalue;
MHPrvd_n_I2=v062_numerator;
MHPrvd_d_I2=v062_denominator;
MHPrvd_r_I2=v062_other_data_1;
keep
CountyFIPS
PCP2_I2
PCP2_n_I2
PCP2_d_I2
PCP2_r_I2
MHPrvd_I2
MHPrvd_n_I2
MHPrvd_d_I2
MHPrvd_r_I2
;run;
/*N=3142, 9 variables*/
/***/;
data J2014;set J(rename=(fipscode=CountyFIPS));
AirPM_J2=v125_rawvalue;
keep
CountyFIPS
AirPM_J2
;run;
/*N=3142, 2 variables*/
/***/;
data J2015;set J(rename=(fipscode=CountyFIPS));
Obesity_J2=v011_rawvalue;
Obesity_n_J2=v011_numerator;
Obesity_d_J2=v011_denominator;
LAccFood_J2=v083_rawvalue;
LAccFood_n_J2=v083_numerator;
LAccFood_d_J2=v083_denominator;
Diabet_J2=v060_rawvalue;
Diabet_n_J2=v060_numerator;
Diabet_d_J2=v060_denominator;
HIV_J2=v061_rawvalue;
HIV_n_J2=v061_numerator;
HIV_d_J2=v061_denominator;
Inactive_J2=v070_rawvalue;
Inactive_n_J2=v070_numerator;
Inactive_d_J2=v070_denominator;
Housing_J2=v136_rawvalue;
Housing_n_J2=v136_numerator;
Housing_d_J2=v136_denominator;
HousCosts_J2=v136_other_data_1;
HousCrowd_J2=v136_other_data_2;
HousPlumb_J2=v136_other_data_3;
keep
CountyFIPS
Obesity_J2
Obesity_n_J2
Obesity_d_J2
LAccFood_J2
LAccFood_n_J2
LAccFood_d_J2
Diabet_J2
Diabet_n_J2
Diabet_d_J2
HIV_J2
HIV_n_J2
HIV_d_J2
Inactive_J2
Inactive_n_J2
Inactive_d_J2
Housing_J2
Housing_n_J2
Housing_d_J2
HousCosts_J2
HousCrowd_J2
HousPlumb_J2
;run;
/*N=3142, 22 variables*/
/***/;
data J2016;set J(rename=(fipscode=CountyFIPS));
PoorHlth_J2=v002_rawvalue;
PoorPhy_J2=v036_rawvalue;
PoorMH_J2=v042_rawvalue;
Smoke_J2=v009_rawvalue;
EDrink_J2=v049_rawvalue;
STD_CT_J2=v045_rawvalue;
STD_CT_n_J2=v045_numerator;
STD_CT_d_J2=v045_denominator;
InsuredA_J2=v003_rawvalue;
InsuredA_n_J2=v003_numerator;
InsuredA_d_J2=v003_denominator;
Insured_J2=v085_rawvalue;
Insured_n_J2=v085_numerator;
Insured_d_J2=v085_denominator;
InsuredC_J2=v122_rawvalue;
InsuredC_n_J2=v122_numerator;
InsuredC_d_J2=v122_denominator;
PCP_J2=v004_rawvalue;
PCP_n_J2=v004_numerator;
PCP_d_J2=v004_denominator;
PCP_r_J2=v004_other_data_1;
PrvtHosp_J2=v005_rawvalue;
PrvtHospW_J2=v005_race_white;
PrvtHospB_J2=v005_race_black;
PrvtHospH_J2=v005_race_hispanic;
Mammo_J2=v050_rawvalue;
MammoW_J2=v050_race_white;
MammoB_J2=v050_race_black;
MammoH_J2=v050_race_hispanic;
SocAsso_J2=v140_rawvalue;
SocAsso_n_J2=v140_numerator;
SocAsso_d_J2=v140_denominator;
Violent_J2=v043_rawvalue;
Violent_n_J2=v043_numerator;
Violent_d_J2=v043_denominator;
FoodEnv_J2=v133_rawvalue;
FoodEnv_n_J2=v133_numerator;
FoodEnv_d_J2=v133_denominator;
FoodIns_J2=v139_rawvalue;
FoodIns_n_J2=v139_numerator;
Physical_J2=v144_rawvalue;
Mental_J2=v145_rawvalue;
Sleep_J2=v143_rawvalue;
FluVacc_J2=v155_rawvalue;
FluVaccW_J2=v155_race_white;
FluVaccB_J2=v155_race_black;
FluVaccH_J2=v155_race_hispanic;
keep
CountyFIPS
PoorHlth_J2
PoorPhy_J2
PoorMH_J2
Smoke_J2
EDrink_J2
STD_CT_J2
STD_CT_n_J2
STD_CT_d_J2
InsuredA_J2
InsuredA_n_J2
InsuredA_d_J2
Insured_J2
Insured_n_J2
Insured_d_J2
InsuredC_J2
InsuredC_n_J2
InsuredC_d_J2
PCP_J2
PCP_n_J2
PCP_d_J2
PCP_r_J2
PrvtHosp_J2
PrvtHospW_J2
PrvtHospB_J2
PrvtHospH_J2
Mammo_J2
MammoW_J2
MammoB_J2
MammoH_J2
SocAsso_J2
SocAsso_n_J2
SocAsso_d_J2
Violent_J2
Violent_n_J2
Violent_d_J2
FoodEnv_J2
FoodEnv_n_J2
FoodEnv_d_J2
FoodIns_J2
FoodIns_n_J2
Physical_J2
Mental_J2
Sleep_J2
FluVacc_J2
FluVaccW_J2
FluVaccB_J2
FluVaccH_J2
;run;
/*N=3142, 48 variables*/
/***/;
data J2017;set J(rename=(fipscode=CountyFIPS));
PrmDeath_J2=v001_rawvalue;
PrmDeath_n_J2=v001_numerator;
PrmDeath_d_J2=v001_denominator;
PrmDeathW_J2=v001_race_white;
PrmDeathB_J2=v001_race_black;
PrmDeathH_J2=v001_race_hispanic;
LowBW_J2=v037_rawvalue;
LowBW_n_J2=v037_numerator;
LowBW_d_J2=v037_denominator;
LowBWW_J2=v037_race_white;
LowBWB_J2=v037_race_black;
LowBWH_J2=v037_race_hispanic;
DWIDeath_J2=v134_rawvalue;
DWIDeath_n_J2=v134_numerator;
DWIDeath_d_J2=v134_denominator;
CarDeath_J2=v039_rawvalue;
CarDeath_n_J2=v039_numerator;
CarDeath_d_J2=v039_denominator;
TeenBth_J2=v014_rawvalue;
TeenBth_n_J2=v014_numerator;
TeenBth_d_J2=v014_denominator;
TeenBthW_J2=v014_race_white;
TeenBthB_J2=v014_race_black;
TeenBthH_J2=v014_race_hispanic;
Murder_J2=v015_rawvalue;
Murder_n_J2=v015_numerator;
Murder_d_J2=v015_denominator;
Water2_J2=v124_rawvalue;
FrLunch_J2=v065_rawvalue;
FrLunch_n_J2=v065_numerator;
FrLunch_d_J2=v065_denominator;
Dentist_J2=v088_rawvalue;
Dentist_n_J2=v088_numerator;
Dentist_d_J2=v088_denominator;
Dentist_r_J2=v088_other_data_1;
PrmDeath2_J2=v127_rawvalue;
PrmDeath2_n_J2=v127_numerator;
PrmDeath2_d_J2=v127_denominator;
PrmDeath2W_J2=v127_race_white;
PrmDeath2B_J2=v127_race_black;
PrmDeath2H_J2=v127_race_hispanic;
ChdDeath_J2=v128_rawvalue;
ChdDeath_n_J2=v128_numerator;
ChdDeath_d_J2=v128_denominator;
ChdDeathW_J2=v128_race_white;
ChdDeathB_J2=v128_race_black;
ChdDeathH_J2=v128_race_hispanic;
InfDeath_J2=v129_rawvalue;
InfDeath_n_J2=v129_numerator;
InfDeath_d_J2=v129_denominator;
InfDeathW_J2=v129_race_white;
InfDeathB_J2=v129_race_black;
InfDeathH_J2=v129_race_hispanic;
Injury_J2=v135_rawvalue;
Injury_n_J2=v135_numerator;
Injury_d_J2=v135_denominator;
HousCost_J2=v154_rawvalue;
HousCost_n_J2=v154_numerator;
HousCost_d_J2=v154_denominator;
LongComm_J2=v137_rawvalue;
LongComm_d_J2=v137_denominator;
DrugOd_J2=v138_rawvalue;
DrugOd_n_J2=v138_numerator;
DrugOd_d_J2=v138_denominator;
SegBW_J2=v141_rawvalue;
SegNW_J2=v142_rawvalue;
DcYouth_J2=v149_rawvalue;
DcYouth_n_J2=v149_numerator;
DcYouth_d_J2=v149_denominator;
GunDeath_J2=v148_rawvalue;
GunDeath_n_J2=v148_numerator;
GunDeath_d_J2=v148_denominator;
LifeExp_J2=v147_rawvalue;
LifeExpW_J2=v147_race_white;
LifeExpB_J2=v147_race_black;
LifeExpH_J2=v147_race_hispanic;
keep
CountyFIPS
PrmDeath_J2
PrmDeath_n_J2
PrmDeath_d_J2
PrmDeathW_J2
PrmDeathB_J2
PrmDeathH_J2
LowBW_J2
LowBW_n_J2
LowBW_d_J2
LowBWW_J2
LowBWB_J2
LowBWH_J2
DWIDeath_J2
DWIDeath_n_J2
DWIDeath_d_J2
CarDeath_J2
CarDeath_n_J2
CarDeath_d_J2
TeenBth_J2
TeenBth_n_J2
TeenBth_d_J2
TeenBthW_J2
TeenBthB_J2
TeenBthH_J2
Murder_J2
Murder_n_J2
Murder_d_J2
Water2_J2
FrLunch_J2
FrLunch_n_J2
FrLunch_d_J2
Dentist_J2
Dentist_n_J2
Dentist_d_J2
Dentist_r_J2
PrmDeath2_J2
PrmDeath2_n_J2
PrmDeath2_d_J2
PrmDeath2W_J2
PrmDeath2B_J2
PrmDeath2H_J2
ChdDeath_J2
ChdDeath_n_J2
ChdDeath_d_J2
ChdDeathW_J2
ChdDeathB_J2
ChdDeathH_J2
InfDeath_J2
InfDeath_n_J2
InfDeath_d_J2
InfDeathW_J2
InfDeathB_J2
InfDeathH_J2
Injury_J2
Injury_n_J2
Injury_d_J2
HousCost_J2
HousCost_n_J2
HousCost_d_J2
LongComm_J2
LongComm_d_J2
DrugOd_J2
DrugOd_n_J2
DrugOd_d_J2
SegBW_J2
SegNW_J2
DcYouth_J2
DcYouth_n_J2
DcYouth_d_J2
GunDeath_J2
GunDeath_n_J2
GunDeath_d_J2
LifeExp_J2
LifeExpW_J2
LifeExpB_J2
LifeExpH_J2
;run;
/*N=3142, 77 variables*/
/***/;
data J2018;set J(rename=(fipscode=CountyFIPS));
PCP2_J2=v131_rawvalue;
PCP2_n_J2=v131_numerator;
PCP2_d_J2=v131_denominator;
PCP2_r_J2=v131_other_data_1;
Gym2_J2=v132_rawvalue;
Gym2_n_J2=v132_numerator;
Gym2_d_J2=v132_denominator;
MHPrvd_J2=v062_rawvalue;
MHPrvd_n_J2=v062_numerator;
MHPrvd_d_J2=v062_denominator;
MHPrvd_r_J2=v062_other_data_1;
keep
CountyFIPS
PCP2_J2
PCP2_n_J2
PCP2_d_J2
PCP2_r_J2
Gym2_J2
Gym2_n_J2
Gym2_d_J2
MHPrvd_J2
MHPrvd_n_J2
MHPrvd_d_J2
MHPrvd_r_J2
;run;
/*N=3142, 12 variables*/
/***/;
data K2014;set K(rename=(fipscode=CountyFIPS));
AirPM_K2=v125_rawvalue;
keep
CountyFIPS
AirPM_K2
;run;
/*N=3142, 2 variables*/
/***/;
data K2015;set K(rename=(fipscode=CountyFIPS));
LAccFood_K2=v083_rawvalue;
LAccFood_n_K2=v083_numerator;
LAccFood_d_K2=v083_denominator;
keep
CountyFIPS
LAccFood_K2
LAccFood_n_K2
LAccFood_d_K2
;run;
/*N=3142, 4 variables*/
/***/;
data K2016;set K(rename=(fipscode=CountyFIPS));
Obesity_K2=v011_rawvalue;
Obesity_n_K2=v011_numerator;
Violent_K2=v043_rawvalue;
Violent_n_K2=v043_numerator;
Violent_d_K2=v043_denominator;
Diabet_K2=v060_rawvalue;
Diabet_n_K2=v060_numerator;
HIV_K2=v061_rawvalue;
HIV_n_K2=v061_numerator;
HIV_d_K2=v061_denominator;
Inactive_K2=v070_rawvalue;
Inactive_n_K2=v070_numerator;
Housing_K2=v136_rawvalue;
Housing_n_K2=v136_numerator;
Housing_d_K2=v136_denominator;
HousCosts_K2=v136_other_data_1;
HousCrowd_K2=v136_other_data_2;
HousPlumb_K2=v136_other_data_3;
Sleep_K2=v143_rawvalue;
Read_K2=v159_rawvalue;
ReadW_K2=v159_race_white;
ReadB_K2=v159_race_black;
ReadH_K2=v159_race_hispanic;
ReadA_K2=v159_race_asian;
Math_K2=v160_rawvalue;
MathW_K2=v160_race_white;
MathB_K2=v160_race_black;
MathH_K2=v160_race_hispanic;
MathA_K2=v160_race_asian;
keep
CountyFIPS
Obesity_K2
Obesity_n_K2
Violent_K2
Violent_n_K2
Violent_d_K2
Diabet_K2
Diabet_n_K2
HIV_K2
HIV_n_K2
HIV_d_K2
Inactive_K2
Inactive_n_K2
Housing_K2
Housing_n_K2
Housing_d_K2
HousCosts_K2
HousCrowd_K2
HousPlumb_K2
Sleep_K2
Read_K2
ReadW_K2
ReadB_K2
ReadH_K2
ReadA_K2
Math_K2
MathW_K2
MathB_K2
MathH_K2
MathA_K2
;run;
/*N=3142, 30 variables*/
/***/;
data K2017;set K(rename=(fipscode=CountyFIPS));
PoorHlth_K2=v002_rawvalue;
PoorPhy_K2=v036_rawvalue;
PoorMH_K2=v042_rawvalue;
Smoke_K2=v009_rawvalue;
EDrink_K2=v049_rawvalue;
STD_CT_K2=v045_rawvalue;
STD_CT_n_K2=v045_numerator;
STD_CT_d_K2=v045_denominator;
InsuredA_K2=v003_rawvalue;
InsuredA_n_K2=v003_numerator;
InsuredA_d_K2=v003_denominator;
Insured_K2=v085_rawvalue;
Insured_n_K2=v085_numerator;
Insured_d_K2=v085_denominator;
InsuredC_K2=v122_rawvalue;
InsuredC_n_K2=v122_numerator;
InsuredC_d_K2=v122_denominator;
PCP_K2=v004_rawvalue;
PCP_n_K2=v004_numerator;
PCP_d_K2=v004_denominator;
PCP_r_K2=v004_other_data_1;
PrvtHosp_K2=v005_rawvalue;
PrvtHospW_K2=v005_race_white;
PrvtHospB_K2=v005_race_black;
PrvtHospH_K2=v005_race_hispanic;
PrvtHospN_K2=v005_race_aian;
PrvtHospA_K2=v005_race_asian;
Mammo_K2=v050_rawvalue;
MammoW_K2=v050_race_white;
MammoB_K2=v050_race_black;
MammoH_K2=v050_race_hispanic;
MammoN_K2=v050_race_aian;
MammoA_K2=v050_race_asian;
SocAsso_K2=v140_rawvalue;
SocAsso_n_K2=v140_numerator;
SocAsso_d_K2=v140_denominator;
FoodEnv_K2=v133_rawvalue;
FoodEnv_n_K2=v133_numerator;
FoodEnv_d_K2=v133_denominator;
FoodIns_K2=v139_rawvalue;
FoodIns_n_K2=v139_numerator;
Physical_K2=v144_rawvalue;
Mental_K2=v145_rawvalue;
FluVacc_K2=v155_rawvalue;
FluVaccW_K2=v155_race_white;
FluVaccB_K2=v155_race_black;
FluVaccH_K2=v155_race_hispanic;
FluVaccN_K2=v155_race_aian;
FluVaccA_K2=v155_race_asian;
JuvArr_K2=v158_rawvalue;
JuvArr_d_K2=v158_denominator;
JuvArrF_K2=v158_other_data_1;
JuvArrI_K2=v158_other_data_2;
keep
CountyFIPS
PoorHlth_K2
PoorPhy_K2
PoorMH_K2
Smoke_K2
EDrink_K2
STD_CT_K2
STD_CT_n_K2
STD_CT_d_K2
InsuredA_K2
InsuredA_n_K2
InsuredA_d_K2
Insured_K2
Insured_n_K2
Insured_d_K2
InsuredC_K2
InsuredC_n_K2
InsuredC_d_K2
PCP_K2
PCP_n_K2
PCP_d_K2
PCP_r_K2
PrvtHosp_K2
PrvtHospW_K2
PrvtHospB_K2
PrvtHospH_K2
PrvtHospN_K2
PrvtHospA_K2
Mammo_K2
MammoW_K2
MammoB_K2
MammoH_K2
MammoN_K2
MammoA_K2
SocAsso_K2
SocAsso_n_K2
SocAsso_d_K2
FoodEnv_K2
FoodEnv_n_K2
FoodEnv_d_K2
FoodIns_K2
FoodIns_n_K2
Physical_K2
Mental_K2
FluVacc_K2
FluVaccW_K2
FluVaccB_K2
FluVaccH_K2
FluVaccN_K2
FluVaccA_K2
JuvArr_K2
JuvArr_d_K2
JuvArrF_K2
JuvArrI_K2
;run;
/*N=3142, 54 variables*/
/***/;
data K2018;set K(rename=(fipscode=CountyFIPS));
PrmDeath_K2=v001_rawvalue;
PrmDeath_n_K2=v001_numerator;
PrmDeath_d_K2=v001_denominator;
PrmDeathW_K2=v001_race_white;
PrmDeathB_K2=v001_race_black;
PrmDeathH_K2=v001_race_hispanic;
PrmDeathN_K2=v001_race_aian;
PrmDeathA_K2=v001_race_asian;
LowBW_K2=v037_rawvalue;
LowBW_n_K2=v037_numerator;
LowBW_d_K2=v037_denominator;
LowBWW_K2=v037_race_white;
LowBWB_K2=v037_race_black;
LowBWH_K2=v037_race_hispanic;
LowBWN_K2=v037_race_aian;
LowBWA_K2=v037_race_asian;
DWIDeath_K2=v134_rawvalue;
DWIDeath_n_K2=v134_numerator;
DWIDeath_d_K2=v134_denominator;
CarDeath_K2=v039_rawvalue;
CarDeath_n_K2=v039_numerator;
CarDeath_d_K2=v039_denominator;
CarDeathW_K2=v039_race_white;
CarDeathB_K2=v039_race_black;
CarDeathH_K2=v039_race_hispanic;
CarDeathN_K2=v039_race_aian;
CarDeathA_K2=v039_race_asian;
TeenBth_K2=v014_rawvalue;
TeenBth_n_K2=v014_numerator;
TeenBth_d_K2=v014_denominator;
TeenBthW_K2=v014_race_white;
TeenBthB_K2=v014_race_black;
TeenBthH_K2=v014_race_hispanic;
TeenBthN_K2=v014_race_aian;
TeenBthA_K2=v014_race_asian;
Murder_K2=v015_rawvalue;
Murder_n_K2=v015_numerator;
Murder_d_K2=v015_denominator;
Water2_K2=v124_rawvalue;
FrLunch_K2=v065_rawvalue;
FrLunch_n_K2=v065_numerator;
FrLunch_d_K2=v065_denominator;
Dentist_K2=v088_rawvalue;
Dentist_n_K2=v088_numerator;
Dentist_d_K2=v088_denominator;
Dentist_r_K2=v088_other_data_1;
PrmDeath2_K2=v127_rawvalue;
PrmDeath2_n_K2=v127_numerator;
PrmDeath2_d_K2=v127_denominator;
PrmDeath2W_K2=v127_race_white;
PrmDeath2B_K2=v127_race_black;
PrmDeath2H_K2=v127_race_hispanic;
PrmDeath2N_K2=v127_race_aian;
PrmDeath2A_K2=v127_race_asian;
ChdDeath_K2=v128_rawvalue;
ChdDeath_n_K2=v128_numerator;
ChdDeath_d_K2=v128_denominator;
ChdDeathW_K2=v128_race_white;
ChdDeathB_K2=v128_race_black;
ChdDeathH_K2=v128_race_hispanic;
ChdDeathN_K2=v128_race_aian;
ChdDeathA_K2=v128_race_asian;
InfDeath_K2=v129_rawvalue;
InfDeath_n_K2=v129_numerator;
InfDeath_d_K2=v129_denominator;
InfDeathW_K2=v129_race_white;
InfDeathB_K2=v129_race_black;
InfDeathH_K2=v129_race_hispanic;
InfDeathN_K2=v129_race_aian;
InfDeathA_K2=v129_race_asian;
Injury_K2=v135_rawvalue;
Injury_n_K2=v135_numerator;
Injury_d_K2=v135_denominator;
InjuryW_K2=v135_race_white;
InjuryB_K2=v135_race_black;
InjuryH_K2=v135_race_hispanic;
InjuryN_K2=v135_race_aian;
InjuryA_K2=v135_race_asian;
HousCost_K2=v154_rawvalue;
HousCost_n_K2=v154_numerator;
HousCost_d_K2=v154_denominator;
LongComm_K2=v137_rawvalue;
LongComm_d_K2=v137_denominator;
DrugOd_K2=v138_rawvalue;
DrugOd_n_K2=v138_numerator;
DrugOd_d_K2=v138_denominator;
DrugOdW_K2=v138_race_white;
DrugOdB_K2=v138_race_black;
DrugOdH_K2=v138_race_hispanic;
DrugOdN_K2=v138_race_aian;
DrugOdA_K2=v138_race_asian;
SegBW_K2=v141_rawvalue;
SegNW_K2=v142_rawvalue;
DcYouth_K2=v149_rawvalue;
DcYouth_n_K2=v149_numerator;
DcYouth_d_K2=v149_denominator;
GunDeath_K2=v148_rawvalue;
GunDeath_n_K2=v148_numerator;
GunDeath_d_K2=v148_denominator;
GunDeathW_K2=v148_race_white;
GunDeathB_K2=v148_race_black;
GunDeathH_K2=v148_race_hispanic;
GunDeathN_K2=v148_race_aian;
GunDeathA_K2=v148_race_asian;
LifeExp_K2=v147_rawvalue;
LifeExpW_K2=v147_race_white;
LifeExpB_K2=v147_race_black;
LifeExpH_K2=v147_race_hispanic;
LifeExpN_K2=v147_race_aian;
LifeExpA_K2=v147_race_asian;
Suicide_K2=v161_rawvalue;
Suicide_n_K2=v161_numerator;
Suicide_d_K2=v161_denominator;
Suicide2_K2=v161_other_data_1;
SuicideW_K2=v161_race_white;
SuicideB_K2=v161_race_black;
SuicideH_K2=v161_race_hispanic;
SuicideN_K2=v161_race_aian;
SuicideA_K2=v161_race_asian;
Traffic_K2=v156_rawvalue;
keep
CountyFIPS
PrmDeath_K2
PrmDeath_n_K2
PrmDeath_d_K2
PrmDeathW_K2
PrmDeathB_K2
PrmDeathH_K2
PrmDeathN_K2
PrmDeathA_K2
LowBW_K2
LowBW_n_K2
LowBW_d_K2
LowBWW_K2
LowBWB_K2
LowBWH_K2
LowBWN_K2
LowBWA_K2
DWIDeath_K2
DWIDeath_n_K2
DWIDeath_d_K2
CarDeath_K2
CarDeath_n_K2
CarDeath_d_K2
CarDeathW_K2
CarDeathB_K2
CarDeathH_K2
CarDeathN_K2
CarDeathA_K2
TeenBth_K2
TeenBth_n_K2
TeenBth_d_K2
TeenBthW_K2
TeenBthB_K2
TeenBthH_K2
TeenBthN_K2
TeenBthA_K2
Murder_K2
Murder_n_K2
Murder_d_K2
Water2_K2
FrLunch_K2
FrLunch_n_K2
FrLunch_d_K2
Dentist_K2
Dentist_n_K2
Dentist_d_K2
Dentist_r_K2
PrmDeath2_K2
PrmDeath2_n_K2
PrmDeath2_d_K2
PrmDeath2W_K2
PrmDeath2B_K2
PrmDeath2H_K2
PrmDeath2N_K2
PrmDeath2A_K2
ChdDeath_K2
ChdDeath_n_K2
ChdDeath_d_K2
ChdDeathW_K2
ChdDeathB_K2
ChdDeathH_K2
ChdDeathN_K2
ChdDeathA_K2
InfDeath_K2
InfDeath_n_K2
InfDeath_d_K2
InfDeathW_K2
InfDeathB_K2
InfDeathH_K2
InfDeathN_K2
InfDeathA_K2
Injury_K2
Injury_n_K2
Injury_d_K2
InjuryW_K2
InjuryB_K2
InjuryH_K2
InjuryN_K2
InjuryA_K2
HousCost_K2
HousCost_n_K2
HousCost_d_K2
LongComm_K2
LongComm_d_K2
DrugOd_K2
DrugOd_n_K2
DrugOd_d_K2
DrugOdW_K2
DrugOdB_K2
DrugOdH_K2
DrugOdN_K2
DrugOdA_K2
SegBW_K2
SegNW_K2
DcYouth_K2
DcYouth_n_K2
DcYouth_d_K2
GunDeath_K2
GunDeath_n_K2
GunDeath_d_K2
GunDeathW_K2
GunDeathB_K2
GunDeathH_K2
GunDeathN_K2
GunDeathA_K2
LifeExp_K2
LifeExpW_K2
LifeExpB_K2
LifeExpH_K2
LifeExpN_K2
LifeExpA_K2
Suicide_K2
Suicide_n_K2
Suicide_d_K2
Suicide2_K2
SuicideW_K2
SuicideB_K2
SuicideH_K2
SuicideN_K2
SuicideA_K2
Traffic_K2
;run;
/*N=3142, 121 variables*/
/***/;
data K2019;set K(rename=(fipscode=CountyFIPS));
PCP2_K2=v131_rawvalue;
PCP2_n_K2=v131_numerator;
PCP2_d_K2=v131_denominator;
PCP2_r_K2=v131_other_data_1;
Gym2_K2=v132_rawvalue;
Gym2_n_K2=v132_numerator;
Gym2_d_K2=v132_denominator;
MHPrvd_K2=v062_rawvalue;
MHPrvd_n_K2=v062_numerator;
MHPrvd_d_K2=v062_denominator;
MHPrvd_r_K2=v062_other_data_1;
keep
CountyFIPS
PCP2_K2
PCP2_n_K2
PCP2_d_K2
PCP2_r_K2
Gym2_K2
Gym2_n_K2
Gym2_d_K2
MHPrvd_K2
MHPrvd_n_K2
MHPrvd_d_K2
MHPrvd_r_K2
;run;
/*N=3142, 12 variables*/





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/********************************* Merging Yearly Datasets by Measurement Year *************************************************************************************************/
/********************************* Merging Yearly Datasets by Measurement Year *************************************************************************************************/
/********************************* Merging Yearly Datasets by Measurement Year *************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/***/
/* Sorting Data */;
proc sort data=A2005;by CountyFIPS;run;
proc sort data=A2006;by CountyFIPS;run;
proc sort data=B2006;by CountyFIPS;run;
proc sort data=C2006;by CountyFIPS;run;
proc sort data=A2007;by CountyFIPS;run;
proc sort data=B2007;by CountyFIPS;run;
proc sort data=C2007;by CountyFIPS;run;
proc sort data=A2008;by CountyFIPS;run;
proc sort data=B2008;by CountyFIPS;run;
proc sort data=C2008;by CountyFIPS;run;
proc sort data=D2008;by CountyFIPS;run;
proc sort data=E2008;by CountyFIPS;run;
proc sort data=B2009;by CountyFIPS;run;
proc sort data=C2009;by CountyFIPS;run;
proc sort data=D2009;by CountyFIPS;run;
proc sort data=C2010;by CountyFIPS;run;
proc sort data=D2010;by CountyFIPS;run;
proc sort data=E2010;by CountyFIPS;run;
proc sort data=F2010;by CountyFIPS;run;
proc sort data=G2010;by CountyFIPS;run;
proc sort data=H2010;by CountyFIPS;run;
proc sort data=D2011;by CountyFIPS;run;
proc sort data=E2011;by CountyFIPS;run;
proc sort data=F2011;by CountyFIPS;run;
proc sort data=G2011;by CountyFIPS;run;
proc sort data=D2012;by CountyFIPS;run;
proc sort data=E2012;by CountyFIPS;run;
proc sort data=F2012;by CountyFIPS;run;
proc sort data=G2012;by CountyFIPS;run;
proc sort data=H2012;by CountyFIPS;run;
proc sort data=I2012;by CountyFIPS;run;
proc sort data=E2013;by CountyFIPS;run;
proc sort data=F2013;by CountyFIPS;run;
proc sort data=G2013;by CountyFIPS;run;
proc sort data=H2013;by CountyFIPS;run;
proc sort data=F2014;by CountyFIPS;run;
proc sort data=G2014;by CountyFIPS;run;
proc sort data=H2014;by CountyFIPS;run;
proc sort data=I2014;by CountyFIPS;run;
proc sort data=J2014;by CountyFIPS;run;
proc sort data=K2014;by CountyFIPS;run;
proc sort data=G2015;by CountyFIPS;run;
proc sort data=H2015;by CountyFIPS;run;
proc sort data=I2015;by CountyFIPS;run;
proc sort data=J2015;by CountyFIPS;run;
proc sort data=K2015;by CountyFIPS;run;
proc sort data=H2016;by CountyFIPS;run;
proc sort data=I2016;by CountyFIPS;run;
proc sort data=J2016;by CountyFIPS;run;
proc sort data=K2016;by CountyFIPS;run;
proc sort data=I2017;by CountyFIPS;run;
proc sort data=J2017;by CountyFIPS;run;
proc sort data=K2017;by CountyFIPS;run;
proc sort data=J2018;by CountyFIPS;run;
proc sort data=K2018;by CountyFIPS;run;
proc sort data=K2019;by CountyFIPS;run;
/***/
/* Merging Data */;
data Z2005;set   A2005                                            ;Year=2005;run; /*N=3141,   7 variables*/
data Z2006;merge A2006 B2006 C2006                  ;by CountyFIPS;Year=2006;run; /*N=3141,  34 variables*/
data Z2007;merge A2007 B2007 C2007                  ;by CountyFIPS;Year=2007;run; /*N=3141,  42 variables*/
data Z2008;merge A2008 B2008 C2008 D2008 E2008      ;by CountyFIPS;Year=2008;run; /*N=3141,  59 variables*/
data Z2009;merge B2009 C2009 D2009                  ;by CountyFIPS;Year=2009;run; /*N=3141,  57 variables*/
data Z2010;merge C2010 D2010 E2010 F2010 G2010 H2010;by CountyFIPS;Year=2010;run; /*N=3143, 124 variables*/
data Z2011;merge D2011 E2011 F2011 G2011            ;by CountyFIPS;Year=2011;run; /*N=3141,  78 variables*/
data Z2012;merge D2012 E2012 F2012 G2012 H2012 I2012;by CountyFIPS;Year=2012;run; /*N=3149, 150 variables*/
data Z2013;merge E2013 F2013 G2013 H2013            ;by CountyFIPS;Year=2013;run; /*N=3143,  99 variables*/
data Z2014;merge F2014 G2014 H2014 I2014 J2014 K2014;by CountyFIPS;Year=2014;run; /*N=3149, 112 variables*/
data Z2015;merge G2015 H2015 I2015 J2015 K2015      ;by CountyFIPS;Year=2015;run; /*N=3149, 110 variables*/
data Z2016;merge H2016 I2016 J2016 K2016            ;by CountyFIPS;Year=2016;run; /*N=3143, 165 variables*/
data Z2017;merge I2017 J2017 K2017                  ;by CountyFIPS;Year=2017;run; /*N=3142, 139 variables*/
data Z2018;merge J2018 K2018                        ;by CountyFIPS;Year=2018;run; /*N=3142, 133 variables*/
data Z2019;set   K2019                                            ;Year=2019;run; /*N=3142,  13 variables*/





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/********************************* Checking Duplicate Variables and Cleaning Them Up *******************************************************************************************/
/********************************* Checking Duplicate Variables and Cleaning Them Up *******************************************************************************************/
/********************************* Checking Duplicate Variables and Cleaning Them Up *******************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/* Some variables in different CHR yearly datasets were measured in the same year.
   For example, "premature death" in CHR 2013 and "premature death" in CHR 2014 were both measured in 2008-2010.
   Let's check such variables and clean them up. */
/***/
/* Duplicate variables in Z2005: None */;
data Z2005a;set Z2005(rename=(
InsuredA_A2=InsuredA 
Hospice_A2=Hospice 
Hospice_d_A2=Hospice_d 
AirPM2_A2=AirPM2 
AirO3_A2=AirO3
));
run;
/*N=3141, 7 variables*/
/***/
/* Dpulicate variables in Z2006: FrLunch_B2 FrLunch_C2 
   proc contents data=Z2006;run;
   proc corr data=Z2006;var FrLunch_B2 FrLunch_C2;run;*/;
data Z2006a;set Z2006(rename=(
PrmDeath_A2=PrmDeath
PrmDeath_n_A2=PrmDeath_n
PrmDeath_d_A2=PrmDeath_d
LowBW_A2=LowBW
LowBW_n_A2=LowBW_n
LowBW_d_A2=LowBW_d
CarDeath_A2=CarDeath
STD_CT_d_A2=STD_CT_d
TeenBth_A2=TeenBth
TeenBth_n_A2=TeenBth_n
PCP_A2=PCP
PCP_n_A2=PCP_n
PCP_d_A2=PCP_d
PCP_r_A2=PCP_r
PrvtHosp_A2=PrvtHosp
PrvtHosp_n_A2=PrvtHosp_n
PrvtHosp_d_A2=PrvtHosp_d
DiabetM_A2=DiabetM
DiabetM_d_A2=DiabetM_d
Murder_A2=Murder
AccFood_A2=AccFood
AccFood_n_A2=AccFood_n
AccFood_d_A2=AccFood_d
Liquor_A2=Liquor
Liquor_n_A2=Liquor_n
Liquor_d_A2=Liquor_d
AirPM2_B2=AirPM2
AirO3_B2=AirO3
FrLunch_C2=FrLunch
LAccFood_C2=LAccFood
LAccFood_n_C2=LAccFood_n
));
drop FrLunch_B2;
run;
/*N=3141, 33 variables*/
/***/
/* Duplicate variables in Z2007: None
   proc contents data=Z2007;run; */;
data Z2007a;set Z2007(rename=(
AirO3_C2=AirO3
AirPM2_C2=AirPM2
CarDeath_B2=CarDeath
CarDeath_n_B2=CarDeath_n
Dentist_C2=Dentist
Dentist_d_C2=Dentist_d
Dentist_n_C2=Dentist_n
Dentist_r_C2=Dentist_r
DiabetM_B2=DiabetM
DiabetM_d_B2=DiabetM_d
HIV_B2=HIV
HIV_d_B2=HIV_d
HlthCost_C2=HlthCost
HlthCost_n_C2=HlthCost_n
InsuredA_B2=InsuredA
InsuredA_d_B2=InsuredA_d
InsuredA_n_B2=InsuredA_n
LowBW_B2=LowBW
LowBW_d_B2=LowBW_d
LowBW_n_B2=LowBW_n
MHPrvd_C2=MHPrvd
MHPrvd_d_C2=MHPrvd_d
MHPrvd_n_C2=MHPrvd_n
MHPrvd_r_C2=MHPrvd_r
Mammo_B2=Mammo
Mammo_d_B2=Mammo_d
Murder_B2=Murder
Murder_d_B2=Murder_d
Murder_n_B2=Murder_n
PrmDeath_B2=PrmDeath
PrmDeath_n_B2=PrmDeath_n
PrvtHosp_B2=PrvtHosp
PrvtHosp_d_B2=PrvtHosp_d
STD_CT_A2=STD_CT
STD_CT_n_A2=STD_CT_n
TeenBth_B2=TeenBth
TeenBth_n_B2=TeenBth_n
Violent_A2=Violent
Violent_d_A2=Violent_d
Violent_n_A2=Violent_n
));
run;
/*N=3141, 42 variables*/
/***/
/* Duplicate variables in Z2008: Obesity_A2 Obesity_B2
   proc contents data=Z2008;run;
   proc corr data=Z2008;var Obesity_A2 Obesity_B2;run; 
   Obesity_A2 and Obesity_B2 are not exactly but practically same (r=0.96) -- RULE: use the most current one (Obesity_B2) */;
data Z2008a;set Z2008(rename=(
AccFood_B2=AccFood
AccFood_d_B2=AccFood_d
AccFood_n_B2=AccFood_n
AirPM_D2=AirPM
BDrink_A2=BDrink
BDrink_d_A2=BDrink_d
BDrink_n_A2=BDrink_n
CarDeath_C2=CarDeath
CarDeath_d_C2=CarDeath_d
CarDeath_n_C2=CarDeath_n
Diabet_B2=Diabet
Gym_B2=Gym
Gym_d_B2=Gym_d
Gym_n_B2=Gym_n
HIV_C2=HIV
HIV_d_C2=HIV_d
Inactive_B2=Inactive
InfDeath_E2=InfDeath
Liquor_B2=Liquor
LowBW_C2=LowBW
LowBW_d_C2=LowBW_d
LowBW_n_C2=LowBW_n
MHPrvd_B2=MHPrvd
MHPrvd_r_B2=MHPrvd_r
Murder_C2=Murder
Murder_d_C2=Murder_d
Murder_n_C2=Murder_n
Obesity_B2=Obesity
PCP_B2=PCP
PCP_d_B2=PCP_d
PCP_n_B2=PCP_n
PCP_r_B2=PCP_r
PoorHlth_A2=PoorHlth
PoorHlth_d_A2=PoorHlth_d
PoorHlth_n_A2=PoorHlth_n
PoorMH_A2=PoorMH
PoorMH_d_A2=PoorMH_d
PoorPhy_A2=PoorPhy
PoorPhy_d_A2=PoorPhy_d
PrmDeath_C2=PrmDeath
PrmDeath_n_C2=PrmDeath_n
STD_CT_B2=STD_CT
STD_CT_d_B2=STD_CT_d
STD_CT_n_B2=STD_CT_n
Smoke_A2=Smoke
Smoke_d_A2=Smoke_d
Smoke_n_A2=Smoke_n
SocSupp_A2=SocSupp
SocSupp_d_A2=SocSupp_d
SocSupp_n_A2=SocSupp_n
TeenBth_C2=TeenBth
TeenBth_d_C2=TeenBth_d
TeenBth_n_C2=TeenBth_n
Violent_B2=Violent
Violent_d_B2=Violent_d
Violent_n_B2=Violent_n
));
drop Obesity_A2;
run;
/*N=3141, 58 variables*/
/***/
/* Duplicate variables in Z2009: Diabet_C2 Diabet_D2 Inactive_C2 Inactive_D2 Obesity_C2 Obesity_D2
   proc contents data=Z2009;run;
   proc corr data=Z2009;var Diabet_C2 Diabet_D2 Inactive_C2 Inactive_D2 Obesity_C2 Obesity_D2;run; */;
data Z2009a;set Z2009(rename=(
AccFood_C2=AccFood
AccFood_d_C2=AccFood_d
AccFood_n_C2=AccFood_n
BDrink_B2=BDrink
BDrink_d_B2=BDrink_d
DiabetM_C2=DiabetM
DiabetM_d_C2=DiabetM_d
Diabet_D2=Diabet
EDrink_B2=EDrink
EDrink_d_B2=EDrink_d
FastFood_C2=FastFood
FastFood_d_C2=FastFood_d
FastFood_n_C2=FastFood_n
Gym_C2=Gym
Gym_d_C2=Gym_d
Gym_n_C2=Gym_n
HIV_D2=HIV
HIV_n_D2=HIV_n
HlthCost_D2=HlthCost
HlthCost_d_D2=HlthCost_d
Inactive_D2=Inactive
InsuredA_C2=InsuredA
InsuredA_d_C2=InsuredA_d
InsuredA_n_C2=InsuredA_n
Insured_C2=Insured
Insured_d_C2=Insured_d
Insured_n_C2=Insured_n
Mammo_C2=Mammo
Mammo_d_C2=Mammo_d
Obesity_D2=Obesity
PCP_C2=PCP
PCP_d_C2=PCP_d
PCP_n_C2=PCP_n
PCP_r_C2=PCP_r
PoorHlth_B2=PoorHlth
PoorHlth_d_B2=PoorHlth_d
PoorMH_B2=PoorMH
PoorMH_d_B2=PoorMH_d
PoorPhy_B2=PoorPhy
PoorPhy_d_B2=PoorPhy_d
PrvtHosp_C2=PrvtHosp
PrvtHosp_d_C2=PrvtHosp_d
STD_CT_C2=STD_CT
STD_CT_d_C2=STD_CT_d
STD_CT_n_C2=STD_CT_n
Smoke_B2=Smoke
Smoke_d_B2=Smoke_d
SocSupp_B2=SocSupp
SocSupp_d_B2=SocSupp_d
Violent_C2=Violent
Violent_d_C2=Violent_d
Violent_n_C2=Violent_n
));
drop Diabet_C2 Inactive_C2 Obesity_C2;
run;
/*N=3141, 54 variables*/
/***/
/* Duplicate variables in Z2010: 
       CarDeath_D2 CarDeath_E2 CarDeath_d_D2 CarDeath_d_E2 CarDeath_n_D2 CarDeath_n_E2
       ChdDeath_D2 ChdDeath_E2 ChdDeath_d_D2 ChdDeath_d_E2 ChdDeath_n_D2 ChdDeath_n_E2
       HIV_E2 HIV_F2 HIV_d_E2 HIV_d_F2 HIV_n_E2 HIV_n_F2
       InfDeath_D2 InfDeath_F2 InfDeath_d_D2 InfDeath_d_F2 InfDeath_n_D2 InfDeath_n_F2
       LAccFood_F2 LAccFood_G2 LAccFood_H2 LAccFood_n_F2 LAccFood_n_G2 LAccFood_n_H2
       Murder_D2 Murder_E2 Murder_d_D2 Murder_d_E2 Murder_n_D2 Murder_n_E2
       PrmDeath_D2 PrmDeath_E2 PrmDeath_d_D2 PrmDeath_d_E2 PrmDeath_n_D2 PrmDeath_n_E2
       PrmDeath2_D2 PrmDeath2_E2 PrmDeath2_d_D2 PrmDeath2_d_E2 PrmDeath2_n_D2 PrmDeath2_n_E2
       SocSupp_C2 SocSupp_D2 SocSupp_E2 SocSupp_d_C2 SocSupp_d_D2 SocSupp_d_E2 SocSupp_n_C2 SocSupp_n_D2 SocSupp_n_E2
   proc contents data=Z2010;run;
   proc corr data=Z2010;var CarDeath_D2 CarDeath_E2 CarDeath_d_D2 CarDeath_d_E2 CarDeath_n_D2 CarDeath_n_E2;run;
   proc corr data=Z2010;var ChdDeath_D2 ChdDeath_E2 ChdDeath_d_D2 ChdDeath_d_E2 ChdDeath_n_D2 ChdDeath_n_E2;run;
   proc corr data=Z2010;var HIV_E2 HIV_F2 HIV_d_E2 HIV_d_F2 HIV_n_E2 HIV_n_F2;run;
   proc corr data=Z2010;var InfDeath_D2 InfDeath_F2 InfDeath_d_D2 InfDeath_d_F2 InfDeath_n_D2 InfDeath_n_F2;run;
   proc corr data=Z2010;var LAccFood_F2 LAccFood_G2 LAccFood_H2 LAccFood_n_F2 LAccFood_n_G2 LAccFood_n_H2;run;
   proc corr data=Z2010;var Murder_D2 Murder_E2 Murder_d_D2 Murder_d_E2 Murder_n_D2 Murder_n_E2;run;
   proc corr data=Z2010;var PrmDeath_D2 PrmDeath_E2 PrmDeath_d_D2 PrmDeath_d_E2 PrmDeath_n_D2 PrmDeath_n_E2;run;
   proc corr data=Z2010;var PrmDeath2_D2 PrmDeath2_E2 PrmDeath2_d_D2 PrmDeath2_d_E2 PrmDeath2_n_D2 PrmDeath2_n_E2;run;
   proc corr data=Z2010;var SocSupp_C2 SocSupp_D2 SocSupp_E2 SocSupp_d_C2 SocSupp_d_D2 SocSupp_d_E2 SocSupp_n_C2 SocSupp_n_D2 SocSupp_n_E2;run; */;
data Z2010a;set Z2010(rename=(
CarDeath_E2=CarDeath
CarDeath_d_E2=CarDeath_d
CarDeath_n_E2=CarDeath_n
ChdDeath_E2=ChdDeath
ChdDeath_d_E2=ChdDeath_d
ChdDeath_n_E2=ChdDeath_n
DiabetM_D2=DiabetM
DiabetM_d_D2=DiabetM_d
Diabet_E2=Diabet
Diabet_d_E2=Diabet_d
Diabet_n_E2=Diabet_n
DrCost_C2=DrCost
DrCost_d_C2=DrCost_d
DrCost_n_C2=DrCost_n
DrugOd_E2=DrugOd
DrugOd_d_E2=DrugOd_d
DrugOd_n_E2=DrugOd_n
EDrink_C2=EDrink
EDrink_d_C2=EDrink_d
EDrink_n_C2=EDrink_n
FastFood_D2=FastFood
FastFood_d_D2=FastFood_d
FastFood_n_D2=FastFood_n
Gym_D2=Gym
Gym_n_D2=Gym_n
HIV_F2=HIV
HIV_d_F2=HIV_d
HIV_n_F2=HIV_n
Housing_E2=Housing
Housing_d_E2=Housing_d
Housing_n_E2=Housing_n
Inactive_E2=Inactive
Inactive_d_E2=Inactive_d
Inactive_n_E2=Inactive_n
InfDeath_F2=InfDeath
InfDeath_d_F2=InfDeath_d
InfDeath_n_F2=InfDeath_n
Injury_E2=Injury
Injury_d_E2=Injury_d
Injury_n_E2=Injury_n
InsuredA_D2=InsuredA
InsuredA_d_D2=InsuredA_d
InsuredA_n_D2=InsuredA_n
InsuredC_D2=InsuredC
InsuredC_d_D2=InsuredC_d
InsuredC_n_D2=InsuredC_n
Insured_D2=Insured
Insured_d_D2=Insured_d
Insured_n_D2=Insured_n
LAccFood_H2=LAccFood
LAccFood_n_H2=LAccFood_n
LowBW_D2=LowBW
LowBW_d_D2=LowBW_d
LowBW_n_D2=LowBW_n
Mammo_D2=Mammo
Mammo_d_D2=Mammo_d
Murder_E2=Murder
Murder_d_E2=Murder_d
Murder_n_E2=Murder_n
Obesity_E2=Obesity
Park_D2=Park
PoorHlth_C2=PoorHlth
PoorHlth_n_C2=PoorHlth_n
PoorHlth_d_C2=PoorHlth_d
PoorMH_C2=PoorMH
PoorMH_d_C2=PoorMH_d
PoorPhy_C2=PoorPhy
PoorPhy_d_C2=PoorPhy_d
PrmDeath_E2=PrmDeath
PrmDeath_d_E2=PrmDeath_d
PrmDeath_n_E2=PrmDeath_n
PrmDeath2_E2=PrmDeath2
PrmDeath2_d_E2=PrmDeath2_d
PrmDeath2_n_E2=PrmDeath2_n
PrvtHosp_D2=PrvtHosp
PrvtHosp_d_D2=PrvtHosp_d
STD_CT_D2=STD_CT
STD_CT_d_D2=STD_CT_d
STD_CT_n_D2=STD_CT_n
Smoke_C2=Smoke
Smoke_d_C2=Smoke_d
Smoke_n_C2=Smoke_n
SocSupp_E2=SocSupp
SocSupp_d_E2=SocSupp_d
SocSupp_n_E2=SocSupp_n
TeenBth_D2=TeenBth
TeenBth_d_D2=TeenBth_d
TeenBth_n_D2=TeenBth_n
Violent_D2=Violent
Violent_d_D2=Violent_d
Violent_n_D2=Violent_n
));
drop
CarDeath_D2 
CarDeath_d_D2 
CarDeath_n_D2 
ChdDeath_D2 
ChdDeath_d_D2 
ChdDeath_n_D2 
HIV_E2 
HIV_d_E2 
HIV_n_E2 
InfDeath_D2 
InfDeath_d_D2 
InfDeath_n_D2
LAccFood_F2 
LAccFood_G2 
LAccFood_n_F2 
LAccFood_n_G2 
Murder_D2 
Murder_d_D2 
Murder_n_D2 
PrmDeath_D2 
PrmDeath_d_D2 
PrmDeath_n_D2
PrmDeath2_D2 
PrmDeath2_d_D2 
PrmDeath2_n_D2
SocSupp_C2 
SocSupp_D2 
SocSupp_d_C2 
SocSupp_d_D2 
SocSupp_n_C2 
SocSupp_n_D2
;run;
/*N=3143, 93 variables*/
/***/
/* Duplicate variables in Z2011: 
       AirPM_E2 AirPM_F2 AirPM_G2
       FrLunch_D2 FrLunch_E2 FrLunch_d_D2 FrLunch_d_E2 FrLunch_n_D2 FrLunch_n_E2
proc contents data=Z2011;run;
proc corr data=Z2011;var AirPM_E2 AirPM_F2 AirPM_G2;run;
proc corr data=Z2011;var FrLunch_D2 FrLunch_E2 FrLunch_d_D2 FrLunch_d_E2 FrLunch_n_D2 FrLunch_n_E2;run; */;
data Z2011a;set Z2011(rename=(
AirPM_G2=AirPM
DiabetM_E2=DiabetM
DiabetM_d_E2=DiabetM_d
Diabet_F2=Diabet
Diabet_d_F2=Diabet_d
Diabet_n_F2=Diabet_n
DrCost_D2=DrCost
DrCost_d_D2=DrCost_d
DrCost_n_D2=DrCost_n
EDrink_D2=EDrink
EDrink_d_D2=EDrink_d
EDrink_n_D2=EDrink_n
FoodEnv_E2=FoodEnv
FoodEnv_d_E2=FoodEnv_d
FoodEnv_n_E2=FoodEnv_n
FoodIns_E2=FoodIns
FoodIns_d_E2=FoodIns_d
FoodIns_n_E2=FoodIns_n
FrLunch_E2=FrLunch
FrLunch_d_E2=FrLunch_d
FrLunch_n_E2=FrLunch_n
HlthCost_E2=HlthCost
HlthCost_d_E2=HlthCost_d
Housing_F2=Housing
Housing_d_F2=Housing_d
Housing_n_F2=Housing_n
Inactive_F2=Inactive
Inactive_d_F2=Inactive_d
Inactive_n_F2=Inactive_n
InsuredA_E2=InsuredA
InsuredA_d_E2=InsuredA_d
InsuredA_n_E2=InsuredA_n
InsuredC_E2=InsuredC
InsuredC_d_E2=InsuredC_d
InsuredC_n_E2=InsuredC_n
Insured_E2=Insured
Insured_d_E2=Insured_d
Insured_n_E2=Insured_n
LowBW_E2=LowBW
LowBW_d_E2=LowBW_d
LowBW_n_E2=LowBW_n
Mammo_E2=Mammo
Mammo_d_E2=Mammo_d
Obesity_F2=Obesity
Obesity_d_F2=Obesity_d
Obesity_n_F2=Obesity_n
PCP_E2=PCP
PCP_d_E2=PCP_d
PCP_n_E2=PCP_n
PCP_r_E2=PCP_r
PoorHlth_D2=PoorHlth
PoorHlth_d_D2=PoorHlth_d
PoorHlth_n_D2=PoorHlth_n
PoorMH_D2=PoorMH
PoorMH_d_D2=PoorMH_d
PoorPhy_D2=PoorPhy
PoorPhy_d_D2=PoorPhy_d
PrvtHosp_E2=PrvtHosp
PrvtHosp_d_E2=PrvtHosp_d
STD_CT_E2=STD_CT
STD_CT_d_E2=STD_CT_d
STD_CT_n_E2=STD_CT_n
Smoke_D2=Smoke
Smoke_d_D2=Smoke_d
Smoke_n_D2=Smoke_n
TeenBth_E2=TeenBth
TeenBth_d_E2=TeenBth_d
TeenBth_n_E2=TeenBth_n
Violent_E2=Violent
Violent_d_E2=Violent_d
Violent_n_E2=Violent_n
));
drop
AirPM_E2
AirPM_F2
FrLunch_D2
FrLunch_d_D2
FrLunch_n_D2
;run;
/*N=3141, 73 variables*/
/***/
/* Duplicate variables in Z2012: 
       AirPM_H2 AirPM_I2
       Dentist_D2 Dentist_E2 Dentist_d_D2 Dentist_d_E2 Dentist_n_D2 Dentist_n_E2 Dentist_r_D2 Dentist_r_E2 (not exactly but practically same - use the most current one)
       DrCost_E2 DrCost_F2 DrCost_d_E2 DrCost_d_F2 DrCost_n_E2 DrCost_n_F2
       EDrink_E2 EDrink_F2 EDrink_d_E2 EDrink_d_F2 EDrink_n_E2 EDrink_n_F2
       LAccFood_D2 LAccFood_E2 LAccFood_n_D2 LAccFood_n_E2
       PCP_D2 PCP_F2 PCP_d_D2 PCP_d_F2 PCP_n_D2 PCP_n_F2 PCP_r_D2 PCP_r_F2 (not exactly but practically same - use the most current one)
       PoorHlth_E2 PoorHlth_F2 PoorHlth_d_E2 PoorHlth_d_F2 PoorHlth_n_E2 PoorHlth_n_F2
       PoorMH_E2 PoorMH_F2 PoorMH_d_E2 PoorMH_d_F2
       PoorPhy_E2 PoorPhy_F2 PoorPhy_d_E2 PoorPhy_d_F2
       Smoke_E2 Smoke_F2 Smoke_d_E2 Smoke_d_F2 Smoke_n_E2 Smoke_n_F2
       Violent_F2 Violent_G2 Violent_d_F2 Violent_d_G2 Violent_n_F2 Violent_n_G2 
proc contents data=Z2012;run;
proc corr data=Z2012;var AirPM_H2 AirPM_I2;run;
proc corr data=Z2012;var Dentist_D2 Dentist_E2 Dentist_d_D2 Dentist_d_E2 Dentist_n_D2 Dentist_n_E2 Dentist_r_D2 Dentist_r_E2;run;
proc corr data=Z2012;var DrCost_E2 DrCost_F2 DrCost_d_E2 DrCost_d_F2 DrCost_n_E2 DrCost_n_F2;run;
proc corr data=Z2012;var EDrink_E2 EDrink_F2 EDrink_d_E2 EDrink_d_F2 EDrink_n_E2 EDrink_n_F2;run;
proc corr data=Z2012;var LAccFood_D2 LAccFood_E2 LAccFood_n_D2 LAccFood_n_E2;run;
proc corr data=Z2012;var PCP_D2 PCP_F2 PCP_d_D2 PCP_d_F2 PCP_n_D2 PCP_n_F2 PCP_r_D2 PCP_r_F2;run;
proc corr data=Z2012;var PoorHlth_E2 PoorHlth_F2 PoorHlth_d_E2 PoorHlth_d_F2 PoorHlth_n_E2 PoorHlth_n_F2;run;
proc corr data=Z2012;var PoorMH_E2 PoorMH_F2 PoorMH_d_E2 PoorMH_d_F2;run;
proc corr data=Z2012;var PoorPhy_E2 PoorPhy_F2 PoorPhy_d_E2 PoorPhy_d_F2;run;
proc corr data=Z2012;var Smoke_E2 Smoke_F2 Smoke_d_E2 Smoke_d_F2 Smoke_n_E2 Smoke_n_F2;run;
proc corr data=Z2012;var Violent_F2 Violent_G2 Violent_d_F2 Violent_d_G2 Violent_n_F2 Violent_n_G2;run; */;
data Z2012a;set Z2012(rename=(
AirPM_I2=AirPM
CarDeath_F2=CarDeath
CarDeath_d_F2=CarDeath_d
CarDeath_n_F2=CarDeath_n
ChdDeath_F2=ChdDeath
ChdDeath_d_F2=ChdDeath_d
ChdDeath_n_F2=ChdDeath_n
DWIDeath_E2=DWIDeath
DWIDeath_d_E2=DWIDeath_d
DWIDeath_n_E2=DWIDeath_n
DcYouth_H2=DcYouth
Dentist_E2=Dentist
Dentist_d_E2=Dentist_d
Dentist_n_E2=Dentist_n
Dentist_r_E2=Dentist_r
DiabetM_F2=DiabetM
DiabetM_d_F2=DiabetM_d
Diabet_G2=Diabet
DrCost_F2=DrCost
DrCost_d_F2=DrCost_d
DrCost_n_F2=DrCost_n
DrugOd_F2=DrugOd
DrugOd_d_F2=DrugOd_d
DrugOd_n_F2=DrugOd_n
EDrink_F2=EDrink
EDrink_d_F2=EDrink_d
EDrink_n_F2=EDrink_n
FoodEnv_F2=FoodEnv
FoodEnv_d_F2=FoodEnv_d
FoodEnv_n_F2=FoodEnv_n
FoodIns_F2=FoodIns
FoodIns_n_F2=FoodIns_n
FrLunch_F2=FrLunch
FrLunch_d_F2=FrLunch_d
FrLunch_n_F2=FrLunch_n
Gym2_E2=Gym2
HIV_G2=HIV
HIV_d_G2=HIV_d
HIV_n_G2=HIV_n
HlthCost_F2=HlthCost
HlthCost_d_F2=HlthCost_d
Housing_G2=Housing
Housing_d_G2=Housing_d
Housing_n_G2=Housing_n
Inactive_G2=Inactive
Inactive_d_G2=Inactive_d
Inactive_n_G2=Inactive_n
InfDeath_G2=InfDeath
InfDeath_d_G2=InfDeath_d
InfDeath_n_G2=InfDeath_n
Injury_F2=Injury
Injury_d_F2=Injury_d
Injury_n_F2=Injury_n
InsuredA_F2=InsuredA
InsuredA_d_F2=InsuredA_d
InsuredA_n_F2=InsuredA_n
InsuredC_F2=InsuredC
InsuredC_d_F2=InsuredC_d
InsuredC_n_F2=InsuredC_n
Insured_F2=Insured
Insured_d_F2=Insured_d
Insured_n_F2=Insured_n
LAccFood_E2=LAccFood
LAccFood_n_E2=LAccFood_n
LongComm_E2=LongComm
LongComm_d_E2=LongComm_d
LowBW_F2=LowBW
LowBW_d_F2=LowBW_d
LowBW_n_F2=LowBW_n
MHPrvd_D2=MHPrvd
MHPrvd_d_D2=MHPrvd_d
MHPrvd_n_D2=MHPrvd_n
MHPrvd_r_D2=MHPrvd_r
Mammo_F2=Mammo
Mammo_d_F2=Mammo_d
Murder_F2=Murder
Murder_d_F2=Murder_d
Murder_n_F2=Murder_n
Obesity_G2=Obesity
Obesity_d_G2=Obesity_d
Obesity_n_G2=Obesity_n
PCP_F2=PCP
PCP_d_F2=PCP_d
PCP_n_F2=PCP_n
PCP_r_F2=PCP_r
PoorHlth_F2=PoorHlth
PoorHlth_d_F2=PoorHlth_d
PoorHlth_n_F2=PoorHlth_n
PoorMH_F2=PoorMH
PoorMH_d_F2=PoorMH_d
PoorPhy_F2=PoorPhy
PoorPhy_d_F2=PoorPhy_d
PrmDeath_F2=PrmDeath
PrmDeath_d_F2=PrmDeath_d
PrmDeath_n_F2=PrmDeath_n
PrmDeath2_F2=PrmDeath2
PrmDeath2_d_F2=PrmDeath2_d
PrmDeath2_n_F2=PrmDeath2_n
PrvtHosp_F2=PrvtHosp
PrvtHosp_d_F2=PrvtHosp_d
STD_CT_F2=STD_CT
STD_CT_d_F2=STD_CT_d
STD_CT_n_F2=STD_CT_n
Smoke_F2=Smoke
Smoke_d_F2=Smoke_d
Smoke_n_F2=Smoke_n
SocAsso_F2=SocAsso
SocAsso_d_F2=SocAsso_d
SocAsso_n_F2=SocAsso_n
TeenBth_F2=TeenBth
TeenBth_d_F2=TeenBth_d
TeenBth_n_F2=TeenBth_n
Violent_G2=Violent
Violent_d_G2=Violent_d
Violent_n_G2=Violent_n
Water_D2=Water
Water_d_D2=Water_d
Water_n_D2=Water_n
));
drop
AirPM_H2
Dentist_D2
Dentist_d_D2
Dentist_n_D2
Dentist_r_D2
DrCost_E2
DrCost_d_E2
DrCost_n_E2
EDrink_E2
EDrink_d_E2
EDrink_n_E2
LAccFood_D2
LAccFood_n_D2
PCP_D2
PCP_d_D2
PCP_n_D2
PCP_r_D2
PoorHlth_E2
PoorHlth_d_E2
PoorHlth_n_E2
PoorMH_E2
PoorMH_d_E2
PoorPhy_E2
PoorPhy_d_E2
Smoke_E2
Smoke_d_E2
Smoke_n_E2
Violent_F2
Violent_d_F2
Violent_n_F2
;run;
/*N=3149, 120 variables*/
/***/
/* Duplicate variables in Z2013: None
   proc contents data=Z2013;run; */;
data Z2013a;set Z2013(rename=(
CarDeath_G2=CarDeath
CarDeath_d_G2=CarDeath_d
CarDeath_n_G2=CarDeath_n
ChdDeath_G2=ChdDeath
ChdDeath_d_G2=ChdDeath_d
ChdDeath_n_G2=ChdDeath_n
DWIDeath_F2=DWIDeath
DWIDeath_d_F2=DWIDeath_d
DWIDeath_n_F2=DWIDeath_n
Dentist_F2=Dentist
Dentist_d_F2=Dentist_d
Dentist_n_F2=Dentist_n
Dentist_r_F2=Dentist_r
DiabetM_G2=DiabetM
DiabetM_d_G2=DiabetM_d
Diabet_H2=Diabet
Diabet_d_H2=Diabet_d
Diabet_n_H2=Diabet_n
FoodEnv_G2=FoodEnv
FoodEnv_d_G2=FoodEnv_d
FoodEnv_n_G2=FoodEnv_n
FoodIns_G2=FoodIns
FoodIns_n_G2=FoodIns_n
FrLunch_G2=FrLunch
FrLunch_d_G2=FrLunch_d
FrLunch_n_G2=FrLunch_n
Gym2_F2=Gym2
Gym2_d_F2=Gym2_d
Gym2_n_F2=Gym2_n
HIV_H2=HIV
HIV_d_H2=HIV_d
HIV_n_H2=HIV_n
HlthCost_G2=HlthCost
HlthCost_d_G2=HlthCost_d
Housing_H2=Housing
Housing_d_H2=Housing_d
Housing_n_H2=Housing_n
Inactive_H2=Inactive
Inactive_d_H2=Inactive_d
Inactive_n_H2=Inactive_n
InfDeath_H2=InfDeath
InfDeath_d_H2=InfDeath_d
InfDeath_n_H2=InfDeath_n
Injury_G2=Injury
Injury_d_G2=Injury_d
Injury_n_G2=Injury_n
InsuredA_G2=InsuredA
InsuredA_d_G2=InsuredA_d
InsuredA_n_G2=InsuredA_n
InsuredC_G2=InsuredC
InsuredC_d_G2=InsuredC_d
InsuredC_n_G2=InsuredC_n
Insured_G2=Insured
Insured_d_G2=Insured_d
Insured_n_G2=Insured_n
LongComm_F2=LongComm
LongComm_d_F2=LongComm_d
LowBW_G2=LowBW
LowBW_d_G2=LowBW_d
LowBW_n_G2=LowBW_n
MHPrvd_E2=MHPrvd
MHPrvd_d_E2=MHPrvd_d
MHPrvd_n_E2=MHPrvd_n
MHPrvd_r_E2=MHPrvd_r
Mammo_G2=Mammo
Mammo_d_G2=Mammo_d
Murder_G2=Murder
Murder_d_G2=Murder_d
Murder_n_G2=Murder_n
Obesity_H2=Obesity
Obesity_d_H2=Obesity_d
Obesity_n_H2=Obesity_n
PCP2_d_E2=PCP2_d
PCP_G2=PCP
PCP_d_G2=PCP_d
PCP_n_G2=PCP_n
PCP_r_G2=PCP_r
PrmDeath_G2=PrmDeath
PrmDeath_d_G2=PrmDeath_d
PrmDeath_n_G2=PrmDeath_n
PrmDeath2_G2=PrmDeath2
PrmDeath2_d_G2=PrmDeath2_d
PrmDeath2_n_G2=PrmDeath2_n
PrvtHosp_G2=PrvtHosp
PrvtHosp_d_G2=PrvtHosp_d
STD_CT_G2=STD_CT
STD_CT_d_G2=STD_CT_d
STD_CT_n_G2=STD_CT_n
SocAsso_G2=SocAsso
SocAsso_d_G2=SocAsso_d
SocAsso_n_G2=SocAsso_n
TeenBth_G2=TeenBth
TeenBth_d_G2=TeenBth_d
TeenBth_n_G2=TeenBth_n
Water_E2=Water
Water_d_E2=Water_d
Water_n_E2=Water_n
));
run;
/*N=3143, 99 variables*/
/***/
/* Duplicate variables in Z2014:
       AirPM_J2 AirPM_K2
       DiabetM_H2 DiabetM_I2 DiabetM_d_H2 DiabetM_d_I2
       Gym2_G2 Gym2_H2
       Mammo_H2 Mammo_I2 Mammo_d_H2 Mammo_d_I2
       Sleep_G2 Sleep_H2
       Violent_H2 Violent_I2 Violent_d_H2 Violent_d_I2 Violent_n_H2 Violent_n_I2
       Water2_G2 Water2_H2
proc contents data=Z2014;run;
proc corr data=Z2014;var AirPM_J2 AirPM_K2;run;
proc corr data=Z2014;var DiabetM_H2 DiabetM_I2 DiabetM_d_H2 DiabetM_d_I2;run;
proc corr data=Z2014;var Gym2_G2 Gym2_H2;run;
proc corr data=Z2014;var Mammo_H2 Mammo_I2 Mammo_d_H2 Mammo_d_I2;run;
proc corr data=Z2014;var Sleep_G2 Sleep_H2;run;
proc corr data=Z2014;var Violent_H2 Violent_I2 Violent_d_H2 Violent_d_I2 Violent_n_H2 Violent_n_I2;run;
proc corr data=Z2014;var Water2_G2 Water2_H2;run; */;
data Z2014a;set Z2014(rename=(
AirPM_K2=AirPM
DWIDeath_G2=DWIDeath
DWIDeath_d_G2=DWIDeath_d
DWIDeath_n_G2=DWIDeath_n
DcYouth_I2=DcYouth
DcYouth_n_I2=DcYouth_n
Dentist_G2=Dentist
Dentist_d_G2=Dentist_d
Dentist_n_G2=Dentist_n
Dentist_r_G2=Dentist_r
DiabetB_I2=DiabetB
DiabetM_I2=DiabetM
DiabetM_d_I2=DiabetM_d
DiabetW_I2=DiabetW
Diabet_I2=Diabet
Diabet_d_I2=Diabet_d
Diabet_n_I2=Diabet_n
DrugOd_G2=DrugOd
DrugOd_d_G2=DrugOd_d
DrugOd_n_G2=DrugOd_n
DrugOdm_G2=DrugOdm
EDrink_G2=EDrink
FoodEnv_H2=FoodEnv
FoodEnv_d_H2=FoodEnv_d
FoodEnv_n_H2=FoodEnv_n
FoodIns_H2=FoodIns
FoodIns_n_H2=FoodIns_n
Gym2_H2=Gym2
HlthCost_H2=HlthCost
HlthCost_d_H2=HlthCost_d
Housing_I2=Housing
Housing_d_I2=Housing_d
Housing_n_I2=Housing_n
Inactive_I2=Inactive
Inactive_d_I2=Inactive_d
Inactive_n_I2=Inactive_n
InsuredA_H2=InsuredA
InsuredA_d_H2=InsuredA_d
InsuredA_n_H2=InsuredA_n
InsuredC_H2=InsuredC
InsuredC_d_H2=InsuredC_d
InsuredC_n_H2=InsuredC_n
Insured_H2=Insured
Insured_d_H2=Insured_d
Insured_n_H2=Insured_n
LongComm_G2=LongComm
LongComm_d_G2=LongComm_d
LowBW_H2=LowBW
LowBW_d_H2=LowBW_d
LowBW_n_H2=LowBW_n
MHPrvd_F2=MHPrvd
MHPrvd_d_F2=MHPrvd_d
MHPrvd_n_F2=MHPrvd_n
MHPrvd_r_F2=MHPrvd_r
MammoB_I2=MammoB
MammoW_I2=MammoW
Mammo_I2=Mammo
Mammo_d_I2=Mammo_d
Mental_G2=Mental
Obesity_I2=Obesity
Obesity_d_I2=Obesity_d
Obesity_n_I2=Obesity_n
PCP2_F2=PCP2
PCP2_d_F2=PCP2_d
PCP2_n_F2=PCP2_n
PCP2_r_F2=PCP2_r
PCP_H2=PCP
PCP_d_H2=PCP_d
PCP_n_H2=PCP_n
PCP_r_H2=PCP_r
Physical_G2=Physical
PoorHlth_G2=PoorHlth
PoorMH_G2=PoorMH
PoorPhy_G2=PoorPhy
PrmDeath_H2=PrmDeath
PrmDeath_d_H2=PrmDeath_d
PrmDeath_n_H2=PrmDeath_n
PrvtHosp_H2=PrvtHosp
PrvtHosp_d_H2=PrvtHosp_d
STD_CT_H2=STD_CT
STD_CT_d_H2=STD_CT_d
STD_CT_n_H2=STD_CT_n
SegBW_G2=SegBW
SegNW_G2=SegNW
Sleep_H2=Sleep
Smoke_G2=Smoke
SocAsso_H2=SocAsso
SocAsso_d_H2=SocAsso_d
SocAsso_n_H2=SocAsso_n
TeenBth_H2=TeenBth
TeenBth_d_H2=TeenBth_d
TeenBth_n_H2=TeenBth_n
Violent_I2=Violent
Violent_d_I2=Violent_d
Violent_n_I2=Violent_n
Water2_H2=Water2
Water_F2=Water
Water_d_F2=Water_d
Water_n_F2=Water_n
));
drop
AirPM_J2
DiabetM_H2
DiabetM_d_H2
Gym2_G2
Mammo_H2
Mammo_d_H2
Sleep_G2
Violent_H2
Violent_d_H2
Violent_n_H2
Water2_G2
;run;
/*N=3149, 101 variables*/
/***/
/* Duplicate variables in Z2015:
       HIV_I2 HIV_J2 HIV_d_I2 HIV_d_J2 HIV_n_I2 HIV_n_J2
       LAccFood_I2 LAccFood_J2 LAccFood_K2 LAccFood_d_I2 LAccFood_d_J2 LAccFood_d_K2 LAccFood_n_I2 LAccFood_n_J2 LAccFood_n_K2
proc contents data=Z2015;run;
proc corr data=Z2015;var HIV_I2 HIV_J2 HIV_d_I2 HIV_d_J2 HIV_n_I2 HIV_n_J2;run;
proc corr data=Z2015;var LAccFood_I2 LAccFood_J2 LAccFood_K2 LAccFood_d_I2 LAccFood_d_J2 LAccFood_d_K2 LAccFood_n_I2 LAccFood_n_J2 LAccFood_n_K2;run;*/;
data Z2015a;set Z2015(rename=(
CarDeath_H2=CarDeath
CarDeath_d_H2=CarDeath_d
CarDeath_n_H2=CarDeath_n
ChdDeath_H2=ChdDeath
ChdDeath_d_H2=ChdDeath_d
ChdDeath_n_H2=ChdDeath_n
DWIDeath_H2=DWIDeath
DWIDeath_d_H2=DWIDeath_d
DWIDeath_n_H2=DWIDeath_n
Dentist_H2=Dentist
Dentist_d_H2=Dentist_d
Dentist_n_H2=Dentist_n
Dentist_r_H2=Dentist_r
Diabet_J2=Diabet
Diabet_d_J2=Diabet_d
Diabet_n_J2=Diabet_n
DrugOd_H2=DrugOd
DrugOd_d_H2=DrugOd_d
DrugOd_n_H2=DrugOd_n
EDrink_H2=EDrink
FoodEnv_I2=FoodEnv
FoodEnv_d_I2=FoodEnv_d
FoodEnv_n_I2=FoodEnv_n
FoodIns_I2=FoodIns
FoodIns_n_I2=FoodIns_n
FrLunch_H2=FrLunch
FrLunch_d_H2=FrLunch_d
FrLunch_n_H2=FrLunch_n
GunDeath_H2=GunDeath
GunDeath_d_H2=GunDeath_d
GunDeath_n_H2=GunDeath_n
HIV_J2=HIV
HIV_d_J2=HIV_d
HIV_n_J2=HIV_n
HlthCost_I2=HlthCost
HlthCost_d_I2=HlthCost_d
HousCosts_J2=HousCosts
HousCrowd_J2=HousCrowd
HousPlumb_J2=HousPlumb
Housing_J2=Housing
Housing_d_J2=Housing_d
Housing_n_J2=Housing_n
Inactive_J2=Inactive
Inactive_d_J2=Inactive_d
Inactive_n_J2=Inactive_n
Injury_H2=Injury
Injury_d_H2=Injury_d
Injury_n_H2=Injury_n
InsuredA_I2=InsuredA
InsuredA_d_I2=InsuredA_d
InsuredA_n_I2=InsuredA_n
InsuredC_I2=InsuredC
InsuredC_d_I2=InsuredC_d
InsuredC_n_I2=InsuredC_n
Insured_I2=Insured
Insured_d_I2=Insured_d
Insured_n_I2=Insured_n
LAccFood_K2=LAccFood
LAccFood_d_K2=LAccFood_d
LAccFood_n_K2=LAccFood_n
LongComm_H2=LongComm
LongComm_d_H2=LongComm_d
MHPrvd_G2=MHPrvd
MHPrvd_d_G2=MHPrvd_d
MHPrvd_n_G2=MHPrvd_n
MHPrvd_r_G2=MHPrvd_r
Mental_H2=Mental
Murder_H2=Murder
Murder_d_H2=Murder_d
Murder_n_H2=Murder_n
Obesity_J2=Obesity
Obesity_d_J2=Obesity_d
Obesity_n_J2=Obesity_n
PCP2_G2=PCP2
PCP2_d_G2=PCP2_d
PCP2_n_G2=PCP2_n
PCP2_r_G2=PCP2_r
PCP_I2=PCP
PCP_d_I2=PCP_d
PCP_n_I2=PCP_n
PCP_r_I2=PCP_r
Physical_H2=Physical
PoorHlth_H2=PoorHlth
PoorMH_H2=PoorMH
PoorPhy_H2=PoorPhy
PrmDeath2_H2=PrmDeath2
PrmDeath2_d_H2=PrmDeath2_d
PrmDeath2_n_H2=PrmDeath2_n
PrvtHosp_I2=PrvtHosp
PrvtHosp_d_I2=PrvtHosp_d
STD_CT_I2=STD_CT
STD_CT_d_I2=STD_CT_d
STD_CT_n_I2=STD_CT_n
SegBW_H2=SegBW
SegNW_H2=SegNW
Smoke_H2=Smoke
SocAsso_I2=SocAsso
SocAsso_d_I2=SocAsso_d
SocAsso_n_I2=SocAsso_n
));
drop
HIV_I2
HIV_d_I2
HIV_n_I2
LAccFood_I2
LAccFood_J2
LAccFood_d_I2
LAccFood_d_J2
LAccFood_n_I2
LAccFood_n_J2
;run;
/*N=3149, 101 variables*/
/***/
/* Duplicate variables in Z2016:
       EDrink_I2 EDrink_J2
       Mental_I2 Mental_J2
       Physical_I2 Physical_J2
       PoorHlth_I2 PoorHlth_J2
       PoorMH_I2 PoorMH_J2
       PoorPhy_I2 PoorPhy_J2
       Sleep_I2 Sleep_J2 Sleep_K2
       Smoke_I2 Smoke_J2
       Violent_J2 Violent_K2 Violent_d_J2 Violent_d_K2 Violent_n_J2 Violent_n_K2
proc contents data=Z2016;run;
proc corr data=Z2016;var EDrink_I2 EDrink_J2;run;
proc corr data=Z2016;var Mental_I2 Mental_J2;run;
proc corr data=Z2016;var Physical_I2 Physical_J2;run;
proc corr data=Z2016;var PoorHlth_I2 PoorHlth_J2;run;
proc corr data=Z2016;var PoorMH_I2 PoorMH_J2;run;
proc corr data=Z2016;var PoorPhy_I2 PoorPhy_J2;run;
proc corr data=Z2016;var Sleep_I2 Sleep_J2 Sleep_K2;run;
proc corr data=Z2016;var Smoke_I2 Smoke_J2;run;
proc corr data=Z2016;var Violent_J2 Violent_K2 Violent_d_J2 Violent_d_K2 Violent_n_J2 Violent_n_K2;run; */;
data Z2016a;set Z2016(rename=(
CarDeath_I2=CarDeath
CarDeath_d_I2=CarDeath_d
CarDeath_n_I2=CarDeath_n
ChdDeathB_I2=ChdDeathB
ChdDeathH_I2=ChdDeathH
ChdDeathW_I2=ChdDeathW
ChdDeath_I2=ChdDeath
ChdDeath_d_I2=ChdDeath_d
ChdDeath_n_I2=ChdDeath_n
DWIDeath_I2=DWIDeath
DWIDeath_d_I2=DWIDeath_d
DWIDeath_n_I2=DWIDeath_n
Dentist_I2=Dentist
Dentist_d_I2=Dentist_d
Dentist_n_I2=Dentist_n
Dentist_r_I2=Dentist_r
Diabet_K2=Diabet
Diabet_n_K2=Diabet_n
DrugOd_I2=DrugOd
DrugOd_d_I2=DrugOd_d
DrugOd_n_I2=DrugOd_n
DrugOdm_I2=DrugOdm
DrugOdm_d_I2=DrugOdm_d
EDrink_J2=EDrink
FluVaccB_J2=FluVaccB
FluVaccH_J2=FluVaccH
FluVaccW_J2=FluVaccW
FluVacc_J2=FluVacc
FoodEnv_J2=FoodEnv
FoodEnv_d_J2=FoodEnv_d
FoodEnv_n_J2=FoodEnv_n
FoodIns_J2=FoodIns
FoodIns_n_J2=FoodIns_n
FrLunch_I2=FrLunch
FrLunch_d_I2=FrLunch_d
FrLunch_n_I2=FrLunch_n
GunDeath_I2=GunDeath
GunDeath_d_I2=GunDeath_d
GunDeath_n_I2=GunDeath_n
Gym2_I2=Gym2
Gym2_d_I2=Gym2_d
Gym2_n_I2=Gym2_n
HIV_K2=HIV
HIV_d_K2=HIV_d
HIV_n_K2=HIV_n
HousCosts_K2=HousCosts
HousCrowd_K2=HousCrowd
HousPlumb_K2=HousPlumb
Housing_K2=Housing
Housing_d_K2=Housing_d
Housing_n_K2=Housing_n
Inactive_K2=Inactive
Inactive_n_K2=Inactive_n
InfDeathB_I2=InfDeathB
InfDeathH_I2=InfDeathH
InfDeathW_I2=InfDeathW
InfDeath_I2=InfDeath
InfDeath_d_I2=InfDeath_d
InfDeath_n_I2=InfDeath_n
Injury_I2=Injury
Injury_d_I2=Injury_d
Injury_n_I2=Injury_n
InsuredA_J2=InsuredA
InsuredA_d_J2=InsuredA_d
InsuredA_n_J2=InsuredA_n
InsuredC_J2=InsuredC
InsuredC_d_J2=InsuredC_d
InsuredC_n_J2=InsuredC_n
Insured_J2=Insured
Insured_d_J2=Insured_d
Insured_n_J2=Insured_n
LongComm_I2=LongComm
LongComm_d_I2=LongComm_d
LowBWB_I2=LowBWB
LowBWH_I2=LowBWH
LowBWW_I2=LowBWW
LowBW_I2=LowBW
LowBW_d_I2=LowBW_d
LowBW_n_I2=LowBW_n
MHPrvd_H2=MHPrvd
MHPrvd_d_H2=MHPrvd_d
MHPrvd_n_H2=MHPrvd_n
MHPrvd_r_H2=MHPrvd_r
MammoB_J2=MammoB
MammoH_J2=MammoH
MammoW_J2=MammoW
Mammo_J2=Mammo
Math_K2=Math
MathW_K2=MathW
MathB_K2=MathB
MathH_K2=MathH
MathA_K2=MathA
Mental_J2=Mental
Murder_I2=Murder
Murder_d_I2=Murder_d
Murder_n_I2=Murder_n
Obesity_K2=Obesity
Obesity_n_K2=Obesity_n
PCP2_H2=PCP2
PCP2_d_H2=PCP2_d
PCP2_n_H2=PCP2_n
PCP2_r_H2=PCP2_r
PCP_J2=PCP
PCP_d_J2=PCP_d
PCP_n_J2=PCP_n
PCP_r_J2=PCP_r
Physical_J2=Physical
PoorHlth_J2=PoorHlth
PoorMH_J2=PoorMH
PoorPhy_J2=PoorPhy
PrmDeathB_I2=PrmDeathB
PrmDeathH_I2=PrmDeathH
PrmDeathW_I2=PrmDeathW
PrmDeath_I2=PrmDeath
PrmDeath_d_I2=PrmDeath_d
PrmDeath_n_I2=PrmDeath_n
PrmDeath2B_I2=PrmDeath2B
PrmDeath2H_I2=PrmDeath2H
PrmDeath2W_I2=PrmDeath2W
PrmDeath2_I2=PrmDeath2
PrmDeath2_d_I2=PrmDeath2_d
PrmDeath2_n_I2=PrmDeath2_n
PrvtHospB_J2=PrvtHospB
PrvtHospH_J2=PrvtHospH
PrvtHospW_J2=PrvtHospW
PrvtHosp_J2=PrvtHosp
Read_K2=Read
ReadW_K2=ReadW
ReadB_K2=ReadB
ReadH_K2=ReadH
ReadA_K2=ReadA
STD_CT_J2=STD_CT
STD_CT_d_J2=STD_CT_d
STD_CT_n_J2=STD_CT_n
SegBW_I2=SegBW
SegNW_I2=SegNW
Sleep_K2=Sleep
Smoke_J2=Smoke
SocAsso_J2=SocAsso
SocAsso_d_J2=SocAsso_d
SocAsso_n_J2=SocAsso_n
TeenBthB_I2=TeenBthB
TeenBthH_I2=TeenBthH
TeenBthW_I2=TeenBthW
TeenBth_I2=TeenBth
TeenBth_d_I2=TeenBth_d
TeenBth_n_I2=TeenBth_n
Violent_K2=Violent
Violent_d_K2=Violent_d
Violent_n_K2=Violent_n
Water2_I2=Water2
));
drop
EDrink_I2
Mental_I2
Physical_I2
PoorHlth_I2
PoorMH_I2
PoorPhy_I2
Sleep_I2
Sleep_J2
Smoke_I2
Violent_J2
Violent_d_J2
Violent_n_J2
;run;
/*N=3143, 153 variables*/
/***/
/* Duplicate variables in Z2017: None
   proc contents data=Z2017;run; */;
data Z2017a;set Z2017(rename=(
CarDeath_J2=CarDeath
CarDeath_d_J2=CarDeath_d
CarDeath_n_J2=CarDeath_n
ChdDeathB_J2=ChdDeathB
ChdDeathH_J2=ChdDeathH
ChdDeathW_J2=ChdDeathW
ChdDeath_J2=ChdDeath
ChdDeath_d_J2=ChdDeath_d
ChdDeath_n_J2=ChdDeath_n
DWIDeath_J2=DWIDeath
DWIDeath_d_J2=DWIDeath_d
DWIDeath_n_J2=DWIDeath_n
DcYouth_J2=DcYouth
DcYouth_d_J2=DcYouth_d
DcYouth_n_J2=DcYouth_n
Dentist_J2=Dentist
Dentist_d_J2=Dentist_d
Dentist_n_J2=Dentist_n
Dentist_r_J2=Dentist_r
DrugOd_J2=DrugOd
DrugOd_d_J2=DrugOd_d
DrugOd_n_J2=DrugOd_n
EDrink_K2=EDrink
FluVaccA_K2=FluVaccA
FluVaccB_K2=FluVaccB
FluVaccH_K2=FluVaccH
FluVaccN_K2=FluVaccN
FluVaccW_K2=FluVaccW
FluVacc_K2=FluVacc
FoodEnv_K2=FoodEnv
FoodEnv_d_K2=FoodEnv_d
FoodEnv_n_K2=FoodEnv_n
FoodIns_K2=FoodIns
FoodIns_n_K2=FoodIns_n
FrLunch_J2=FrLunch
FrLunch_d_J2=FrLunch_d
FrLunch_n_J2=FrLunch_n
GunDeath_J2=GunDeath
GunDeath_d_J2=GunDeath_d
GunDeath_n_J2=GunDeath_n
HousCost_J2=HousCost
HousCost_d_J2=HousCost_d
HousCost_n_J2=HousCost_n
InfDeathB_J2=InfDeathB
InfDeathH_J2=InfDeathH
InfDeathW_J2=InfDeathW
InfDeath_J2=InfDeath
InfDeath_d_J2=InfDeath_d
InfDeath_n_J2=InfDeath_n
Injury_J2=Injury
Injury_d_J2=Injury_d
Injury_n_J2=Injury_n
InsuredA_K2=InsuredA
InsuredA_d_K2=InsuredA_d
InsuredA_n_K2=InsuredA_n
InsuredC_K2=InsuredC
InsuredC_d_K2=InsuredC_d
InsuredC_n_K2=InsuredC_n
Insured_K2=Insured
Insured_d_K2=Insured_d
Insured_n_K2=Insured_n
JuvArrF_K2=JuvArrF
JuvArrI_K2=JuvArrI
JuvArr_K2=JuvArr
JuvArr_d_K2=JuvArr_d
LifeExpB_J2=LifeExpB
LifeExpH_J2=LifeExpH
LifeExpW_J2=LifeExpW
LifeExp_J2=LifeExp
LongComm_J2=LongComm
LongComm_d_J2=LongComm_d
LowBWB_J2=LowBWB
LowBWH_J2=LowBWH
LowBWW_J2=LowBWW
LowBW_J2=LowBW
LowBW_d_J2=LowBW_d
LowBW_n_J2=LowBW_n
MHPrvd_I2=MHPrvd
MHPrvd_d_I2=MHPrvd_d
MHPrvd_n_I2=MHPrvd_n
MHPrvd_r_I2=MHPrvd_r
MammoA_K2=MammoA
MammoB_K2=MammoB
MammoH_K2=MammoH
MammoN_K2=MammoN
MammoW_K2=MammoW
Mammo_K2=Mammo
Mental_K2=Mental
Murder_J2=Murder
Murder_d_J2=Murder_d
Murder_n_J2=Murder_n
PCP2_I2=PCP2
PCP2_d_I2=PCP2_d
PCP2_n_I2=PCP2_n
PCP2_r_I2=PCP2_r
PCP_K2=PCP
PCP_d_K2=PCP_d
PCP_n_K2=PCP_n
PCP_r_K2=PCP_r
Physical_K2=Physical
PoorHlth_K2=PoorHlth
PoorMH_K2=PoorMH
PoorPhy_K2=PoorPhy
PrmDeathB_J2=PrmDeathB
PrmDeathH_J2=PrmDeathH
PrmDeathW_J2=PrmDeathW
PrmDeath_J2=PrmDeath
PrmDeath_d_J2=PrmDeath_d
PrmDeath_n_J2=PrmDeath_n
PrmDeath2B_J2=PrmDeath2B
PrmDeath2H_J2=PrmDeath2H
PrmDeath2W_J2=PrmDeath2W
PrmDeath2_J2=PrmDeath2
PrmDeath2_d_J2=PrmDeath2_d
PrmDeath2_n_J2=PrmDeath2_n
PrvtHospA_K2=PrvtHospA
PrvtHospB_K2=PrvtHospB
PrvtHospH_K2=PrvtHospH
PrvtHospN_K2=PrvtHospN
PrvtHospW_K2=PrvtHospW
PrvtHosp_K2=PrvtHosp
STD_CT_K2=STD_CT
STD_CT_d_K2=STD_CT_d
STD_CT_n_K2=STD_CT_n
SegBW_J2=SegBW
SegNW_J2=SegNW
Smoke_K2=Smoke
SocAsso_K2=SocAsso
SocAsso_d_K2=SocAsso_d
SocAsso_n_K2=SocAsso_n
TeenBthB_J2=TeenBthB
TeenBthH_J2=TeenBthH
TeenBthW_J2=TeenBthW
TeenBth_J2=TeenBth
TeenBth_d_J2=TeenBth_d
TeenBth_n_J2=TeenBth_n
Water2_J2=Water2
));
run;
/*N=3142, 139 variables*/
/***/
/* Duplicate variables in Z2018: None
   proc contents data=Z2018;run; */;
data Z2018a;set Z2018(rename=(
CarDeathA_K2=CarDeathA
CarDeathB_K2=CarDeathB
CarDeathH_K2=CarDeathH
CarDeathN_K2=CarDeathN
CarDeathW_K2=CarDeathW
CarDeath_K2=CarDeath
CarDeath_d_K2=CarDeath_d
CarDeath_n_K2=CarDeath_n
ChdDeathA_K2=ChdDeathA
ChdDeathB_K2=ChdDeathB
ChdDeathH_K2=ChdDeathH
ChdDeathN_K2=ChdDeathN
ChdDeathW_K2=ChdDeathW
ChdDeath_K2=ChdDeath
ChdDeath_d_K2=ChdDeath_d
ChdDeath_n_K2=ChdDeath_n
DWIDeath_K2=DWIDeath
DWIDeath_d_K2=DWIDeath_d
DWIDeath_n_K2=DWIDeath_n
DcYouth_K2=DcYouth
DcYouth_d_K2=DcYouth_d
DcYouth_n_K2=DcYouth_n
Dentist_K2=Dentist
Dentist_d_K2=Dentist_d
Dentist_n_K2=Dentist_n
Dentist_r_K2=Dentist_r
DrugOdA_K2=DrugOdA
DrugOdB_K2=DrugOdB
DrugOdH_K2=DrugOdH
DrugOdN_K2=DrugOdN
DrugOdW_K2=DrugOdW
DrugOd_K2=DrugOd
DrugOd_d_K2=DrugOd_d
DrugOd_n_K2=DrugOd_n
FrLunch_K2=FrLunch
FrLunch_d_K2=FrLunch_d
FrLunch_n_K2=FrLunch_n
GunDeathA_K2=GunDeathA
GunDeathB_K2=GunDeathB
GunDeathH_K2=GunDeathH
GunDeathN_K2=GunDeathN
GunDeathW_K2=GunDeathW
GunDeath_K2=GunDeath
GunDeath_d_K2=GunDeath_d
GunDeath_n_K2=GunDeath_n
Gym2_J2=Gym2
Gym2_d_J2=Gym2_d
Gym2_n_J2=Gym2_n
HousCost_K2=HousCost
HousCost_d_K2=HousCost_d
HousCost_n_K2=HousCost_n
InfDeathA_K2=InfDeathA
InfDeathB_K2=InfDeathB
InfDeathH_K2=InfDeathH
InfDeathN_K2=InfDeathN
InfDeathW_K2=InfDeathW
InfDeath_K2=InfDeath
InfDeath_d_K2=InfDeath_d
InfDeath_n_K2=InfDeath_n
InjuryA_K2=InjuryA
InjuryB_K2=InjuryB
InjuryH_K2=InjuryH
InjuryN_K2=InjuryN
InjuryW_K2=InjuryW
Injury_K2=Injury
Injury_d_K2=Injury_d
Injury_n_K2=Injury_n
LifeExpA_K2=LifeExpA
LifeExpB_K2=LifeExpB
LifeExpH_K2=LifeExpH
LifeExpN_K2=LifeExpN
LifeExpW_K2=LifeExpW
LifeExp_K2=LifeExp
LongComm_K2=LongComm
LongComm_d_K2=LongComm_d
LowBWA_K2=LowBWA
LowBWB_K2=LowBWB
LowBWH_K2=LowBWH
LowBWN_K2=LowBWN
LowBWW_K2=LowBWW
LowBW_K2=LowBW
LowBW_d_K2=LowBW_d
LowBW_n_K2=LowBW_n
MHPrvd_J2=MHPrvd
MHPrvd_d_J2=MHPrvd_d
MHPrvd_n_J2=MHPrvd_n
MHPrvd_r_J2=MHPrvd_r
Murder_K2=Murder
Murder_d_K2=Murder_d
Murder_n_K2=Murder_n
PCP2_J2=PCP2
PCP2_d_J2=PCP2_d
PCP2_n_J2=PCP2_n
PCP2_r_J2=PCP2_r
PrmDeathA_K2=PrmDeathA
PrmDeathB_K2=PrmDeathB
PrmDeathH_K2=PrmDeathH
PrmDeathN_K2=PrmDeathN
PrmDeathW_K2=PrmDeathW
PrmDeath_K2=PrmDeath
PrmDeath_d_K2=PrmDeath_d
PrmDeath_n_K2=PrmDeath_n
PrmDeath2A_K2=PrmDeath2A
PrmDeath2B_K2=PrmDeath2B
PrmDeath2H_K2=PrmDeath2H
PrmDeath2N_K2=PrmDeath2N
PrmDeath2W_K2=PrmDeath2W
PrmDeath2_K2=PrmDeath2
PrmDeath2_d_K2=PrmDeath2_d
PrmDeath2_n_K2=PrmDeath2_n
SegBW_K2=SegBW
SegNW_K2=SegNW
Suicide2_K2=Suicide2
SuicideA_K2=SuicideA
SuicideB_K2=SuicideB
SuicideH_K2=SuicideH
SuicideN_K2=SuicideN
SuicideW_K2=SuicideW
Suicide_K2=Suicide
Suicide_d_K2=Suicide_d
Suicide_n_K2=Suicide_n
TeenBthA_K2=TeenBthA
TeenBthB_K2=TeenBthB
TeenBthH_K2=TeenBthH
TeenBthN_K2=TeenBthN
TeenBthW_K2=TeenBthW
TeenBth_K2=TeenBth
TeenBth_d_K2=TeenBth_d
TeenBth_n_K2=TeenBth_n
Traffic_K2=Traffic
Water2_K2=Water2
));
run;
/*N=3142, 133 variables*/
/***/
/* Duplicate variables in Z2019: None
   proc contents data=Z2019;run; */;
data Z2019a;set Z2019(rename=(
Gym2_K2=Gym2
Gym2_d_K2=Gym2_d
Gym2_n_K2=Gym2_n
MHPrvd_K2=MHPrvd
MHPrvd_d_K2=MHPrvd_d
MHPrvd_n_K2=MHPrvd_n
MHPrvd_r_K2=MHPrvd_r
PCP2_K2=PCP2
PCP2_d_K2=PCP2_d
PCP2_n_K2=PCP2_n
PCP2_r_K2=PCP2_r
));
run;
/*N=3142, 13 variables*/





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/********************************* Creating Longitudinal Data, Labeling Variables & Saving Permanent Data **********************************************************************/
/********************************* Creating Longitudinal Data, Labeling Variables & Saving Permanent Data **********************************************************************/
/********************************* Creating Longitudinal Data, Labeling Variables & Saving Permanent Data **********************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/***/;
data a.CHR;set Z2005a Z2006a Z2007a Z2008a Z2009a Z2010a Z2011a Z2012a Z2013a Z2014a Z2015a Z2016a Z2017a Z2018a Z2019a;
label
PrmDeath="Premature death: Age-adjusted Years of Potential Life Lost (YPLL) before age 75 per 100k population"
PrmDeath_n="Premature death numerator: # deaths < age 75"
PrmDeath_d="Premature death denominator: Aggregate population < age 75"
PrmDeathW="Premature death: Age-adjusted YPLL before age 75 per 100k non-Hispanic Whites"
PrmDeathB="Premature death: Age-adjusted YPLL before age 75 per 100k non-Hispanic Blacks"
PrmDeathH="Premature death: Age-adjusted YPLL before age 75 per 100k Hispanics"
PrmDeathN="Premature death: Age-adjusted YPLL before age 75 per 100k non-Hispanic American Indians/Alaska Natives"
PrmDeathA="Premature death: Age-adjusted YPLL before age 75 per 100k non-Hispanic Asians/Pacific Islanders"
PoorHlth="Poor or fair health: % adults reporting fair or poor health (age-adjusted)"
PoorHlth_n="Poor or fair health numerator: # adults reporting fair or poor health"
PoorHlth_d="Poor or fair health denominator: # respondents"
PoorPhy="Poor physical health days: Average # physically unhealthy days reported in past 30 days (age-adjusted)"
PoorPhy_d="Poor physical health days denominator: # respondents"
PoorMH="Poor mental health days: Average # mentally unhealthy days reported in past 30 days (age-adjusted)"
PoorMH_d="Poor mental health days denominator: # respondents"
LowBW="Low birthweight: % births with low birth weight (<2.5kg)"
LowBW_n="Low birthweight numerator: # births with low birth weight (<2.5kg)"
LowBW_d="Low birthweight denominator: # live births"
LowBWW="Low birthweight: % births with low birth weight (<2.5kg) for non-Hispanic Whites"
LowBWB="Low birthweight: % births with low birth weight (<2.5kg) for non-Hispanic Blacks"
LowBWH="Low birthweight: % births with low birth weight (<2.5kg) for Hispanics"
LowBWN="Low birthweight: % births with low birthweight (<2.5kg) for non-Hispanic American Indian and Alaska Natives"
LowBWA="Low birthweight: % births with low birthweight (<2.5kg) for non-Hispanic Asians"
Smoke="Adult smoking: % adults reporting currently smoking"
Smoke_n="Adult smoking numerator: # adults reporting currently smoking"
Smoke_d="Adult smoking denominator: # respondents"
Obesity="Adult obesity: % adults reporting BMI >= 30"
Obesity_n="Adult obesity numerator: # adults reporting BMI >= 30"
Obesity_d="Adult obesity denominator: # adults"
BDrink="Binge drinking: % adults reporting binge drinking in past 30 days"
BDrink_n="Binge drinking numerator: % adults reporting binge drinking in past 30 days"
BDrink_d="Binge drinking denominator: # respondents"
EDrink="Excessive drinking: % adults reporting excessive (binge or heavy) drinking in past 30 days"
EDrink_n="Excessive drinking numerator: # adults reporting excessive (binge or heavy) drinking in past 30 days"
EDrink_d="Excessive drinking denominator: # respondents"
DWIDeath="Alcohol-impaired driving deaths: % driving deaths with alcohol involvement"
DWIDeath_n="Alcohol-impaired driving deaths numerator: # alcohol-impaired motor vehicle deaths"
DWIDeath_d="Alcohol-impaired driving deaths denominator: # motor vehicle deaths"
CarDeath="Motor vehicle crash deaths: # motor vehicle crash deaths per 100k population"
CarDeath_n="Motor vehicle crash deaths numerator: Total # motor vehicle-related deaths"
CarDeath_d="Motor vehicle crash deaths denominator: population"
CarDeathW="Motor vehicle crash deaths: # motor vehicle crash deaths per 100k population, White"
CarDeathB="Motor vehicle crash deaths: # motor vehicle crash deaths per 100k population, Black"
CarDeathH="Motor vehicle crash deaths: # motor vehicle crash deaths per 100k population, Hispanic"
CarDeathN="Motor vehicle crash deaths: # motor vehicle crash deaths per 100k population, AIAN"
CarDeathA="Motor vehicle crash deaths: # motor vehicle crash deaths per 100k population, Asian/Pacific Islander"
STD_CT="Chlamydia rate: # newly diagnosed chlamydia cases per 100k population"
STD_CT_n="Chlamydia rate numerator: # chlamydia cases"
STD_CT_d="Chlamydia rate denominator: Population"
TeenBth="Teen births: # births per 1k females ages 15-19"
TeenBth_n="Teen births numerator: Teen birth count, ages 15-19"
TeenBth_d="Teen births denominator: Female population, ages 15-19"
TeenBthW="Teen births: # births per 1k females ages 15-19 for White non-Hispanic mothers"
TeenBthB="Teen births: # births per 1k females ages 15-19 for Black non-Hispanic mothers"
TeenBthH="Teen births: # births per 1k females ages 15-19 for Hispanic mothers"
TeenBthN="Teen births: # births per 1k females ages 15-19 for non-Hispanic American Indian/Alaska Native mothers"
TeenBthA="Teen births: # births per 1k females ages 15-19 for non-Hispanic Asian mothers"
InsuredA="Uninsured adults: % adults 18-64 without health insurance"
InsuredA_n="Uninsured adults numerator: # adults 18-64 without health insurance"
InsuredA_d="Uninsured adults denominator: # adults 18-64"
Insured="Uninsured: % population < age 65 without health insurance"
Insured_n="Uninsured numerator: # of people < age 65 without health insurance"
Insured_d="Uninsured denominator: # of people < age 65"
InsuredC="Uninsured children: % children < age 19 without health insurance"
InsuredC_n="Uninsured children numerator: # children < age 19 without health insurance"
InsuredC_d="Uninsured children denominator: # children < age 19"
PCP="Primary care physicians: Primary care physicians in patient care per 100k population"
PCP_n="Primary care physicians numerator: # primary care physicians in patient care"
PCP_d="Primary care physicians denominator: Population estimate"
PCP_r="Ratio of population to primary care physicians: Population to primary care physician ratio"
PCP2="Other primary care providers: Primary care providers other than physicians (ie, nurse practitioners, physician assistants, clinical nurse specialists)"
PCP2_n="Other primary care providers numerator"
PCP2_d="Other primary care providers denominator"
PCP2_r="Ratio of population to primary care providers other than physicians: "
PrvtHosp="Preventable hospital stays: # hospital stays for ambulatory-care sensitive conditions per 1k Medicare enrollees (per 100k after 2018)"
PrvtHosp_n="Preventable hospital stays numerator: # hospital stays for ambulatory-care sensitive conditions among Medicare enrollees"
PrvtHosp_d="Preventable hospital stays denominator: # Medicare enrollees"
PrvtHospW="Preventable hospital stays: # hospital stays for ambulatory-care sensitive conditions per 1k Medicare enrollees for Whites"
PrvtHospB="Preventable hospital stays: # hospital stays for ambulatory-care sensitive conditions per 1k Medicare enrollees for Blacks"
PrvtHospH="Preventable hospital stays: # hospital stays for ambulatory-care sensitive conditions per 1k Medicare enrollees for Hispanics"
PrvtHospN="Preventable hospital stays: # hospital stays for ambulatory-care sensitive conditions per 1k Medicare enrollees for American Indian/Alaska Natives"
PrvtHospA="Preventable hospital stays: # hospital stays for ambulatory-care sensitive conditions per 1k Medicare enrollees for Asian/Pacific Islanders"
DiabetM="Diabetes monitoring: % diabetic Medicare enrollees (ages 65-75) receiving HbA1c monitoring"
DiabetM_d="Diabetes monitoring denominator: # diabetic Medicare enrollees (ages 65-75)"
DiabetW="Diabetes monitoring: % White diabetic Medicare enrollees (ages 65-75) receiving HbA1c monitoring"
DiabetB="Diabetes monitoring: % Black diabetic Medicare enrollees (ages 65-75) receiving HbA1c monitoring"
Hospice="Hospice use: % chronically ill Medicare enrollees admitted to hospice in last 6 months of life"
Hospice_d="Hospice use denominator: # chronically ill Medicare enrollees"
Mammo="Mammography screening: % female Medicare enrollees (ages 67-69) having at least 1 mammogram in 2 yrs (age 65-74 after 2018)"
Mammo_d="Mammography screening denominator: # female Medicare enrollees (ages 67-69) (age 65-74 after 2018)"
MammoW="Mammography screening: % White female Medicare enrollees (ages 67-69) having at least 1 mammogram in 2 yrs (age 65-74 after 2018)"
MammoB="Mammography screening: % Black female Medicare enrollees (ages 67-69) having at least 1 mammogram in 2 yrs (age 65-74 after 2018)"
MammoH="Mammography screening: % Hispanic female Medicare enrollees (ages 67-69) having at least 1 mammogram in 2 yrs (age 65-74 after 2018)"
MammoN="Mammography screening: % American Indian/Alaska Native female Medicare enrollees (ages 67-69) having at least 1 mammogram in 2 yrs (age 65-74 after 2018)"
MammoA="Mammography screening: % Asian/Pacific Islander female Medicare enrollees (ages 67-69) having at least 1 mammogram in 2 yrs (age 65-74 after 2018)"
SocSupp="Inadequate social support: % adults reporting not getting social/emotional support"
SocSupp_n="Inadequate social support numerator: # adults reporting not getting social/emotional support"
SocSupp_d="Inadequate social support denominator: # respondents"
SocAsso="Social associations: # membership associations per 10k population"
SocAsso_n="Social associations numerator: # associations"
SocAsso_d="Social associations denominator: population"
Violent="Violent crime: # reported violent crime offenses per 100k population"
Violent_n="Violent crime numerator: # violent crimes"
Violent_d="Violent crime denominator: Aggregate population"
Murder="Homicides: # deaths from assaults per 100k population (age-adjusted in 2010-2011; crude in 2012-2020)"
Murder_n="Homicides numerator: # deaths from assaults"
Murder_d="Homicides denominator: population"
AirPM2="Air pollution-particulate matter days: # days in a year that air quality was unhealthy due to fine particulate matter"
AirO3="Air pollution-ozone days: # days in a year that air quality was unhealthy due to ozone"
AirPM="Air pollution - particulate matter: Average daily density of fine particulate matter in micrograms per cubic meter (PM2.5)"
Water="Drinking water violations: % population potentially exposed to water exceeding a violation limit during the past year"
Water_n="Drinking water violations numerator: Average annual population affected by a water violation"
Water_d="Drinking water violations denominator: "
Water2="Drinking water violations: Presence of health-related drinking water violations: 1-Yes, 0-No"
AccFood="Access to healthy foods: % zip codes in county with a healthy food outlet"
AccFood_n="Access to healthy foods numerator: # zip codes in county with a healthy food outlet"
AccFood_d="Access to healthy foods denominator: # zip codes in county"
LAccFood="Limited access to healthy foods: % population living in poverty and more than 1 or 10 miles from a grocery store"
LAccFood_n="Limited access to healthy foods numerator: "
LAccFood_d="Limited access to healthy foods denominator: "
FastFood="Fast food restaurants: % restaurants that are fast food restaurants"
FastFood_n="Fast food restaurants numerator: # fast food outlets"
FastFood_d="Fast food restaurants denominator: # restaurants"
FoodEnv="Food environment index: Indicator of access to healthy foods - 0 is worst, 10 is best"
FoodEnv_n="Food environment index numerator"
FoodEnv_d="Food environment index denominator"
Liquor="Liquor store density: Liquor store density (per 10k for 2010; per 100k for 2011 and later)"
Liquor_n="Liquor store density numerator: # liquor stores (NAICS=445310)"
Liquor_d="Liquor store density denominator: Estimated population"
Gym="Access to recreational facilities: Recreational facility access rate per 100K population"
Gym_n="Access to recreational facilities numerator: Total recreational facilities"
Gym_d="Access to recreational facilities denominator: Estimated population from Census"
Diabet="Diabetes prevalence: % adults >= age 20 with diagnosed diabetes"
Diabet_n="Diabetes prevalence numerator: # adults >= age 20 with diagnosed diabetes"
Diabet_d="Diabetes prevalence denominator: # adults >= age 20"
HIV="HIV prevalence: # screened positive for HIV per 100k population >= age 13"
HIV_n="HIV prevalence numerator: # screened positive for HIV"
HIV_d="HIV prevalence denominator: population"
Inactive="Physical inactivity: % adults >= age 20 reporting no leisure time physical activity"
Inactive_n="Physical inactivity numerator: # adults >= age 20 reporting no leisure time physical activity"
Inactive_d="Physical inactivity denominator: # adults >= age 20"
Gym2="Access to exercise opportunities: % population with adequate access to locations for physical activity"
Gym2_n="Access to exercise opportunities numerator: # persons with adequate access to locations for physical activity"
Gym2_d="Access to exercise opportunities denominator: population"
MHPrvd="Mental health providers: # Mental Health Providers per 100k population"
MHPrvd_n="Mental health providers numerator: # mental health providers"
MHPrvd_d="Mental health providers denominator: population"
MHPrvd_r="Ratio of population to mental health providers: Ratio of population to mental health providers"
HlthCost="Health care costs: Health care costs"
HlthCost_n="Health care costs numerator"
HlthCost_d="Health care costs denominator"
FrLunch="Children eligible for free lunch: % children (in public schools) eligible for free lunch"
FrLunch_n="Children eligible for free lunch numerator: # children (in public schools) eligible for free lunch"
FrLunch_d="Children eligible for free lunch denominator: # children (in public schools)"
DrCost="Could not see doctor due to cost: Could not see doctor due to cost"
DrCost_n="Could not see doctor due to cost numerator"
DrCost_d="Could not see doctor due to cost denominator"
Dentist="Dentists: # dentists per 100k population"
Dentist_n="Dentists numerator: # dentists"
Dentist_d="Dentists denominator: population"
Dentist_r="Ratio of population to dentists: Population to dentists ratio"
PrmDeath2="Premature age-adjusted mortality: # deaths among residents under age 75 per 100k population (age-adjusted)"
PrmDeath2_n="Premature age-adjusted mortality numerator: # deaths among residents under age 75"
PrmDeath2_d="Premature age-adjusted mortality denominator: # residents under age 75"
PrmDeath2W="Premature age-adjusted mortality: # deaths among residents under age 75 per 100k population (age-adjusted), White"
PrmDeath2B="Premature age-adjusted mortality: # deaths among residents under age 75 per 100k population (age-adjusted), Black"
PrmDeath2H="Premature age-adjusted mortality: # deaths among residents under age 75 per 100k population (age-adjusted), Hispanic"
PrmDeath2N="Premature age-adjusted mortality: # deaths among residents under age 75 per 100k population (age-adjusted), AIAN"
PrmDeath2A="Premature age-adjusted mortality: # deaths among residents under age 75 per 100k population (age-adjusted), Asian/Pacific Islander"
ChdDeath="Child mortality: # deaths among children under age 18 per 100k population"
ChdDeath_n="Child mortality numerator: # deaths among children under age 18"
ChdDeath_d="Child mortality denominator: # children under age 18"
ChdDeathW="Child mortality: # deaths among children under age 18 per 100k population, White"
ChdDeathB="Child mortality: # deaths among children under age 18 per 100k population, Black"
ChdDeathH="Child mortality: # deaths among children under age 18 per 100k population, Hispanic"
ChdDeathN="Child mortality: # deaths among children under age 18 per 100k population, AIAN"
ChdDeathA="Child mortality: # deaths among children under age 18 per 100k population, Asian/Pacific Islander"
InfDeath="Infant mortality: # all infant deaths (within 1 year), per 1k live births"
InfDeath_n="Infant mortality numerator: # all infant deaths (within 1 year)"
InfDeath_d="Infant mortality denominator:# live births"
InfDeathW="Infant mortality: # all infant deaths (within 1 year), per 1k live births, White"
InfDeathB="Infant mortality: # all infant deaths (within 1 year), per 1k live births, Black"
InfDeathH="Infant mortality: # all infant deaths (within 1 year), per 1k live births, Hispanic"
InfDeathN="Infant mortality: # all infant deaths (within 1 year), per 1k live births, AIAN"
InfDeathA="Infant mortality: # all infant deaths (within 1 year), per 1k live births, Asian/Pacific Islander"
Park="Access to parks: Access to parks"
Injury="Injury deaths: # deaths due to injury per 100k population"
Injury_n="Injury deaths numerator: # injury deaths"
Injury_d="Injury deaths denominator: population"
InjuryW="Injury deaths: # deaths due to injury per 100k for non-Hispanic Whites"
InjuryB="Injury deaths: # deaths due to injury per 100k for non-Hispanic Blacks"
InjuryH="Injury deaths: # deaths due to injury per 100k for Hispanics"
InjuryN="Injury deaths: # deaths due to injury per 100k for non-Hispanic American Indian and Alaska Natives"
InjuryA="Injury deaths: # deaths due to injury per 100k for non-Hispanic Asians"
Housing="Severe housing problems: % households with at least 1 of 4 housing problems: overcrowding, high housing costs, or lack of kitchen or plumbing facilities"
Housing_n="Severe housing problems numerator: # households with at least 1 of 4 housing problems: overcrowding, high housing costs, or lack of kitchen or plumbing facilities"
Housing_d="Severe housing problems denominator: # households"
HousCosts="Housing problem: high housing costs: % households with high housing costs"
HousCrowd="Housing problem: overcrowding: % households with overcrowding"
HousPlumb="Housing problem: lack of kitchen or plumbing facilities: % households with lack of kitchen or plumbing facilities"
HousCost="Severe housing cost burden: % households that spend 50% or more of their household income on housing"
HousCost_n="Severe housing cost burden numerator: # households that spend 50% or more of their household income on housing"
HousCost_d="Severe housing cost burden denominator: % households"
LongComm="Long commute - driving alone: % commuting > 30 minutes among workers commuting in their car alone"
LongComm_d="Long commute - driving alone denominator: # workers who commute in their car,truck or van alone"
FoodIns="Food insecurity: % population who lack adequate access to food"
FoodIns_n="Food insecurity numerator: # persons who lack adequate access to food"
FoodIns_d="Food insecurity denominator: population"
DrugOd="Drug overdose deaths: # drug poisoning deaths per 100k population"
DrugOd_n="Drug overdose deaths numerator: # drug poisoning deaths"
DrugOd_d="Drug overdose deaths denominator: population"
DrugOdW="Drug overdose deaths: # drug poisoning deaths per 100k Whites"
DrugOdB="Drug overdose deaths: # drug poisoning deaths per 100k Blacks"
DrugOdH="Drug overdose deaths: # drug poisoning deaths per 100k Hispanics"
DrugOdN="Drug overdose deaths: # drug poisoning deaths per 100k AIANs"
DrugOdA="Drug overdose deaths: # drug poisoning deaths per 100k Asian/Pacific Islanders"
DrugOdm="Drug overdose deaths - modeled: Drug overdose deaths-modeled"
DrugOdm_d="Drug overdose deaths - modeled denominator"
Physical="Frequent physical distress: % adults reporting >= 14 days of poor physical health per month"
Mental="Frequent mental distress: % adults reporting >= 14 days of poor mental health per month"
Sleep="Insufficient sleep: % adults reporting < 7 hours of sleep on average"
SegBW="Residential segregation - black/white: Index of dissimilarity (higher values = greater residential segregation b/w Black & White residents)"
SegNW="Residential segregation - non-white/white: Index of dissimilarity (higher values=greater residential segregation b/w non-White & White residents)"
DcYouth="Disconnected youth: % youth ages 16-19 who are neither working nor in school"
DcYouth_n="Disconnected youth numerator: # youth ages 16-19 who are neither working nor in school"
DcYouth_d="Disconnected youth denominator: # youth ages 16-19"
GunDeath="Firearm fatalities: # deaths due to firearms per 100k population"
GunDeath_n="Firearm fatalities numerator: # deaths due to firearms"
GunDeath_d="Firearm fatalities denominator: population"
GunDeathW="Firearm fatalities: # deaths due to firearms per 100k population, White"
GunDeathB="Firearm fatalities: # deaths due to firearms per 100k population, Black"
GunDeathH="Firearm fatalities: # deaths due to firearms per 100k population, Hispanic"
GunDeathN="Firearm fatalities: # deaths due to firearms per 100k population, AIAN"
GunDeathA="Firearm fatalities: # deaths due to firearms per 100k population, Asian/Pacific Islander"
FluVacc="Flu vaccinations: % annual Medicare enrollees having an annual flu vaccination"
FluVaccW="Flu vaccinations: % annual Medicare enrollees having an annual flu vaccination for Whites"
FluVaccB="Flu vaccinations: % annual Medicare enrollees having an annual flu vaccination for Blacks"
FluVaccH="Flu vaccinations: % annual Medicare enrollees having an annual flu vaccination for Hispanics"
FluVaccN="Flu vaccinations: % annual Medicare enrollees having an annual flu vaccination for American Indian/Alaska Natives"
FluVaccA="Flu vaccinations: % annual Medicare enrollees having an annual flu vaccination for Asian/Pacific Islanders"
LifeExp="Life expectancy: Average # of years a person can expect to live"
LifeExpW="Life expectancy: Average # of years a person can expect to live, White"
LifeExpB="Life expectancy: Average # of years a person can expect to live, Black"
LifeExpH="Life expectancy: Average # of years a person can expect to live, Hispanic"
LifeExpN="Life expectancy: Average # of years a person can expect to live, Hispanic"
LifeExpA="Life expectancy: Average # of years a person can expect to live, Hispanic"
Read="Reading scores: Average grade level performance for 3rd graders on English Language Arts standardized tests"
ReadW="Reading scores: Average grade level performance for 3rd graders on English Language Arts standardized tests, White"
ReadB="Reading scores: Average grade level performance for 3rd graders on English Language Arts standardized tests, Black"
ReadH="Reading scores: Average grade level performance for 3rd graders on English Language Arts standardized tests, Hispanic"
ReadA="Reading scores: Average grade level performance for 3rd graders on English Language Arts standardized tests, Asian/Pacific Islander"
Math="Math scores: Average grade level performance for 3rd graders on math standardized tests"
MathW="Math scores: Average grade level performance for 3rd graders on math standardized tests, White"
MathB="Math scores: Average grade level performance for 3rd graders on math standardized tests, Black"
MathH="Math scores: Average grade level performance for 3rd graders on math standardized tests, Hispanic"
MathA="Math scores: Average grade level performance for 3rd graders on math standardized tests, Asian/Pacific Islander"
Suicide="Suicides: # deaths due to suicide per 100k population"
Suicide_n="Suicides numerator: # deaths due to suicide"
Suicide_d="Suicides denominator: population"
Suicide2="Crude suicide rate"
SuicideW="Suicides: # deaths due to suicide per 100k population, White"
SuicideB="Suicides: # deaths due to suicide per 100k population, Black"
SuicideH="Suicides: # deaths due to suicide per 100k population, Hispanic"
SuicideN="Suicides: # deaths due to suicide per 100k population, AIAN"
SuicideA="Suicides: # deaths due to suicide per 100k population, Asian/Pacific Islander"
JuvArr="Juvenile arrests: Rate of delinquency cases per 1k juveniles"
JuvArr_d="Juvenile arrests denominator: # juveniles"
JuvArrF="Juvenile delinquency formal cases: Number of juvenile delinquency cases formally processed by a juvenile court"
JuvArrI="Juvenile delinquency informal cases: Number of informally handled juvenile delinquency cases"
Traffic="Traffic volume: Average traffic volume per meter of major roadways in the county"
;run; 
/*N=47148, 272 variables*/;
proc contents data=a.CHR;run;





/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/********************************* Checking Longitudinal Availability and Stability ********************************************************************************************/
/********************************* Checking Longitudinal Availability and Stability ********************************************************************************************/
/********************************* Checking Longitudinal Availability and Stability ********************************************************************************************/
/*******************************************************************************************************************************************************************************/
/*******************************************************************************************************************************************************************************/
/***/;
/* The below code will great a table for checking longitudinal availability and stability of CHR data
***
data a;set a.CHR;run;
proc sort data=a;by Year;run;
proc means data=a noprint;by Year;output out=CHR_grid n= mean= std=/autoname;run;
proc transpose data=CHR_grid out=CHR_grid2;run;
data CHR_grid2;set CHR_grid2;if _NAME_="Year" then _NAME_="AAA_Year";if _NAME_="_FREQ_" then _NAME_="AA_FREQ";if _NAME_^="_TYPE_";run;
proc sort data=CHR_grid2;by _NAME_;run;
proc print data=CHR_grid2;run;
*/

